Class: Late::AdAudiencesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/late-sdk/api/ad_audiences_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AdAudiencesApi

Returns a new instance of AdAudiencesApi.



19
20
21
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_users_to_ad_audience(audience_id, add_users_to_ad_audience_request, opts = {}) ⇒ AddUsersToAdAudience200Response

Add users to a customer list audience Upload user data (emails and/or phone numbers) to a customer_list audience. Data is SHA256-hashed server-side before sending to Meta. Max 10,000 users per request.

Parameters:

  • audience_id (String)
  • add_users_to_ad_audience_request (AddUsersToAdAudienceRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 28

def add_users_to_ad_audience(audience_id, add_users_to_ad_audience_request, opts = {})
  data, _status_code, _headers = add_users_to_ad_audience_with_http_info(audience_id, add_users_to_ad_audience_request, opts)
  data
end

#add_users_to_ad_audience_with_http_info(audience_id, add_users_to_ad_audience_request, opts = {}) ⇒ Array<(AddUsersToAdAudience200Response, Integer, Hash)>

Add users to a customer list audience Upload user data (emails and/or phone numbers) to a customer_list audience. Data is SHA256-hashed server-side before sending to Meta. Max 10,000 users per request.

Parameters:

  • audience_id (String)
  • add_users_to_ad_audience_request (AddUsersToAdAudienceRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 39

def add_users_to_ad_audience_with_http_info(audience_id, add_users_to_ad_audience_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdAudiencesApi.add_users_to_ad_audience ...'
  end
  # verify the required parameter 'audience_id' is set
  if @api_client.config.client_side_validation && audience_id.nil?
    fail ArgumentError, "Missing the required parameter 'audience_id' when calling AdAudiencesApi.add_users_to_ad_audience"
  end
  # verify the required parameter 'add_users_to_ad_audience_request' is set
  if @api_client.config.client_side_validation && add_users_to_ad_audience_request.nil?
    fail ArgumentError, "Missing the required parameter 'add_users_to_ad_audience_request' when calling AdAudiencesApi.add_users_to_ad_audience"
  end
  # resource path
  local_var_path = '/v1/ads/audiences/{audienceId}/users'.sub('{' + 'audienceId' + '}', CGI.escape(audience_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(add_users_to_ad_audience_request)

  # return_type
  return_type = opts[:debug_return_type] || 'AddUsersToAdAudience200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"AdAudiencesApi.add_users_to_ad_audience",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdAudiencesApi#add_users_to_ad_audience\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_ad_audience(create_ad_audience_request, opts = {}) ⇒ CreateAdAudience201Response

Create a custom audience (Meta only) Create a customer list, website retargeting, or lookalike audience on Meta (Facebook/Instagram).

Parameters:

Returns:



101
102
103
104
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 101

def create_ad_audience(create_ad_audience_request, opts = {})
  data, _status_code, _headers = create_ad_audience_with_http_info(create_ad_audience_request, opts)
  data
end

#create_ad_audience_with_http_info(create_ad_audience_request, opts = {}) ⇒ Array<(CreateAdAudience201Response, Integer, Hash)>

Create a custom audience (Meta only) Create a customer list, website retargeting, or lookalike audience on Meta (Facebook/Instagram).

Parameters:

Returns:

  • (Array<(CreateAdAudience201Response, Integer, Hash)>)

    CreateAdAudience201Response data, response status code and response headers



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 111

def create_ad_audience_with_http_info(create_ad_audience_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdAudiencesApi.create_ad_audience ...'
  end
  # verify the required parameter 'create_ad_audience_request' is set
  if @api_client.config.client_side_validation && create_ad_audience_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_ad_audience_request' when calling AdAudiencesApi.create_ad_audience"
  end
  # resource path
  local_var_path = '/v1/ads/audiences'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_ad_audience_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateAdAudience201Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"AdAudiencesApi.create_ad_audience",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdAudiencesApi#create_ad_audience\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_ad_audience(audience_id, opts = {}) ⇒ DeleteAccountGroup200Response

Delete a custom audience Deletes the audience from both Meta and the local database.

Parameters:

  • audience_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



169
170
171
172
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 169

def delete_ad_audience(audience_id, opts = {})
  data, _status_code, _headers = delete_ad_audience_with_http_info(audience_id, opts)
  data
end

#delete_ad_audience_with_http_info(audience_id, opts = {}) ⇒ Array<(DeleteAccountGroup200Response, Integer, Hash)>

Delete a custom audience Deletes the audience from both Meta and the local database.

Parameters:

  • audience_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 179

def delete_ad_audience_with_http_info(audience_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdAudiencesApi.delete_ad_audience ...'
  end
  # verify the required parameter 'audience_id' is set
  if @api_client.config.client_side_validation && audience_id.nil?
    fail ArgumentError, "Missing the required parameter 'audience_id' when calling AdAudiencesApi.delete_ad_audience"
  end
  # resource path
  local_var_path = '/v1/ads/audiences/{audienceId}'.sub('{' + 'audienceId' + '}', CGI.escape(audience_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteAccountGroup200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"AdAudiencesApi.delete_ad_audience",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdAudiencesApi#delete_ad_audience\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_ad_audience(audience_id, opts = {}) ⇒ GetAdAudience200Response

Get audience details Returns the local audience record and fresh data from Meta (if available).

Parameters:

  • audience_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



232
233
234
235
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 232

def get_ad_audience(audience_id, opts = {})
  data, _status_code, _headers = get_ad_audience_with_http_info(audience_id, opts)
  data
end

#get_ad_audience_with_http_info(audience_id, opts = {}) ⇒ Array<(GetAdAudience200Response, Integer, Hash)>

Get audience details Returns the local audience record and fresh data from Meta (if available).

Parameters:

  • audience_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetAdAudience200Response, Integer, Hash)>)

    GetAdAudience200Response data, response status code and response headers



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 242

def get_ad_audience_with_http_info(audience_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdAudiencesApi.get_ad_audience ...'
  end
  # verify the required parameter 'audience_id' is set
  if @api_client.config.client_side_validation && audience_id.nil?
    fail ArgumentError, "Missing the required parameter 'audience_id' when calling AdAudiencesApi.get_ad_audience"
  end
  # resource path
  local_var_path = '/v1/ads/audiences/{audienceId}'.sub('{' + 'audienceId' + '}', CGI.escape(audience_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetAdAudience200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"AdAudiencesApi.get_ad_audience",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdAudiencesApi#get_ad_audience\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_ad_audiences(account_id, ad_account_id, opts = {}) ⇒ ListAdAudiences200Response

List custom audiences Returns custom audiences for the given ad account. Supports Meta, Google, TikTok, and Pinterest.

Parameters:

  • account_id (String)

    Social account ID

  • ad_account_id (String)

    Platform ad account ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :platform (String)

Returns:



297
298
299
300
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 297

def list_ad_audiences(, , opts = {})
  data, _status_code, _headers = list_ad_audiences_with_http_info(, , opts)
  data
end

#list_ad_audiences_with_http_info(account_id, ad_account_id, opts = {}) ⇒ Array<(ListAdAudiences200Response, Integer, Hash)>

List custom audiences Returns custom audiences for the given ad account. Supports Meta, Google, TikTok, and Pinterest.

Parameters:

  • account_id (String)

    Social account ID

  • ad_account_id (String)

    Platform ad account ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :platform (String)

Returns:

  • (Array<(ListAdAudiences200Response, Integer, Hash)>)

    ListAdAudiences200Response data, response status code and response headers



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/late-sdk/api/ad_audiences_api.rb', line 309

def list_ad_audiences_with_http_info(, , opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AdAudiencesApi.list_ad_audiences ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AdAudiencesApi.list_ad_audiences"
  end
  # verify the required parameter 'ad_account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'ad_account_id' when calling AdAudiencesApi.list_ad_audiences"
  end
  allowable_values = ["facebook", "instagram", "googleads", "tiktok", "pinterest"]
  if @api_client.config.client_side_validation && opts[:'platform'] && !allowable_values.include?(opts[:'platform'])
    fail ArgumentError, "invalid value for \"platform\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/v1/ads/audiences'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'accountId'] = 
  query_params[:'adAccountId'] = 
  query_params[:'platform'] = opts[:'platform'] if !opts[:'platform'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListAdAudiences200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"AdAudiencesApi.list_ad_audiences",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AdAudiencesApi#list_ad_audiences\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end