Class: Late::BoostPostRequest

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/boost_post_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BoostPostRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/late-sdk/models/boost_post_request.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::BoostPostRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::BoostPostRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'post_id')
    self.post_id = attributes[:'post_id']
  end

  if attributes.key?(:'platform_post_id')
    self.platform_post_id = attributes[:'platform_post_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'goal')
    self.goal = attributes[:'goal']
  else
    self.goal = nil
  end

  if attributes.key?(:'budget')
    self.budget = attributes[:'budget']
  else
    self.budget = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'schedule')
    self.schedule = attributes[:'schedule']
  end

  if attributes.key?(:'targeting')
    self.targeting = attributes[:'targeting']
  end
end

Instance Attribute Details

#account_idObject

Social account ID



25
26
27
# File 'lib/late-sdk/models/boost_post_request.rb', line 25

def 
  @account_id
end

#ad_account_idObject

Platform ad account ID



28
29
30
# File 'lib/late-sdk/models/boost_post_request.rb', line 28

def 
  @ad_account_id
end

#budgetObject

Returns the value of attribute budget.



34
35
36
# File 'lib/late-sdk/models/boost_post_request.rb', line 34

def budget
  @budget
end

#currencyObject

Returns the value of attribute currency.



36
37
38
# File 'lib/late-sdk/models/boost_post_request.rb', line 36

def currency
  @currency
end

#goalObject

Returns the value of attribute goal.



32
33
34
# File 'lib/late-sdk/models/boost_post_request.rb', line 32

def goal
  @goal
end

#nameObject

Returns the value of attribute name.



30
31
32
# File 'lib/late-sdk/models/boost_post_request.rb', line 30

def name
  @name
end

#platform_post_idObject

Platform post ID (alternative to postId)



22
23
24
# File 'lib/late-sdk/models/boost_post_request.rb', line 22

def platform_post_id
  @platform_post_id
end

#post_idObject

Zernio post ID (provide this or platformPostId)



19
20
21
# File 'lib/late-sdk/models/boost_post_request.rb', line 19

def post_id
  @post_id
end

#scheduleObject

Returns the value of attribute schedule.



38
39
40
# File 'lib/late-sdk/models/boost_post_request.rb', line 38

def schedule
  @schedule
end

#targetingObject

Returns the value of attribute targeting.



40
41
42
# File 'lib/late-sdk/models/boost_post_request.rb', line 40

def targeting
  @targeting
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/late-sdk/models/boost_post_request.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/late-sdk/models/boost_post_request.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/late-sdk/models/boost_post_request.rb', line 65

def self.attribute_map
  {
    :'post_id' => :'postId',
    :'platform_post_id' => :'platformPostId',
    :'account_id' => :'accountId',
    :'ad_account_id' => :'adAccountId',
    :'name' => :'name',
    :'goal' => :'goal',
    :'budget' => :'budget',
    :'currency' => :'currency',
    :'schedule' => :'schedule',
    :'targeting' => :'targeting'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/late-sdk/models/boost_post_request.rb', line 312

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/late-sdk/models/boost_post_request.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/late-sdk/models/boost_post_request.rb', line 91

def self.openapi_types
  {
    :'post_id' => :'String',
    :'platform_post_id' => :'String',
    :'account_id' => :'String',
    :'ad_account_id' => :'String',
    :'name' => :'String',
    :'goal' => :'String',
    :'budget' => :'BoostPostRequestBudget',
    :'currency' => :'String',
    :'schedule' => :'BoostPostRequestSchedule',
    :'targeting' => :'BoostPostRequestTargeting'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/late-sdk/models/boost_post_request.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      post_id == o.post_id &&
      platform_post_id == o.platform_post_id &&
       == o. &&
       == o. &&
      name == o.name &&
      goal == o.goal &&
      budget == o.budget &&
      currency == o.currency &&
      schedule == o.schedule &&
      targeting == o.targeting
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


299
300
301
# File 'lib/late-sdk/models/boost_post_request.rb', line 299

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



305
306
307
# File 'lib/late-sdk/models/boost_post_request.rb', line 305

def hash
  [post_id, platform_post_id, , , name, goal, budget, currency, schedule, targeting].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/late-sdk/models/boost_post_request.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @ad_account_id.nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @goal.nil?
    invalid_properties.push('invalid value for "goal", goal cannot be nil.')
  end

  if @budget.nil?
    invalid_properties.push('invalid value for "budget", budget cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/late-sdk/models/boost_post_request.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/late-sdk/models/boost_post_request.rb', line 213

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @ad_account_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if @goal.nil?
  goal_validator = EnumAttributeValidator.new('String', ["engagement", "traffic", "awareness", "video_views"])
  return false unless goal_validator.valid?(@goal)
  return false if @budget.nil?
  true
end