Class: Late::CreateCommentAutomationRequest

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/create_comment_automation_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateCommentAutomationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::CreateCommentAutomationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::CreateCommentAutomationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'platform_post_id')
    self.platform_post_id = attributes[:'platform_post_id']
  else
    self.platform_post_id = nil
  end

  if attributes.key?(:'post_id')
    self.post_id = attributes[:'post_id']
  end

  if attributes.key?(:'post_title')
    self.post_title = attributes[:'post_title']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'keywords')
    if (value = attributes[:'keywords']).is_a?(Array)
      self.keywords = value
    end
  end

  if attributes.key?(:'match_mode')
    self.match_mode = attributes[:'match_mode']
  else
    self.match_mode = 'contains'
  end

  if attributes.key?(:'dm_message')
    self.dm_message = attributes[:'dm_message']
  else
    self.dm_message = nil
  end

  if attributes.key?(:'comment_reply')
    self.comment_reply = attributes[:'comment_reply']
  end
end

Instance Attribute Details

#account_idObject

Instagram or Facebook account ID



21
22
23
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 21

def 
  @account_id
end

#comment_replyObject

Optional public reply to the comment



44
45
46
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 44

def comment_reply
  @comment_reply
end

#dm_messageObject

DM text to send to commenter



41
42
43
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 41

def dm_message
  @dm_message
end

#keywordsObject

Trigger keywords (empty = any comment triggers)



36
37
38
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 36

def keywords
  @keywords
end

#match_modeObject

Returns the value of attribute match_mode.



38
39
40
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 38

def match_mode
  @match_mode
end

#nameObject

Automation label



33
34
35
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 33

def name
  @name
end

#platform_post_idObject

Platform media/post ID



24
25
26
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 24

def platform_post_id
  @platform_post_id
end

#post_idObject

Zernio post ID (optional)



27
28
29
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 27

def post_id
  @post_id
end

#post_titleObject

Post content snippet for display



30
31
32
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 30

def post_title
  @post_title
end

#profile_idObject

Returns the value of attribute profile_id.



18
19
20
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 18

def profile_id
  @profile_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 69

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'account_id' => :'accountId',
    :'platform_post_id' => :'platformPostId',
    :'post_id' => :'postId',
    :'post_title' => :'postTitle',
    :'name' => :'name',
    :'keywords' => :'keywords',
    :'match_mode' => :'matchMode',
    :'dm_message' => :'dmMessage',
    :'comment_reply' => :'commentReply'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 321

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 95

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'account_id' => :'String',
    :'platform_post_id' => :'String',
    :'post_id' => :'String',
    :'post_title' => :'String',
    :'name' => :'String',
    :'keywords' => :'Array<String>',
    :'match_mode' => :'String',
    :'dm_message' => :'String',
    :'comment_reply' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 291

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
       == o. &&
      platform_post_id == o.platform_post_id &&
      post_id == o.post_id &&
      post_title == o.post_title &&
      name == o.name &&
      keywords == o.keywords &&
      match_mode == o.match_mode &&
      dm_message == o.dm_message &&
      comment_reply == o.comment_reply
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


308
309
310
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 308

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



314
315
316
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 314

def hash
  [profile_id, , platform_post_id, post_id, post_title, name, keywords, match_mode, dm_message, comment_reply].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 189

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @platform_post_id.nil?
    invalid_properties.push('invalid value for "platform_post_id", platform_post_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @dm_message.nil?
    invalid_properties.push('invalid value for "dm_message", dm_message cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



217
218
219
220
221
222
223
224
225
226
227
# File 'lib/late-sdk/models/create_comment_automation_request.rb', line 217

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_id.nil?
  return false if @account_id.nil?
  return false if @platform_post_id.nil?
  return false if @name.nil?
  match_mode_validator = EnumAttributeValidator.new('String', ["exact", "contains"])
  return false unless match_mode_validator.valid?(@match_mode)
  return false if @dm_message.nil?
  true
end