Class: Late::GetAdAnalytics200ResponseAnalyticsDailyInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::GetAdAnalytics200ResponseAnalyticsDailyInner
- Defined in:
- lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb
Instance Attribute Summary collapse
-
#clicks ⇒ Object
Returns the value of attribute clicks.
-
#cpc ⇒ Object
Cost per click.
-
#cpm ⇒ Object
Cost per 1000 impressions.
-
#ctr ⇒ Object
Click-through rate (%).
-
#date ⇒ Object
Returns the value of attribute date.
-
#engagement ⇒ Object
Returns the value of attribute engagement.
-
#impressions ⇒ Object
Returns the value of attribute impressions.
-
#last_synced_at ⇒ Object
Present on individual ads only, not on campaign aggregations.
-
#reach ⇒ Object
Returns the value of attribute reach.
-
#spend ⇒ Object
Returns the value of attribute spend.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetAdAnalytics200ResponseAnalyticsDailyInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetAdAnalytics200ResponseAnalyticsDailyInner
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::GetAdAnalytics200ResponseAnalyticsDailyInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::GetAdAnalytics200ResponseAnalyticsDailyInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'spend') self.spend = attributes[:'spend'] end if attributes.key?(:'impressions') self.impressions = attributes[:'impressions'] end if attributes.key?(:'reach') self.reach = attributes[:'reach'] end if attributes.key?(:'clicks') self.clicks = attributes[:'clicks'] end if attributes.key?(:'ctr') self.ctr = attributes[:'ctr'] end if attributes.key?(:'cpc') self.cpc = attributes[:'cpc'] end if attributes.key?(:'cpm') self.cpm = attributes[:'cpm'] end if attributes.key?(:'engagement') self.engagement = attributes[:'engagement'] end if attributes.key?(:'last_synced_at') self.last_synced_at = attributes[:'last_synced_at'] end if attributes.key?(:'date') self.date = attributes[:'date'] end end |
Instance Attribute Details
#clicks ⇒ Object
Returns the value of attribute clicks.
24 25 26 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 24 def clicks @clicks end |
#cpc ⇒ Object
Cost per click
30 31 32 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 30 def cpc @cpc end |
#cpm ⇒ Object
Cost per 1000 impressions
33 34 35 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 33 def cpm @cpm end |
#ctr ⇒ Object
Click-through rate (%)
27 28 29 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 27 def ctr @ctr end |
#date ⇒ Object
Returns the value of attribute date.
40 41 42 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 40 def date @date end |
#engagement ⇒ Object
Returns the value of attribute engagement.
35 36 37 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 35 def engagement @engagement end |
#impressions ⇒ Object
Returns the value of attribute impressions.
20 21 22 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 20 def impressions @impressions end |
#last_synced_at ⇒ Object
Present on individual ads only, not on campaign aggregations
38 39 40 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 38 def last_synced_at @last_synced_at end |
#reach ⇒ Object
Returns the value of attribute reach.
22 23 24 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 22 def reach @reach end |
#spend ⇒ Object
Returns the value of attribute spend.
18 19 20 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 18 def spend @spend end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 43 def self.attribute_map { :'spend' => :'spend', :'impressions' => :'impressions', :'reach' => :'reach', :'clicks' => :'clicks', :'ctr' => :'ctr', :'cpc' => :'cpc', :'cpm' => :'cpm', :'engagement' => :'engagement', :'last_synced_at' => :'lastSyncedAt', :'date' => :'date' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 201 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
91 92 93 94 95 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 91 def self.openapi_all_of [ :'AdMetrics' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 69 def self.openapi_types { :'spend' => :'Float', :'impressions' => :'Integer', :'reach' => :'Integer', :'clicks' => :'Integer', :'ctr' => :'Float', :'cpc' => :'Float', :'cpm' => :'Float', :'engagement' => :'Integer', :'last_synced_at' => :'Time', :'date' => :'Date' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && spend == o.spend && impressions == o.impressions && reach == o.reach && clicks == o.clicks && ctr == o.ctr && cpc == o.cpc && cpm == o.cpm && engagement == o.engagement && last_synced_at == o.last_synced_at && date == o.date end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 194 def hash [spend, impressions, reach, clicks, ctr, cpc, cpm, engagement, last_synced_at, date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 |
# File 'lib/late-sdk/models/get_ad_analytics200_response_analytics_daily_inner.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |