Class: Late::GetGoogleBusinessReviews200ResponseReviewsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::GetGoogleBusinessReviews200ResponseReviewsInner
- Defined in:
- lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#comment ⇒ Object
Review text.
-
#create_time ⇒ Object
Returns the value of attribute create_time.
-
#id ⇒ Object
Review ID.
-
#name ⇒ Object
Full resource name.
-
#rating ⇒ Object
Numeric star rating.
-
#review_reply ⇒ Object
Returns the value of attribute review_reply.
-
#reviewer ⇒ Object
Returns the value of attribute reviewer.
-
#star_rating ⇒ Object
Google’s string rating.
-
#update_time ⇒ Object
Returns the value of attribute update_time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetGoogleBusinessReviews200ResponseReviewsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetGoogleBusinessReviews200ResponseReviewsInner
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::GetGoogleBusinessReviews200ResponseReviewsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::GetGoogleBusinessReviews200ResponseReviewsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'reviewer') self.reviewer = attributes[:'reviewer'] end if attributes.key?(:'rating') self. = attributes[:'rating'] end if attributes.key?(:'star_rating') self. = attributes[:'star_rating'] end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'create_time') self.create_time = attributes[:'create_time'] end if attributes.key?(:'update_time') self.update_time = attributes[:'update_time'] end if attributes.key?(:'review_reply') self.review_reply = attributes[:'review_reply'] end end |
Instance Attribute Details
#comment ⇒ Object
Review text
33 34 35 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 33 def comment @comment end |
#create_time ⇒ Object
Returns the value of attribute create_time.
35 36 37 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 35 def create_time @create_time end |
#id ⇒ Object
Review ID
19 20 21 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 19 def id @id end |
#name ⇒ Object
Full resource name
22 23 24 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 22 def name @name end |
#rating ⇒ Object
Numeric star rating
27 28 29 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 27 def @rating end |
#review_reply ⇒ Object
Returns the value of attribute review_reply.
39 40 41 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 39 def review_reply @review_reply end |
#reviewer ⇒ Object
Returns the value of attribute reviewer.
24 25 26 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 24 def reviewer @reviewer end |
#star_rating ⇒ Object
Google’s string rating
30 31 32 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 30 def @star_rating end |
#update_time ⇒ Object
Returns the value of attribute update_time.
37 38 39 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 37 def update_time @update_time end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 64 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'reviewer' => :'reviewer', :'rating' => :'rating', :'star_rating' => :'starRating', :'comment' => :'comment', :'create_time' => :'createTime', :'update_time' => :'updateTime', :'review_reply' => :'reviewReply' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 248 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 89 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'reviewer' => :'GetGoogleBusinessReviews200ResponseReviewsInnerReviewer', :'rating' => :'Integer', :'star_rating' => :'String', :'comment' => :'String', :'create_time' => :'Time', :'update_time' => :'Time', :'review_reply' => :'GetGoogleBusinessReviews200ResponseReviewsInnerReviewReply' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 219 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && reviewer == o.reviewer && == o. && == o. && comment == o.comment && create_time == o.create_time && update_time == o.update_time && review_reply == o.review_reply end |
#eql?(o) ⇒ Boolean
235 236 237 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 235 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
241 242 243 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 241 def hash [id, name, reviewer, , , comment, create_time, update_time, review_reply].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@rating.nil? && @rating > 5 invalid_properties.push('invalid value for "rating", must be smaller than or equal to 5.') end if !@rating.nil? && @rating < 1 invalid_properties.push('invalid value for "rating", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 270 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 |
# File 'lib/late-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@rating.nil? && @rating > 5 return false if !@rating.nil? && @rating < 1 = EnumAttributeValidator.new('String', ["ONE", "TWO", "THREE", "FOUR", "FIVE"]) return false unless .valid?(@star_rating) true end |