Class: Late::GetWhatsAppBroadcasts200ResponseBroadcastsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWhatsAppBroadcasts200ResponseBroadcastsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 131

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::GetWhatsAppBroadcasts200ResponseBroadcastsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::GetWhatsAppBroadcasts200ResponseBroadcastsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'template')
    self.template = attributes[:'template']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'message_preview')
    self.message_preview = attributes[:'message_preview']
  end

  if attributes.key?(:'recipient_count')
    self.recipient_count = attributes[:'recipient_count']
  end

  if attributes.key?(:'scheduled_at')
    self.scheduled_at = attributes[:'scheduled_at']
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end

  if attributes.key?(:'sent_count')
    self.sent_count = attributes[:'sent_count']
  end

  if attributes.key?(:'delivered_count')
    self.delivered_count = attributes[:'delivered_count']
  end

  if attributes.key?(:'read_count')
    self.read_count = attributes[:'read_count']
  end

  if attributes.key?(:'failed_count')
    self.failed_count = attributes[:'failed_count']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#completed_atObject

Returns the value of attribute completed_at.



37
38
39
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 37

def completed_at
  @completed_at
end

#created_atObject

Returns the value of attribute created_at.



47
48
49
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 47

def created_at
  @created_at
end

#delivered_countObject

Returns the value of attribute delivered_count.



41
42
43
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 41

def delivered_count
  @delivered_count
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 22

def description
  @description
end

#failed_countObject

Returns the value of attribute failed_count.



45
46
47
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 45

def failed_count
  @failed_count
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 18

def id
  @id
end

#message_previewObject

Template name or message text snippet



29
30
31
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 29

def message_preview
  @message_preview
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 20

def name
  @name
end

#read_countObject

Returns the value of attribute read_count.



43
44
45
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 43

def read_count
  @read_count
end

#recipient_countObject

Returns the value of attribute recipient_count.



31
32
33
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 31

def recipient_count
  @recipient_count
end

#scheduled_atObject

Returns the value of attribute scheduled_at.



33
34
35
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 33

def scheduled_at
  @scheduled_at
end

#sent_countObject

Returns the value of attribute sent_count.



39
40
41
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 39

def sent_count
  @sent_count
end

#started_atObject

Returns the value of attribute started_at.



35
36
37
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 35

def started_at
  @started_at
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 26

def status
  @status
end

#templateObject

Returns the value of attribute template.



24
25
26
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 24

def template
  @template
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



93
94
95
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 93

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 98

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 72

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'template' => :'template',
    :'status' => :'status',
    :'message_preview' => :'messagePreview',
    :'recipient_count' => :'recipientCount',
    :'scheduled_at' => :'scheduledAt',
    :'started_at' => :'startedAt',
    :'completed_at' => :'completedAt',
    :'sent_count' => :'sentCount',
    :'delivered_count' => :'deliveredCount',
    :'read_count' => :'readCount',
    :'failed_count' => :'failedCount',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 270

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 124

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 103

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'template' => :'GetWhatsAppBroadcasts200ResponseBroadcastsInnerTemplate',
    :'status' => :'String',
    :'message_preview' => :'String',
    :'recipient_count' => :'Integer',
    :'scheduled_at' => :'Time',
    :'started_at' => :'Time',
    :'completed_at' => :'Time',
    :'sent_count' => :'Integer',
    :'delivered_count' => :'Integer',
    :'read_count' => :'Integer',
    :'failed_count' => :'Integer',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      template == o.template &&
      status == o.status &&
      message_preview == o.message_preview &&
      recipient_count == o.recipient_count &&
      scheduled_at == o.scheduled_at &&
      started_at == o.started_at &&
      completed_at == o.completed_at &&
      sent_count == o.sent_count &&
      delivered_count == o.delivered_count &&
      read_count == o.read_count &&
      failed_count == o.failed_count &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


257
258
259
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 257

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



263
264
265
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 263

def hash
  [id, name, description, template, status, message_preview, recipient_count, scheduled_at, started_at, completed_at, sent_count, delivered_count, read_count, failed_count, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



208
209
210
211
212
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 208

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 292

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



216
217
218
219
220
221
# File 'lib/late-sdk/models/get_whats_app_broadcasts200_response_broadcasts_inner.rb', line 216

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["draft", "scheduled", "sending", "completed", "failed", "cancelled"])
  return false unless status_validator.valid?(@status)
  true
end