Class: Late::GetWhatsAppPhoneNumbers200ResponseNumbersInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::GetWhatsAppPhoneNumbers200ResponseNumbersInner
- Defined in:
- lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#country ⇒ Object
Returns the value of attribute country.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#meta_preverified_id ⇒ Object
Returns the value of attribute meta_preverified_id.
-
#meta_verification_status ⇒ Object
Returns the value of attribute meta_verification_status.
-
#phone_number ⇒ Object
Returns the value of attribute phone_number.
-
#profile_id ⇒ Object
Returns the value of attribute profile_id.
-
#provisioned_at ⇒ Object
Returns the value of attribute provisioned_at.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetWhatsAppPhoneNumbers200ResponseNumbersInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetWhatsAppPhoneNumbers200ResponseNumbersInner
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::GetWhatsAppPhoneNumbers200ResponseNumbersInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::GetWhatsAppPhoneNumbers200ResponseNumbersInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'provisioned_at') self.provisioned_at = attributes[:'provisioned_at'] end if attributes.key?(:'meta_preverified_id') self. = attributes[:'meta_preverified_id'] end if attributes.key?(:'meta_verification_status') self. = attributes[:'meta_verification_status'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 18 def _id @_id end |
#country ⇒ Object
Returns the value of attribute country.
22 23 24 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 22 def country @country end |
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 34 def created_at @created_at end |
#meta_preverified_id ⇒ Object
Returns the value of attribute meta_preverified_id.
30 31 32 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 30 def @meta_preverified_id end |
#meta_verification_status ⇒ Object
Returns the value of attribute meta_verification_status.
32 33 34 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 32 def @meta_verification_status end |
#phone_number ⇒ Object
Returns the value of attribute phone_number.
20 21 22 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 20 def phone_number @phone_number end |
#profile_id ⇒ Object
Returns the value of attribute profile_id.
26 27 28 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 26 def profile_id @profile_id end |
#provisioned_at ⇒ Object
Returns the value of attribute provisioned_at.
28 29 30 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 28 def provisioned_at @provisioned_at end |
#status ⇒ Object
Returns the value of attribute status.
24 25 26 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 24 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 59 def self.attribute_map { :'_id' => :'_id', :'phone_number' => :'phoneNumber', :'country' => :'country', :'status' => :'status', :'profile_id' => :'profileId', :'provisioned_at' => :'provisionedAt', :'meta_preverified_id' => :'metaPreverifiedId', :'meta_verification_status' => :'metaVerificationStatus', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 215 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 84 def self.openapi_types { :'_id' => :'String', :'phone_number' => :'String', :'country' => :'String', :'status' => :'String', :'profile_id' => :'Object', :'provisioned_at' => :'Time', :'meta_preverified_id' => :'String', :'meta_verification_status' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && phone_number == o.phone_number && country == o.country && status == o.status && profile_id == o.profile_id && provisioned_at == o.provisioned_at && == o. && == o. && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
202 203 204 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 202 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 208 def hash [_id, phone_number, country, status, profile_id, provisioned_at, , , created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 237 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 |
# File 'lib/late-sdk/models/get_whats_app_phone_numbers200_response_numbers_inner.rb', line 167 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["pending_payment", "provisioning", "active", "suspended", "releasing", "released"]) return false unless status_validator.valid?(@status) true end |