Class: Late::ListCommentAutomations200ResponseAutomationsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::ListCommentAutomations200ResponseAutomationsInner
- Defined in:
- lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#dm_message ⇒ Object
Returns the value of attribute dm_message.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#keywords ⇒ Object
Returns the value of attribute keywords.
-
#match_mode ⇒ Object
Returns the value of attribute match_mode.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
-
#post_title ⇒ Object
Returns the value of attribute post_title.
-
#stats ⇒ Object
Returns the value of attribute stats.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListCommentAutomations200ResponseAutomationsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListCommentAutomations200ResponseAutomationsInner
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::ListCommentAutomations200ResponseAutomationsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::ListCommentAutomations200ResponseAutomationsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] end if attributes.key?(:'post_title') self.post_title = attributes[:'post_title'] end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end end if attributes.key?(:'match_mode') self.match_mode = attributes[:'match_mode'] end if attributes.key?(:'dm_message') self. = attributes[:'dm_message'] end if attributes.key?(:'comment_reply') self.comment_reply = attributes[:'comment_reply'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'stats') self.stats = attributes[:'stats'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
24 25 26 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 24 def account_id @account_id end |
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
36 37 38 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 36 def comment_reply @comment_reply end |
#created_at ⇒ Object
Returns the value of attribute created_at.
42 43 44 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 42 def created_at @created_at end |
#dm_message ⇒ Object
Returns the value of attribute dm_message.
34 35 36 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 34 def @dm_message end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 18 def id @id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
38 39 40 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 38 def is_active @is_active end |
#keywords ⇒ Object
Returns the value of attribute keywords.
30 31 32 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 30 def keywords @keywords end |
#match_mode ⇒ Object
Returns the value of attribute match_mode.
32 33 34 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 32 def match_mode @match_mode end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 20 def name @name end |
#platform ⇒ Object
Returns the value of attribute platform.
22 23 24 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 22 def platform @platform end |
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
26 27 28 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 26 def platform_post_id @platform_post_id end |
#post_title ⇒ Object
Returns the value of attribute post_title.
28 29 30 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 28 def post_title @post_title end |
#stats ⇒ Object
Returns the value of attribute stats.
40 41 42 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 40 def stats @stats end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 67 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'platform' => :'platform', :'account_id' => :'accountId', :'platform_post_id' => :'platformPostId', :'post_title' => :'postTitle', :'keywords' => :'keywords', :'match_mode' => :'matchMode', :'dm_message' => :'dmMessage', :'comment_reply' => :'commentReply', :'is_active' => :'isActive', :'stats' => :'stats', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 265 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 115 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 96 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'platform' => :'String', :'account_id' => :'String', :'platform_post_id' => :'String', :'post_title' => :'String', :'keywords' => :'Array<String>', :'match_mode' => :'String', :'dm_message' => :'String', :'comment_reply' => :'String', :'is_active' => :'Boolean', :'stats' => :'ListCommentAutomations200ResponseAutomationsInnerStats', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 232 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && platform == o.platform && account_id == o.account_id && platform_post_id == o.platform_post_id && post_title == o.post_title && keywords == o.keywords && match_mode == o.match_mode && == o. && comment_reply == o.comment_reply && is_active == o.is_active && stats == o.stats && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
252 253 254 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 252 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
258 259 260 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 258 def hash [id, name, platform, account_id, platform_post_id, post_title, keywords, match_mode, , comment_reply, is_active, stats, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
193 194 195 196 197 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 193 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
201 202 203 204 205 206 207 208 |
# File 'lib/late-sdk/models/list_comment_automations200_response_automations_inner.rb', line 201 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' platform_validator = EnumAttributeValidator.new('String', ["instagram", "facebook"]) return false unless platform_validator.valid?(@platform) match_mode_validator = EnumAttributeValidator.new('String', ["exact", "contains"]) return false unless match_mode_validator.valid?(@match_mode) true end |