Class: Late::WebhookPayloadCommentComment

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/webhook_payload_comment_comment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadCommentComment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::WebhookPayloadCommentComment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::WebhookPayloadCommentComment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'post_id')
    self.post_id = attributes[:'post_id']
  end

  if attributes.key?(:'platform_post_id')
    self.platform_post_id = attributes[:'platform_post_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'author')
    self.author = attributes[:'author']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'is_reply')
    self.is_reply = attributes[:'is_reply']
  end

  if attributes.key?(:'parent_comment_id')
    self.parent_comment_id = attributes[:'parent_comment_id']
  end
end

Instance Attribute Details

#authorObject

Returns the value of attribute author.



32
33
34
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 32

def author
  @author
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 34

def created_at
  @created_at
end

#idObject

Platform comment ID



19
20
21
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 19

def id
  @id
end

#is_replyObject

Whether this is a reply to another comment



37
38
39
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 37

def is_reply
  @is_reply
end

#parent_comment_idObject

Parent comment ID if this is a reply



40
41
42
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 40

def parent_comment_id
  @parent_comment_id
end

#platformObject

Returns the value of attribute platform.



27
28
29
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 27

def platform
  @platform
end

#platform_post_idObject

Platform’s post ID



25
26
27
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 25

def platform_post_id
  @platform_post_id
end

#post_idObject

Internal post ID



22
23
24
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 22

def post_id
  @post_id
end

#textObject

Comment text content



30
31
32
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 30

def text
  @text
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'post_id' => :'postId',
    :'platform_post_id' => :'platformPostId',
    :'platform' => :'platform',
    :'text' => :'text',
    :'author' => :'author',
    :'created_at' => :'createdAt',
    :'is_reply' => :'isReply',
    :'parent_comment_id' => :'parentCommentId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 105

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 90

def self.openapi_types
  {
    :'id' => :'String',
    :'post_id' => :'String',
    :'platform_post_id' => :'String',
    :'platform' => :'String',
    :'text' => :'String',
    :'author' => :'WebhookPayloadCommentCommentAuthor',
    :'created_at' => :'Time',
    :'is_reply' => :'Boolean',
    :'parent_comment_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      post_id == o.post_id &&
      platform_post_id == o.platform_post_id &&
      platform == o.platform &&
      text == o.text &&
      author == o.author &&
      created_at == o.created_at &&
      is_reply == o.is_reply &&
      parent_comment_id == o.parent_comment_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 214

def hash
  [id, post_id, platform_post_id, platform, text, author, created_at, is_reply, parent_comment_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
# File 'lib/late-sdk/models/webhook_payload_comment_comment.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  platform_validator = EnumAttributeValidator.new('String', ["instagram", "facebook", "twitter", "youtube", "linkedin", "bluesky", "reddit"])
  return false unless platform_validator.valid?(@platform)
  true
end