Class: Late::WhatsAppPhoneNumbersApi
- Inherits:
-
Object
- Object
- Late::WhatsAppPhoneNumbersApi
- Defined in:
- lib/late-sdk/api/whats_app_phone_numbers_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_whats_app_phone_number(phone_number_id, opts = {}) ⇒ GetWhatsAppPhoneNumber200Response
Get phone number Retrieve the current status of a purchased phone number.
-
#get_whats_app_phone_number_with_http_info(phone_number_id, opts = {}) ⇒ Array<(GetWhatsAppPhoneNumber200Response, Integer, Hash)>
Get phone number Retrieve the current status of a purchased phone number.
-
#get_whats_app_phone_numbers(opts = {}) ⇒ GetWhatsAppPhoneNumbers200Response
List phone numbers List all WhatsApp phone numbers purchased by the authenticated user.
-
#get_whats_app_phone_numbers_with_http_info(opts = {}) ⇒ Array<(GetWhatsAppPhoneNumbers200Response, Integer, Hash)>
List phone numbers List all WhatsApp phone numbers purchased by the authenticated user.
-
#initialize(api_client = ApiClient.default) ⇒ WhatsAppPhoneNumbersApi
constructor
A new instance of WhatsAppPhoneNumbersApi.
-
#purchase_whats_app_phone_number(purchase_whats_app_phone_number_request, opts = {}) ⇒ PurchaseWhatsAppPhoneNumber200Response
Purchase phone number Initiate purchasing a WhatsApp phone number.
-
#purchase_whats_app_phone_number_with_http_info(purchase_whats_app_phone_number_request, opts = {}) ⇒ Array<(PurchaseWhatsAppPhoneNumber200Response, Integer, Hash)>
Purchase phone number Initiate purchasing a WhatsApp phone number.
-
#release_whats_app_phone_number(phone_number_id, opts = {}) ⇒ ReleaseWhatsAppPhoneNumber200Response
Release phone number Release a purchased phone number.
-
#release_whats_app_phone_number_with_http_info(phone_number_id, opts = {}) ⇒ Array<(ReleaseWhatsAppPhoneNumber200Response, Integer, Hash)>
Release phone number Release a purchased phone number.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WhatsAppPhoneNumbersApi
Returns a new instance of WhatsAppPhoneNumbersApi.
19 20 21 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_whats_app_phone_number(phone_number_id, opts = {}) ⇒ GetWhatsAppPhoneNumber200Response
Get phone number Retrieve the current status of a purchased phone number. Used to poll for Meta pre-verification completion after purchase.
27 28 29 30 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 27 def get_whats_app_phone_number(phone_number_id, opts = {}) data, _status_code, _headers = get_whats_app_phone_number_with_http_info(phone_number_id, opts) data end |
#get_whats_app_phone_number_with_http_info(phone_number_id, opts = {}) ⇒ Array<(GetWhatsAppPhoneNumber200Response, Integer, Hash)>
Get phone number Retrieve the current status of a purchased phone number. Used to poll for Meta pre-verification completion after purchase.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 37 def get_whats_app_phone_number_with_http_info(phone_number_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WhatsAppPhoneNumbersApi.get_whats_app_phone_number ...' end # verify the required parameter 'phone_number_id' is set if @api_client.config.client_side_validation && phone_number_id.nil? fail ArgumentError, "Missing the required parameter 'phone_number_id' when calling WhatsAppPhoneNumbersApi.get_whats_app_phone_number" end # resource path local_var_path = '/v1/whatsapp/phone-numbers/{phoneNumberId}'.sub('{' + 'phoneNumberId' + '}', CGI.escape(phone_number_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWhatsAppPhoneNumber200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WhatsAppPhoneNumbersApi.get_whats_app_phone_number", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WhatsAppPhoneNumbersApi#get_whats_app_phone_number\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_whats_app_phone_numbers(opts = {}) ⇒ GetWhatsAppPhoneNumbers200Response
List phone numbers List all WhatsApp phone numbers purchased by the authenticated user. By default, released numbers are excluded.
91 92 93 94 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 91 def get_whats_app_phone_numbers(opts = {}) data, _status_code, _headers = get_whats_app_phone_numbers_with_http_info(opts) data end |
#get_whats_app_phone_numbers_with_http_info(opts = {}) ⇒ Array<(GetWhatsAppPhoneNumbers200Response, Integer, Hash)>
List phone numbers List all WhatsApp phone numbers purchased by the authenticated user. By default, released numbers are excluded.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 102 def get_whats_app_phone_numbers_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WhatsAppPhoneNumbersApi.get_whats_app_phone_numbers ...' end allowable_values = ["provisioning", "active", "suspended", "releasing", "released"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end # resource path local_var_path = '/v1/whatsapp/phone-numbers' # query parameters query_params = opts[:query_params] || {} query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'profileId'] = opts[:'profile_id'] if !opts[:'profile_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWhatsAppPhoneNumbers200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WhatsAppPhoneNumbersApi.get_whats_app_phone_numbers", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WhatsAppPhoneNumbersApi#get_whats_app_phone_numbers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#purchase_whats_app_phone_number(purchase_whats_app_phone_number_request, opts = {}) ⇒ PurchaseWhatsAppPhoneNumber200Response
Purchase phone number Initiate purchasing a WhatsApp phone number. Payment-first flow: the user does not pick a specific number. The system either creates a Stripe Checkout Session (first number) or increments the existing subscription quantity and provisions inline (subsequent numbers). Requires a paid plan. The maximum number of phone numbers is determined by the user’s plan.
157 158 159 160 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 157 def purchase_whats_app_phone_number(purchase_whats_app_phone_number_request, opts = {}) data, _status_code, _headers = purchase_whats_app_phone_number_with_http_info(purchase_whats_app_phone_number_request, opts) data end |
#purchase_whats_app_phone_number_with_http_info(purchase_whats_app_phone_number_request, opts = {}) ⇒ Array<(PurchaseWhatsAppPhoneNumber200Response, Integer, Hash)>
Purchase phone number Initiate purchasing a WhatsApp phone number. Payment-first flow: the user does not pick a specific number. The system either creates a Stripe Checkout Session (first number) or increments the existing subscription quantity and provisions inline (subsequent numbers). Requires a paid plan. The maximum number of phone numbers is determined by the user's plan.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 167 def purchase_whats_app_phone_number_with_http_info(purchase_whats_app_phone_number_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WhatsAppPhoneNumbersApi.purchase_whats_app_phone_number ...' end # verify the required parameter 'purchase_whats_app_phone_number_request' is set if @api_client.config.client_side_validation && purchase_whats_app_phone_number_request.nil? fail ArgumentError, "Missing the required parameter 'purchase_whats_app_phone_number_request' when calling WhatsAppPhoneNumbersApi.purchase_whats_app_phone_number" end # resource path local_var_path = '/v1/whatsapp/phone-numbers/purchase' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(purchase_whats_app_phone_number_request) # return_type return_type = opts[:debug_return_type] || 'PurchaseWhatsAppPhoneNumber200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WhatsAppPhoneNumbersApi.purchase_whats_app_phone_number", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WhatsAppPhoneNumbersApi#purchase_whats_app_phone_number\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#release_whats_app_phone_number(phone_number_id, opts = {}) ⇒ ReleaseWhatsAppPhoneNumber200Response
Release phone number Release a purchased phone number. This will: 1. Disconnect any linked WhatsApp social account 2. Decrement the Stripe subscription quantity (or cancel if last number) 3. Release the number from Telnyx 4. Mark the number as released
225 226 227 228 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 225 def release_whats_app_phone_number(phone_number_id, opts = {}) data, _status_code, _headers = release_whats_app_phone_number_with_http_info(phone_number_id, opts) data end |
#release_whats_app_phone_number_with_http_info(phone_number_id, opts = {}) ⇒ Array<(ReleaseWhatsAppPhoneNumber200Response, Integer, Hash)>
Release phone number Release a purchased phone number. This will: 1. Disconnect any linked WhatsApp social account 2. Decrement the Stripe subscription quantity (or cancel if last number) 3. Release the number from Telnyx 4. Mark the number as released
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/late-sdk/api/whats_app_phone_numbers_api.rb', line 235 def release_whats_app_phone_number_with_http_info(phone_number_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WhatsAppPhoneNumbersApi.release_whats_app_phone_number ...' end # verify the required parameter 'phone_number_id' is set if @api_client.config.client_side_validation && phone_number_id.nil? fail ArgumentError, "Missing the required parameter 'phone_number_id' when calling WhatsAppPhoneNumbersApi.release_whats_app_phone_number" end # resource path local_var_path = '/v1/whatsapp/phone-numbers/{phoneNumberId}'.sub('{' + 'phoneNumberId' + '}', CGI.escape(phone_number_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ReleaseWhatsAppPhoneNumber200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WhatsAppPhoneNumbersApi.release_whats_app_phone_number", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WhatsAppPhoneNumbersApi#release_whats_app_phone_number\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |