Class: Zernio::APIKeysApi

Inherits:
Object
  • Object
show all
Defined in:
lib/zernio-sdk/api/api_keys_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ APIKeysApi



19
20
21
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_client ⇒ Object

Returns the value of attribute api_client.



17
18
19
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_api_key(create_api_key_request, opts = {}) ⇒ CreateApiKey201Response

Create key Creates a new API key with an optional expiry. The full key value is only returned once in the response.



27
28
29
30
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 27

def create_api_key(create_api_key_request, opts = {})
  data, _status_code, _headers = create_api_key_with_http_info(create_api_key_request, opts)
  data
end

#create_api_key_with_http_info(create_api_key_request, opts = {}) ⇒ Array<(CreateApiKey201Response, Integer, Hash)>

Create key Creates a new API key with an optional expiry. The full key value is only returned once in the response.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 37

def create_api_key_with_http_info(create_api_key_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: APIKeysApi.create_api_key ...'
  end
  # verify the required parameter 'create_api_key_request' is set
  if @api_client.config.client_side_validation && create_api_key_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_api_key_request' when calling APIKeysApi.create_api_key"
  end
  # resource path
  local_var_path = '/v1/api-keys'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_api_key_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateApiKey201Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"APIKeysApi.create_api_key",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: APIKeysApi#create_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_api_key(key_id, opts = {}) ⇒ DeleteAccountGroup200Response

Delete key Permanently revokes and deletes an API key.



95
96
97
98
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 95

def delete_api_key(key_id, opts = {})
  data, _status_code, _headers = delete_api_key_with_http_info(key_id, opts)
  data
end

#delete_api_key_with_http_info(key_id, opts = {}) ⇒ Array<(DeleteAccountGroup200Response, Integer, Hash)>

Delete key Permanently revokes and deletes an API key.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 105

def delete_api_key_with_http_info(key_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: APIKeysApi.delete_api_key ...'
  end
  # verify the required parameter 'key_id' is set
  if @api_client.config.client_side_validation && key_id.nil?
    fail ArgumentError, "Missing the required parameter 'key_id' when calling APIKeysApi.delete_api_key"
  end
  # resource path
  local_var_path = '/v1/api-keys/{keyId}'.sub('{' + 'keyId' + '}', CGI.escape(key_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteAccountGroup200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"APIKeysApi.delete_api_key",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: APIKeysApi#delete_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_api_keys(opts = {}) ⇒ ListApiKeys200Response

List keys Returns all API keys for the authenticated user. Keys are returned with a preview only, not the full key value.



157
158
159
160
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 157

def list_api_keys(opts = {})
  data, _status_code, _headers = list_api_keys_with_http_info(opts)
  data
end

#list_api_keys_with_http_info(opts = {}) ⇒ Array<(ListApiKeys200Response, Integer, Hash)>

List keys Returns all API keys for the authenticated user. Keys are returned with a preview only, not the full key value.



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 166

def list_api_keys_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: APIKeysApi.list_api_keys ...'
  end
  # resource path
  local_var_path = '/v1/api-keys'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListApiKeys200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"APIKeysApi.list_api_keys",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: APIKeysApi#list_api_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#verify_credential(opts = {}) ⇒ VerifyCredential200Response

Verify credential Checks whether the bearer credential on this request is valid, without reading any data. Accepts an API key or an OAuth access token. Intended for clients that must validate a credential before use (for example an MCP server verifying an incoming token) so they do not have to call a data endpoint to do it.



214
215
216
217
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 214

def verify_credential(opts = {})
  data, _status_code, _headers = verify_credential_with_http_info(opts)
  data
end

#verify_credential_with_http_info(opts = {}) ⇒ Array<(VerifyCredential200Response, Integer, Hash)>

Verify credential Checks whether the bearer credential on this request is valid, without reading any data. Accepts an API key or an OAuth access token. Intended for clients that must validate a credential before use (for example an MCP server verifying an incoming token) so they do not have to call a data endpoint to do it.



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zernio-sdk/api/api_keys_api.rb', line 223

def verify_credential_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: APIKeysApi.verify_credential ...'
  end
  # resource path
  local_var_path = '/v1/auth/verify'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'VerifyCredential200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"APIKeysApi.verify_credential",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: APIKeysApi#verify_credential\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end