Class: Zernio::AdjustConversionsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::AdjustConversionsRequest
- Defined in:
- lib/zernio-sdk/models/adjust_conversions_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
SocialAccount ID.
-
#adjustments ⇒ Object
Returns the value of attribute adjustments.
-
#destination_id ⇒ Object
Conversion action resource name, e.g.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdjustConversionsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdjustConversionsRequest
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AdjustConversionsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AdjustConversionsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'destination_id') self.destination_id = attributes[:'destination_id'] else self.destination_id = nil end if attributes.key?(:'adjustments') if (value = attributes[:'adjustments']).is_a?(Array) self.adjustments = value end else self.adjustments = nil end end |
Instance Attribute Details
#account_id ⇒ Object
SocialAccount ID. Must be a googleads account.
19 20 21 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 19 def account_id @account_id end |
#adjustments ⇒ Object
Returns the value of attribute adjustments.
24 25 26 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 24 def adjustments @adjustments end |
#destination_id ⇒ Object
Conversion action resource name, e.g. customers/1234567890/conversionActions/987654321.
22 23 24 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 22 def destination_id @destination_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 27 def self.attribute_map { :'account_id' => :'accountId', :'destination_id' => :'destinationId', :'adjustments' => :'adjustments' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 200 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 46 def self.openapi_types { :'account_id' => :'String', :'destination_id' => :'String', :'adjustments' => :'Array<AdjustConversionsRequestAdjustmentsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && destination_id == o.destination_id && adjustments == o.adjustments end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 193 def hash [account_id, destination_id, adjustments].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 99 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @destination_id.nil? invalid_properties.push('invalid value for "destination_id", destination_id cannot be nil.') end if @adjustments.nil? invalid_properties.push('invalid value for "adjustments", adjustments cannot be nil.') end if @adjustments.length > 2000 invalid_properties.push('invalid value for "adjustments", number of items must be less than or equal to 2000.') end if @adjustments.length < 1 invalid_properties.push('invalid value for "adjustments", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 133 134 135 |
# File 'lib/zernio-sdk/models/adjust_conversions_request.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @destination_id.nil? return false if @adjustments.nil? return false if @adjustments.length > 2000 return false if @adjustments.length < 1 true end |