Class: Zernio::AnalyticsListResponse

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/analytics_list_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AnalyticsListResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AnalyticsListResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AnalyticsListResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'overview')
    self.overview = attributes[:'overview']
  end

  if attributes.key?(:'posts')
    if (value = attributes[:'posts']).is_a?(Array)
      self.posts = value
    end
  end

  if attributes.key?(:'pagination')
    self.pagination = attributes[:'pagination']
  end

  if attributes.key?(:'accounts')
    if (value = attributes[:'accounts']).is_a?(Array)
      self.accounts = value
    end
  end

  if attributes.key?(:'has_analytics_access')
    self.has_analytics_access = attributes[:'has_analytics_access']
  end
end

Instance Attribute Details

#accountsObject

Connected social accounts (followerCount and followersLastUpdated only included if user has analytics add-on)



25
26
27
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 25

def accounts
  @accounts
end

#has_analytics_accessObject

Whether user has analytics add-on access



28
29
30
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 28

def has_analytics_access
  @has_analytics_access
end

#overviewObject

Returns the value of attribute overview.



18
19
20
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 18

def overview
  @overview
end

#paginationObject

Returns the value of attribute pagination.



22
23
24
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 22

def pagination
  @pagination
end

#postsObject

Returns the value of attribute posts.



20
21
22
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 20

def posts
  @posts
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 31

def self.attribute_map
  {
    :'overview' => :'overview',
    :'posts' => :'posts',
    :'pagination' => :'pagination',
    :'accounts' => :'accounts',
    :'has_analytics_access' => :'hasAnalyticsAccess'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 151

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 63

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 52

def self.openapi_types
  {
    :'overview' => :'AnalyticsOverview',
    :'posts' => :'Array<AnalyticsListResponsePostsInner>',
    :'pagination' => :'Pagination',
    :'accounts' => :'Array<SocialAccount>',
    :'has_analytics_access' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
132
133
134
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 126

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      overview == o.overview &&
      posts == o.posts &&
      pagination == o.pagination &&
      accounts == o.accounts &&
      has_analytics_access == o.has_analytics_access
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


138
139
140
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 138

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



144
145
146
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 144

def hash
  [overview, posts, pagination, accounts, has_analytics_access].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 173

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



119
120
121
122
# File 'lib/zernio-sdk/models/analytics_list_response.rb', line 119

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end