Class: Zernio::BusinessAgentBudget
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::BusinessAgentBudget
- Defined in:
- lib/zernio-sdk/models/business_agent_budget.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#budget_id ⇒ Object
Pass it back to edit an existing budget; omit to add one.
-
#max_budget ⇒ Object
Returns the value of attribute max_budget.
-
#time_window ⇒ Object
Rolling window in the WABA timezone.
-
#unit_type ⇒ Object
Tokens count across the Business Manager, AI turns per conversation.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BusinessAgentBudget
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BusinessAgentBudget
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BusinessAgentBudget` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BusinessAgentBudget`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'budget_id') self.budget_id = attributes[:'budget_id'] end if attributes.key?(:'unit_type') self.unit_type = attributes[:'unit_type'] else self.unit_type = nil end if attributes.key?(:'time_window') self.time_window = attributes[:'time_window'] else self.time_window = nil end if attributes.key?(:'max_budget') self.max_budget = attributes[:'max_budget'] else self.max_budget = nil end end |
Instance Attribute Details
#budget_id ⇒ Object
Pass it back to edit an existing budget; omit to add one.
19 20 21 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 19 def budget_id @budget_id end |
#max_budget ⇒ Object
Returns the value of attribute max_budget.
27 28 29 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 27 def max_budget @max_budget end |
#time_window ⇒ Object
Rolling window in the WABA timezone.
25 26 27 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 25 def time_window @time_window end |
#unit_type ⇒ Object
Tokens count across the Business Manager, AI turns per conversation.
22 23 24 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 22 def unit_type @unit_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 52 def self.attribute_map { :'budget_id' => :'budget_id', :'unit_type' => :'unit_type', :'time_window' => :'time_window', :'max_budget' => :'max_budget' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 225 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 72 def self.openapi_types { :'budget_id' => :'String', :'unit_type' => :'String', :'time_window' => :'String', :'max_budget' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
201 202 203 204 205 206 207 208 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 201 def ==(o) return true if self.equal?(o) self.class == o.class && budget_id == o.budget_id && unit_type == o.unit_type && time_window == o.time_window && max_budget == o.max_budget end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 218 def hash [budget_id, unit_type, time_window, max_budget].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @unit_type.nil? invalid_properties.push('invalid value for "unit_type", unit_type cannot be nil.') end if @time_window.nil? invalid_properties.push('invalid value for "time_window", time_window cannot be nil.') end if @max_budget.nil? invalid_properties.push('invalid value for "max_budget", max_budget cannot be nil.') end if @max_budget < 1 invalid_properties.push('invalid value for "max_budget", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/models/business_agent_budget.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @unit_type.nil? unit_type_validator = EnumAttributeValidator.new('String', ["token", "ai_turn"]) return false unless unit_type_validator.valid?(@unit_type) return false if @time_window.nil? time_window_validator = EnumAttributeValidator.new('String', ["one_day", "seven_days", "fourteen_days", "thirty_days"]) return false unless time_window_validator.valid?(@time_window) return false if @max_budget.nil? return false if @max_budget < 1 true end |