Class: Zernio::BusinessAgentEventStatus
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::BusinessAgentEventStatus
- Defined in:
- lib/zernio-sdk/models/business_agent_event_status.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#error_message ⇒ Object
Returns the value of attribute error_message.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#skipped_reason ⇒ Object
Returns the value of attribute skipped_reason.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BusinessAgentEventStatus
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BusinessAgentEventStatus
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BusinessAgentEventStatus` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BusinessAgentEventStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] else self.event_type = nil end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'skipped_reason') self.skipped_reason = attributes[:'skipped_reason'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
26 27 28 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 26 def created_at @created_at end |
#error_message ⇒ Object
Returns the value of attribute error_message.
22 23 24 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 22 def end |
#event_type ⇒ Object
Returns the value of attribute event_type.
20 21 22 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 20 def event_type @event_type end |
#skipped_reason ⇒ Object
Returns the value of attribute skipped_reason.
24 25 26 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 24 def skipped_reason @skipped_reason end |
#status ⇒ Object
Returns the value of attribute status.
18 19 20 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 18 def status @status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
28 29 30 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 28 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 53 def self.attribute_map { :'status' => :'status', :'event_type' => :'event_type', :'error_message' => :'error_message', :'skipped_reason' => :'skipped_reason', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 75 def self.openapi_types { :'status' => :'String', :'event_type' => :'String', :'error_message' => :'String', :'skipped_reason' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && event_type == o.event_type && == o. && skipped_reason == o.skipped_reason && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 239 def hash [status, event_type, , skipped_reason, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 143 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @event_type.nil? invalid_properties.push('invalid value for "event_type", event_type cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/zernio-sdk/models/business_agent_event_status.rb', line 167 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["request_received", "processing", "sent", "failed", "skipped", "success"]) return false unless status_validator.valid?(@status) return false if @event_type.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |