Class: Zernio::CommentAutomationTemplateElement
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CommentAutomationTemplateElement
- Defined in:
- lib/zernio-sdk/models/comment_automation_template_element.rb
Instance Attribute Summary collapse
-
#buttons ⇒ Object
Up to 3 card buttons.
-
#image_url ⇒ Object
Publicly reachable http(s) image rendered large above the card.
-
#subtitle ⇒ Object
Card description, e.g.
-
#title ⇒ Object
Card headline (80 chars max).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommentAutomationTemplateElement
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CommentAutomationTemplateElement
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CommentAutomationTemplateElement` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CommentAutomationTemplateElement`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'subtitle') self.subtitle = attributes[:'subtitle'] end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'buttons') if (value = attributes[:'buttons']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#buttons ⇒ Object
Up to 3 card buttons. A generic template has NO phone button, on either platform. url buttons are click-tracked when linkTracking is on.
28 29 30 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 28 def @buttons end |
#image_url ⇒ Object
Publicly reachable http(s) image rendered large above the card.
25 26 27 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 25 def image_url @image_url end |
#subtitle ⇒ Object
Card description, e.g. the price or a short pitch (80 chars max).
22 23 24 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 22 def subtitle @subtitle end |
#title ⇒ Object
Card headline (80 chars max). Also used as the Inbox preview for the sent DM.
19 20 21 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 19 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 31 def self.attribute_map { :'title' => :'title', :'subtitle' => :'subtitle', :'image_url' => :'imageUrl', :'buttons' => :'buttons' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 206 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 51 def self.openapi_types { :'title' => :'String', :'subtitle' => :'String', :'image_url' => :'String', :'buttons' => :'Array<CommentAutomationTemplateElementButtonsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 182 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && subtitle == o.subtitle && image_url == o.image_url && == o. end |
#eql?(o) ⇒ Boolean
193 194 195 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 193 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 199 def hash [title, subtitle, image_url, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @title.to_s.length > 80 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 80.') end if !@subtitle.nil? && @subtitle.to_s.length > 80 invalid_properties.push('invalid value for "subtitle", the character length must be smaller than or equal to 80.') end if !@buttons.nil? && @buttons.length > 3 invalid_properties.push('invalid value for "buttons", number of items must be less than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
129 130 131 132 133 134 135 136 |
# File 'lib/zernio-sdk/models/comment_automation_template_element.rb', line 129 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @title.nil? return false if @title.to_s.length > 80 return false if !@subtitle.nil? && @subtitle.to_s.length > 80 return false if !@buttons.nil? && @buttons.length > 3 true end |