Class: Zernio::CommentAutomationTemplateElementButtonsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CommentAutomationTemplateElementButtonsInner
- Defined in:
- lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#payload ⇒ Object
Postback payload delivered via the messaging_postbacks webhook (required when type is postback).
-
#title ⇒ Object
Returns the value of attribute title.
-
#type ⇒ Object
Returns the value of attribute type.
-
#url ⇒ Object
Target URL (required when type is url).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommentAutomationTemplateElementButtonsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CommentAutomationTemplateElementButtonsInner
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CommentAutomationTemplateElementButtonsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CommentAutomationTemplateElementButtonsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'payload') self.payload = attributes[:'payload'] end end |
Instance Attribute Details
#payload ⇒ Object
Postback payload delivered via the messaging_postbacks webhook (required when type is postback)
26 27 28 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 26 def payload @payload end |
#title ⇒ Object
Returns the value of attribute title.
20 21 22 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 20 def title @title end |
#type ⇒ Object
Returns the value of attribute type.
18 19 20 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 18 def type @type end |
#url ⇒ Object
Target URL (required when type is url)
23 24 25 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 23 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 51 def self.attribute_map { :'type' => :'type', :'title' => :'title', :'url' => :'url', :'payload' => :'payload' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 205 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 71 def self.openapi_types { :'type' => :'String', :'title' => :'String', :'url' => :'String', :'payload' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 181 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && title == o.title && url == o.url && payload == o.payload end |
#eql?(o) ⇒ Boolean
192 193 194 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 192 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 198 def hash [type, title, url, payload].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @title.to_s.length > 20 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 20.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 151 152 153 |
# File 'lib/zernio-sdk/models/comment_automation_template_element_buttons_inner.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["url", "postback"]) return false unless type_validator.valid?(@type) return false if @title.nil? return false if @title.to_s.length > 20 true end |