Class: Zernio::ConnectWhatsAppCredentials200ResponseAccount

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConnectWhatsAppCredentials200ResponseAccount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ConnectWhatsAppCredentials200ResponseAccount` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ConnectWhatsAppCredentials200ResponseAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'verified_name')
    self.verified_name = attributes[:'verified_name']
  end

  if attributes.key?(:'quality_rating')
    self.quality_rating = attributes[:'quality_rating']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 18

def 
  @account_id
end

#display_nameObject

Meta-verified business name



26
27
28
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 26

def display_name
  @display_name
end

#is_activeObject

Returns the value of attribute is_active.



28
29
30
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 28

def is_active
  @is_active
end

#phone_numberObject

The connected phone number



31
32
33
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 31

def phone_number
  @phone_number
end

#platformObject

Returns the value of attribute platform.



20
21
22
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 20

def platform
  @platform
end

#quality_ratingObject

Meta quality rating for the phone number (e.g. GREEN, YELLOW, RED, UNKNOWN)



37
38
39
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 37

def quality_rating
  @quality_rating
end

#usernameObject

Display phone number



23
24
25
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 23

def username
  @username
end

#verified_nameObject

Meta-verified business name for the phone number



34
35
36
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 34

def verified_name
  @verified_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 62

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'username' => :'username',
    :'display_name' => :'displayName',
    :'is_active' => :'isActive',
    :'phone_number' => :'phoneNumber',
    :'verified_name' => :'verifiedName',
    :'quality_rating' => :'qualityRating'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 211

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 86

def self.openapi_types
  {
    :'account_id' => :'String',
    :'platform' => :'String',
    :'username' => :'String',
    :'display_name' => :'String',
    :'is_active' => :'Boolean',
    :'phone_number' => :'String',
    :'verified_name' => :'String',
    :'quality_rating' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 183

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      platform == o.platform &&
      username == o.username &&
      display_name == o.display_name &&
      is_active == o.is_active &&
      phone_number == o.phone_number &&
      verified_name == o.verified_name &&
      quality_rating == o.quality_rating
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 198

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



204
205
206
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 204

def hash
  [, platform, username, display_name, is_active, phone_number, verified_name, quality_rating].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 156

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
# File 'lib/zernio-sdk/models/connect_whats_app_credentials200_response_account.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  platform_validator = EnumAttributeValidator.new('String', ["whatsapp"])
  return false unless platform_validator.valid?(@platform)
  true
end