Class: Zernio::ConnectWordPressWithApplicationPasswordRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConnectWordPressWithApplicationPasswordRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ConnectWordPressWithApplicationPasswordRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ConnectWordPressWithApplicationPasswordRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'site_url')
    self.site_url = attributes[:'site_url']
  else
    self.site_url = nil
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  else
    self.username = nil
  end

  if attributes.key?(:'application_password')
    self.application_password = attributes[:'application_password']
  else
    self.application_password = nil
  end
end

Instance Attribute Details

#application_passwordObject

Application password created for the WordPress user. Spaces in WordPress display formatting are accepted.



28
29
30
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 28

def application_password
  @application_password
end

#profile_idObject

Your Zernio profile ID (get from /v1/profiles).



19
20
21
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 19

def profile_id
  @profile_id
end

#site_urlObject

HTTPS base URL of the WordPress installation, including a subdirectory path when applicable.



22
23
24
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 22

def site_url
  @site_url
end

#usernameObject

WordPress login name. A colon is not allowed.



25
26
27
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 25

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 31

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'site_url' => :'siteUrl',
    :'username' => :'username',
    :'application_password' => :'applicationPassword'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 266

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 51

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'site_url' => :'String',
    :'username' => :'String',
    :'application_password' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      site_url == o.site_url &&
      username == o.username &&
      application_password == o.application_password
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 253

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



259
260
261
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 259

def hash
  [profile_id, site_url, username, application_password].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 109

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if @site_url.nil?
    invalid_properties.push('invalid value for "site_url", site_url cannot be nil.')
  end

  pattern = Regexp.new(/^https:\/\//)
  if @site_url !~ pattern
    invalid_properties.push("invalid value for \"site_url\", must conform to the pattern #{pattern}.")
  end

  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  if @username.to_s.length > 255
    invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 255.')
  end

  if @username.to_s.length < 1
    invalid_properties.push('invalid value for "username", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[^:\r\n]+$/)
  if @username !~ pattern
    invalid_properties.push("invalid value for \"username\", must conform to the pattern #{pattern}.")
  end

  if @application_password.nil?
    invalid_properties.push('invalid value for "application_password", application_password cannot be nil.')
  end

  if @application_password.to_s.length > 1024
    invalid_properties.push('invalid value for "application_password", the character length must be smaller than or equal to 1024.')
  end

  if @application_password.to_s.length < 1
    invalid_properties.push('invalid value for "application_password", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 288

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/zernio-sdk/models/connect_word_press_with_application_password_request.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_id.nil?
  return false if @site_url.nil?
  return false if @site_url !~ Regexp.new(/^https:\/\//)
  return false if @username.nil?
  return false if @username.to_s.length > 255
  return false if @username.to_s.length < 1
  return false if @username !~ Regexp.new(/^[^:\r\n]+$/)
  return false if @application_password.nil?
  return false if @application_password.to_s.length > 1024
  return false if @application_password.to_s.length < 1
  true
end