Class: Zernio::ContactsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/zernio-sdk/api/contacts_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ContactsApi

Returns a new instance of ContactsApi.



19
20
21
# File 'lib/zernio-sdk/api/contacts_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/zernio-sdk/api/contacts_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#bulk_create_contacts(bulk_create_contacts_request, opts = {}) ⇒ BulkCreateContacts200Response

Bulk create contacts Import up to 1000 contacts at a time. Skips duplicates.

Parameters:

Returns:



27
28
29
30
# File 'lib/zernio-sdk/api/contacts_api.rb', line 27

def bulk_create_contacts(bulk_create_contacts_request, opts = {})
  data, _status_code, _headers = bulk_create_contacts_with_http_info(bulk_create_contacts_request, opts)
  data
end

#bulk_create_contacts_with_http_info(bulk_create_contacts_request, opts = {}) ⇒ Array<(BulkCreateContacts200Response, Integer, Hash)>

Bulk create contacts Import up to 1000 contacts at a time. Skips duplicates.

Parameters:

Returns:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/api/contacts_api.rb', line 37

def bulk_create_contacts_with_http_info(bulk_create_contacts_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContactsApi.bulk_create_contacts ...'
  end
  # verify the required parameter 'bulk_create_contacts_request' is set
  if @api_client.config.client_side_validation && bulk_create_contacts_request.nil?
    fail ArgumentError, "Missing the required parameter 'bulk_create_contacts_request' when calling ContactsApi.bulk_create_contacts"
  end
  # resource path
  local_var_path = '/v1/contacts/bulk'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(bulk_create_contacts_request)

  # return_type
  return_type = opts[:debug_return_type] || 'BulkCreateContacts200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ContactsApi.bulk_create_contacts",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContactsApi#bulk_create_contacts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_contact(create_contact_request, opts = {}) ⇒ CreateContact200Response

Create contact Create a new contact. Optionally create a platform channel in the same request by providing accountId, platform, and platformIdentifier.

Parameters:

  • create_contact_request (CreateContactRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



95
96
97
98
# File 'lib/zernio-sdk/api/contacts_api.rb', line 95

def create_contact(create_contact_request, opts = {})
  data, _status_code, _headers = create_contact_with_http_info(create_contact_request, opts)
  data
end

#create_contact_with_http_info(create_contact_request, opts = {}) ⇒ Array<(CreateContact200Response, Integer, Hash)>

Create contact Create a new contact. Optionally create a platform channel in the same request by providing accountId, platform, and platformIdentifier.

Parameters:

  • create_contact_request (CreateContactRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CreateContact200Response, Integer, Hash)>)

    CreateContact200Response data, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/zernio-sdk/api/contacts_api.rb', line 105

def create_contact_with_http_info(create_contact_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContactsApi.create_contact ...'
  end
  # verify the required parameter 'create_contact_request' is set
  if @api_client.config.client_side_validation && create_contact_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_contact_request' when calling ContactsApi.create_contact"
  end
  # resource path
  local_var_path = '/v1/contacts'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_contact_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateContact200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ContactsApi.create_contact",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContactsApi#create_contact\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_contact(contact_id, opts = {}) ⇒ nil

Delete contact Permanently deletes a contact and all associated channels.

Parameters:

  • contact_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


163
164
165
166
# File 'lib/zernio-sdk/api/contacts_api.rb', line 163

def delete_contact(contact_id, opts = {})
  delete_contact_with_http_info(contact_id, opts)
  nil
end

#delete_contact_with_http_info(contact_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete contact Permanently deletes a contact and all associated channels.

Parameters:

  • contact_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/zernio-sdk/api/contacts_api.rb', line 173

def delete_contact_with_http_info(contact_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContactsApi.delete_contact ...'
  end
  # verify the required parameter 'contact_id' is set
  if @api_client.config.client_side_validation && contact_id.nil?
    fail ArgumentError, "Missing the required parameter 'contact_id' when calling ContactsApi.delete_contact"
  end
  # resource path
  local_var_path = '/v1/contacts/{contactId}'.sub('{' + 'contactId' + '}', CGI.escape(contact_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ContactsApi.delete_contact",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContactsApi#delete_contact\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_contact(contact_id, opts = {}) ⇒ GetContact200Response

Get contact Returns a contact with all associated messaging channels.

Parameters:

  • contact_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



226
227
228
229
# File 'lib/zernio-sdk/api/contacts_api.rb', line 226

def get_contact(contact_id, opts = {})
  data, _status_code, _headers = get_contact_with_http_info(contact_id, opts)
  data
end

#get_contact_channels(contact_id, opts = {}) ⇒ GetContactChannels200Response

List channels for a contact Returns all messaging channels linked to a contact (e.g. Instagram DM, Telegram, WhatsApp).

Parameters:

  • contact_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



289
290
291
292
# File 'lib/zernio-sdk/api/contacts_api.rb', line 289

def get_contact_channels(contact_id, opts = {})
  data, _status_code, _headers = get_contact_channels_with_http_info(contact_id, opts)
  data
end

#get_contact_channels_with_http_info(contact_id, opts = {}) ⇒ Array<(GetContactChannels200Response, Integer, Hash)>

List channels for a contact Returns all messaging channels linked to a contact (e.g. Instagram DM, Telegram, WhatsApp).

Parameters:

  • contact_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/zernio-sdk/api/contacts_api.rb', line 299

def get_contact_channels_with_http_info(contact_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContactsApi.get_contact_channels ...'
  end
  # verify the required parameter 'contact_id' is set
  if @api_client.config.client_side_validation && contact_id.nil?
    fail ArgumentError, "Missing the required parameter 'contact_id' when calling ContactsApi.get_contact_channels"
  end
  # resource path
  local_var_path = '/v1/contacts/{contactId}/channels'.sub('{' + 'contactId' + '}', CGI.escape(contact_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetContactChannels200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ContactsApi.get_contact_channels",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContactsApi#get_contact_channels\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_contact_with_http_info(contact_id, opts = {}) ⇒ Array<(GetContact200Response, Integer, Hash)>

Get contact Returns a contact with all associated messaging channels.

Parameters:

  • contact_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetContact200Response, Integer, Hash)>)

    GetContact200Response data, response status code and response headers



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/zernio-sdk/api/contacts_api.rb', line 236

def get_contact_with_http_info(contact_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContactsApi.get_contact ...'
  end
  # verify the required parameter 'contact_id' is set
  if @api_client.config.client_side_validation && contact_id.nil?
    fail ArgumentError, "Missing the required parameter 'contact_id' when calling ContactsApi.get_contact"
  end
  # resource path
  local_var_path = '/v1/contacts/{contactId}'.sub('{' + 'contactId' + '}', CGI.escape(contact_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetContact200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ContactsApi.get_contact",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContactsApi#get_contact\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_contacts(opts = {}) ⇒ ListContacts200Response

List contacts List and search contacts for a profile. Supports filtering by tags, platform, subscription status, and full-text search.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :profile_id (String)

    Filter by profile. Omit to list across all profiles

  • :search (String)
  • :tag (String)
  • :platform (String)
  • :is_subscribed (String)
  • :limit (Integer) — default: default to 50
  • :skip (Integer) — default: default to 0

Returns:



358
359
360
361
# File 'lib/zernio-sdk/api/contacts_api.rb', line 358

def list_contacts(opts = {})
  data, _status_code, _headers = list_contacts_with_http_info(opts)
  data
end

#list_contacts_with_http_info(opts = {}) ⇒ Array<(ListContacts200Response, Integer, Hash)>

List contacts List and search contacts for a profile. Supports filtering by tags, platform, subscription status, and full-text search.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :profile_id (String)

    Filter by profile. Omit to list across all profiles

  • :search (String)
  • :tag (String)
  • :platform (String)
  • :is_subscribed (String)
  • :limit (Integer) — default: default to 50
  • :skip (Integer) — default: default to 0

Returns:

  • (Array<(ListContacts200Response, Integer, Hash)>)

    ListContacts200Response data, response status code and response headers



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/zernio-sdk/api/contacts_api.rb', line 374

def list_contacts_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContactsApi.list_contacts ...'
  end
  allowable_values = ["instagram", "facebook", "telegram", "twitter", "bluesky", "reddit", "whatsapp"]
  if @api_client.config.client_side_validation && opts[:'platform'] && !allowable_values.include?(opts[:'platform'])
    fail ArgumentError, "invalid value for \"platform\", must be one of #{allowable_values}"
  end
  allowable_values = ["true", "false"]
  if @api_client.config.client_side_validation && opts[:'is_subscribed'] && !allowable_values.include?(opts[:'is_subscribed'])
    fail ArgumentError, "invalid value for \"is_subscribed\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 200
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling ContactsApi.list_contacts, must be smaller than or equal to 200.'
  end

  # resource path
  local_var_path = '/v1/contacts'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'profileId'] = opts[:'profile_id'] if !opts[:'profile_id'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?
  query_params[:'tag'] = opts[:'tag'] if !opts[:'tag'].nil?
  query_params[:'platform'] = opts[:'platform'] if !opts[:'platform'].nil?
  query_params[:'isSubscribed'] = opts[:'is_subscribed'] if !opts[:'is_subscribed'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'skip'] = opts[:'skip'] if !opts[:'skip'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListContacts200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ContactsApi.list_contacts",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContactsApi#list_contacts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_contact(contact_id, opts = {}) ⇒ UpdateContact200Response

Update contact Update one or more fields on a contact. Only provided fields are changed.

Parameters:

  • contact_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



443
444
445
446
# File 'lib/zernio-sdk/api/contacts_api.rb', line 443

def update_contact(contact_id, opts = {})
  data, _status_code, _headers = update_contact_with_http_info(contact_id, opts)
  data
end

#update_contact_with_http_info(contact_id, opts = {}) ⇒ Array<(UpdateContact200Response, Integer, Hash)>

Update contact Update one or more fields on a contact. Only provided fields are changed.

Parameters:

  • contact_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(UpdateContact200Response, Integer, Hash)>)

    UpdateContact200Response data, response status code and response headers



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/zernio-sdk/api/contacts_api.rb', line 454

def update_contact_with_http_info(contact_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContactsApi.update_contact ...'
  end
  # verify the required parameter 'contact_id' is set
  if @api_client.config.client_side_validation && contact_id.nil?
    fail ArgumentError, "Missing the required parameter 'contact_id' when calling ContactsApi.update_contact"
  end
  # resource path
  local_var_path = '/v1/contacts/{contactId}'.sub('{' + 'contactId' + '}', CGI.escape(contact_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'update_contact_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'UpdateContact200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"ContactsApi.update_contact",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContactsApi#update_contact\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end