Class: Zernio::CreateAdCatalogFeedRequestSchedule

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateAdCatalogFeedRequestSchedule

Initializes the object



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateAdCatalogFeedRequestSchedule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateAdCatalogFeedRequestSchedule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'interval')
    self.interval = attributes[:'interval']
  else
    self.interval = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'hour')
    self.hour = attributes[:'hour']
  end

  if attributes.key?(:'day_of_week')
    self.day_of_week = attributes[:'day_of_week']
  end
end

Instance Attribute Details

#day_of_weekObject

Returns the value of attribute day_of_week.



24
25
26
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 24

def day_of_week
  @day_of_week
end

#hourObject

Returns the value of attribute hour.



22
23
24
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 22

def hour
  @hour
end

#intervalObject

Returns the value of attribute interval.



18
19
20
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 18

def interval
  @interval
end

#urlObject

Returns the value of attribute url.



20
21
22
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 20

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 49

def self.attribute_map
  {
    :'interval' => :'interval',
    :'url' => :'url',
    :'hour' => :'hour',
    :'day_of_week' => :'dayOfWeek'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 234

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 69

def self.openapi_types
  {
    :'interval' => :'String',
    :'url' => :'String',
    :'hour' => :'Integer',
    :'day_of_week' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



210
211
212
213
214
215
216
217
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      interval == o.interval &&
      url == o.url &&
      hour == o.hour &&
      day_of_week == o.day_of_week
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


221
222
223
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



227
228
229
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 227

def hash
  [interval, url, hour, day_of_week].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 123

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @interval.nil?
    invalid_properties.push('invalid value for "interval", interval cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if !@hour.nil? && @hour > 23
    invalid_properties.push('invalid value for "hour", must be smaller than or equal to 23.')
  end

  if !@hour.nil? && @hour < 0
    invalid_properties.push('invalid value for "hour", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/zernio-sdk/models/create_ad_catalog_feed_request_schedule.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @interval.nil?
  interval_validator = EnumAttributeValidator.new('String', ["HOURLY", "DAILY", "WEEKLY"])
  return false unless interval_validator.valid?(@interval)
  return false if @url.nil?
  return false if !@hour.nil? && @hour > 23
  return false if !@hour.nil? && @hour < 0
  day_of_week_validator = EnumAttributeValidator.new('String', ["SUNDAY", "MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY"])
  return false unless day_of_week_validator.valid?(@day_of_week)
  true
end