Class: Zernio::CreateAdInsightsReportRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_ad_insights_report_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateAdInsightsReportRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 136

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateAdInsightsReportRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateAdInsightsReportRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'object_id')
    self.object_id = attributes[:'object_id']
  else
    self.object_id = nil
  end

  if attributes.key?(:'level')
    self.level = attributes[:'level']
  end

  if attributes.key?(:'fields')
    self.fields = attributes[:'fields']
  end

  if attributes.key?(:'breakdowns')
    self.breakdowns = attributes[:'breakdowns']
  end

  if attributes.key?(:'action_breakdowns')
    self.action_breakdowns = attributes[:'action_breakdowns']
  end

  if attributes.key?(:'action_attribution_windows')
    if (value = attributes[:'action_attribution_windows']).is_a?(Array)
      self.action_attribution_windows = value
    end
  end

  if attributes.key?(:'action_report_time')
    self.action_report_time = attributes[:'action_report_time']
  end

  if attributes.key?(:'use_unified_attribution_setting')
    self.use_unified_attribution_setting = attributes[:'use_unified_attribution_setting']
  end

  if attributes.key?(:'filtering')
    if (value = attributes[:'filtering']).is_a?(Array)
      self.filtering = value
    end
  end

  if attributes.key?(:'date_preset')
    self.date_preset = attributes[:'date_preset']
  end

  if attributes.key?(:'from_date')
    self.from_date = attributes[:'from_date']
  end

  if attributes.key?(:'to_date')
    self.to_date = attributes[:'to_date']
  end

  if attributes.key?(:'time_increment')
    self.time_increment = attributes[:'time_increment']
  end
end

Instance Attribute Details

#account_idObject

Zernio SocialAccount id (posting or ads variant).



19
20
21
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 19

def 
  @account_id
end

#action_attribution_windowsObject

Meta attribution windows (e.g. ["7d_click", "1d_view"]). Action values are returned keyed per window.



36
37
38
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 36

def action_attribution_windows
  @action_attribution_windows
end

#action_breakdownsObject

Comma-separated Graph action breakdowns (e.g. action_type,action_destination).



33
34
35
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 33

def action_breakdowns
  @action_breakdowns
end

#action_report_timeObject

When actions are counted: impression, conversion or mixed.



39
40
41
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 39

def action_report_time
  @action_report_time
end

#breakdownsObject

Comma-separated Graph breakdowns.



30
31
32
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 30

def breakdowns
  @breakdowns
end

#date_presetObject

Mutually exclusive with fromDate/toDate.



48
49
50
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 48

def date_preset
  @date_preset
end

#fieldsObject

Comma-separated Graph insights fields.



27
28
29
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 27

def fields
  @fields
end

#filteringObject

Meta filter objects, applied server-side.



45
46
47
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 45

def filtering
  @filtering
end

#from_dateObject

Returns the value of attribute from_date.



50
51
52
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 50

def from_date
  @from_date
end

#levelObject

Returns the value of attribute level.



24
25
26
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 24

def level
  @level
end

#object_idObject

Meta insights node: act_, campaign id, ad set id or ad id.



22
23
24
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 22

def object_id
  @object_id
end

#time_incrementObject

Returns the value of attribute time_increment.



54
55
56
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 54

def time_increment
  @time_increment
end

#to_dateObject

Returns the value of attribute to_date.



52
53
54
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 52

def to_date
  @to_date
end

#use_unified_attribution_settingObject

Use the ad sets' own attribution settings for action counting.



42
43
44
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 42

def use_unified_attribution_setting
  @use_unified_attribution_setting
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



99
100
101
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 99

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 104

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 79

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'object_id' => :'objectId',
    :'level' => :'level',
    :'fields' => :'fields',
    :'breakdowns' => :'breakdowns',
    :'action_breakdowns' => :'actionBreakdowns',
    :'action_attribution_windows' => :'actionAttributionWindows',
    :'action_report_time' => :'actionReportTime',
    :'use_unified_attribution_setting' => :'useUnifiedAttributionSetting',
    :'filtering' => :'filtering',
    :'date_preset' => :'datePreset',
    :'from_date' => :'fromDate',
    :'to_date' => :'toDate',
    :'time_increment' => :'timeIncrement'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 308

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



129
130
131
132
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 129

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 109

def self.openapi_types
  {
    :'account_id' => :'String',
    :'object_id' => :'String',
    :'level' => :'String',
    :'fields' => :'String',
    :'breakdowns' => :'String',
    :'action_breakdowns' => :'String',
    :'action_attribution_windows' => :'Array<String>',
    :'action_report_time' => :'String',
    :'use_unified_attribution_setting' => :'Boolean',
    :'filtering' => :'Array<CreateAdInsightsReportRequestFilteringInner>',
    :'date_preset' => :'String',
    :'from_date' => :'Date',
    :'to_date' => :'Date',
    :'time_increment' => :'CreateAdInsightsReportRequestTimeIncrement'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      object_id == o.object_id &&
      level == o.level &&
      fields == o.fields &&
      breakdowns == o.breakdowns &&
      action_breakdowns == o.action_breakdowns &&
      action_attribution_windows == o.action_attribution_windows &&
      action_report_time == o.action_report_time &&
      use_unified_attribution_setting == o.use_unified_attribution_setting &&
      filtering == o.filtering &&
      date_preset == o.date_preset &&
      from_date == o.from_date &&
      to_date == o.to_date &&
      time_increment == o.time_increment
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


295
296
297
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 295

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



301
302
303
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 301

def hash
  [, object_id, level, fields, breakdowns, action_breakdowns, action_attribution_windows, action_report_time, use_unified_attribution_setting, filtering, date_preset, from_date, to_date, time_increment].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 217

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @object_id.nil?
    invalid_properties.push('invalid value for "object_id", object_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 330

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
238
239
240
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 233

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @object_id.nil?
  level_validator = EnumAttributeValidator.new('String', ["ad", "adset", "campaign", "account"])
  return false unless level_validator.valid?(@level)
  true
end