Class: Zernio::CreateBidStrategy201ResponseStrategy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateBidStrategy201ResponseStrategy
- Defined in:
- lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb
Instance Attribute Summary collapse
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#id ⇒ Object
Numeric bid strategy id; pass as portfolioBidStrategyId or in the strategyId path.
-
#resource_name ⇒ Object
Returns the value of attribute resource_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBidStrategy201ResponseStrategy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateBidStrategy201ResponseStrategy
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 61 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateBidStrategy201ResponseStrategy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateBidStrategy201ResponseStrategy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] end end |
Instance Attribute Details
#customer_id ⇒ Object
Returns the value of attribute customer_id.
18 19 20 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 18 def customer_id @customer_id end |
#id ⇒ Object
Numeric bid strategy id; pass as portfolioBidStrategyId or in the strategyId path.
21 22 23 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 21 def id @id end |
#resource_name ⇒ Object
Returns the value of attribute resource_name.
23 24 25 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 23 def resource_name @resource_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 26 def self.attribute_map { :'customer_id' => :'customerId', :'id' => :'id', :'resource_name' => :'resourceName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 128 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
54 55 56 57 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 54 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 45 def self.openapi_types { :'customer_id' => :'String', :'id' => :'String', :'resource_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
105 106 107 108 109 110 111 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 105 def ==(o) return true if self.equal?(o) self.class == o.class && customer_id == o.customer_id && id == o.id && resource_name == o.resource_name end |
#eql?(o) ⇒ Boolean
115 116 117 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 115 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
121 122 123 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 121 def hash [customer_id, id, resource_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
90 91 92 93 94 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 90 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 150 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
98 99 100 101 |
# File 'lib/zernio-sdk/models/create_bid_strategy201_response_strategy.rb', line 98 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |