Class: Zernio::CreateBidStrategyRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateBidStrategyRequest
- Defined in:
- lib/zernio-sdk/models/create_bid_strategy_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Google ads SocialAccount id.
-
#customer_id ⇒ Object
Numeric Google Ads customer id (no dashes).
-
#name ⇒ Object
Returns the value of attribute name.
-
#target_cpa ⇒ Object
Required when type is TARGET_CPA, in the account's currency units.
-
#target_roas ⇒ Object
Required when type is TARGET_ROAS; a multiplier (2.0 = 2.0x).
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBidStrategyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateBidStrategyRequest
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateBidStrategyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateBidStrategyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'target_cpa') self.target_cpa = attributes[:'target_cpa'] end if attributes.key?(:'target_roas') self.target_roas = attributes[:'target_roas'] end end |
Instance Attribute Details
#account_id ⇒ Object
Google ads SocialAccount id.
19 20 21 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 19 def account_id @account_id end |
#customer_id ⇒ Object
Numeric Google Ads customer id (no dashes). Defaults to the account's connected customer.
22 23 24 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 22 def customer_id @customer_id end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 24 def name @name end |
#target_cpa ⇒ Object
Required when type is TARGET_CPA, in the account's currency units.
29 30 31 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 29 def target_cpa @target_cpa end |
#target_roas ⇒ Object
Required when type is TARGET_ROAS; a multiplier (2.0 = 2.0x).
32 33 34 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 32 def target_roas @target_roas end |
#type ⇒ Object
Returns the value of attribute type.
26 27 28 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 26 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 57 def self.attribute_map { :'account_id' => :'accountId', :'customer_id' => :'customerId', :'name' => :'name', :'type' => :'type', :'target_cpa' => :'targetCpa', :'target_roas' => :'targetRoas' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 251 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 79 def self.openapi_types { :'account_id' => :'String', :'customer_id' => :'String', :'name' => :'String', :'type' => :'String', :'target_cpa' => :'Float', :'target_roas' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 234 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 225 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && customer_id == o.customer_id && name == o.name && type == o.type && target_cpa == o.target_cpa && target_roas == o.target_roas end |
#eql?(o) ⇒ Boolean
238 239 240 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 238 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
244 245 246 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 244 def hash [account_id, customer_id, name, type, target_cpa, target_roas].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 273 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/zernio-sdk/models/create_bid_strategy_request.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @name.nil? return false if @name.to_s.length > 255 return false if @name.to_s.length < 1 return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["TARGET_CPA", "TARGET_ROAS", "MAXIMIZE_CONVERSIONS", "MAXIMIZE_CONVERSION_VALUE"]) return false unless type_validator.valid?(@type) true end |