Class: Zernio::CreateContact200ResponseContact

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/create_contact200_response_contact.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateContact200ResponseContact

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateContact200ResponseContact` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateContact200ResponseContact`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'company')
    self.company = attributes[:'company']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'is_subscribed')
    self.is_subscribed = attributes[:'is_subscribed']
  end

  if attributes.key?(:'is_blocked')
    self.is_blocked = attributes[:'is_blocked']
  end

  if attributes.key?(:'custom_fields')
    self.custom_fields = attributes[:'custom_fields']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#companyObject

Returns the value of attribute company.



24
25
26
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 24

def company
  @company
end

#created_atObject

Returns the value of attribute created_at.



36
37
38
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 36

def created_at
  @created_at
end

#custom_fieldsObject

Returns the value of attribute custom_fields.



32
33
34
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 32

def custom_fields
  @custom_fields
end

#emailObject

Returns the value of attribute email.



22
23
24
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 22

def email
  @email
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 18

def id
  @id
end

#is_blockedObject

Returns the value of attribute is_blocked.



30
31
32
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 30

def is_blocked
  @is_blocked
end

#is_subscribedObject

Returns the value of attribute is_subscribed.



28
29
30
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 28

def is_subscribed
  @is_subscribed
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 20

def name
  @name
end

#notesObject

Returns the value of attribute notes.



34
35
36
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 34

def notes
  @notes
end

#tagsObject

Returns the value of attribute tags.



26
27
28
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 26

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 39

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'email' => :'email',
    :'company' => :'company',
    :'tags' => :'tags',
    :'is_subscribed' => :'isSubscribed',
    :'is_blocked' => :'isBlocked',
    :'custom_fields' => :'customFields',
    :'notes' => :'notes',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 65

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'email' => :'String',
    :'company' => :'String',
    :'tags' => :'Array<String>',
    :'is_subscribed' => :'Boolean',
    :'is_blocked' => :'Boolean',
    :'custom_fields' => :'Object',
    :'notes' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      email == o.email &&
      company == o.company &&
      tags == o.tags &&
      is_subscribed == o.is_subscribed &&
      is_blocked == o.is_blocked &&
      custom_fields == o.custom_fields &&
      notes == o.notes &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 185

def hash
  [id, name, email, company, tags, is_subscribed, is_blocked, custom_fields, notes, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
# File 'lib/zernio-sdk/models/create_contact200_response_contact.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end