Class: Zernio::CreateGoogleAssetGroupRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateGoogleAssetGroupRequest
- Defined in:
- lib/zernio-sdk/models/create_google_asset_group_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#assets ⇒ Object
Returns the value of attribute assets.
-
#final_mobile_urls ⇒ Object
Returns the value of attribute final_mobile_urls.
-
#final_urls ⇒ Object
Returns the value of attribute final_urls.
-
#listing_group_filter ⇒ Object
Returns the value of attribute listing_group_filter.
-
#name ⇒ Object
Unique within the campaign.
-
#path1 ⇒ Object
Returns the value of attribute path1.
-
#path2 ⇒ Object
Requires path1.
-
#status ⇒ Object
Returns the value of attribute status.
-
#validate_only ⇒ Object
Returns the value of attribute validate_only.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateGoogleAssetGroupRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateGoogleAssetGroupRequest
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateGoogleAssetGroupRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateGoogleAssetGroupRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'final_urls') if (value = attributes[:'final_urls']).is_a?(Array) self.final_urls = value end else self.final_urls = nil end if attributes.key?(:'final_mobile_urls') if (value = attributes[:'final_mobile_urls']).is_a?(Array) self.final_mobile_urls = value end end if attributes.key?(:'path1') self.path1 = attributes[:'path1'] end if attributes.key?(:'path2') self.path2 = attributes[:'path2'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'PAUSED' end if attributes.key?(:'assets') if (value = attributes[:'assets']).is_a?(Array) self.assets = value end end if attributes.key?(:'listing_group_filter') self.listing_group_filter = attributes[:'listing_group_filter'] end if attributes.key?(:'validate_only') self.validate_only = attributes[:'validate_only'] else self.validate_only = false end end |
Instance Attribute Details
#assets ⇒ Object
Returns the value of attribute assets.
32 33 34 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 32 def assets @assets end |
#final_mobile_urls ⇒ Object
Returns the value of attribute final_mobile_urls.
23 24 25 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 23 def final_mobile_urls @final_mobile_urls end |
#final_urls ⇒ Object
Returns the value of attribute final_urls.
21 22 23 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 21 def final_urls @final_urls end |
#listing_group_filter ⇒ Object
Returns the value of attribute listing_group_filter.
34 35 36 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 34 def listing_group_filter @listing_group_filter end |
#name ⇒ Object
Unique within the campaign.
19 20 21 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 19 def name @name end |
#path1 ⇒ Object
Returns the value of attribute path1.
25 26 27 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 25 def path1 @path1 end |
#path2 ⇒ Object
Requires path1.
28 29 30 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 28 def path2 @path2 end |
#status ⇒ Object
Returns the value of attribute status.
30 31 32 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 30 def status @status end |
#validate_only ⇒ Object
Returns the value of attribute validate_only.
36 37 38 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 36 def validate_only @validate_only end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
76 77 78 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 76 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 81 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 61 def self.attribute_map { :'name' => :'name', :'final_urls' => :'finalUrls', :'final_mobile_urls' => :'finalMobileUrls', :'path1' => :'path1', :'path2' => :'path2', :'status' => :'status', :'assets' => :'assets', :'listing_group_filter' => :'listingGroupFilter', :'validate_only' => :'validateOnly' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 382 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 86 def self.openapi_types { :'name' => :'String', :'final_urls' => :'Array<String>', :'final_mobile_urls' => :'Array<String>', :'path1' => :'String', :'path2' => :'String', :'status' => :'String', :'assets' => :'Array<GoogleAssetGroupAssetLink>', :'listing_group_filter' => :'GoogleListingGroupTree', :'validate_only' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 353 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && final_urls == o.final_urls && final_mobile_urls == o.final_mobile_urls && path1 == o.path1 && path2 == o.path2 && status == o.status && assets == o.assets && listing_group_filter == o.listing_group_filter && validate_only == o.validate_only end |
#eql?(o) ⇒ Boolean
369 370 371 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 369 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
375 376 377 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 375 def hash [name, final_urls, final_mobile_urls, path1, path2, status, assets, listing_group_filter, validate_only].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @final_urls.nil? invalid_properties.push('invalid value for "final_urls", final_urls cannot be nil.') end if @final_urls.length > 10 invalid_properties.push('invalid value for "final_urls", number of items must be less than or equal to 10.') end if @final_urls.length < 1 invalid_properties.push('invalid value for "final_urls", number of items must be greater than or equal to 1.') end if !@final_mobile_urls.nil? && @final_mobile_urls.length > 10 invalid_properties.push('invalid value for "final_mobile_urls", number of items must be less than or equal to 10.') end if !@final_mobile_urls.nil? && @final_mobile_urls.length < 1 invalid_properties.push('invalid value for "final_mobile_urls", number of items must be greater than or equal to 1.') end if !@path1.nil? && @path1.to_s.length > 15 invalid_properties.push('invalid value for "path1", the character length must be smaller than or equal to 15.') end if !@path2.nil? && @path2.to_s.length > 15 invalid_properties.push('invalid value for "path2", the character length must be smaller than or equal to 15.') end if !@assets.nil? && @assets.length > 100 invalid_properties.push('invalid value for "assets", number of items must be less than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 404 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/zernio-sdk/models/create_google_asset_group_request.rb', line 227 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 128 return false if @name.to_s.length < 1 return false if @final_urls.nil? return false if @final_urls.length > 10 return false if @final_urls.length < 1 return false if !@final_mobile_urls.nil? && @final_mobile_urls.length > 10 return false if !@final_mobile_urls.nil? && @final_mobile_urls.length < 1 return false if !@path1.nil? && @path1.to_s.length > 15 return false if !@path2.nil? && @path2.to_s.length > 15 status_validator = EnumAttributeValidator.new('String', ["ENABLED", "PAUSED"]) return false unless status_validator.valid?(@status) return false if !@assets.nil? && @assets.length > 100 true end |