Class: Zernio::CreateGoogleBusinessMediaRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateGoogleBusinessMediaRequest
- Defined in:
- lib/zernio-sdk/models/create_google_business_media_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#category ⇒ Object
Where the photo appears on the listing.
-
#description ⇒ Object
Photo description.
-
#media_format ⇒ Object
Returns the value of attribute media_format.
-
#source_url ⇒ Object
Publicly accessible image URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateGoogleBusinessMediaRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateGoogleBusinessMediaRequest
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateGoogleBusinessMediaRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateGoogleBusinessMediaRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'source_url') self.source_url = attributes[:'source_url'] else self.source_url = nil end if attributes.key?(:'media_format') self.media_format = attributes[:'media_format'] else self.media_format = 'PHOTO' end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'category') self.category = attributes[:'category'] end end |
Instance Attribute Details
#category ⇒ Object
Where the photo appears on the listing
27 28 29 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 27 def category @category end |
#description ⇒ Object
Photo description
24 25 26 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 24 def description @description end |
#media_format ⇒ Object
Returns the value of attribute media_format.
21 22 23 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 21 def media_format @media_format end |
#source_url ⇒ Object
Publicly accessible image URL
19 20 21 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 19 def source_url @source_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 52 def self.attribute_map { :'source_url' => :'sourceUrl', :'media_format' => :'mediaFormat', :'description' => :'description', :'category' => :'category' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 204 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 72 def self.openapi_types { :'source_url' => :'String', :'media_format' => :'String', :'description' => :'String', :'category' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && source_url == o.source_url && media_format == o.media_format && description == o.description && category == o.category end |
#eql?(o) ⇒ Boolean
191 192 193 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 191 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
197 198 199 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 197 def hash [source_url, media_format, description, category].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @source_url.nil? invalid_properties.push('invalid value for "source_url", source_url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 226 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 142 143 144 145 146 |
# File 'lib/zernio-sdk/models/create_google_business_media_request.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @source_url.nil? media_format_validator = EnumAttributeValidator.new('String', ["PHOTO", "VIDEO"]) return false unless media_format_validator.valid?(@media_format) category_validator = EnumAttributeValidator.new('String', ["COVER", "PROFILE", "LOGO", "EXTERIOR", "INTERIOR", "FOOD_AND_DRINK", "MENU", "PRODUCT", "TEAMS", "ADDITIONAL"]) return false unless category_validator.valid?(@category) true end |