Class: Zernio::CreateInboxConversationRequestTemplateCardsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateInboxConversationRequestTemplateCardsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateInboxConversationRequestTemplateCardsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateInboxConversationRequestTemplateCardsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'card_index')
    self.card_index = attributes[:'card_index']
  else
    self.card_index = nil
  end

  if attributes.key?(:'params')
    if (value = attributes[:'params']).is_a?(Array)
      self.params = value
    end
  end

  if attributes.key?(:'header_media')
    self.header_media = attributes[:'header_media']
  end

  if attributes.key?(:'buttons')
    if (value = attributes[:'buttons']).is_a?(Array)
      self.buttons = value
    end
  end
end

Instance Attribute Details

#buttonsObject

Values for this card's own buttons, each addressed by the button's index within the card.



27
28
29
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 27

def buttons
  @buttons
end

#card_indexObject

The card's card_index in the approved template.



19
20
21
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 19

def card_index
  @card_index
end

#header_mediaObject

Returns the value of attribute header_media.



24
25
26
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 24

def header_media
  @header_media
end

#paramsObject

Values for this card's own body variables, in the card's own {1}, {2}, ... order (or named-slot order of appearance).



22
23
24
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 22

def params
  @params
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 30

def self.attribute_map
  {
    :'card_index' => :'cardIndex',
    :'params' => :'params',
    :'header_media' => :'headerMedia',
    :'buttons' => :'buttons'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 50

def self.openapi_types
  {
    :'card_index' => :'Integer',
    :'params' => :'Array<String>',
    :'header_media' => :'CreateInboxConversationRequestTemplateCardsInnerHeaderMedia',
    :'buttons' => :'Array<CreateInboxConversationRequestTemplateCardsInnerButtonsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      card_index == o.card_index &&
      params == o.params &&
      header_media == o.header_media &&
      buttons == o.buttons
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 190

def hash
  [card_index, params, header_media, buttons].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 106

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @card_index.nil?
    invalid_properties.push('invalid value for "card_index", card_index cannot be nil.')
  end

  if @card_index > 9
    invalid_properties.push('invalid value for "card_index", must be smaller than or equal to 9.')
  end

  if @card_index < 0
    invalid_properties.push('invalid value for "card_index", must be greater than or equal to 0.')
  end

  if !@buttons.nil? && @buttons.length > 2
    invalid_properties.push('invalid value for "buttons", number of items must be less than or equal to 2.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
135
136
137
# File 'lib/zernio-sdk/models/create_inbox_conversation_request_template_cards_inner.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @card_index.nil?
  return false if @card_index > 9
  return false if @card_index < 0
  return false if !@buttons.nil? && @buttons.length > 2
  true
end