Class: Zernio::CreatePhoneNumberPortIn201Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreatePhoneNumberPortIn201Response
- Defined in:
- lib/zernio-sdk/models/create_phone_number_port_in201_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#id ⇒ Object
Porting order ID.
-
#orders ⇒ Object
Returns the value of attribute orders.
-
#phone_numbers ⇒ Object
Returns the value of attribute phone_numbers.
-
#status ⇒ Object
Returns the value of attribute status.
-
#telnyx_porting_order_id ⇒ Object
Returns the value of attribute telnyx_porting_order_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePhoneNumberPortIn201Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreatePhoneNumberPortIn201Response
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreatePhoneNumberPortIn201Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreatePhoneNumberPortIn201Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'telnyx_porting_order_id') self.telnyx_porting_order_id = attributes[:'telnyx_porting_order_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'phone_numbers') if (value = attributes[:'phone_numbers']).is_a?(Array) self.phone_numbers = value end end if attributes.key?(:'orders') if (value = attributes[:'orders']).is_a?(Array) self.orders = value end end end |
Instance Attribute Details
#id ⇒ Object
Porting order ID.
19 20 21 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 19 def id @id end |
#orders ⇒ Object
Returns the value of attribute orders.
27 28 29 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 27 def orders @orders end |
#phone_numbers ⇒ Object
Returns the value of attribute phone_numbers.
25 26 27 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 25 def phone_numbers @phone_numbers end |
#status ⇒ Object
Returns the value of attribute status.
23 24 25 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 23 def status @status end |
#telnyx_porting_order_id ⇒ Object
Returns the value of attribute telnyx_porting_order_id.
21 22 23 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 21 def telnyx_porting_order_id @telnyx_porting_order_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 52 def self.attribute_map { :'id' => :'id', :'telnyx_porting_order_id' => :'telnyxPortingOrderId', :'status' => :'status', :'phone_numbers' => :'phoneNumbers', :'orders' => :'orders' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 84 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 73 def self.openapi_types { :'id' => :'String', :'telnyx_porting_order_id' => :'String', :'status' => :'String', :'phone_numbers' => :'Array<String>', :'orders' => :'Array<CreatePhoneNumberPortIn201ResponseOrdersInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 166 167 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 159 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && telnyx_porting_order_id == o.telnyx_porting_order_id && status == o.status && phone_numbers == o.phone_numbers && orders == o.orders end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 177 def hash [id, telnyx_porting_order_id, status, phone_numbers, orders].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 144 145 |
# File 'lib/zernio-sdk/models/create_phone_number_port_in201_response.rb', line 140 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["draft", "pending", "foc_confirmed", "ported", "exception", "cancelled"]) return false unless status_validator.valid?(@status) true end |