Class: Zernio::CreateSequenceRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_sequence_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateSequenceRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateSequenceRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateSequenceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  else
    self.platform = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'steps')
    if (value = attributes[:'steps']).is_a?(Array)
      self.steps = value
    end
  end

  if attributes.key?(:'exit_on_reply')
    self.exit_on_reply = attributes[:'exit_on_reply']
  else
    self.exit_on_reply = true
  end

  if attributes.key?(:'exit_on_unsubscribe')
    self.exit_on_unsubscribe = attributes[:'exit_on_unsubscribe']
  else
    self.exit_on_unsubscribe = true
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



20
21
22
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 20

def 
  @account_id
end

#descriptionObject

Returns the value of attribute description.



26
27
28
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 26

def description
  @description
end

#exit_on_replyObject

Returns the value of attribute exit_on_reply.



30
31
32
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 30

def exit_on_reply
  @exit_on_reply
end

#exit_on_unsubscribeObject

Returns the value of attribute exit_on_unsubscribe.



32
33
34
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 32

def exit_on_unsubscribe
  @exit_on_unsubscribe
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 24

def name
  @name
end

#platformObject

Returns the value of attribute platform.



22
23
24
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 22

def platform
  @platform
end

#profile_idObject

Returns the value of attribute profile_id.



18
19
20
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 18

def profile_id
  @profile_id
end

#stepsObject

Returns the value of attribute steps.



28
29
30
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 28

def steps
  @steps
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 57

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'name' => :'name',
    :'description' => :'description',
    :'steps' => :'steps',
    :'exit_on_reply' => :'exitOnReply',
    :'exit_on_unsubscribe' => :'exitOnUnsubscribe'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 270

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 81

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'account_id' => :'String',
    :'platform' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'steps' => :'Array<CreateSequenceRequestStepsInner>',
    :'exit_on_reply' => :'Boolean',
    :'exit_on_unsubscribe' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
       == o. &&
      platform == o.platform &&
      name == o.name &&
      description == o.description &&
      steps == o.steps &&
      exit_on_reply == o.exit_on_reply &&
      exit_on_unsubscribe == o.exit_on_unsubscribe
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


257
258
259
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 257

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



263
264
265
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 263

def hash
  [profile_id, , platform, name, description, steps, exit_on_reply, exit_on_unsubscribe].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @platform.nil?
    invalid_properties.push('invalid value for "platform", platform cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 292

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
194
195
196
197
198
# File 'lib/zernio-sdk/models/create_sequence_request.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_id.nil?
  return false if @account_id.nil?
  return false if @platform.nil?
  platform_validator = EnumAttributeValidator.new('String', ["instagram", "facebook", "telegram", "twitter", "bluesky", "reddit", "whatsapp"])
  return false unless platform_validator.valid?(@platform)
  return false if @name.nil?
  true
end