Class: Zernio::CreateWhatsAppTemplateRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_whats_app_template_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateWhatsAppTemplateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateWhatsAppTemplateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateWhatsAppTemplateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = nil
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  else
    self.language = nil
  end

  if attributes.key?(:'parameter_format')
    self.parameter_format = attributes[:'parameter_format']
  end

  if attributes.key?(:'components')
    if (value = attributes[:'components']).is_a?(Array)
      self.components = value
    end
  end

  if attributes.key?(:'library_template_name')
    self.library_template_name = attributes[:'library_template_name']
  end

  if attributes.key?(:'library_template_body_inputs')
    self.library_template_body_inputs = attributes[:'library_template_body_inputs']
  end

  if attributes.key?(:'library_template_button_inputs')
    if (value = attributes[:'library_template_button_inputs']).is_a?(Array)
      self.library_template_button_inputs = value
    end
  end
end

Instance Attribute Details

#account_idObject

WhatsApp social account ID



19
20
21
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 19

def 
  @account_id
end

#categoryObject

Template category



25
26
27
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 25

def category
  @category
end

#componentsObject

Template components (header, body, footer, buttons, carousel, limited_time_offer). Required for custom templates, omit when using library_template_name.



34
35
36
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 34

def components
  @components
end

#languageObject

Template language code (e.g., en_US)



28
29
30
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 28

def language
  @language
end

#library_template_body_inputsObject

Optional body customizations for library templates. Available options depend on the template (e.g., add_contact_number, add_learn_more_link, add_security_recommendation, add_track_package_link, code_expiration_minutes).



40
41
42
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 40

def library_template_body_inputs
  @library_template_body_inputs
end

#library_template_button_inputsObject

Optional button customizations for library templates. Each item specifies button type and configuration (e.g., URL, phone number, quick reply).



43
44
45
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 43

def library_template_button_inputs
  @library_template_button_inputs
end

#library_template_nameObject

Name of a pre-built template from Meta's template library (e.g., "appointment_reminder", "auto_pay_reminder_1", "address_update"). When provided, the template is pre-approved by Meta with no review wait. Omit components when using this field.



37
38
39
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 37

def library_template_name
  @library_template_name
end

#nameObject

Template name (lowercase, letters/numbers/underscores, must start with a letter)



22
23
24
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 22

def name
  @name
end

#parameter_formatObject

Variable style: POSITIONAL ({1}, the default) or NAMED ({customer_name}). Named templates provide examples via body_text_named_params / header_text_named_params. Inferred as NAMED when omitted but a named-params example is present.



31
32
33
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 31

def parameter_format
  @parameter_format
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 68

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'category' => :'category',
    :'language' => :'language',
    :'parameter_format' => :'parameter_format',
    :'components' => :'components',
    :'library_template_name' => :'library_template_name',
    :'library_template_body_inputs' => :'library_template_body_inputs',
    :'library_template_button_inputs' => :'library_template_button_inputs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 328

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 93

def self.openapi_types
  {
    :'account_id' => :'String',
    :'name' => :'String',
    :'category' => :'String',
    :'language' => :'String',
    :'parameter_format' => :'String',
    :'components' => :'Array<WhatsAppTemplateComponent>',
    :'library_template_name' => :'String',
    :'library_template_body_inputs' => :'Object',
    :'library_template_button_inputs' => :'Array<CreateWhatsAppTemplateRequestLibraryTemplateButtonInputsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 299

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      category == o.category &&
      language == o.language &&
      parameter_format == o.parameter_format &&
      components == o.components &&
      library_template_name == o.library_template_name &&
      library_template_body_inputs == o.library_template_body_inputs &&
      library_template_button_inputs == o.library_template_button_inputs
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


315
316
317
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 315

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



321
322
323
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 321

def hash
  [, name, category, language, parameter_format, components, library_template_name, library_template_body_inputs, library_template_button_inputs].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 180

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  pattern = Regexp.new(/^[a-z][a-z0-9_]*$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @language.nil?
    invalid_properties.push('invalid value for "language", language cannot be nil.')
  end

  if !@components.nil? && @components.length < 1
    invalid_properties.push('invalid value for "components", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/zernio-sdk/models/create_whats_app_template_request.rb', line 213

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @name !~ Regexp.new(/^[a-z][a-z0-9_]*$/)
  return false if @category.nil?
  category_validator = EnumAttributeValidator.new('String', ["AUTHENTICATION", "MARKETING", "UTILITY"])
  return false unless category_validator.valid?(@category)
  return false if @language.nil?
  parameter_format_validator = EnumAttributeValidator.new('String', ["POSITIONAL", "NAMED", "positional", "named"])
  return false unless parameter_format_validator.valid?(@parameter_format)
  return false if !@components.nil? && @components.length < 1
  true
end