Class: Zernio::CtwaMultiResponse

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/ctwa_multi_response.rb

Overview

Response returned by POST /v1/ads/ctwa when the request used the multi-creative shape (creatives[]). N persisted Ad documents share the returned platformCampaignId and platformAdSetId. adType is the union discriminator.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CtwaMultiResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CtwaMultiResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CtwaMultiResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_type')
    self.ad_type = attributes[:'ad_type']
  else
    self.ad_type = nil
  end

  if attributes.key?(:'ads')
    if (value = attributes[:'ads']).is_a?(Array)
      self.ads = value
    end
  else
    self.ads = nil
  end

  if attributes.key?(:'platform_campaign_id')
    self.platform_campaign_id = attributes[:'platform_campaign_id']
  else
    self.platform_campaign_id = nil
  end

  if attributes.key?(:'platform_ad_set_id')
    self.platform_ad_set_id = attributes[:'platform_ad_set_id']
  else
    self.platform_ad_set_id = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end
end

Instance Attribute Details

#ad_typeObject

Returns the value of attribute ad_type.



19
20
21
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 19

def ad_type
  @ad_type
end

#adsObject

The persisted Ad documents (one per creative), all sharing the same platformCampaignId and platformAdSetId.



22
23
24
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 22

def ads
  @ads
end

#messageObject

Returns the value of attribute message.



28
29
30
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 28

def message
  @message
end

#platform_ad_set_idObject

Returns the value of attribute platform_ad_set_id.



26
27
28
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 26

def platform_ad_set_id
  @platform_ad_set_id
end

#platform_campaign_idObject

Returns the value of attribute platform_campaign_id.



24
25
26
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 24

def platform_campaign_id
  @platform_campaign_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 53

def self.attribute_map
  {
    :'ad_type' => :'adType',
    :'ads' => :'ads',
    :'platform_campaign_id' => :'platformCampaignId',
    :'platform_ad_set_id' => :'platformAdSetId',
    :'message' => :'message'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 258

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 74

def self.openapi_types
  {
    :'ad_type' => :'String',
    :'ads' => :'Array<Object>',
    :'platform_campaign_id' => :'String',
    :'platform_ad_set_id' => :'String',
    :'message' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



233
234
235
236
237
238
239
240
241
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 233

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ad_type == o.ad_type &&
      ads == o.ads &&
      platform_campaign_id == o.platform_campaign_id &&
      platform_ad_set_id == o.platform_ad_set_id &&
      message == o.message
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 251

def hash
  [ad_type, ads, platform_campaign_id, platform_ad_set_id, message].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ad_type.nil?
    invalid_properties.push('invalid value for "ad_type", ad_type cannot be nil.')
  end

  if @ads.nil?
    invalid_properties.push('invalid value for "ads", ads cannot be nil.')
  end

  if @platform_campaign_id.nil?
    invalid_properties.push('invalid value for "platform_campaign_id", platform_campaign_id cannot be nil.')
  end

  if @platform_ad_set_id.nil?
    invalid_properties.push('invalid value for "platform_ad_set_id", platform_ad_set_id cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
173
174
175
176
177
178
179
# File 'lib/zernio-sdk/models/ctwa_multi_response.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ad_type.nil?
  ad_type_validator = EnumAttributeValidator.new('String', ["multi"])
  return false unless ad_type_validator.valid?(@ad_type)
  return false if @ads.nil?
  return false if @platform_campaign_id.nil?
  return false if @platform_ad_set_id.nil?
  return false if @message.nil?
  true
end