Class: Zernio::CustomFieldsApi
- Inherits:
-
Object
- Object
- Zernio::CustomFieldsApi
- Defined in:
- lib/zernio-sdk/api/custom_fields_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#clear_contact_field_value(contact_id, slug, opts = {}) ⇒ nil
Clear custom field value Remove a custom field value from a contact.
-
#clear_contact_field_value_with_http_info(contact_id, slug, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Clear custom field value Remove a custom field value from a contact.
-
#create_custom_field(create_custom_field_request, opts = {}) ⇒ CreateCustomField200Response
Create custom field Create a new custom field definition.
-
#create_custom_field_with_http_info(create_custom_field_request, opts = {}) ⇒ Array<(CreateCustomField200Response, Integer, Hash)>
Create custom field Create a new custom field definition.
-
#delete_custom_field(field_id, opts = {}) ⇒ nil
Delete custom field Delete a custom field definition and remove its values from all contacts.
-
#delete_custom_field_with_http_info(field_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete custom field Delete a custom field definition and remove its values from all contacts.
-
#initialize(api_client = ApiClient.default) ⇒ CustomFieldsApi
constructor
A new instance of CustomFieldsApi.
-
#list_custom_fields(opts = {}) ⇒ ListCustomFields200Response
List custom field definitions Returns all custom field definitions.
-
#list_custom_fields_with_http_info(opts = {}) ⇒ Array<(ListCustomFields200Response, Integer, Hash)>
List custom field definitions Returns all custom field definitions.
-
#set_contact_field_value(contact_id, slug, set_contact_field_value_request, opts = {}) ⇒ nil
Set custom field value Set or overwrite a custom field value on a contact.
-
#set_contact_field_value_with_http_info(contact_id, slug, set_contact_field_value_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Set custom field value Set or overwrite a custom field value on a contact.
-
#update_custom_field(field_id, update_custom_field_request, opts = {}) ⇒ UpdateCustomField200Response
Update custom field Update a custom field definition.
-
#update_custom_field_with_http_info(field_id, update_custom_field_request, opts = {}) ⇒ Array<(UpdateCustomField200Response, Integer, Hash)>
Update custom field Update a custom field definition.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CustomFieldsApi
Returns a new instance of CustomFieldsApi.
19 20 21 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#clear_contact_field_value(contact_id, slug, opts = {}) ⇒ nil
Clear custom field value Remove a custom field value from a contact. The field definition is not affected.
28 29 30 31 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 28 def clear_contact_field_value(contact_id, slug, opts = {}) clear_contact_field_value_with_http_info(contact_id, slug, opts) nil end |
#clear_contact_field_value_with_http_info(contact_id, slug, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Clear custom field value Remove a custom field value from a contact. The field definition is not affected.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 39 def clear_contact_field_value_with_http_info(contact_id, slug, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomFieldsApi.clear_contact_field_value ...' end # verify the required parameter 'contact_id' is set if @api_client.config.client_side_validation && contact_id.nil? fail ArgumentError, "Missing the required parameter 'contact_id' when calling CustomFieldsApi.clear_contact_field_value" end # verify the required parameter 'slug' is set if @api_client.config.client_side_validation && slug.nil? fail ArgumentError, "Missing the required parameter 'slug' when calling CustomFieldsApi.clear_contact_field_value" end # resource path local_var_path = '/v1/contacts/{contactId}/fields/{slug}'.sub('{' + 'contactId' + '}', CGI.escape(contact_id.to_s)).sub('{' + 'slug' + '}', CGI.escape(slug.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CustomFieldsApi.clear_contact_field_value", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomFieldsApi#clear_contact_field_value\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_custom_field(create_custom_field_request, opts = {}) ⇒ CreateCustomField200Response
Create custom field Create a new custom field definition. Supported types are text, number, date, boolean, and select.
96 97 98 99 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 96 def create_custom_field(create_custom_field_request, opts = {}) data, _status_code, _headers = create_custom_field_with_http_info(create_custom_field_request, opts) data end |
#create_custom_field_with_http_info(create_custom_field_request, opts = {}) ⇒ Array<(CreateCustomField200Response, Integer, Hash)>
Create custom field Create a new custom field definition. Supported types are text, number, date, boolean, and select.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 106 def create_custom_field_with_http_info(create_custom_field_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomFieldsApi.create_custom_field ...' end # verify the required parameter 'create_custom_field_request' is set if @api_client.config.client_side_validation && create_custom_field_request.nil? fail ArgumentError, "Missing the required parameter 'create_custom_field_request' when calling CustomFieldsApi.create_custom_field" end # resource path local_var_path = '/v1/custom-fields' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_custom_field_request) # return_type return_type = opts[:debug_return_type] || 'CreateCustomField200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CustomFieldsApi.create_custom_field", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomFieldsApi#create_custom_field\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_custom_field(field_id, opts = {}) ⇒ nil
Delete custom field Delete a custom field definition and remove its values from all contacts.
164 165 166 167 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 164 def delete_custom_field(field_id, opts = {}) delete_custom_field_with_http_info(field_id, opts) nil end |
#delete_custom_field_with_http_info(field_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete custom field Delete a custom field definition and remove its values from all contacts.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 174 def delete_custom_field_with_http_info(field_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomFieldsApi.delete_custom_field ...' end # verify the required parameter 'field_id' is set if @api_client.config.client_side_validation && field_id.nil? fail ArgumentError, "Missing the required parameter 'field_id' when calling CustomFieldsApi.delete_custom_field" end # resource path local_var_path = '/v1/custom-fields/{fieldId}'.sub('{' + 'fieldId' + '}', CGI.escape(field_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CustomFieldsApi.delete_custom_field", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomFieldsApi#delete_custom_field\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_custom_fields(opts = {}) ⇒ ListCustomFields200Response
List custom field definitions Returns all custom field definitions. Optionally filter by profile.
227 228 229 230 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 227 def list_custom_fields(opts = {}) data, _status_code, _headers = list_custom_fields_with_http_info(opts) data end |
#list_custom_fields_with_http_info(opts = {}) ⇒ Array<(ListCustomFields200Response, Integer, Hash)>
List custom field definitions Returns all custom field definitions. Optionally filter by profile.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 237 def list_custom_fields_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomFieldsApi.list_custom_fields ...' end # resource path local_var_path = '/v1/custom-fields' # query parameters query_params = opts[:query_params] || {} query_params[:'profileId'] = opts[:'profile_id'] if !opts[:'profile_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCustomFields200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CustomFieldsApi.list_custom_fields", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomFieldsApi#list_custom_fields\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_contact_field_value(contact_id, slug, set_contact_field_value_request, opts = {}) ⇒ nil
Set custom field value Set or overwrite a custom field value on a contact. The value type must match the field definition.
289 290 291 292 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 289 def set_contact_field_value(contact_id, slug, set_contact_field_value_request, opts = {}) set_contact_field_value_with_http_info(contact_id, slug, set_contact_field_value_request, opts) nil end |
#set_contact_field_value_with_http_info(contact_id, slug, set_contact_field_value_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Set custom field value Set or overwrite a custom field value on a contact. The value type must match the field definition.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 301 def set_contact_field_value_with_http_info(contact_id, slug, set_contact_field_value_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomFieldsApi.set_contact_field_value ...' end # verify the required parameter 'contact_id' is set if @api_client.config.client_side_validation && contact_id.nil? fail ArgumentError, "Missing the required parameter 'contact_id' when calling CustomFieldsApi.set_contact_field_value" end # verify the required parameter 'slug' is set if @api_client.config.client_side_validation && slug.nil? fail ArgumentError, "Missing the required parameter 'slug' when calling CustomFieldsApi.set_contact_field_value" end # verify the required parameter 'set_contact_field_value_request' is set if @api_client.config.client_side_validation && set_contact_field_value_request.nil? fail ArgumentError, "Missing the required parameter 'set_contact_field_value_request' when calling CustomFieldsApi.set_contact_field_value" end # resource path local_var_path = '/v1/contacts/{contactId}/fields/{slug}'.sub('{' + 'contactId' + '}', CGI.escape(contact_id.to_s)).sub('{' + 'slug' + '}', CGI.escape(slug.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(set_contact_field_value_request) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CustomFieldsApi.set_contact_field_value", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomFieldsApi#set_contact_field_value\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_custom_field(field_id, update_custom_field_request, opts = {}) ⇒ UpdateCustomField200Response
Update custom field Update a custom field definition. The field type cannot be changed after creation.
368 369 370 371 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 368 def update_custom_field(field_id, update_custom_field_request, opts = {}) data, _status_code, _headers = update_custom_field_with_http_info(field_id, update_custom_field_request, opts) data end |
#update_custom_field_with_http_info(field_id, update_custom_field_request, opts = {}) ⇒ Array<(UpdateCustomField200Response, Integer, Hash)>
Update custom field Update a custom field definition. The field type cannot be changed after creation.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/zernio-sdk/api/custom_fields_api.rb', line 379 def update_custom_field_with_http_info(field_id, update_custom_field_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomFieldsApi.update_custom_field ...' end # verify the required parameter 'field_id' is set if @api_client.config.client_side_validation && field_id.nil? fail ArgumentError, "Missing the required parameter 'field_id' when calling CustomFieldsApi.update_custom_field" end # verify the required parameter 'update_custom_field_request' is set if @api_client.config.client_side_validation && update_custom_field_request.nil? fail ArgumentError, "Missing the required parameter 'update_custom_field_request' when calling CustomFieldsApi.update_custom_field" end # resource path local_var_path = '/v1/custom-fields/{fieldId}'.sub('{' + 'fieldId' + '}', CGI.escape(field_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_custom_field_request) # return_type return_type = opts[:debug_return_type] || 'UpdateCustomField200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"CustomFieldsApi.update_custom_field", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomFieldsApi#update_custom_field\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |