Class: Zernio::DialVoiceWebCall200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/dial_voice_web_call200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DialVoiceWebCall200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::DialVoiceWebCall200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::DialVoiceWebCall200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'call_id')
    self.call_id = attributes[:'call_id']
  end

  if attributes.key?(:'telnyx_call_control_id')
    self.telnyx_call_control_id = attributes[:'telnyx_call_control_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'recording_enabled')
    self.recording_enabled = attributes[:'recording_enabled']
  end
end

Instance Attribute Details

#call_idObject

Returns the value of attribute call_id.



20
21
22
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 20

def call_id
  @call_id
end

#directionObject

Returns the value of attribute direction.



26
27
28
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 26

def direction
  @direction
end

#fromObject

Returns the value of attribute from.



28
29
30
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 28

def from
  @from
end

#recording_enabledObject

Returns the value of attribute recording_enabled.



32
33
34
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 32

def recording_enabled
  @recording_enabled
end

#statusObject

Returns the value of attribute status.



24
25
26
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 24

def status
  @status
end

#successObject

Returns the value of attribute success.



18
19
20
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 18

def success
  @success
end

#telnyx_call_control_idObject

Returns the value of attribute telnyx_call_control_id.



22
23
24
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 22

def telnyx_call_control_id
  @telnyx_call_control_id
end

#toObject

Returns the value of attribute to.



30
31
32
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 30

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 57

def self.attribute_map
  {
    :'success' => :'success',
    :'call_id' => :'callId',
    :'telnyx_call_control_id' => :'telnyxCallControlId',
    :'status' => :'status',
    :'direction' => :'direction',
    :'from' => :'from',
    :'to' => :'to',
    :'recording_enabled' => :'recordingEnabled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 81

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'call_id' => :'String',
    :'telnyx_call_control_id' => :'String',
    :'status' => :'String',
    :'direction' => :'String',
    :'from' => :'String',
    :'to' => :'String',
    :'recording_enabled' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
      call_id == o.call_id &&
      telnyx_call_control_id == o.telnyx_call_control_id &&
      status == o.status &&
      direction == o.direction &&
      from == o.from &&
      to == o.to &&
      recording_enabled == o.recording_enabled
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 211

def hash
  [success, call_id, telnyx_call_control_id, status, direction, from, to, recording_enabled].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
163
164
165
166
# File 'lib/zernio-sdk/models/dial_voice_web_call200_response.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["dialing"])
  return false unless status_validator.valid?(@status)
  direction_validator = EnumAttributeValidator.new('String', ["outbound"])
  return false unless direction_validator.valid?(@direction)
  true
end