Class: Zernio::DialVoiceWebCallRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/dial_voice_web_call_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DialVoiceWebCallRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::DialVoiceWebCallRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::DialVoiceWebCallRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  else
    self.to = nil
  end

  if attributes.key?(:'credential_id')
    self.credential_id = attributes[:'credential_id']
  else
    self.credential_id = nil
  end

  if attributes.key?(:'from_number')
    self.from_number = attributes[:'from_number']
  end

  if attributes.key?(:'record_override')
    self.record_override = attributes[:'record_override']
  end
end

Instance Attribute Details

#credential_idObject

The WebRTC credential id returned by POST /v1/voice/calls/web (the registered browser).



22
23
24
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 22

def credential_id
  @credential_id
end

#from_numberObject

Which of your voice-enabled numbers to call from (optional when you have one).



25
26
27
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 25

def from_number
  @from_number
end

#record_overrideObject

Returns the value of attribute record_override.



27
28
29
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 27

def record_override
  @record_override
end

#toObject

The number to call, E.164 with leading +.



19
20
21
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 19

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 30

def self.attribute_map
  {
    :'to' => :'to',
    :'credential_id' => :'credentialId',
    :'from_number' => :'fromNumber',
    :'record_override' => :'recordOverride'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 205

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 50

def self.openapi_types
  {
    :'to' => :'String',
    :'credential_id' => :'String',
    :'from_number' => :'String',
    :'record_override' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      to == o.to &&
      credential_id == o.credential_id &&
      from_number == o.from_number &&
      record_override == o.record_override
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


192
193
194
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 192

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



198
199
200
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 198

def hash
  [to, credential_id, from_number, record_override].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 104

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  pattern = Regexp.new(/^\+\d{6,15}$/)
  if @to !~ pattern
    invalid_properties.push("invalid value for \"to\", must conform to the pattern #{pattern}.")
  end

  if @credential_id.nil?
    invalid_properties.push('invalid value for "credential_id", credential_id cannot be nil.')
  end

  pattern = Regexp.new(/^\+\d{6,15}$/)
  if !@from_number.nil? && @from_number !~ pattern
    invalid_properties.push("invalid value for \"from_number\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 227

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
135
136
137
# File 'lib/zernio-sdk/models/dial_voice_web_call_request.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @to.nil?
  return false if @to !~ Regexp.new(/^\+\d{6,15}$/)
  return false if @credential_id.nil?
  return false if !@from_number.nil? && @from_number !~ Regexp.new(/^\+\d{6,15}$/)
  true
end