Class: Zernio::DiscordPlatformDataPoll

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/discord_platform_data_poll.rb

Overview

Native Discord poll. Cannot be combined with media attachments in the same message.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DiscordPlatformDataPoll

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::DiscordPlatformDataPoll` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::DiscordPlatformDataPoll`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'question')
    self.question = attributes[:'question']
  end

  if attributes.key?(:'answers')
    if (value = attributes[:'answers']).is_a?(Array)
      self.answers = value
    end
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'allow_multiselect')
    self.allow_multiselect = attributes[:'allow_multiselect']
  end
end

Instance Attribute Details

#allow_multiselectObject

Allow users to select multiple answers. Default false.



28
29
30
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 28

def allow_multiselect
  @allow_multiselect
end

#answersObject

1-10 answer options



22
23
24
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 22

def answers
  @answers
end

#durationObject

Poll duration in hours (1-768). Default 24.



25
26
27
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 25

def duration
  @duration
end

#questionObject

Returns the value of attribute question.



19
20
21
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 19

def question
  @question
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 31

def self.attribute_map
  {
    :'question' => :'question',
    :'answers' => :'answers',
    :'duration' => :'duration',
    :'allow_multiselect' => :'allow_multiselect'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 51

def self.openapi_types
  {
    :'question' => :'DiscordPlatformDataPollQuestion',
    :'answers' => :'Array<DiscordPlatformDataPollAnswersInner>',
    :'duration' => :'Integer',
    :'allow_multiselect' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      question == o.question &&
      answers == o.answers &&
      duration == o.duration &&
      allow_multiselect == o.allow_multiselect
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 182

def hash
  [question, answers, duration, allow_multiselect].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 103

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@answers.nil? && @answers.length > 10
    invalid_properties.push('invalid value for "answers", number of items must be less than or equal to 10.')
  end

  if !@duration.nil? && @duration > 768
    invalid_properties.push('invalid value for "duration", must be smaller than or equal to 768.')
  end

  if !@duration.nil? && @duration < 1
    invalid_properties.push('invalid value for "duration", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
127
128
129
# File 'lib/zernio-sdk/models/discord_platform_data_poll.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@answers.nil? && @answers.length > 10
  return false if !@duration.nil? && @duration > 768
  return false if !@duration.nil? && @duration < 1
  true
end