Class: Zernio::DuplicateWorkflow201ResponseWorkflow

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DuplicateWorkflow201ResponseWorkflow

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::DuplicateWorkflow201ResponseWorkflow` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::DuplicateWorkflow201ResponseWorkflow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'entry_node_id')
    self.entry_node_id = attributes[:'entry_node_id']
  end

  if attributes.key?(:'node_count')
    self.node_count = attributes[:'node_count']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



28
29
30
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 28

def 
  @account_id
end

#created_atObject

Returns the value of attribute created_at.



36
37
38
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 36

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 22

def description
  @description
end

#entry_node_idObject

Returns the value of attribute entry_node_id.



32
33
34
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 32

def entry_node_id
  @entry_node_id
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 18

def id
  @id
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 20

def name
  @name
end

#node_countObject

Returns the value of attribute node_count.



34
35
36
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 34

def node_count
  @node_count
end

#platformObject

Returns the value of attribute platform.



26
27
28
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 26

def platform
  @platform
end

#profile_idObject

Returns the value of attribute profile_id.



30
31
32
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 30

def profile_id
  @profile_id
end

#statusObject

Returns the value of attribute status.



24
25
26
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 24

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 61

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'status' => :'status',
    :'platform' => :'platform',
    :'account_id' => :'accountId',
    :'profile_id' => :'profileId',
    :'entry_node_id' => :'entryNodeId',
    :'node_count' => :'nodeCount',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 225

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
107
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 103

def self.openapi_nullable
  Set.new([
    :'entry_node_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 87

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'status' => :'String',
    :'platform' => :'String',
    :'account_id' => :'String',
    :'profile_id' => :'String',
    :'entry_node_id' => :'String',
    :'node_count' => :'Integer',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      status == o.status &&
      platform == o.platform &&
       == o. &&
      profile_id == o.profile_id &&
      entry_node_id == o.entry_node_id &&
      node_count == o.node_count &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 212

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



218
219
220
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 218

def hash
  [id, name, description, status, platform, , profile_id, entry_node_id, node_count, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 247

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
# File 'lib/zernio-sdk/models/duplicate_workflow201_response_workflow.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["draft"])
  return false unless status_validator.valid?(@status)
  true
end