Class: Zernio::EditGoogleAssetGroupAssetsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EditGoogleAssetGroupAssetsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 60

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::EditGoogleAssetGroupAssetsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::EditGoogleAssetGroupAssetsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'link')
    if (value = attributes[:'link']).is_a?(Array)
      self.link = value
    end
  end

  if attributes.key?(:'unlink')
    if (value = attributes[:'unlink']).is_a?(Array)
      self.unlink = value
    end
  end

  if attributes.key?(:'validate_only')
    self.validate_only = attributes[:'validate_only']
  else
    self.validate_only = false
  end
end

Instance Attribute Details

Returns the value of attribute link.



18
19
20
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 18

def link
  @link
end

Returns the value of attribute unlink.



20
21
22
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 20

def unlink
  @unlink
end

#validate_only ⇒ Object

Returns the value of attribute validate_only.



22
23
24
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 22

def validate_only
  @validate_only
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



34
35
36
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 25

def self.attribute_map
  {
    :'link' => :'link',
    :'unlink' => :'unlink',
    :'validate_only' => :'validateOnly'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



53
54
55
56
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 53

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



44
45
46
47
48
49
50
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 44

def self.openapi_types
  {
    :'link' => :'Array<GoogleAssetGroupAssetLink>',
    :'unlink' => :'Array<GoogleAssetGroupAssetUnlink>',
    :'validate_only' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



148
149
150
151
152
153
154
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      link == o.link &&
      unlink == o.unlink &&
      validate_only == o.validate_only
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 158

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



164
165
166
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 164

def hash
  [link, unlink, validate_only].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 95

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@link.nil? && @link.length > 100
    invalid_properties.push('invalid value for "link", number of items must be less than or equal to 100.')
  end

  if !@unlink.nil? && @unlink.length > 100
    invalid_properties.push('invalid value for "unlink", number of items must be less than or equal to 100.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



111
112
113
114
115
116
# File 'lib/zernio-sdk/models/edit_google_asset_group_assets_request.rb', line 111

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@link.nil? && @link.length > 100
  return false if !@unlink.nil? && @unlink.length > 100
  true
end