Class: Zernio::GMBLocationDetailsApi
- Inherits:
-
Object
- Object
- Zernio::GMBLocationDetailsApi
- Defined in:
- lib/zernio-sdk/api/gmb_location_details_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_google_business_location_details(account_id, opts = {}) ⇒ GetGoogleBusinessLocationDetails200Response
Get location details Returns detailed GBP location info (hours, description, phone, website, categories, services).
-
#get_google_business_location_details_with_http_info(account_id, opts = {}) ⇒ Array<(GetGoogleBusinessLocationDetails200Response, Integer, Hash)>
Get location details Returns detailed GBP location info (hours, description, phone, website, categories, services).
-
#initialize(api_client = ApiClient.default) ⇒ GMBLocationDetailsApi
constructor
A new instance of GMBLocationDetailsApi.
-
#update_google_business_location_details(account_id, update_google_business_location_details_request, opts = {}) ⇒ UpdateGoogleBusinessLocationDetails200Response
Update location details Updates GBP location details.
-
#update_google_business_location_details_with_http_info(account_id, update_google_business_location_details_request, opts = {}) ⇒ Array<(UpdateGoogleBusinessLocationDetails200Response, Integer, Hash)>
Update location details Updates GBP location details.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ GMBLocationDetailsApi
Returns a new instance of GMBLocationDetailsApi.
19 20 21 |
# File 'lib/zernio-sdk/api/gmb_location_details_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zernio-sdk/api/gmb_location_details_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_google_business_location_details(account_id, opts = {}) ⇒ GetGoogleBusinessLocationDetails200Response
Get location details Returns detailed GBP location info (hours, description, phone, website, categories, services). Use readMask to request specific fields.
29 30 31 32 |
# File 'lib/zernio-sdk/api/gmb_location_details_api.rb', line 29 def get_google_business_location_details(account_id, opts = {}) data, _status_code, _headers = get_google_business_location_details_with_http_info(account_id, opts) data end |
#get_google_business_location_details_with_http_info(account_id, opts = {}) ⇒ Array<(GetGoogleBusinessLocationDetails200Response, Integer, Hash)>
Get location details Returns detailed GBP location info (hours, description, phone, website, categories, services). Use readMask to request specific fields.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zernio-sdk/api/gmb_location_details_api.rb', line 41 def get_google_business_location_details_with_http_info(account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBLocationDetailsApi.get_google_business_location_details ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBLocationDetailsApi.get_google_business_location_details" end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-location-details'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? query_params[:'readMask'] = opts[:'read_mask'] if !opts[:'read_mask'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetGoogleBusinessLocationDetails200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBLocationDetailsApi.get_google_business_location_details", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBLocationDetailsApi#get_google_business_location_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_google_business_location_details(account_id, update_google_business_location_details_request, opts = {}) ⇒ UpdateGoogleBusinessLocationDetails200Response
Update location details Updates GBP location details. The updateMask field is required and specifies which fields to update. This endpoint proxies Google's Business Information API locations.patch, so any valid updateMask field is supported. Common fields: regularHours, specialHours, profile.description, websiteUri, phoneNumbers, categories, serviceItems.
98 99 100 101 |
# File 'lib/zernio-sdk/api/gmb_location_details_api.rb', line 98 def update_google_business_location_details(account_id, update_google_business_location_details_request, opts = {}) data, _status_code, _headers = update_google_business_location_details_with_http_info(account_id, update_google_business_location_details_request, opts) data end |
#update_google_business_location_details_with_http_info(account_id, update_google_business_location_details_request, opts = {}) ⇒ Array<(UpdateGoogleBusinessLocationDetails200Response, Integer, Hash)>
Update location details Updates GBP location details. The updateMask field is required and specifies which fields to update. This endpoint proxies Google's Business Information API locations.patch, so any valid updateMask field is supported. Common fields: regularHours, specialHours, profile.description, websiteUri, phoneNumbers, categories, serviceItems.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/zernio-sdk/api/gmb_location_details_api.rb', line 110 def update_google_business_location_details_with_http_info(account_id, update_google_business_location_details_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBLocationDetailsApi.update_google_business_location_details ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBLocationDetailsApi.update_google_business_location_details" end # verify the required parameter 'update_google_business_location_details_request' is set if @api_client.config.client_side_validation && update_google_business_location_details_request.nil? fail ArgumentError, "Missing the required parameter 'update_google_business_location_details_request' when calling GMBLocationDetailsApi.update_google_business_location_details" end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-location-details'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_google_business_location_details_request) # return_type return_type = opts[:debug_return_type] || 'UpdateGoogleBusinessLocationDetails200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBLocationDetailsApi.update_google_business_location_details", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBLocationDetailsApi#update_google_business_location_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |