Class: Zernio::GenerateAdPreviewsRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/generate_ad_previews_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GenerateAdPreviewsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GenerateAdPreviewsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GenerateAdPreviewsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'formats')
    if (value = attributes[:'formats']).is_a?(Array)
      self.formats = value
    end
  end

  if attributes.key?(:'existing_creative_id')
    self.existing_creative_id = attributes[:'existing_creative_id']
  end

  if attributes.key?(:'creative_spec')
    if (value = attributes[:'creative_spec']).is_a?(Hash)
      self.creative_spec = value
    end
  end
end

Instance Attribute Details

#account_idObject

Zernio SocialAccount id used to resolve the Meta token.



19
20
21
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 19

def 
  @account_id
end

#ad_account_idObject

Meta ad account id (act_).



22
23
24
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 22

def 
  @ad_account_id
end

#creative_specObject

Raw Meta creative spec forwarded verbatim to /generatepreviews. Mutually exclusive with existingCreativeId.



31
32
33
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 31

def creative_spec
  @creative_spec
end

#existing_creative_idObject

Preview an existing ad-account creative by id. Mutually exclusive with creativeSpec.



28
29
30
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 28

def existing_creative_id
  @existing_creative_id
end

#formatsObject

Meta ad_format values, one preview per format. Defaults to [DESKTOP_FEED_STANDARD].



25
26
27
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 25

def formats
  @formats
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 34

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'ad_account_id' => :'adAccountId',
    :'formats' => :'formats',
    :'existing_creative_id' => :'existingCreativeId',
    :'creative_spec' => :'creativeSpec'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 216

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 55

def self.openapi_types
  {
    :'account_id' => :'String',
    :'ad_account_id' => :'String',
    :'formats' => :'Array<String>',
    :'existing_creative_id' => :'String',
    :'creative_spec' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      formats == o.formats &&
      existing_creative_id == o.existing_creative_id &&
      creative_spec == o.creative_spec
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 203

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 209

def hash
  [, , formats, existing_creative_id, creative_spec].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @ad_account_id.nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  if !@formats.nil? && @formats.length > 10
    invalid_properties.push('invalid value for "formats", number of items must be less than or equal to 10.')
  end

  if !@formats.nil? && @formats.length < 1
    invalid_properties.push('invalid value for "formats", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
148
149
# File 'lib/zernio-sdk/models/generate_ad_previews_request.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @ad_account_id.nil?
  return false if !@formats.nil? && @formats.length > 10
  return false if !@formats.nil? && @formats.length < 1
  true
end