Class: Zernio::GenerateKeywordIdeasRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/generate_keyword_ideas_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GenerateKeywordIdeasRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GenerateKeywordIdeasRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GenerateKeywordIdeasRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'seed_keywords')
    if (value = attributes[:'seed_keywords']).is_a?(Array)
      self.seed_keywords = value
    end
  end

  if attributes.key?(:'seed_url')
    self.seed_url = attributes[:'seed_url']
  end

  if attributes.key?(:'countries')
    if (value = attributes[:'countries']).is_a?(Array)
      self.countries = value
    end
  end

  if attributes.key?(:'language_constant_id')
    self.language_constant_id = attributes[:'language_constant_id']
  else
    self.language_constant_id = '1000'
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  else
    self.network = 'GOOGLE_SEARCH'
  end

  if attributes.key?(:'include_adult_keywords')
    self.include_adult_keywords = attributes[:'include_adult_keywords']
  end

  if attributes.key?(:'page_size')
    self.page_size = attributes[:'page_size']
  end

  if attributes.key?(:'page_token')
    self.page_token = attributes[:'page_token']
  end
end

Instance Attribute Details

#account_idObject

Zernio googleads SocialAccount id.



19
20
21
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 19

def 
  @account_id
end

#countriesObject

ISO 3166-1 alpha-2 country codes. Omitted = worldwide.



31
32
33
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 31

def countries
  @countries
end

#customer_idObject

Numeric Google Ads customer id (no dashes); only needed when the connection has several accounts.



22
23
24
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 22

def customer_id
  @customer_id
end

#include_adult_keywordsObject

Returns the value of attribute include_adult_keywords.



38
39
40
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 38

def include_adult_keywords
  @include_adult_keywords
end

#language_constant_idObject

Google languageConstant id (1000 = English).



34
35
36
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 34

def language_constant_id
  @language_constant_id
end

#networkObject

Returns the value of attribute network.



36
37
38
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 36

def network
  @network
end

#page_sizeObject

Returns the value of attribute page_size.



40
41
42
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 40

def page_size
  @page_size
end

#page_tokenObject

Cursor from paging.nextPageToken of the previous page.



43
44
45
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 43

def page_token
  @page_token
end

#seed_keywordsObject

Seed terms. Provide these, seedUrl, or both.



25
26
27
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 25

def seed_keywords
  @seed_keywords
end

#seed_urlObject

Landing page to mine for ideas. Provide this, seedKeywords, or both.



28
29
30
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 28

def seed_url
  @seed_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



84
85
86
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 84

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 89

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 68

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'customer_id' => :'customerId',
    :'seed_keywords' => :'seedKeywords',
    :'seed_url' => :'seedUrl',
    :'countries' => :'countries',
    :'language_constant_id' => :'languageConstantId',
    :'network' => :'network',
    :'include_adult_keywords' => :'includeAdultKeywords',
    :'page_size' => :'pageSize',
    :'page_token' => :'pageToken'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 340

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 110

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 94

def self.openapi_types
  {
    :'account_id' => :'String',
    :'customer_id' => :'String',
    :'seed_keywords' => :'Array<String>',
    :'seed_url' => :'String',
    :'countries' => :'Array<String>',
    :'language_constant_id' => :'String',
    :'network' => :'String',
    :'include_adult_keywords' => :'Boolean',
    :'page_size' => :'Integer',
    :'page_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 310

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      customer_id == o.customer_id &&
      seed_keywords == o.seed_keywords &&
      seed_url == o.seed_url &&
      countries == o.countries &&
      language_constant_id == o.language_constant_id &&
      network == o.network &&
      include_adult_keywords == o.include_adult_keywords &&
      page_size == o.page_size &&
      page_token == o.page_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


327
328
329
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 327

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



333
334
335
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 333

def hash
  [, customer_id, seed_keywords, seed_url, countries, language_constant_id, network, include_adult_keywords, page_size, page_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if !@seed_keywords.nil? && @seed_keywords.length > 20
    invalid_properties.push('invalid value for "seed_keywords", number of items must be less than or equal to 20.')
  end

  if !@seed_keywords.nil? && @seed_keywords.length < 1
    invalid_properties.push('invalid value for "seed_keywords", number of items must be greater than or equal to 1.')
  end

  if !@countries.nil? && @countries.length > 10
    invalid_properties.push('invalid value for "countries", number of items must be less than or equal to 10.')
  end

  if !@countries.nil? && @countries.length < 1
    invalid_properties.push('invalid value for "countries", number of items must be greater than or equal to 1.')
  end

  if !@page_size.nil? && @page_size > 10000
    invalid_properties.push('invalid value for "page_size", must be smaller than or equal to 10000.')
  end

  if !@page_size.nil? && @page_size < 1
    invalid_properties.push('invalid value for "page_size", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 362

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/zernio-sdk/models/generate_keyword_ideas_request.rb', line 220

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if !@seed_keywords.nil? && @seed_keywords.length > 20
  return false if !@seed_keywords.nil? && @seed_keywords.length < 1
  return false if !@countries.nil? && @countries.length > 10
  return false if !@countries.nil? && @countries.length < 1
  network_validator = EnumAttributeValidator.new('String', ["GOOGLE_SEARCH", "GOOGLE_SEARCH_AND_PARTNERS"])
  return false unless network_validator.valid?(@network)
  return false if !@page_size.nil? && @page_size > 10000
  return false if !@page_size.nil? && @page_size < 1
  true
end