Class: Zernio::GetAdAccountHierarchy200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetAdAccountHierarchy200Response
- Defined in:
- lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#cached_at ⇒ Object
When this data was fetched from Google.
-
#direct_customers ⇒ Object
Returns the value of attribute direct_customers.
-
#roots ⇒ Object
Returns the value of attribute roots.
-
#stale ⇒ Object
True when Google's quota was exhausted and this is the last successful fetch.
-
#truncated ⇒ Object
Returns the value of attribute truncated.
-
#unavailable ⇒ Object
Returns the value of attribute unavailable.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetAdAccountHierarchy200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetAdAccountHierarchy200Response
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAdAccountHierarchy200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAdAccountHierarchy200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'roots') if (value = attributes[:'roots']).is_a?(Array) self.roots = value end end if attributes.key?(:'direct_customers') if (value = attributes[:'direct_customers']).is_a?(Array) self.direct_customers = value end end if attributes.key?(:'unavailable') if (value = attributes[:'unavailable']).is_a?(Array) self.unavailable = value end end if attributes.key?(:'truncated') self.truncated = attributes[:'truncated'] end if attributes.key?(:'cached_at') self.cached_at = attributes[:'cached_at'] end if attributes.key?(:'stale') self.stale = attributes[:'stale'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 18 def account_id @account_id end |
#cached_at ⇒ Object
When this data was fetched from Google. Null on a live read.
29 30 31 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 29 def cached_at @cached_at end |
#direct_customers ⇒ Object
Returns the value of attribute direct_customers.
22 23 24 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 22 def direct_customers @direct_customers end |
#roots ⇒ Object
Returns the value of attribute roots.
20 21 22 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 20 def roots @roots end |
#stale ⇒ Object
True when Google's quota was exhausted and this is the last successful fetch.
32 33 34 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 32 def stale @stale end |
#truncated ⇒ Object
Returns the value of attribute truncated.
26 27 28 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 26 def truncated @truncated end |
#unavailable ⇒ Object
Returns the value of attribute unavailable.
24 25 26 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 24 def unavailable @unavailable end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 35 def self.attribute_map { :'account_id' => :'accountId', :'roots' => :'roots', :'direct_customers' => :'directCustomers', :'unavailable' => :'unavailable', :'truncated' => :'truncated', :'cached_at' => :'cachedAt', :'stale' => :'stale' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 75 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 71 def self.openapi_nullable Set.new([ :'cached_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 58 def self.openapi_types { :'account_id' => :'String', :'roots' => :'Array<GetAdAccountHierarchy200ResponseRootsInner>', :'direct_customers' => :'Array<GetAdAccountHierarchy200ResponseDirectCustomersInner>', :'unavailable' => :'Array<GetAdAccountHierarchy200ResponseUnavailableInner>', :'truncated' => :'Boolean', :'cached_at' => :'Time', :'stale' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && roots == o.roots && direct_customers == o.direct_customers && unavailable == o.unavailable && truncated == o.truncated && cached_at == o.cached_at && stale == o.stale end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 165 def hash [account_id, roots, direct_customers, unavailable, truncated, cached_at, stale].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 134 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 130 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 |
# File 'lib/zernio-sdk/models/get_ad_account_hierarchy200_response.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |