Class: Zernio::GetAdAnalytics200ResponseAd

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetAdAnalytics200ResponseAd

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAdAnalytics200ResponseAd` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAdAnalytics200ResponseAd`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'trigger')
    self.trigger = attributes[:'trigger']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end
end

Instance Attribute Details

#currencyObject

ISO 4217 code of the ad account that owns this ad (e.g. USD, THB, INR). All money values in summary and daily are in this currency. Null only on legacy ads synced before currency was persisted.



29
30
31
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 29

def currency
  @currency
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 18

def id
  @id
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 20

def name
  @name
end

#platformObject

Returns the value of attribute platform.



22
23
24
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 22

def platform
  @platform
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 26

def status
  @status
end

#triggerObject

Returns the value of attribute trigger.



24
25
26
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 24

def trigger
  @trigger
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 54

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'platform' => :'platform',
    :'trigger' => :'trigger',
    :'status' => :'status',
    :'currency' => :'currency'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 190

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
92
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 88

def self.openapi_nullable
  Set.new([
    :'currency'
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 76

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'platform' => :'String',
    :'trigger' => :'String',
    :'status' => :'String',
    :'currency' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



164
165
166
167
168
169
170
171
172
173
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 164

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      platform == o.platform &&
      trigger == o.trigger &&
      status == o.status &&
      currency == o.currency
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 177

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



183
184
185
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 183

def hash
  [id, name, platform, trigger, status, currency].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
# File 'lib/zernio-sdk/models/get_ad_analytics200_response_ad.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  trigger_validator = EnumAttributeValidator.new('String', ["comment", "story_reply"])
  return false unless trigger_validator.valid?(@trigger)
  true
end