Class: Zernio::GetAdInsightsReport200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_ad_insights_report200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetAdInsightsReport200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAdInsightsReport200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAdInsightsReport200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'report_run_id')
    self.report_run_id = attributes[:'report_run_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'percent_completion')
    self.percent_completion = attributes[:'percent_completion']
  end

  if attributes.key?(:'date_start')
    self.date_start = attributes[:'date_start']
  end

  if attributes.key?(:'date_stop')
    self.date_stop = attributes[:'date_stop']
  end

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Array)
      self.data = value
    end
  end

  if attributes.key?(:'paging')
    self.paging = attributes[:'paging']
  end
end

Instance Attribute Details

#dataObject

Present only when status is Job Completed.



30
31
32
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 30

def data
  @data
end

#date_startObject

Returns the value of attribute date_start.



25
26
27
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 25

def date_start
  @date_start
end

#date_stopObject

Returns the value of attribute date_stop.



27
28
29
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 27

def date_stop
  @date_stop
end

#pagingObject

Returns the value of attribute paging.



32
33
34
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 32

def paging
  @paging
end

#percent_completionObject

Returns the value of attribute percent_completion.



23
24
25
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 23

def percent_completion
  @percent_completion
end

#report_run_idObject

Returns the value of attribute report_run_id.



18
19
20
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 18

def report_run_id
  @report_run_id
end

#statusObject

Meta async_status: Job Not Started, Job Started, Job Running, Job Completed, Job Failed, Job Skipped.



21
22
23
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 21

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 35

def self.attribute_map
  {
    :'report_run_id' => :'reportRunId',
    :'status' => :'status',
    :'percent_completion' => :'percentCompletion',
    :'date_start' => :'dateStart',
    :'date_stop' => :'dateStop',
    :'data' => :'data',
    :'paging' => :'paging'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 167

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 58

def self.openapi_types
  {
    :'report_run_id' => :'String',
    :'status' => :'String',
    :'percent_completion' => :'Integer',
    :'date_start' => :'String',
    :'date_stop' => :'String',
    :'data' => :'Array<Object>',
    :'paging' => :'GetAdInsightsReport200ResponsePaging'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



140
141
142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 140

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      report_run_id == o.report_run_id &&
      status == o.status &&
      percent_completion == o.percent_completion &&
      date_start == o.date_start &&
      date_stop == o.date_stop &&
      data == o.data &&
      paging == o.paging
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 154

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



160
161
162
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 160

def hash
  [report_run_id, status, percent_completion, date_start, date_stop, data, paging].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 189

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
# File 'lib/zernio-sdk/models/get_ad_insights_report200_response.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end