Class: Zernio::GetBroadcast200ResponseBroadcast

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetBroadcast200ResponseBroadcast

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 146

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetBroadcast200ResponseBroadcast` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetBroadcast200ResponseBroadcast`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'template')
    self.template = attributes[:'template']
  end

  if attributes.key?(:'segment_filters')
    self.segment_filters = attributes[:'segment_filters']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'scheduled_at')
    self.scheduled_at = attributes[:'scheduled_at']
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end

  if attributes.key?(:'recipient_count')
    self.recipient_count = attributes[:'recipient_count']
  end

  if attributes.key?(:'sent_count')
    self.sent_count = attributes[:'sent_count']
  end

  if attributes.key?(:'delivered_count')
    self.delivered_count = attributes[:'delivered_count']
  end

  if attributes.key?(:'read_count')
    self.read_count = attributes[:'read_count']
  end

  if attributes.key?(:'failed_count')
    self.failed_count = attributes[:'failed_count']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



26
27
28
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 26

def 
  @account_id
end

#completed_atObject

Returns the value of attribute completed_at.



40
41
42
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 40

def completed_at
  @completed_at
end

#created_atObject

Returns the value of attribute created_at.



52
53
54
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 52

def created_at
  @created_at
end

#delivered_countObject

Returns the value of attribute delivered_count.



46
47
48
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 46

def delivered_count
  @delivered_count
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 22

def description
  @description
end

#failed_countObject

Returns the value of attribute failed_count.



50
51
52
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 50

def failed_count
  @failed_count
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 18

def id
  @id
end

#messageObject

Returns the value of attribute message.



28
29
30
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 28

def message
  @message
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 20

def name
  @name
end

#platformObject

Returns the value of attribute platform.



24
25
26
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 24

def platform
  @platform
end

#read_countObject

Returns the value of attribute read_count.



48
49
50
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 48

def read_count
  @read_count
end

#recipient_countObject

Returns the value of attribute recipient_count.



42
43
44
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 42

def recipient_count
  @recipient_count
end

#scheduled_atObject

Returns the value of attribute scheduled_at.



36
37
38
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 36

def scheduled_at
  @scheduled_at
end

#segment_filtersObject

Returns the value of attribute segment_filters.



32
33
34
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 32

def segment_filters
  @segment_filters
end

#sent_countObject

Returns the value of attribute sent_count.



44
45
46
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 44

def sent_count
  @sent_count
end

#started_atObject

Returns the value of attribute started_at.



38
39
40
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 38

def started_at
  @started_at
end

#statusObject

Returns the value of attribute status.



34
35
36
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 34

def status
  @status
end

#templateObject

Returns the value of attribute template.



30
31
32
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 30

def template
  @template
end

#updated_atObject

Returns the value of attribute updated_at.



54
55
56
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 54

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



104
105
106
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 104

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



109
110
111
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 109

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 79

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'platform' => :'platform',
    :'account_id' => :'accountId',
    :'message' => :'message',
    :'template' => :'template',
    :'segment_filters' => :'segmentFilters',
    :'status' => :'status',
    :'scheduled_at' => :'scheduledAt',
    :'started_at' => :'startedAt',
    :'completed_at' => :'completedAt',
    :'recipient_count' => :'recipientCount',
    :'sent_count' => :'sentCount',
    :'delivered_count' => :'deliveredCount',
    :'read_count' => :'readCount',
    :'failed_count' => :'failedCount',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 305

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



139
140
141
142
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 139

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 114

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'platform' => :'String',
    :'account_id' => :'String',
    :'message' => :'GetBroadcast200ResponseBroadcastMessage',
    :'template' => :'GetBroadcast200ResponseBroadcastTemplate',
    :'segment_filters' => :'ListContacts200ResponseFilters',
    :'status' => :'String',
    :'scheduled_at' => :'Time',
    :'started_at' => :'Time',
    :'completed_at' => :'Time',
    :'recipient_count' => :'Integer',
    :'sent_count' => :'Integer',
    :'delivered_count' => :'Integer',
    :'read_count' => :'Integer',
    :'failed_count' => :'Integer',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 266

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      platform == o.platform &&
       == o. &&
      message == o.message &&
      template == o.template &&
      segment_filters == o.segment_filters &&
      status == o.status &&
      scheduled_at == o.scheduled_at &&
      started_at == o.started_at &&
      completed_at == o.completed_at &&
      recipient_count == o.recipient_count &&
      sent_count == o.sent_count &&
      delivered_count == o.delivered_count &&
      read_count == o.read_count &&
      failed_count == o.failed_count &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


292
293
294
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 292

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



298
299
300
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 298

def hash
  [id, name, description, platform, , message, template, segment_filters, status, scheduled_at, started_at, completed_at, recipient_count, sent_count, delivered_count, read_count, failed_count, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



239
240
241
242
243
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 239

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 327

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



247
248
249
250
251
252
# File 'lib/zernio-sdk/models/get_broadcast200_response_broadcast.rb', line 247

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["draft", "scheduled", "sending", "completed", "failed", "cancelled"])
  return false unless status_validator.valid?(@status)
  true
end