Class: Zernio::GetCampaignAdSchedule200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetCampaignAdSchedule200Response

Initializes the object



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetCampaignAdSchedule200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetCampaignAdSchedule200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'schedule')
    if (value = attributes[:'schedule']).is_a?(Array)
      self.schedule = value
    end
  end

  if attributes.key?(:'serves_around_the_clock')
    self.serves_around_the_clock = attributes[:'serves_around_the_clock']
  end

  if attributes.key?(:'cached_at')
    self.cached_at = attributes[:'cached_at']
  end

  if attributes.key?(:'stale')
    self.stale = attributes[:'stale']
  end

  if attributes.key?(:'performance')
    self.performance = attributes[:'performance']
  end
end

Instance Attribute Details

#cached_atObject

Returns the value of attribute cached_at.



25
26
27
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 25

def cached_at
  @cached_at
end

#campaign_idObject

Returns the value of attribute campaign_id.



18
19
20
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 18

def campaign_id
  @campaign_id
end

#performanceObject

Returns the value of attribute performance.



30
31
32
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 30

def performance
  @performance
end

#scheduleObject

Returns the value of attribute schedule.



20
21
22
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 20

def schedule
  @schedule
end

#serves_around_the_clockObject

True when the campaign carries no ad schedule at all, so it can serve at any time.



23
24
25
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 23

def serves_around_the_clock
  @serves_around_the_clock
end

#staleObject

True when a quota-exhausted read served the last-good copy.



28
29
30
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 28

def stale
  @stale
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 33

def self.attribute_map
  {
    :'campaign_id' => :'campaignId',
    :'schedule' => :'schedule',
    :'serves_around_the_clock' => :'servesAroundTheClock',
    :'cached_at' => :'cachedAt',
    :'stale' => :'stale',
    :'performance' => :'performance'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 159

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 67

def self.openapi_nullable
  Set.new([
    :'cached_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 55

def self.openapi_types
  {
    :'campaign_id' => :'String',
    :'schedule' => :'Array<AdScheduleWindow>',
    :'serves_around_the_clock' => :'Boolean',
    :'cached_at' => :'Time',
    :'stale' => :'Boolean',
    :'performance' => :'GetCampaignAdSchedule200ResponsePerformance'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



133
134
135
136
137
138
139
140
141
142
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 133

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      campaign_id == o.campaign_id &&
      schedule == o.schedule &&
      serves_around_the_clock == o.serves_around_the_clock &&
      cached_at == o.cached_at &&
      stale == o.stale &&
      performance == o.performance
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


146
147
148
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 146

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



152
153
154
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 152

def hash
  [campaign_id, schedule, serves_around_the_clock, cached_at, stale, performance].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



118
119
120
121
122
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 181

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



126
127
128
129
# File 'lib/zernio-sdk/models/get_campaign_ad_schedule200_response.rb', line 126

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end