Class: Zernio::GetContact200ResponseChannelsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetContact200ResponseChannelsInner
- Defined in:
- lib/zernio-sdk/models/get_contact200_response_channels_inner.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#display_identifier ⇒ Object
Returns the value of attribute display_identifier.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_subscribed ⇒ Object
Returns the value of attribute is_subscribed.
-
#last_active_at ⇒ Object
Most recent message (either direction) in this channel's conversation, or null if none.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_identifier ⇒ Object
Returns the value of attribute platform_identifier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetContact200ResponseChannelsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetContact200ResponseChannelsInner
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetContact200ResponseChannelsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetContact200ResponseChannelsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'platform_identifier') self.platform_identifier = attributes[:'platform_identifier'] end if attributes.key?(:'display_identifier') self.display_identifier = attributes[:'display_identifier'] end if attributes.key?(:'is_subscribed') self.is_subscribed = attributes[:'is_subscribed'] end if attributes.key?(:'conversation_id') self.conversation_id = attributes[:'conversation_id'] end if attributes.key?(:'last_active_at') self.last_active_at = attributes[:'last_active_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
20 21 22 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 20 def account_id @account_id end |
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
30 31 32 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 30 def conversation_id @conversation_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
35 36 37 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 35 def created_at @created_at end |
#display_identifier ⇒ Object
Returns the value of attribute display_identifier.
26 27 28 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 26 def display_identifier @display_identifier end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 18 def id @id end |
#is_subscribed ⇒ Object
Returns the value of attribute is_subscribed.
28 29 30 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 28 def is_subscribed @is_subscribed end |
#last_active_at ⇒ Object
Most recent message (either direction) in this channel's conversation, or null if none.
33 34 35 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 33 def last_active_at @last_active_at end |
#platform ⇒ Object
Returns the value of attribute platform.
22 23 24 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 22 def platform @platform end |
#platform_identifier ⇒ Object
Returns the value of attribute platform_identifier.
24 25 26 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 24 def platform_identifier @platform_identifier end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 38 def self.attribute_map { :'id' => :'id', :'account_id' => :'accountId', :'platform' => :'platform', :'platform_identifier' => :'platformIdentifier', :'display_identifier' => :'displayIdentifier', :'is_subscribed' => :'isSubscribed', :'conversation_id' => :'conversationId', :'last_active_at' => :'lastActiveAt', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 183 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 82 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 78 def self.openapi_nullable Set.new([ :'last_active_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 63 def self.openapi_types { :'id' => :'String', :'account_id' => :'String', :'platform' => :'String', :'platform_identifier' => :'String', :'display_identifier' => :'String', :'is_subscribed' => :'Boolean', :'conversation_id' => :'String', :'last_active_at' => :'Time', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 154 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && account_id == o.account_id && platform == o.platform && platform_identifier == o.platform_identifier && display_identifier == o.display_identifier && is_subscribed == o.is_subscribed && conversation_id == o.conversation_id && last_active_at == o.last_active_at && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
170 171 172 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 170 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 176 def hash [id, account_id, platform, platform_identifier, display_identifier, is_subscribed, conversation_id, last_active_at, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 139 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
147 148 149 150 |
# File 'lib/zernio-sdk/models/get_contact200_response_channels_inner.rb', line 147 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |