Class: Zernio::GetContact200ResponseContact
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetContact200ResponseContact
- Defined in:
- lib/zernio-sdk/models/get_contact200_response_contact.rb
Instance Attribute Summary collapse
-
#avatar_url ⇒ Object
Returns the value of attribute avatar_url.
-
#company ⇒ Object
Returns the value of attribute company.
-
#conversation_ids ⇒ Object
Returns the value of attribute conversation_ids.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
-
#email ⇒ Object
Returns the value of attribute email.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_blocked ⇒ Object
Returns the value of attribute is_blocked.
-
#is_subscribed ⇒ Object
Returns the value of attribute is_subscribed.
-
#last_message_received_at ⇒ Object
Timestamp of the most recent incoming message, or null if none.
-
#last_message_sent_at ⇒ Object
Timestamp of the most recent outgoing message, or null if none.
-
#messages_received_count ⇒ Object
Messages received from the contact, derived live from message history across all linked conversations.
-
#messages_sent_count ⇒ Object
Messages sent to the contact, derived live from message history across all linked conversations.
-
#name ⇒ Object
Returns the value of attribute name.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetContact200ResponseContact
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetContact200ResponseContact
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetContact200ResponseContact` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetContact200ResponseContact`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'avatar_url') self.avatar_url = attributes[:'avatar_url'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'is_subscribed') self.is_subscribed = attributes[:'is_subscribed'] end if attributes.key?(:'is_blocked') self.is_blocked = attributes[:'is_blocked'] end if attributes.key?(:'messages_sent_count') self. = attributes[:'messages_sent_count'] end if attributes.key?(:'messages_received_count') self. = attributes[:'messages_received_count'] end if attributes.key?(:'last_message_sent_at') self. = attributes[:'last_message_sent_at'] end if attributes.key?(:'last_message_received_at') self. = attributes[:'last_message_received_at'] end if attributes.key?(:'custom_fields') self.custom_fields = attributes[:'custom_fields'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'conversation_ids') if (value = attributes[:'conversation_ids']).is_a?(Array) self.conversation_ids = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#avatar_url ⇒ Object
Returns the value of attribute avatar_url.
26 27 28 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 26 def avatar_url @avatar_url end |
#company ⇒ Object
Returns the value of attribute company.
24 25 26 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 24 def company @company end |
#conversation_ids ⇒ Object
Returns the value of attribute conversation_ids.
50 51 52 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 50 def conversation_ids @conversation_ids end |
#created_at ⇒ Object
Returns the value of attribute created_at.
52 53 54 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 52 def created_at @created_at end |
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
46 47 48 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 46 def custom_fields @custom_fields end |
#email ⇒ Object
Returns the value of attribute email.
22 23 24 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 22 def email @email end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 18 def id @id end |
#is_blocked ⇒ Object
Returns the value of attribute is_blocked.
32 33 34 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 32 def is_blocked @is_blocked end |
#is_subscribed ⇒ Object
Returns the value of attribute is_subscribed.
30 31 32 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 30 def is_subscribed @is_subscribed end |
#last_message_received_at ⇒ Object
Timestamp of the most recent incoming message, or null if none.
44 45 46 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 44 def @last_message_received_at end |
#last_message_sent_at ⇒ Object
Timestamp of the most recent outgoing message, or null if none.
41 42 43 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 41 def @last_message_sent_at end |
#messages_received_count ⇒ Object
Messages received from the contact, derived live from message history across all linked conversations.
38 39 40 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 38 def @messages_received_count end |
#messages_sent_count ⇒ Object
Messages sent to the contact, derived live from message history across all linked conversations.
35 36 37 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 35 def @messages_sent_count end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 20 def name @name end |
#notes ⇒ Object
Returns the value of attribute notes.
48 49 50 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 48 def notes @notes end |
#tags ⇒ Object
Returns the value of attribute tags.
28 29 30 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 28 def @tags end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
54 55 56 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 54 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 57 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'email' => :'email', :'company' => :'company', :'avatar_url' => :'avatarUrl', :'tags' => :'tags', :'is_subscribed' => :'isSubscribed', :'is_blocked' => :'isBlocked', :'messages_sent_count' => :'messagesSentCount', :'messages_received_count' => :'messagesReceivedCount', :'last_message_sent_at' => :'lastMessageSentAt', :'last_message_received_at' => :'lastMessageReceivedAt', :'custom_fields' => :'customFields', :'notes' => :'notes', :'conversation_ids' => :'conversationIds', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 263 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 117 118 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 113 def self.openapi_nullable Set.new([ :'last_message_sent_at', :'last_message_received_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 90 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'email' => :'String', :'company' => :'String', :'avatar_url' => :'String', :'tags' => :'Array<String>', :'is_subscribed' => :'Boolean', :'is_blocked' => :'Boolean', :'messages_sent_count' => :'Integer', :'messages_received_count' => :'Integer', :'last_message_sent_at' => :'Time', :'last_message_received_at' => :'Time', :'custom_fields' => :'Object', :'notes' => :'String', :'conversation_ids' => :'Array<String>', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && email == o.email && company == o.company && avatar_url == o.avatar_url && == o. && is_subscribed == o.is_subscribed && is_blocked == o.is_blocked && == o. && == o. && == o. && == o. && custom_fields == o.custom_fields && notes == o.notes && conversation_ids == o.conversation_ids && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
250 251 252 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 250 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
256 257 258 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 256 def hash [id, name, email, company, avatar_url, , is_subscribed, is_blocked, , , , , custom_fields, notes, conversation_ids, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
211 212 213 214 215 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 211 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 |
# File 'lib/zernio-sdk/models/get_contact200_response_contact.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |