Class: Zernio::GetContactChannels200ResponseChannelsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetContactChannels200ResponseChannelsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetContactChannels200ResponseChannelsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetContactChannels200ResponseChannelsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'platform_identifier')
    self.platform_identifier = attributes[:'platform_identifier']
  end

  if attributes.key?(:'display_identifier')
    self.display_identifier = attributes[:'display_identifier']
  end

  if attributes.key?(:'is_subscribed')
    self.is_subscribed = attributes[:'is_subscribed']
  end

  if attributes.key?(:'conversation_id')
    self.conversation_id = attributes[:'conversation_id']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



20
21
22
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 20

def 
  @account_id
end

#conversation_idObject

Returns the value of attribute conversation_id.



30
31
32
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 30

def conversation_id
  @conversation_id
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 34

def created_at
  @created_at
end

#display_identifierObject

Returns the value of attribute display_identifier.



26
27
28
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 26

def display_identifier
  @display_identifier
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 18

def id
  @id
end

#is_subscribedObject

Returns the value of attribute is_subscribed.



28
29
30
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 28

def is_subscribed
  @is_subscribed
end

#metadataObject

Returns the value of attribute metadata.



32
33
34
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 32

def 
  @metadata
end

#platformObject

Returns the value of attribute platform.



22
23
24
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 22

def platform
  @platform
end

#platform_identifierObject

Returns the value of attribute platform_identifier.



24
25
26
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 24

def platform_identifier
  @platform_identifier
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'platform_identifier' => :'platformIdentifier',
    :'display_identifier' => :'displayIdentifier',
    :'is_subscribed' => :'isSubscribed',
    :'conversation_id' => :'conversationId',
    :'metadata' => :'metadata',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 62

def self.openapi_types
  {
    :'id' => :'String',
    :'account_id' => :'String',
    :'platform' => :'String',
    :'platform_identifier' => :'String',
    :'display_identifier' => :'String',
    :'is_subscribed' => :'Boolean',
    :'conversation_id' => :'String',
    :'metadata' => :'Object',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      platform == o.platform &&
      platform_identifier == o.platform_identifier &&
      display_identifier == o.display_identifier &&
      is_subscribed == o.is_subscribed &&
      conversation_id == o.conversation_id &&
       == o. &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 174

def hash
  [id, , platform, platform_identifier, display_identifier, is_subscribed, conversation_id, , created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
# File 'lib/zernio-sdk/models/get_contact_channels200_response_channels_inner.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end