Class: Zernio::GetGmbAttributeMetadata200ResponseAttributeMetadataInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetGmbAttributeMetadata200ResponseAttributeMetadataInner
- Defined in:
- lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb
Instance Attribute Summary collapse
-
#deprecated ⇒ Object
True if this attribute should no longer be used.
-
#display_name ⇒ Object
Localized human-readable attribute name.
-
#group_display_name ⇒ Object
Display name of the attribute group.
-
#parent ⇒ Object
Resource name of the attribute (e.g. "attributes/has_delivery").
-
#repeatable ⇒ Object
True if multiple values can be set simultaneously.
-
#value_metadata ⇒ Object
Possible enum values (for ENUM / REPEATED_ENUM types).
-
#value_type ⇒ Object
Value type (e.g. BOOL, ENUM, URL, REPEATED_ENUM).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetGmbAttributeMetadata200ResponseAttributeMetadataInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetGmbAttributeMetadata200ResponseAttributeMetadataInner
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetGmbAttributeMetadata200ResponseAttributeMetadataInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetGmbAttributeMetadata200ResponseAttributeMetadataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'parent') self.parent = attributes[:'parent'] end if attributes.key?(:'value_type') self.value_type = attributes[:'value_type'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'group_display_name') self.group_display_name = attributes[:'group_display_name'] end if attributes.key?(:'repeatable') self.repeatable = attributes[:'repeatable'] end if attributes.key?(:'deprecated') self.deprecated = attributes[:'deprecated'] end if attributes.key?(:'value_metadata') if (value = attributes[:'value_metadata']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#deprecated ⇒ Object
True if this attribute should no longer be used.
34 35 36 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 34 def deprecated @deprecated end |
#display_name ⇒ Object
Localized human-readable attribute name.
25 26 27 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 25 def display_name @display_name end |
#group_display_name ⇒ Object
Display name of the attribute group.
28 29 30 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 28 def group_display_name @group_display_name end |
#parent ⇒ Object
Resource name of the attribute (e.g. "attributes/has_delivery").
19 20 21 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 19 def parent @parent end |
#repeatable ⇒ Object
True if multiple values can be set simultaneously.
31 32 33 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 31 def repeatable @repeatable end |
#value_metadata ⇒ Object
Possible enum values (for ENUM / REPEATED_ENUM types).
37 38 39 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 37 def @value_metadata end |
#value_type ⇒ Object
Value type (e.g. BOOL, ENUM, URL, REPEATED_ENUM).
22 23 24 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 22 def value_type @value_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 40 def self.attribute_map { :'parent' => :'parent', :'value_type' => :'valueType', :'display_name' => :'displayName', :'group_display_name' => :'groupDisplayName', :'repeatable' => :'repeatable', :'deprecated' => :'deprecated', :'value_metadata' => :'valueMetadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 63 def self.openapi_types { :'parent' => :'String', :'value_type' => :'String', :'display_name' => :'String', :'group_display_name' => :'String', :'repeatable' => :'Boolean', :'deprecated' => :'Boolean', :'value_metadata' => :'Array<GetGmbAttributeMetadata200ResponseAttributeMetadataInnerValueMetadataInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && parent == o.parent && value_type == o.value_type && display_name == o.display_name && group_display_name == o.group_display_name && repeatable == o.repeatable && deprecated == o.deprecated && == o. end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 165 def hash [parent, value_type, display_name, group_display_name, repeatable, deprecated, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 134 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 130 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 |
# File 'lib/zernio-sdk/models/get_gmb_attribute_metadata200_response_attribute_metadata_inner.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |