Class: Zernio::GetGoogleBusinessLocationDetails200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_google_business_location_details200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetGoogleBusinessLocationDetails200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetGoogleBusinessLocationDetails200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetGoogleBusinessLocationDetails200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'location_id')
    self.location_id = attributes[:'location_id']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'regular_hours')
    self.regular_hours = attributes[:'regular_hours']
  end

  if attributes.key?(:'special_hours')
    self.special_hours = attributes[:'special_hours']
  end

  if attributes.key?(:'profile')
    self.profile = attributes[:'profile']
  end

  if attributes.key?(:'website_uri')
    self.website_uri = attributes[:'website_uri']
  end

  if attributes.key?(:'phone_numbers')
    self.phone_numbers = attributes[:'phone_numbers']
  end

  if attributes.key?(:'categories')
    self.categories = attributes[:'categories']
  end

  if attributes.key?(:'service_items')
    if (value = attributes[:'service_items']).is_a?(Array)
      self.service_items = value
    end
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



20
21
22
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 20

def 
  @account_id
end

#categoriesObject

Returns the value of attribute categories.



39
40
41
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 39

def categories
  @categories
end

#locationObject

Returns the value of attribute location.



24
25
26
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 24

def location
  @location
end

#location_idObject

Returns the value of attribute location_id.



22
23
24
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 22

def location_id
  @location_id
end

#phone_numbersObject

Returns the value of attribute phone_numbers.



37
38
39
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 37

def phone_numbers
  @phone_numbers
end

#profileObject

Returns the value of attribute profile.



33
34
35
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 33

def profile
  @profile
end

#regular_hoursObject

Returns the value of attribute regular_hours.



29
30
31
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 29

def regular_hours
  @regular_hours
end

#service_itemsObject

Services offered (returned when readMask includes 'serviceItems')



42
43
44
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 42

def service_items
  @service_items
end

#special_hoursObject

Returns the value of attribute special_hours.



31
32
33
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 31

def special_hours
  @special_hours
end

#successObject

Returns the value of attribute success.



18
19
20
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 18

def success
  @success
end

#titleObject

Business name



27
28
29
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 27

def title
  @title
end

#website_uriObject

Returns the value of attribute website_uri.



35
36
37
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 35

def website_uri
  @website_uri
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 45

def self.attribute_map
  {
    :'success' => :'success',
    :'account_id' => :'accountId',
    :'location_id' => :'locationId',
    :'location' => :'location',
    :'title' => :'title',
    :'regular_hours' => :'regularHours',
    :'special_hours' => :'specialHours',
    :'profile' => :'profile',
    :'website_uri' => :'websiteUri',
    :'phone_numbers' => :'phoneNumbers',
    :'categories' => :'categories',
    :'service_items' => :'serviceItems'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 212

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 73

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'account_id' => :'String',
    :'location_id' => :'String',
    :'location' => :'GetGoogleBusinessLocationDetails200ResponseLocation',
    :'title' => :'String',
    :'regular_hours' => :'GetGoogleBusinessLocationDetails200ResponseRegularHours',
    :'special_hours' => :'GetGoogleBusinessLocationDetails200ResponseSpecialHours',
    :'profile' => :'GetGoogleBusinessLocationDetails200ResponseProfile',
    :'website_uri' => :'String',
    :'phone_numbers' => :'GetGoogleBusinessLocationDetails200ResponsePhoneNumbers',
    :'categories' => :'GetGoogleBusinessLocationDetails200ResponseCategories',
    :'service_items' => :'Array<GetGoogleBusinessLocationDetails200ResponseServiceItemsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 180

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
       == o. &&
      location_id == o.location_id &&
      location == o.location &&
      title == o.title &&
      regular_hours == o.regular_hours &&
      special_hours == o.special_hours &&
      profile == o.profile &&
      website_uri == o.website_uri &&
      phone_numbers == o.phone_numbers &&
      categories == o.categories &&
      service_items == o.service_items
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 199

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



205
206
207
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 205

def hash
  [success, , location_id, location, title, regular_hours, special_hours, profile, website_uri, phone_numbers, categories, service_items].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
# File 'lib/zernio-sdk/models/get_google_business_location_details200_response.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end