Class: Zernio::GetInboxConversationAnalytics200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetInboxConversationAnalytics200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetInboxConversationAnalytics200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetInboxConversationAnalytics200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'conversation_id')
    self.conversation_id = attributes[:'conversation_id']
  end

  if attributes.key?(:'mongo_id')
    self.mongo_id = attributes[:'mongo_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'summary')
    self.summary = attributes[:'summary']
  end

  if attributes.key?(:'timeseries')
    if (value = attributes[:'timeseries']).is_a?(Array)
      self.timeseries = value
    end
  end

  if attributes.key?(:'by_source')
    if (value = attributes[:'by_source']).is_a?(Array)
      self.by_source = value
    end
  end
end

Instance Attribute Details

#by_sourceObject

Returns the value of attribute by_source.



35
36
37
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 35

def by_source
  @by_source
end

#conversation_idObject

The platformConversationId



21
22
23
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 21

def conversation_id
  @conversation_id
end

#fromObject

Returns the value of attribute from.



27
28
29
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 27

def from
  @from
end

#mongo_idObject

Returns the value of attribute mongo_id.



23
24
25
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 23

def mongo_id
  @mongo_id
end

#platformObject

Returns the value of attribute platform.



25
26
27
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 25

def platform
  @platform
end

#successObject

Returns the value of attribute success.



18
19
20
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 18

def success
  @success
end

#summaryObject

Returns the value of attribute summary.



31
32
33
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 31

def summary
  @summary
end

#timeseriesObject

Returns the value of attribute timeseries.



33
34
35
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 33

def timeseries
  @timeseries
end

#toObject

Returns the value of attribute to.



29
30
31
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 29

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 38

def self.attribute_map
  {
    :'success' => :'success',
    :'conversation_id' => :'conversationId',
    :'mongo_id' => :'mongoId',
    :'platform' => :'platform',
    :'from' => :'from',
    :'to' => :'to',
    :'summary' => :'summary',
    :'timeseries' => :'timeseries',
    :'by_source' => :'bySource'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
82
83
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 78

def self.openapi_nullable
  Set.new([
    :'platform',
    :'to',
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 63

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'conversation_id' => :'String',
    :'mongo_id' => :'String',
    :'platform' => :'String',
    :'from' => :'Date',
    :'to' => :'Date',
    :'summary' => :'GetInboxConversationAnalytics200ResponseSummary',
    :'timeseries' => :'Array<GetInboxVolume200ResponseTimeseriesInner>',
    :'by_source' => :'Array<GetInboxConversationAnalytics200ResponseBySourceInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 159

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
      conversation_id == o.conversation_id &&
      mongo_id == o.mongo_id &&
      platform == o.platform &&
      from == o.from &&
      to == o.to &&
      summary == o.summary &&
      timeseries == o.timeseries &&
      by_source == o.by_source
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 181

def hash
  [success, conversation_id, mongo_id, platform, from, to, summary, timeseries, by_source].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
# File 'lib/zernio-sdk/models/get_inbox_conversation_analytics200_response.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end