Class: Zernio::GetInboxPostComments200ResponseCommentsInnerFrom

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetInboxPostComments200ResponseCommentsInnerFrom

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetInboxPostComments200ResponseCommentsInnerFrom` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetInboxPostComments200ResponseCommentsInnerFrom`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'picture')
    self.picture = attributes[:'picture']
  end

  if attributes.key?(:'is_owner')
    self.is_owner = attributes[:'is_owner']
  end

  if attributes.key?(:'verified_type')
    self.verified_type = attributes[:'verified_type']
  end
end

Instance Attribute Details

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 18

def id
  @id
end

#is_ownerObject

Returns the value of attribute is_owner.



26
27
28
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 26

def is_owner
  @is_owner
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 20

def name
  @name
end

#pictureObject

Returns the value of attribute picture.



24
25
26
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 24

def picture
  @picture
end

#usernameObject

Returns the value of attribute username.



22
23
24
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 22

def username
  @username
end

#verified_typeObject

X/Twitter verified badge type. Only present for Twitter/X comments.



29
30
31
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 29

def verified_type
  @verified_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 54

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'username' => :'username',
    :'picture' => :'picture',
    :'is_owner' => :'isOwner',
    :'verified_type' => :'verifiedType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
92
93
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 88

def self.openapi_nullable
  Set.new([
    :'picture',
    :'verified_type'
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 76

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'username' => :'String',
    :'picture' => :'String',
    :'is_owner' => :'Boolean',
    :'verified_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
173
174
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      username == o.username &&
      picture == o.picture &&
      is_owner == o.is_owner &&
      verified_type == o.verified_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 184

def hash
  [id, name, username, picture, is_owner, verified_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
# File 'lib/zernio-sdk/models/get_inbox_post_comments200_response_comments_inner_from.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  verified_type_validator = EnumAttributeValidator.new('String', ["blue", "government", "business", "none"])
  return false unless verified_type_validator.valid?(@verified_type)
  true
end