Class: Zernio::GetInboxVolume200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetInboxVolume200Response
- Defined in:
- lib/zernio-sdk/models/get_inbox_volume200_response.rb
Instance Attribute Summary collapse
-
#by_platform ⇒ Object
Returns the value of attribute by_platform.
-
#from ⇒ Object
Returns the value of attribute from.
-
#success ⇒ Object
Returns the value of attribute success.
-
#summary ⇒ Object
Returns the value of attribute summary.
-
#timeseries ⇒ Object
Returns the value of attribute timeseries.
-
#to ⇒ Object
Returns the value of attribute to.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetInboxVolume200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetInboxVolume200Response
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetInboxVolume200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetInboxVolume200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'to') self.to = attributes[:'to'] end if attributes.key?(:'summary') self.summary = attributes[:'summary'] end if attributes.key?(:'timeseries') if (value = attributes[:'timeseries']).is_a?(Array) self.timeseries = value end end if attributes.key?(:'by_platform') if (value = attributes[:'by_platform']).is_a?(Array) self.by_platform = value end end end |
Instance Attribute Details
#by_platform ⇒ Object
Returns the value of attribute by_platform.
28 29 30 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 28 def by_platform @by_platform end |
#from ⇒ Object
Returns the value of attribute from.
20 21 22 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 20 def from @from end |
#success ⇒ Object
Returns the value of attribute success.
18 19 20 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 18 def success @success end |
#summary ⇒ Object
Returns the value of attribute summary.
24 25 26 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 24 def summary @summary end |
#timeseries ⇒ Object
Returns the value of attribute timeseries.
26 27 28 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 26 def timeseries @timeseries end |
#to ⇒ Object
Returns the value of attribute to.
22 23 24 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 22 def to @to end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 31 def self.attribute_map { :'success' => :'success', :'from' => :'from', :'to' => :'to', :'summary' => :'summary', :'timeseries' => :'timeseries', :'by_platform' => :'byPlatform' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 159 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 69 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 65 def self.openapi_nullable Set.new([ :'to', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 53 def self.openapi_types { :'success' => :'Boolean', :'from' => :'Date', :'to' => :'Date', :'summary' => :'GetInboxVolume200ResponseSummary', :'timeseries' => :'Array<GetInboxVolume200ResponseTimeseriesInner>', :'by_platform' => :'Array<GetInboxVolume200ResponseByPlatformInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 133 def ==(o) return true if self.equal?(o) self.class == o.class && success == o.success && from == o.from && to == o.to && summary == o.summary && timeseries == o.timeseries && by_platform == o.by_platform end |
#eql?(o) ⇒ Boolean
146 147 148 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 146 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 152 def hash [success, from, to, summary, timeseries, by_platform].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 181 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
126 127 128 129 |
# File 'lib/zernio-sdk/models/get_inbox_volume200_response.rb', line 126 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |