Class: Zernio::GetInstagramStoryInsights200ResponseDataMetrics

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetInstagramStoryInsights200ResponseDataMetrics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetInstagramStoryInsights200ResponseDataMetrics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetInstagramStoryInsights200ResponseDataMetrics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'views')
    self.views = attributes[:'views']
  else
    self.views = nil
  end

  if attributes.key?(:'reach')
    self.reach = attributes[:'reach']
  else
    self.reach = nil
  end

  if attributes.key?(:'replies')
    self.replies = attributes[:'replies']
  else
    self.replies = nil
  end

  if attributes.key?(:'shares')
    self.shares = attributes[:'shares']
  else
    self.shares = nil
  end

  if attributes.key?(:'navigation')
    self.navigation = attributes[:'navigation']
  else
    self.navigation = nil
  end

  if attributes.key?(:'taps_forward')
    self.taps_forward = attributes[:'taps_forward']
  else
    self.taps_forward = nil
  end

  if attributes.key?(:'taps_back')
    self.taps_back = attributes[:'taps_back']
  else
    self.taps_back = nil
  end

  if attributes.key?(:'exits')
    self.exits = attributes[:'exits']
  else
    self.exits = nil
  end

  if attributes.key?(:'swipes_forward')
    self.swipes_forward = attributes[:'swipes_forward']
  else
    self.swipes_forward = nil
  end

  if attributes.key?(:'profile_visits')
    self.profile_visits = attributes[:'profile_visits']
  else
    self.profile_visits = nil
  end

  if attributes.key?(:'follows')
    self.follows = attributes[:'follows']
  else
    self.follows = nil
  end

  if attributes.key?(:'reposts')
    self.reposts = attributes[:'reposts']
  else
    self.reposts = nil
  end

  if attributes.key?(:'total_interactions')
    self.total_interactions = attributes[:'total_interactions']
  else
    self.total_interactions = nil
  end
end

Instance Attribute Details

#exitsObject

Closed Stories interface entirely.



39
40
41
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 39

def exits
  @exits
end

#followsObject

Returns the value of attribute follows.



46
47
48
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 46

def follows
  @follows
end

Total nav actions (tapsForward + tapsBack + exits + swipesForward).



30
31
32
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 30

def navigation
  @navigation
end

#profile_visitsObject

Returns the value of attribute profile_visits.



44
45
46
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 44

def profile_visits
  @profile_visits
end

#reachObject

Unique accounts that saw the story.



22
23
24
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 22

def reach
  @reach
end

#repliesObject

DMs sent in reply to the story.



25
26
27
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 25

def replies
  @replies
end

#repostsObject

Returns the value of attribute reposts.



48
49
50
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 48

def reposts
  @reposts
end

#sharesObject

Returns the value of attribute shares.



27
28
29
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 27

def shares
  @shares
end

#swipes_forwardObject

Swiped left to next account's story.



42
43
44
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 42

def swipes_forward
  @swipes_forward
end

#taps_backObject

Tapped left to previous slide.



36
37
38
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 36

def taps_back
  @taps_back
end

#taps_forwardObject

Tapped right to next slide of SAME story.



33
34
35
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 33

def taps_forward
  @taps_forward
end

#total_interactionsObject

Returns the value of attribute total_interactions.



50
51
52
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 50

def total_interactions
  @total_interactions
end

#viewsObject

Total story plays. Replaces deprecated 'impressions' for media created after 2024-07-02.



19
20
21
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 19

def views
  @views
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 53

def self.attribute_map
  {
    :'views' => :'views',
    :'reach' => :'reach',
    :'replies' => :'replies',
    :'shares' => :'shares',
    :'navigation' => :'navigation',
    :'taps_forward' => :'tapsForward',
    :'taps_back' => :'tapsBack',
    :'exits' => :'exits',
    :'swipes_forward' => :'swipesForward',
    :'profile_visits' => :'profileVisits',
    :'follows' => :'follows',
    :'reposts' => :'reposts',
    :'total_interactions' => :'totalInteractions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 446

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 82

def self.openapi_types
  {
    :'views' => :'Integer',
    :'reach' => :'Integer',
    :'replies' => :'Integer',
    :'shares' => :'Integer',
    :'navigation' => :'Integer',
    :'taps_forward' => :'Integer',
    :'taps_back' => :'Integer',
    :'exits' => :'Integer',
    :'swipes_forward' => :'Integer',
    :'profile_visits' => :'Integer',
    :'follows' => :'Integer',
    :'reposts' => :'Integer',
    :'total_interactions' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 413

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      views == o.views &&
      reach == o.reach &&
      replies == o.replies &&
      shares == o.shares &&
      navigation == o.navigation &&
      taps_forward == o.taps_forward &&
      taps_back == o.taps_back &&
      exits == o.exits &&
      swipes_forward == o.swipes_forward &&
      profile_visits == o.profile_visits &&
      follows == o.follows &&
      reposts == o.reposts &&
      total_interactions == o.total_interactions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


433
434
435
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 433

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



439
440
441
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 439

def hash
  [views, reach, replies, shares, navigation, taps_forward, taps_back, exits, swipes_forward, profile_visits, follows, reposts, total_interactions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 203

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @views.nil?
    invalid_properties.push('invalid value for "views", views cannot be nil.')
  end

  if @reach.nil?
    invalid_properties.push('invalid value for "reach", reach cannot be nil.')
  end

  if @replies.nil?
    invalid_properties.push('invalid value for "replies", replies cannot be nil.')
  end

  if @shares.nil?
    invalid_properties.push('invalid value for "shares", shares cannot be nil.')
  end

  if @navigation.nil?
    invalid_properties.push('invalid value for "navigation", navigation cannot be nil.')
  end

  if @taps_forward.nil?
    invalid_properties.push('invalid value for "taps_forward", taps_forward cannot be nil.')
  end

  if @taps_back.nil?
    invalid_properties.push('invalid value for "taps_back", taps_back cannot be nil.')
  end

  if @exits.nil?
    invalid_properties.push('invalid value for "exits", exits cannot be nil.')
  end

  if @swipes_forward.nil?
    invalid_properties.push('invalid value for "swipes_forward", swipes_forward cannot be nil.')
  end

  if @profile_visits.nil?
    invalid_properties.push('invalid value for "profile_visits", profile_visits cannot be nil.')
  end

  if @follows.nil?
    invalid_properties.push('invalid value for "follows", follows cannot be nil.')
  end

  if @reposts.nil?
    invalid_properties.push('invalid value for "reposts", reposts cannot be nil.')
  end

  if @total_interactions.nil?
    invalid_properties.push('invalid value for "total_interactions", total_interactions cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



468
469
470
471
472
473
474
475
476
477
478
479
480
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 468

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/zernio-sdk/models/get_instagram_story_insights200_response_data_metrics.rb', line 263

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @views.nil?
  return false if @reach.nil?
  return false if @replies.nil?
  return false if @shares.nil?
  return false if @navigation.nil?
  return false if @taps_forward.nil?
  return false if @taps_back.nil?
  return false if @exits.nil?
  return false if @swipes_forward.nil?
  return false if @profile_visits.nil?
  return false if @follows.nil?
  return false if @reposts.nil?
  return false if @total_interactions.nil?
  true
end