Class: Zernio::GetLinkedInBidPricingRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetLinkedInBidPricingRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetLinkedInBidPricingRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetLinkedInBidPricingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'spec')
    self.spec = attributes[:'spec']
  else
    self.spec = nil
  end

  if attributes.key?(:'campaign_type')
    self.campaign_type = attributes[:'campaign_type']
  end

  if attributes.key?(:'bid_type')
    self.bid_type = attributes[:'bid_type']
  end

  if attributes.key?(:'match_type')
    self.match_type = attributes[:'match_type']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'objective_type')
    self.objective_type = attributes[:'objective_type']
  end

  if attributes.key?(:'optimization_target_type')
    self.optimization_target_type = attributes[:'optimization_target_type']
  end

  if attributes.key?(:'daily_budget')
    self.daily_budget = attributes[:'daily_budget']
  end
end

Instance Attribute Details

#account_idObject

Zernio social account ID (LinkedIn).



19
20
21
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 19

def 
  @account_id
end

#ad_account_idObject

LinkedIn ad account ID (numeric).



22
23
24
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 22

def 
  @ad_account_id
end

#bid_typeObject

Defaults to CPM.



31
32
33
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 31

def bid_type
  @bid_type
end

#campaign_typeObject

Defaults to SPONSORED_UPDATES.



28
29
30
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 28

def campaign_type
  @campaign_type
end

#currencyObject

ISO 4217, defaults to USD.



37
38
39
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 37

def currency
  @currency
end

#daily_budgetObject

Optional daily budget in whole account-currency units. LinkedIn refines the suggested bid to this budget.



46
47
48
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 46

def daily_budget
  @daily_budget
end

#match_typeObject

Defaults to EXACT.



34
35
36
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 34

def match_type
  @match_type
end

#objective_typeObject

LinkedIn objectiveType, e.g. WEBSITE_VISIT, LEAD_GENERATION, VIDEO_VIEW.



40
41
42
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 40

def objective_type
  @objective_type
end

#optimization_target_typeObject

LinkedIn optimizationTargetType, e.g. MAX_CLICK, MAX_IMPRESSION.



43
44
45
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 43

def optimization_target_type
  @optimization_target_type
end

#specObject

Same targeting spec used by POST /v1/ads/create.



25
26
27
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 25

def spec
  @spec
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 71

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'ad_account_id' => :'adAccountId',
    :'spec' => :'spec',
    :'campaign_type' => :'campaignType',
    :'bid_type' => :'bidType',
    :'match_type' => :'matchType',
    :'currency' => :'currency',
    :'objective_type' => :'objectiveType',
    :'optimization_target_type' => :'optimizationTargetType',
    :'daily_budget' => :'dailyBudget'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 323

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
117
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 113

def self.openapi_nullable
  Set.new([
    :'spec',
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 97

def self.openapi_types
  {
    :'account_id' => :'String',
    :'ad_account_id' => :'String',
    :'spec' => :'TargetingSpec',
    :'campaign_type' => :'String',
    :'bid_type' => :'String',
    :'match_type' => :'String',
    :'currency' => :'String',
    :'objective_type' => :'String',
    :'optimization_target_type' => :'String',
    :'daily_budget' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 293

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      spec == o.spec &&
      campaign_type == o.campaign_type &&
      bid_type == o.bid_type &&
      match_type == o.match_type &&
      currency == o.currency &&
      objective_type == o.objective_type &&
      optimization_target_type == o.optimization_target_type &&
      daily_budget == o.daily_budget
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 310

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



316
317
318
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 316

def hash
  [, , spec, campaign_type, bid_type, match_type, currency, objective_type, optimization_target_type, daily_budget].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @ad_account_id.nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  if !@currency.nil? && @currency.to_s.length > 3
    invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.')
  end

  if !@currency.nil? && @currency.to_s.length < 3
    invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 3.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 345

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/zernio-sdk/models/get_linked_in_bid_pricing_request.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @ad_account_id.nil?
  campaign_type_validator = EnumAttributeValidator.new('String', ["TEXT_AD", "SPONSORED_UPDATES", "SPONSORED_INMAILS"])
  return false unless campaign_type_validator.valid?(@campaign_type)
  bid_type_validator = EnumAttributeValidator.new('String', ["CPM", "CPC", "CPV"])
  return false unless bid_type_validator.valid?(@bid_type)
  match_type_validator = EnumAttributeValidator.new('String', ["EXACT", "AUDIENCE_EXPANDED"])
  return false unless match_type_validator.valid?(@match_type)
  return false if !@currency.nil? && @currency.to_s.length > 3
  return false if !@currency.nil? && @currency.to_s.length < 3
  true
end