Class: Zernio::GetPhoneNumberKycForm200ResponseFieldsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetPhoneNumberKycForm200ResponseFieldsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetPhoneNumberKycForm200ResponseFieldsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetPhoneNumberKycForm200ResponseFieldsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'requirement_id')
    self.requirement_id = attributes[:'requirement_id']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'example')
    self.example = attributes[:'example']
  end

  if attributes.key?(:'local_to')
    self.local_to = attributes[:'local_to']
  end
end

Instance Attribute Details

#descriptionObject

Plain-English explanation of what to provide.



26
27
28
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 26

def description
  @description
end

#exampleObject

Concrete example value.



29
30
31
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 29

def example
  @example
end

#kindObject

"action" = an out-of-band verification (e.g. Onfido); not filled here, fulfilled after the order via a link.



23
24
25
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 23

def kind
  @kind
end

#labelObject

Returns the value of attribute label.



20
21
22
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 20

def label
  @label
end

#local_toObject

ISO country the value must be local to



32
33
34
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 32

def local_to
  @local_to
end

#requirement_idObject

Returns the value of attribute requirement_id.



18
19
20
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 18

def requirement_id
  @requirement_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 57

def self.attribute_map
  {
    :'requirement_id' => :'requirementId',
    :'label' => :'label',
    :'kind' => :'kind',
    :'description' => :'description',
    :'example' => :'example',
    :'local_to' => :'localTo'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 195

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
96
97
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 91

def self.openapi_nullable
  Set.new([
    :'description',
    :'example',
    :'local_to'
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 79

def self.openapi_types
  {
    :'requirement_id' => :'String',
    :'label' => :'String',
    :'kind' => :'String',
    :'description' => :'String',
    :'example' => :'String',
    :'local_to' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



169
170
171
172
173
174
175
176
177
178
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 169

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      requirement_id == o.requirement_id &&
      label == o.label &&
      kind == o.kind &&
      description == o.description &&
      example == o.example &&
      local_to == o.local_to
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


182
183
184
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 182

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



188
189
190
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 188

def hash
  [requirement_id, label, kind, description, example, local_to].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 217

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
154
155
# File 'lib/zernio-sdk/models/get_phone_number_kyc_form200_response_fields_inner.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  kind_validator = EnumAttributeValidator.new('String', ["text", "date", "address", "file", "action"])
  return false unless kind_validator.valid?(@kind)
  true
end