Class: Zernio::GetPostTimeline200ResponseTimelineInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetPostTimeline200ResponseTimelineInner
- Defined in:
- lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb
Instance Attribute Summary collapse
-
#clicks ⇒ Object
Total clicks on this date.
-
#comments ⇒ Object
Total comments on this date.
-
#date ⇒ Object
Date in YYYY-MM-DD format.
-
#impressions ⇒ Object
Total impressions on this date.
-
#likes ⇒ Object
Total likes on this date.
-
#platform ⇒ Object
Platform name (e.g. instagram, tiktok).
-
#platform_post_id ⇒ Object
Platform-specific post ID.
-
#reach ⇒ Object
Total reach on this date.
-
#saves ⇒ Object
Total saves on this date.
-
#shares ⇒ Object
Total shares on this date.
-
#views ⇒ Object
Total views on this date.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetPostTimeline200ResponseTimelineInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetPostTimeline200ResponseTimelineInner
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetPostTimeline200ResponseTimelineInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetPostTimeline200ResponseTimelineInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] end if attributes.key?(:'impressions') self.impressions = attributes[:'impressions'] end if attributes.key?(:'reach') self.reach = attributes[:'reach'] end if attributes.key?(:'likes') self.likes = attributes[:'likes'] end if attributes.key?(:'comments') self.comments = attributes[:'comments'] end if attributes.key?(:'shares') self.shares = attributes[:'shares'] end if attributes.key?(:'saves') self.saves = attributes[:'saves'] end if attributes.key?(:'clicks') self.clicks = attributes[:'clicks'] end if attributes.key?(:'views') self.views = attributes[:'views'] end end |
Instance Attribute Details
#clicks ⇒ Object
Total clicks on this date
46 47 48 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 46 def clicks @clicks end |
#comments ⇒ Object
Total comments on this date
37 38 39 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 37 def comments @comments end |
#date ⇒ Object
Date in YYYY-MM-DD format
19 20 21 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 19 def date @date end |
#impressions ⇒ Object
Total impressions on this date
28 29 30 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 28 def impressions @impressions end |
#likes ⇒ Object
Total likes on this date
34 35 36 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 34 def likes @likes end |
#platform ⇒ Object
Platform name (e.g. instagram, tiktok)
22 23 24 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 22 def platform @platform end |
#platform_post_id ⇒ Object
Platform-specific post ID
25 26 27 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 25 def platform_post_id @platform_post_id end |
#reach ⇒ Object
Total reach on this date
31 32 33 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 31 def reach @reach end |
#saves ⇒ Object
Total saves on this date
43 44 45 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 43 def saves @saves end |
#shares ⇒ Object
Total shares on this date
40 41 42 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 40 def shares @shares end |
#views ⇒ Object
Total views on this date
49 50 51 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 49 def views @views end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 52 def self.attribute_map { :'date' => :'date', :'platform' => :'platform', :'platform_post_id' => :'platformPostId', :'impressions' => :'impressions', :'reach' => :'reach', :'likes' => :'likes', :'comments' => :'comments', :'shares' => :'shares', :'saves' => :'saves', :'clicks' => :'clicks', :'views' => :'views' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 79 def self.openapi_types { :'date' => :'Date', :'platform' => :'String', :'platform_post_id' => :'String', :'impressions' => :'Integer', :'reach' => :'Integer', :'likes' => :'Integer', :'comments' => :'Integer', :'shares' => :'Integer', :'saves' => :'Integer', :'clicks' => :'Integer', :'views' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && date == o.date && platform == o.platform && platform_post_id == o.platform_post_id && impressions == o.impressions && reach == o.reach && likes == o.likes && comments == o.comments && shares == o.shares && saves == o.saves && clicks == o.clicks && views == o.views end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 203 def hash [date, platform, platform_post_id, impressions, reach, likes, comments, shares, saves, clicks, views].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
172 173 174 175 |
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 172 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |