Class: Zernio::GetPostingFrequency200ResponseFrequencyInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetPostingFrequency200ResponseFrequencyInner
- Defined in:
- lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb
Instance Attribute Summary collapse
-
#avg_engagement ⇒ Object
Average raw engagement (likes+comments+shares+saves).
-
#avg_engagement_rate ⇒ Object
Average engagement rate as percentage (0-100).
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#posts_per_week ⇒ Object
Number of posts published that week.
-
#weeks_count ⇒ Object
Number of calendar weeks observed at this frequency.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetPostingFrequency200ResponseFrequencyInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetPostingFrequency200ResponseFrequencyInner
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetPostingFrequency200ResponseFrequencyInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetPostingFrequency200ResponseFrequencyInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'posts_per_week') self.posts_per_week = attributes[:'posts_per_week'] end if attributes.key?(:'avg_engagement_rate') self.avg_engagement_rate = attributes[:'avg_engagement_rate'] end if attributes.key?(:'avg_engagement') self.avg_engagement = attributes[:'avg_engagement'] end if attributes.key?(:'weeks_count') self.weeks_count = attributes[:'weeks_count'] end end |
Instance Attribute Details
#avg_engagement ⇒ Object
Average raw engagement (likes+comments+shares+saves)
27 28 29 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 27 def avg_engagement @avg_engagement end |
#avg_engagement_rate ⇒ Object
Average engagement rate as percentage (0-100)
24 25 26 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 24 def avg_engagement_rate @avg_engagement_rate end |
#platform ⇒ Object
Returns the value of attribute platform.
18 19 20 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 18 def platform @platform end |
#posts_per_week ⇒ Object
Number of posts published that week
21 22 23 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 21 def posts_per_week @posts_per_week end |
#weeks_count ⇒ Object
Number of calendar weeks observed at this frequency
30 31 32 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 30 def weeks_count @weeks_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 33 def self.attribute_map { :'platform' => :'platform', :'posts_per_week' => :'posts_per_week', :'avg_engagement_rate' => :'avg_engagement_rate', :'avg_engagement' => :'avg_engagement', :'weeks_count' => :'weeks_count' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 149 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 54 def self.openapi_types { :'platform' => :'String', :'posts_per_week' => :'Integer', :'avg_engagement_rate' => :'Float', :'avg_engagement' => :'Float', :'weeks_count' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 124 def ==(o) return true if self.equal?(o) self.class == o.class && platform == o.platform && posts_per_week == o.posts_per_week && avg_engagement_rate == o.avg_engagement_rate && avg_engagement == o.avg_engagement && weeks_count == o.weeks_count end |
#eql?(o) ⇒ Boolean
136 137 138 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 136 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 142 def hash [platform, posts_per_week, avg_engagement_rate, avg_engagement, weeks_count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 109 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 |
# File 'lib/zernio-sdk/models/get_posting_frequency200_response_frequency_inner.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |