Class: Zernio::GetWhatsAppNumberInfo200ResponsePhone

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWhatsAppNumberInfo200ResponsePhone

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsAppNumberInfo200ResponsePhone` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsAppNumberInfo200ResponsePhone`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'display_phone_number')
    self.display_phone_number = attributes[:'display_phone_number']
  end

  if attributes.key?(:'verified_name')
    self.verified_name = attributes[:'verified_name']
  end

  if attributes.key?(:'name_status')
    self.name_status = attributes[:'name_status']
  end

  if attributes.key?(:'quality_rating')
    self.quality_rating = attributes[:'quality_rating']
  end

  if attributes.key?(:'messaging_limit_tier')
    self.messaging_limit_tier = attributes[:'messaging_limit_tier']
  end

  if attributes.key?(:'throughput')
    self.throughput = attributes[:'throughput']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'is_official_business_account')
    self. = attributes[:'is_official_business_account']
  end

  if attributes.key?(:'platform_type')
    self.platform_type = attributes[:'platform_type']
  end

  if attributes.key?(:'health_status')
    self.health_status = attributes[:'health_status']
  end
end

Instance Attribute Details

#display_phone_numberObject

Returns the value of attribute display_phone_number.



18
19
20
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 18

def display_phone_number
  @display_phone_number
end

#health_statusObject

Meta's can_send_message health object (messaging + calling signals)



42
43
44
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 42

def health_status
  @health_status
end

#is_official_business_accountObject

Returns the value of attribute is_official_business_account.



36
37
38
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 36

def 
  @is_official_business_account
end

#messaging_limit_tierObject

e.g. TIER_250, TIER_1K, TIER_UNLIMITED



29
30
31
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 29

def messaging_limit_tier
  @messaging_limit_tier
end

#name_statusObject

APPROVED, AVAILABLE_WITHOUT_REVIEW, PENDING_REVIEW, DECLINED, EXPIRED, NONE



23
24
25
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 23

def name_status
  @name_status
end

#platform_typeObject

e.g. CLOUD_API



39
40
41
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 39

def platform_type
  @platform_type
end

#quality_ratingObject

GREEN, YELLOW, RED, UNKNOWN



26
27
28
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 26

def quality_rating
  @quality_rating
end

#statusObject

e.g. CONNECTED



34
35
36
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 34

def status
  @status
end

#throughputObject

Returns the value of attribute throughput.



31
32
33
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 31

def throughput
  @throughput
end

#verified_nameObject

Returns the value of attribute verified_name.



20
21
22
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 20

def verified_name
  @verified_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 45

def self.attribute_map
  {
    :'display_phone_number' => :'display_phone_number',
    :'verified_name' => :'verified_name',
    :'name_status' => :'name_status',
    :'quality_rating' => :'quality_rating',
    :'messaging_limit_tier' => :'messaging_limit_tier',
    :'throughput' => :'throughput',
    :'status' => :'status',
    :'is_official_business_account' => :'is_official_business_account',
    :'platform_type' => :'platform_type',
    :'health_status' => :'health_status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 71

def self.openapi_types
  {
    :'display_phone_number' => :'String',
    :'verified_name' => :'String',
    :'name_status' => :'String',
    :'quality_rating' => :'String',
    :'messaging_limit_tier' => :'String',
    :'throughput' => :'GetWhatsAppNumberInfo200ResponsePhoneThroughput',
    :'status' => :'String',
    :'is_official_business_account' => :'Boolean',
    :'platform_type' => :'String',
    :'health_status' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 166

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      display_phone_number == o.display_phone_number &&
      verified_name == o.verified_name &&
      name_status == o.name_status &&
      quality_rating == o.quality_rating &&
      messaging_limit_tier == o.messaging_limit_tier &&
      throughput == o.throughput &&
      status == o.status &&
       == o. &&
      platform_type == o.platform_type &&
      health_status == o.health_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 189

def hash
  [display_phone_number, verified_name, name_status, quality_rating, messaging_limit_tier, throughput, status, , platform_type, health_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
# File 'lib/zernio-sdk/models/get_whats_app_number_info200_response_phone.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end