Class: Zernio::GetWorkflow200ResponseWorkflow
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetWorkflow200ResponseWorkflow
- Defined in:
- lib/zernio-sdk/models/get_workflow200_response_workflow.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#edges ⇒ Object
Returns the value of attribute edges.
-
#entry_node_id ⇒ Object
Returns the value of attribute entry_node_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#nodes ⇒ Object
Returns the value of attribute nodes.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#profile_id ⇒ Object
Returns the value of attribute profile_id.
-
#status ⇒ Object
Returns the value of attribute status.
-
#total_completed ⇒ Object
Returns the value of attribute total_completed.
-
#total_exited ⇒ Object
Returns the value of attribute total_exited.
-
#total_started ⇒ Object
Returns the value of attribute total_started.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetWorkflow200ResponseWorkflow
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetWorkflow200ResponseWorkflow
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWorkflow200ResponseWorkflow` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWorkflow200ResponseWorkflow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'entry_node_id') self.entry_node_id = attributes[:'entry_node_id'] end if attributes.key?(:'nodes') if (value = attributes[:'nodes']).is_a?(Array) self.nodes = value end end if attributes.key?(:'edges') if (value = attributes[:'edges']).is_a?(Array) self.edges = value end end if attributes.key?(:'total_started') self.total_started = attributes[:'total_started'] end if attributes.key?(:'total_completed') self.total_completed = attributes[:'total_completed'] end if attributes.key?(:'total_exited') self.total_exited = attributes[:'total_exited'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
26 27 28 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 26 def account_id @account_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
44 45 46 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 44 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 22 def description @description end |
#edges ⇒ Object
Returns the value of attribute edges.
36 37 38 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 36 def edges @edges end |
#entry_node_id ⇒ Object
Returns the value of attribute entry_node_id.
32 33 34 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 32 def entry_node_id @entry_node_id end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 18 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 20 def name @name end |
#nodes ⇒ Object
Returns the value of attribute nodes.
34 35 36 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 34 def nodes @nodes end |
#platform ⇒ Object
Returns the value of attribute platform.
24 25 26 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 24 def platform @platform end |
#profile_id ⇒ Object
Returns the value of attribute profile_id.
28 29 30 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 28 def profile_id @profile_id end |
#status ⇒ Object
Returns the value of attribute status.
30 31 32 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 30 def status @status end |
#total_completed ⇒ Object
Returns the value of attribute total_completed.
40 41 42 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 40 def total_completed @total_completed end |
#total_exited ⇒ Object
Returns the value of attribute total_exited.
42 43 44 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 42 def total_exited @total_exited end |
#total_started ⇒ Object
Returns the value of attribute total_started.
38 39 40 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 38 def total_started @total_started end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
46 47 48 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 46 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
92 93 94 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 92 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 97 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 71 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'platform' => :'platform', :'account_id' => :'accountId', :'profile_id' => :'profileId', :'status' => :'status', :'entry_node_id' => :'entryNodeId', :'nodes' => :'nodes', :'edges' => :'edges', :'total_started' => :'totalStarted', :'total_completed' => :'totalCompleted', :'total_exited' => :'totalExited', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 273 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 102 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'platform' => :'String', :'account_id' => :'String', :'profile_id' => :'String', :'status' => :'String', :'entry_node_id' => :'String', :'nodes' => :'Array<WorkflowNode>', :'edges' => :'Array<WorkflowEdge>', :'total_started' => :'Integer', :'total_completed' => :'Integer', :'total_exited' => :'Integer', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && platform == o.platform && account_id == o.account_id && profile_id == o.profile_id && status == o.status && entry_node_id == o.entry_node_id && nodes == o.nodes && edges == o.edges && total_started == o.total_started && total_completed == o.total_completed && total_exited == o.total_exited && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
260 261 262 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 260 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
266 267 268 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 266 def hash [id, name, description, platform, account_id, profile_id, status, entry_node_id, nodes, edges, total_started, total_completed, total_exited, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
211 212 213 214 215 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 211 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 223 224 |
# File 'lib/zernio-sdk/models/get_workflow200_response_workflow.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["draft", "active", "paused"]) return false unless status_validator.valid?(@status) true end |