Class: Zernio::GoogleBusinessPlatformData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GoogleBusinessPlatformData
- Defined in:
- lib/zernio-sdk/models/google_business_platform_data.rb
Overview
Text and single image only (no videos). Supports STANDARD, EVENT, OFFER, and ALERT post types. Posts appear on GBP, Google Search, and Maps. Use locationId for multi-location posting. Schedule dates accept both ISO 8601 strings (e.g. '2026-04-15T09:00:00Z') and Google's native month, day objects.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#call_to_action ⇒ Object
Returns the value of attribute call_to_action.
-
#event ⇒ Object
Returns the value of attribute event.
-
#language_code ⇒ Object
BCP 47 language code (e.g. "en", "de", "es").
-
#location_id ⇒ Object
Target GBP location ID (e.g. "locations/123456789").
-
#offer ⇒ Object
Returns the value of attribute offer.
-
#topic_type ⇒ Object
Post type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GoogleBusinessPlatformData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GoogleBusinessPlatformData
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GoogleBusinessPlatformData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GoogleBusinessPlatformData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'location_id') self.location_id = attributes[:'location_id'] end if attributes.key?(:'language_code') self.language_code = attributes[:'language_code'] end if attributes.key?(:'topic_type') self.topic_type = attributes[:'topic_type'] else self.topic_type = 'STANDARD' end if attributes.key?(:'call_to_action') self.call_to_action = attributes[:'call_to_action'] end if attributes.key?(:'event') self.event = attributes[:'event'] end if attributes.key?(:'offer') self.offer = attributes[:'offer'] end end |
Instance Attribute Details
#call_to_action ⇒ Object
Returns the value of attribute call_to_action.
28 29 30 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 28 def call_to_action @call_to_action end |
#event ⇒ Object
Returns the value of attribute event.
30 31 32 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 30 def event @event end |
#language_code ⇒ Object
BCP 47 language code (e.g. "en", "de", "es"). Auto-detected if omitted. Set explicitly for short or mixed-language posts.
23 24 25 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 23 def language_code @language_code end |
#location_id ⇒ Object
Target GBP location ID (e.g. "locations/123456789"). If omitted, uses the default location. Use GET /v1/accounts/id/gmb-locations to list locations.
20 21 22 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 20 def location_id @location_id end |
#offer ⇒ Object
Returns the value of attribute offer.
32 33 34 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 32 def offer @offer end |
#topic_type ⇒ Object
Post type. STANDARD is a regular update. EVENT requires the event object. OFFER requires the offer object. Defaults to STANDARD if omitted.
26 27 28 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 26 def topic_type @topic_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 57 def self.attribute_map { :'location_id' => :'locationId', :'language_code' => :'languageCode', :'topic_type' => :'topicType', :'call_to_action' => :'callToAction', :'event' => :'event', :'offer' => :'offer' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 79 def self.openapi_types { :'location_id' => :'String', :'language_code' => :'String', :'topic_type' => :'String', :'call_to_action' => :'GoogleBusinessPlatformDataCallToAction', :'event' => :'GoogleBusinessPlatformDataEvent', :'offer' => :'GoogleBusinessPlatformDataOffer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && location_id == o.location_id && language_code == o.language_code && topic_type == o.topic_type && call_to_action == o.call_to_action && event == o.event && offer == o.offer end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 187 def hash [location_id, language_code, topic_type, call_to_action, event, offer].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 |
# File 'lib/zernio-sdk/models/google_business_platform_data.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' topic_type_validator = EnumAttributeValidator.new('String', ["STANDARD", "EVENT", "OFFER"]) return false unless topic_type_validator.valid?(@topic_type) true end |