Class: Zernio::InitiateWhatsAppCall200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/initiate_whats_app_call200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InitiateWhatsAppCall200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::InitiateWhatsAppCall200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::InitiateWhatsAppCall200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'call_id')
    self.call_id = attributes[:'call_id']
  end

  if attributes.key?(:'telnyx_call_control_id')
    self.telnyx_call_control_id = attributes[:'telnyx_call_control_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'forward_to')
    self.forward_to = attributes[:'forward_to']
  end

  if attributes.key?(:'recording_enabled')
    self.recording_enabled = attributes[:'recording_enabled']
  end
end

Instance Attribute Details

#call_idObject

Internal Call doc ID



21
22
23
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 21

def call_id
  @call_id
end

#directionObject

Returns the value of attribute direction.



28
29
30
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 28

def direction
  @direction
end

#forward_toObject

Returns the value of attribute forward_to.



32
33
34
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 32

def forward_to
  @forward_to
end

#recording_enabledObject

Returns the value of attribute recording_enabled.



34
35
36
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 34

def recording_enabled
  @recording_enabled
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 26

def status
  @status
end

#successObject

Returns the value of attribute success.



18
19
20
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 18

def success
  @success
end

#telnyx_call_control_idObject

Telnyx call_control_id of the outbound leg



24
25
26
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 24

def telnyx_call_control_id
  @telnyx_call_control_id
end

#toObject

Returns the value of attribute to.



30
31
32
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 30

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 59

def self.attribute_map
  {
    :'success' => :'success',
    :'call_id' => :'callId',
    :'telnyx_call_control_id' => :'telnyxCallControlId',
    :'status' => :'status',
    :'direction' => :'direction',
    :'to' => :'to',
    :'forward_to' => :'forwardTo',
    :'recording_enabled' => :'recordingEnabled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
101
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 97

def self.openapi_nullable
  Set.new([
    :'forward_to',
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 83

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'call_id' => :'String',
    :'telnyx_call_control_id' => :'String',
    :'status' => :'String',
    :'direction' => :'String',
    :'to' => :'String',
    :'forward_to' => :'String',
    :'recording_enabled' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
      call_id == o.call_id &&
      telnyx_call_control_id == o.telnyx_call_control_id &&
      status == o.status &&
      direction == o.direction &&
      to == o.to &&
      forward_to == o.forward_to &&
      recording_enabled == o.recording_enabled
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 214

def hash
  [success, call_id, telnyx_call_control_id, status, direction, to, forward_to, recording_enabled].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
169
# File 'lib/zernio-sdk/models/initiate_whats_app_call200_response.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["dialing"])
  return false unless status_validator.valid?(@status)
  direction_validator = EnumAttributeValidator.new('String', ["outbound"])
  return false unless direction_validator.valid?(@direction)
  true
end