Class: Zernio::InstagramDemographicsResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::InstagramDemographicsResponse
- Defined in:
- lib/zernio-sdk/models/instagram_demographics_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The Zernio SocialAccount ID.
-
#demographics ⇒ Object
Object keyed by breakdown dimension (age, city, country, gender).
-
#metric ⇒ Object
Returns the value of attribute metric.
-
#note ⇒ Object
Returns the value of attribute note.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#success ⇒ Object
Returns the value of attribute success.
-
#timeframe ⇒ Object
The timeframe used for demographic data.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InstagramDemographicsResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InstagramDemographicsResponse
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::InstagramDemographicsResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::InstagramDemographicsResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'metric') self.metric = attributes[:'metric'] end if attributes.key?(:'timeframe') self.timeframe = attributes[:'timeframe'] end if attributes.key?(:'demographics') if (value = attributes[:'demographics']).is_a?(Hash) self.demographics = value end end if attributes.key?(:'note') self.note = attributes[:'note'] end end |
Instance Attribute Details
#account_id ⇒ Object
The Zernio SocialAccount ID
21 22 23 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 21 def account_id @account_id end |
#demographics ⇒ Object
Object keyed by breakdown dimension (age, city, country, gender)
31 32 33 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 31 def demographics @demographics end |
#metric ⇒ Object
Returns the value of attribute metric.
25 26 27 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 25 def metric @metric end |
#note ⇒ Object
Returns the value of attribute note.
33 34 35 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 33 def note @note end |
#platform ⇒ Object
Returns the value of attribute platform.
23 24 25 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 23 def platform @platform end |
#success ⇒ Object
Returns the value of attribute success.
18 19 20 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 18 def success @success end |
#timeframe ⇒ Object
The timeframe used for demographic data
28 29 30 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 28 def timeframe @timeframe end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 58 def self.attribute_map { :'success' => :'success', :'account_id' => :'accountId', :'platform' => :'platform', :'metric' => :'metric', :'timeframe' => :'timeframe', :'demographics' => :'demographics', :'note' => :'note' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 94 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 81 def self.openapi_types { :'success' => :'Boolean', :'account_id' => :'String', :'platform' => :'String', :'metric' => :'String', :'timeframe' => :'String', :'demographics' => :'Hash<String, Array<InstagramDemographicsResponseDemographicsValueInner>>', :'note' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 187 def ==(o) return true if self.equal?(o) self.class == o.class && success == o.success && account_id == o.account_id && platform == o.platform && metric == o.metric && timeframe == o.timeframe && demographics == o.demographics && note == o.note end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 207 def hash [success, account_id, platform, metric, timeframe, demographics, note].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/models/instagram_demographics_response.rb', line 156 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' metric_validator = EnumAttributeValidator.new('String', ["follower_demographics", "engaged_audience_demographics"]) return false unless metric_validator.valid?(@metric) timeframe_validator = EnumAttributeValidator.new('String', ["this_week", "this_month"]) return false unless timeframe_validator.valid?(@timeframe) true end |