Class: Zernio::LinkedInAdsPlatformDataFollower

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb

Overview

POST /v1/ads/create only. Dynamic Follower Ad promoting the Company Page. Supported goals: engagement, awareness. headline and description take exactly one of preApproved or custom. Mutually exclusive with the other creative sources.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LinkedInAdsPlatformDataFollower

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::LinkedInAdsPlatformDataFollower` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::LinkedInAdsPlatformDataFollower`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'headline')
    self.headline = attributes[:'headline']
  else
    self.headline = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'call_to_action')
    self.call_to_action = attributes[:'call_to_action']
  else
    self.call_to_action = nil
  end

  if attributes.key?(:'logo_url')
    self.logo_url = attributes[:'logo_url']
  end

  if attributes.key?(:'organization_name')
    self.organization_name = attributes[:'organization_name']
  end

  if attributes.key?(:'show_member_profile_photo')
    self.show_member_profile_photo = attributes[:'show_member_profile_photo']
  end
end

Instance Attribute Details

#call_to_actionObject

Returns the value of attribute call_to_action.



23
24
25
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 23

def call_to_action
  @call_to_action
end

#descriptionObject

Returns the value of attribute description.



21
22
23
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 21

def description
  @description
end

#headlineObject

Returns the value of attribute headline.



19
20
21
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 19

def headline
  @headline
end

#logo_urlObject

Returns the value of attribute logo_url.



25
26
27
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 25

def logo_url
  @logo_url
end

#organization_nameObject

Returns the value of attribute organization_name.



27
28
29
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 27

def organization_name
  @organization_name
end

#show_member_profile_photoObject

Defaults to true.



30
31
32
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 30

def show_member_profile_photo
  @show_member_profile_photo
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 55

def self.attribute_map
  {
    :'headline' => :'headline',
    :'description' => :'description',
    :'call_to_action' => :'callToAction',
    :'logo_url' => :'logoUrl',
    :'organization_name' => :'organizationName',
    :'show_member_profile_photo' => :'showMemberProfilePhoto'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 77

def self.openapi_types
  {
    :'headline' => :'LinkedInAdsPlatformDataFollowerHeadline',
    :'description' => :'LinkedInAdsPlatformDataFollowerDescription',
    :'call_to_action' => :'String',
    :'logo_url' => :'String',
    :'organization_name' => :'String',
    :'show_member_profile_photo' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



205
206
207
208
209
210
211
212
213
214
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 205

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      headline == o.headline &&
      description == o.description &&
      call_to_action == o.call_to_action &&
      logo_url == o.logo_url &&
      organization_name == o.organization_name &&
      show_member_profile_photo == o.show_member_profile_photo
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 224

def hash
  [headline, description, call_to_action, logo_url, organization_name, show_member_profile_photo].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @headline.nil?
    invalid_properties.push('invalid value for "headline", headline cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @call_to_action.nil?
    invalid_properties.push('invalid value for "call_to_action", call_to_action cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
167
168
169
170
171
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_follower.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @headline.nil?
  return false if @description.nil?
  return false if @call_to_action.nil?
  call_to_action_validator = EnumAttributeValidator.new('String', ["VISIT_ORGANIZATION_COMPANY_PAGE", "VISIT_ORGANIZATION_LIFE_PAGE", "VISIT_ORGANIZATION_JOBS_PAGE", "VISIT_ORGANIZATION_CAREERS_PAGE"])
  return false unless call_to_action_validator.valid?(@call_to_action)
  true
end