Class: Zernio::LinkedInAggregateAnalyticsDailyResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::LinkedInAggregateAnalyticsDailyResponse
- Defined in:
- lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb
Overview
Response for DAILY aggregation (time series breakdown)
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_type ⇒ Object
Returns the value of attribute account_type.
-
#aggregation ⇒ Object
Returns the value of attribute aggregation.
-
#analytics ⇒ Object
Returns the value of attribute analytics.
-
#date_range ⇒ Object
Returns the value of attribute date_range.
-
#last_updated ⇒ Object
Returns the value of attribute last_updated.
-
#note ⇒ Object
Returns the value of attribute note.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#skipped_metrics ⇒ Object
Metrics that were skipped due to API limitations.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LinkedInAggregateAnalyticsDailyResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LinkedInAggregateAnalyticsDailyResponse
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::LinkedInAggregateAnalyticsDailyResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::LinkedInAggregateAnalyticsDailyResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'aggregation') self.aggregation = attributes[:'aggregation'] end if attributes.key?(:'date_range') self.date_range = attributes[:'date_range'] end if attributes.key?(:'analytics') self.analytics = attributes[:'analytics'] end if attributes.key?(:'skipped_metrics') if (value = attributes[:'skipped_metrics']).is_a?(Array) self.skipped_metrics = value end end if attributes.key?(:'note') self.note = attributes[:'note'] end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
19 20 21 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 19 def account_id @account_id end |
#account_type ⇒ Object
Returns the value of attribute account_type.
23 24 25 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 23 def account_type @account_type end |
#aggregation ⇒ Object
Returns the value of attribute aggregation.
27 28 29 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 27 def aggregation @aggregation end |
#analytics ⇒ Object
Returns the value of attribute analytics.
31 32 33 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 31 def analytics @analytics end |
#date_range ⇒ Object
Returns the value of attribute date_range.
29 30 31 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 29 def date_range @date_range end |
#last_updated ⇒ Object
Returns the value of attribute last_updated.
38 39 40 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 38 def last_updated @last_updated end |
#note ⇒ Object
Returns the value of attribute note.
36 37 38 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 36 def note @note end |
#platform ⇒ Object
Returns the value of attribute platform.
21 22 23 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 21 def platform @platform end |
#skipped_metrics ⇒ Object
Metrics that were skipped due to API limitations
34 35 36 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 34 def skipped_metrics @skipped_metrics end |
#username ⇒ Object
Returns the value of attribute username.
25 26 27 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 25 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 63 def self.attribute_map { :'account_id' => :'accountId', :'platform' => :'platform', :'account_type' => :'accountType', :'username' => :'username', :'aggregation' => :'aggregation', :'date_range' => :'dateRange', :'analytics' => :'analytics', :'skipped_metrics' => :'skippedMetrics', :'note' => :'note', :'last_updated' => :'lastUpdated' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 228 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 89 def self.openapi_types { :'account_id' => :'String', :'platform' => :'String', :'account_type' => :'String', :'username' => :'String', :'aggregation' => :'String', :'date_range' => :'YouTubeDailyViewsResponseDateRange', :'analytics' => :'LinkedInAggregateAnalyticsDailyResponseAnalytics', :'skipped_metrics' => :'Array<String>', :'note' => :'String', :'last_updated' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && platform == o.platform && account_type == o.account_type && username == o.username && aggregation == o.aggregation && date_range == o.date_range && analytics == o.analytics && skipped_metrics == o.skipped_metrics && note == o.note && last_updated == o.last_updated end |
#eql?(o) ⇒ Boolean
215 216 217 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 215 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 221 def hash [account_id, platform, account_type, username, aggregation, date_range, analytics, skipped_metrics, note, last_updated].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 |
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' aggregation_validator = EnumAttributeValidator.new('String', ["DAILY"]) return false unless aggregation_validator.valid?(@aggregation) true end |