Class: Zernio::LinkedInLeadFormPlatformData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::LinkedInLeadFormPlatformData
- Defined in:
- lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
LinkedIn ad account id (resolves the owning organization).
-
#consents ⇒ Object
Returns the value of attribute consents.
-
#description ⇒ Object
Returns the value of attribute description.
-
#headline ⇒ Object
Returns the value of attribute headline.
-
#locale ⇒ Object
Returns the value of attribute locale.
-
#questions ⇒ Object
Returns the value of attribute questions.
-
#state ⇒ Object
Defaults to DRAFT.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LinkedInLeadFormPlatformData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LinkedInLeadFormPlatformData
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::LinkedInLeadFormPlatformData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::LinkedInLeadFormPlatformData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] else self.ad_account_id = nil end if attributes.key?(:'headline') self.headline = attributes[:'headline'] else self.headline = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'locale') self.locale = attributes[:'locale'] end if attributes.key?(:'consents') if (value = attributes[:'consents']).is_a?(Array) self. = value end end if attributes.key?(:'questions') if (value = attributes[:'questions']).is_a?(Array) self.questions = value end else self.questions = nil end end |
Instance Attribute Details
#ad_account_id ⇒ Object
LinkedIn ad account id (resolves the owning organization).
19 20 21 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 19 def ad_account_id @ad_account_id end |
#consents ⇒ Object
Returns the value of attribute consents.
30 31 32 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 30 def @consents end |
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 23 def description @description end |
#headline ⇒ Object
Returns the value of attribute headline.
21 22 23 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 21 def headline @headline end |
#locale ⇒ Object
Returns the value of attribute locale.
28 29 30 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 28 def locale @locale end |
#questions ⇒ Object
Returns the value of attribute questions.
32 33 34 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 32 def questions @questions end |
#state ⇒ Object
Defaults to DRAFT.
26 27 28 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 26 def state @state end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 57 def self.attribute_map { :'ad_account_id' => :'adAccountId', :'headline' => :'headline', :'description' => :'description', :'state' => :'state', :'locale' => :'locale', :'consents' => :'consents', :'questions' => :'questions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 298 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 80 def self.openapi_types { :'ad_account_id' => :'String', :'headline' => :'String', :'description' => :'String', :'state' => :'String', :'locale' => :'LinkedInLeadFormPlatformDataLocale', :'consents' => :'Array<LinkedInLeadFormPlatformDataConsentsInner>', :'questions' => :'Array<LinkedInLeadFormPlatformDataQuestionsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 271 def ==(o) return true if self.equal?(o) self.class == o.class && ad_account_id == o.ad_account_id && headline == o.headline && description == o.description && state == o.state && locale == o.locale && == o. && questions == o.questions end |
#eql?(o) ⇒ Boolean
285 286 287 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 285 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
291 292 293 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 291 def hash [ad_account_id, headline, description, state, locale, , questions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 157 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @ad_account_id.nil? invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.') end if @headline.nil? invalid_properties.push('invalid value for "headline", headline cannot be nil.') end if @headline.to_s.length > 255 invalid_properties.push('invalid value for "headline", the character length must be smaller than or equal to 255.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @description.to_s.length > 1500 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1500.') end if @questions.nil? invalid_properties.push('invalid value for "questions", questions cannot be nil.') end if @questions.length < 1 invalid_properties.push('invalid value for "questions", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/zernio-sdk/models/linked_in_lead_form_platform_data.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @ad_account_id.nil? return false if @headline.nil? return false if @headline.to_s.length > 255 return false if @description.nil? return false if @description.to_s.length > 1500 state_validator = EnumAttributeValidator.new('String', ["DRAFT", "PUBLISHED"]) return false unless state_validator.valid?(@state) return false if @questions.nil? return false if @questions.length < 1 true end |