Class: Zernio::ListCommentAutomations200ResponseAutomationsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListCommentAutomations200ResponseAutomationsInner
- Defined in:
- lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#buttons ⇒ Object
Inline DM buttons (up to 3).
-
#click_tag ⇒ Object
Tag applied to a contact when they click a tracked link.
-
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
-
#comment_reply_variations ⇒ Object
Alternate public replies rotated at random with commentReply.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#dm_message ⇒ Object
Returns the value of attribute dm_message.
-
#dm_message_variations ⇒ Object
Alternate DM texts rotated at random with dmMessage.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#keywords ⇒ Object
Returns the value of attribute keywords.
-
#link_tracking ⇒ Object
Whether link buttons in the DM are wrapped in a tracked redirect to count clicks.
-
#match_mode ⇒ Object
Returns the value of attribute match_mode.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
-
#post_title ⇒ Object
Returns the value of attribute post_title.
-
#stats ⇒ Object
Returns the value of attribute stats.
-
#trigger ⇒ Object
Returns the value of attribute trigger.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListCommentAutomations200ResponseAutomationsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListCommentAutomations200ResponseAutomationsInner
Initializes the object
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 151 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListCommentAutomations200ResponseAutomationsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListCommentAutomations200ResponseAutomationsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'trigger') self.trigger = attributes[:'trigger'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] end if attributes.key?(:'post_title') self.post_title = attributes[:'post_title'] end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end end if attributes.key?(:'match_mode') self.match_mode = attributes[:'match_mode'] end if attributes.key?(:'dm_message') self. = attributes[:'dm_message'] end if attributes.key?(:'buttons') if (value = attributes[:'buttons']).is_a?(Array) self. = value end end if attributes.key?(:'comment_reply') self.comment_reply = attributes[:'comment_reply'] end if attributes.key?(:'dm_message_variations') if (value = attributes[:'dm_message_variations']).is_a?(Array) self. = value end end if attributes.key?(:'comment_reply_variations') if (value = attributes[:'comment_reply_variations']).is_a?(Array) self.comment_reply_variations = value end end if attributes.key?(:'link_tracking') self.link_tracking = attributes[:'link_tracking'] end if attributes.key?(:'click_tag') self.click_tag = attributes[:'click_tag'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'stats') self.stats = attributes[:'stats'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
26 27 28 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 26 def account_id @account_id end |
#buttons ⇒ Object
Inline DM buttons (up to 3). Omitted when none are set.
39 40 41 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 39 def @buttons end |
#click_tag ⇒ Object
Tag applied to a contact when they click a tracked link.
53 54 55 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 53 def click_tag @click_tag end |
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
41 42 43 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 41 def comment_reply @comment_reply end |
#comment_reply_variations ⇒ Object
Alternate public replies rotated at random with commentReply. Omitted when none.
47 48 49 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 47 def comment_reply_variations @comment_reply_variations end |
#created_at ⇒ Object
Returns the value of attribute created_at.
59 60 61 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 59 def created_at @created_at end |
#dm_message ⇒ Object
Returns the value of attribute dm_message.
36 37 38 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 36 def @dm_message end |
#dm_message_variations ⇒ Object
Alternate DM texts rotated at random with dmMessage. Omitted when none.
44 45 46 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 44 def @dm_message_variations end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 18 def id @id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
55 56 57 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 55 def is_active @is_active end |
#keywords ⇒ Object
Returns the value of attribute keywords.
32 33 34 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 32 def keywords @keywords end |
#link_tracking ⇒ Object
Whether link buttons in the DM are wrapped in a tracked redirect to count clicks.
50 51 52 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 50 def link_tracking @link_tracking end |
#match_mode ⇒ Object
Returns the value of attribute match_mode.
34 35 36 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 34 def match_mode @match_mode end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 20 def name @name end |
#platform ⇒ Object
Returns the value of attribute platform.
22 23 24 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 22 def platform @platform end |
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
28 29 30 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 28 def platform_post_id @platform_post_id end |
#post_title ⇒ Object
Returns the value of attribute post_title.
30 31 32 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 30 def post_title @post_title end |
#stats ⇒ Object
Returns the value of attribute stats.
57 58 59 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 57 def stats @stats end |
#trigger ⇒ Object
Returns the value of attribute trigger.
24 25 26 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 24 def trigger @trigger end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
109 110 111 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 109 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
114 115 116 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 114 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 84 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'platform' => :'platform', :'trigger' => :'trigger', :'account_id' => :'accountId', :'platform_post_id' => :'platformPostId', :'post_title' => :'postTitle', :'keywords' => :'keywords', :'match_mode' => :'matchMode', :'dm_message' => :'dmMessage', :'buttons' => :'buttons', :'comment_reply' => :'commentReply', :'dm_message_variations' => :'dmMessageVariations', :'comment_reply_variations' => :'commentReplyVariations', :'link_tracking' => :'linkTracking', :'click_tag' => :'clickTag', :'is_active' => :'isActive', :'stats' => :'stats', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 342 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
144 145 146 147 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 144 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 119 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'platform' => :'String', :'trigger' => :'String', :'account_id' => :'String', :'platform_post_id' => :'String', :'post_title' => :'String', :'keywords' => :'Array<String>', :'match_mode' => :'String', :'dm_message' => :'String', :'buttons' => :'Array<DmButton>', :'comment_reply' => :'String', :'dm_message_variations' => :'Array<String>', :'comment_reply_variations' => :'Array<String>', :'link_tracking' => :'Boolean', :'click_tag' => :'String', :'is_active' => :'Boolean', :'stats' => :'ListCommentAutomations200ResponseAutomationsInnerStats', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 303 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && platform == o.platform && trigger == o.trigger && account_id == o.account_id && platform_post_id == o.platform_post_id && post_title == o.post_title && keywords == o.keywords && match_mode == o.match_mode && == o. && == o. && comment_reply == o.comment_reply && == o. && comment_reply_variations == o.comment_reply_variations && link_tracking == o.link_tracking && click_tag == o.click_tag && is_active == o.is_active && stats == o.stats && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
329 330 331 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 329 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 335 def hash [id, name, platform, trigger, account_id, platform_post_id, post_title, keywords, match_mode, , , comment_reply, , comment_reply_variations, link_tracking, click_tag, is_active, stats, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
252 253 254 255 256 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 252 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
260 261 262 263 264 265 266 267 268 269 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 260 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' platform_validator = EnumAttributeValidator.new('String', ["instagram", "facebook"]) return false unless platform_validator.valid?(@platform) trigger_validator = EnumAttributeValidator.new('String', ["comment", "story_reply"]) return false unless trigger_validator.valid?(@trigger) match_mode_validator = EnumAttributeValidator.new('String', ["exact", "contains"]) return false unless match_mode_validator.valid?(@match_mode) true end |