Class: Zernio::ListContacts200ResponseContactsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListContacts200ResponseContactsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListContacts200ResponseContactsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListContacts200ResponseContactsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'company')
    self.company = attributes[:'company']
  end

  if attributes.key?(:'avatar_url')
    self.avatar_url = attributes[:'avatar_url']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'is_subscribed')
    self.is_subscribed = attributes[:'is_subscribed']
  end

  if attributes.key?(:'is_blocked')
    self.is_blocked = attributes[:'is_blocked']
  end

  if attributes.key?(:'last_message_sent_at')
    self.last_message_sent_at = attributes[:'last_message_sent_at']
  end

  if attributes.key?(:'last_message_received_at')
    self.last_message_received_at = attributes[:'last_message_received_at']
  end

  if attributes.key?(:'messages_sent_count')
    self.messages_sent_count = attributes[:'messages_sent_count']
  end

  if attributes.key?(:'messages_received_count')
    self.messages_received_count = attributes[:'messages_received_count']
  end

  if attributes.key?(:'custom_fields')
    self.custom_fields = attributes[:'custom_fields']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'platform_identifier')
    self.platform_identifier = attributes[:'platform_identifier']
  end

  if attributes.key?(:'display_identifier')
    self.display_identifier = attributes[:'display_identifier']
  end
end

Instance Attribute Details

#avatar_urlObject

Returns the value of attribute avatar_url.



26
27
28
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 26

def avatar_url
  @avatar_url
end

#companyObject

Returns the value of attribute company.



24
25
26
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 24

def company
  @company
end

#created_atObject

Returns the value of attribute created_at.



46
47
48
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 46

def created_at
  @created_at
end

#custom_fieldsObject

Returns the value of attribute custom_fields.



42
43
44
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 42

def custom_fields
  @custom_fields
end

#display_identifierObject

Returns the value of attribute display_identifier.



52
53
54
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 52

def display_identifier
  @display_identifier
end

#emailObject

Returns the value of attribute email.



22
23
24
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 22

def email
  @email
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 18

def id
  @id
end

#is_blockedObject

Returns the value of attribute is_blocked.



32
33
34
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 32

def is_blocked
  @is_blocked
end

#is_subscribedObject

Returns the value of attribute is_subscribed.



30
31
32
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 30

def is_subscribed
  @is_subscribed
end

#last_message_received_atObject

Returns the value of attribute last_message_received_at.



36
37
38
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 36

def last_message_received_at
  @last_message_received_at
end

#last_message_sent_atObject

Returns the value of attribute last_message_sent_at.



34
35
36
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 34

def last_message_sent_at
  @last_message_sent_at
end

#messages_received_countObject

Returns the value of attribute messages_received_count.



40
41
42
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 40

def messages_received_count
  @messages_received_count
end

#messages_sent_countObject

Returns the value of attribute messages_sent_count.



38
39
40
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 38

def messages_sent_count
  @messages_sent_count
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 20

def name
  @name
end

#notesObject

Returns the value of attribute notes.



44
45
46
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 44

def notes
  @notes
end

#platformObject

Returns the value of attribute platform.



48
49
50
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 48

def platform
  @platform
end

#platform_identifierObject

Returns the value of attribute platform_identifier.



50
51
52
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 50

def platform_identifier
  @platform_identifier
end

#tagsObject

Returns the value of attribute tags.



28
29
30
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 28

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 55

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'email' => :'email',
    :'company' => :'company',
    :'avatar_url' => :'avatarUrl',
    :'tags' => :'tags',
    :'is_subscribed' => :'isSubscribed',
    :'is_blocked' => :'isBlocked',
    :'last_message_sent_at' => :'lastMessageSentAt',
    :'last_message_received_at' => :'lastMessageReceivedAt',
    :'messages_sent_count' => :'messagesSentCount',
    :'messages_received_count' => :'messagesReceivedCount',
    :'custom_fields' => :'customFields',
    :'notes' => :'notes',
    :'created_at' => :'createdAt',
    :'platform' => :'platform',
    :'platform_identifier' => :'platformIdentifier',
    :'display_identifier' => :'displayIdentifier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 264

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 113

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 89

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'email' => :'String',
    :'company' => :'String',
    :'avatar_url' => :'String',
    :'tags' => :'Array<String>',
    :'is_subscribed' => :'Boolean',
    :'is_blocked' => :'Boolean',
    :'last_message_sent_at' => :'Time',
    :'last_message_received_at' => :'Time',
    :'messages_sent_count' => :'Integer',
    :'messages_received_count' => :'Integer',
    :'custom_fields' => :'Object',
    :'notes' => :'String',
    :'created_at' => :'Time',
    :'platform' => :'String',
    :'platform_identifier' => :'String',
    :'display_identifier' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      email == o.email &&
      company == o.company &&
      avatar_url == o.avatar_url &&
      tags == o.tags &&
      is_subscribed == o.is_subscribed &&
      is_blocked == o.is_blocked &&
      last_message_sent_at == o.last_message_sent_at &&
      last_message_received_at == o.last_message_received_at &&
      messages_sent_count == o.messages_sent_count &&
      messages_received_count == o.messages_received_count &&
      custom_fields == o.custom_fields &&
      notes == o.notes &&
      created_at == o.created_at &&
      platform == o.platform &&
      platform_identifier == o.platform_identifier &&
      display_identifier == o.display_identifier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


251
252
253
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 251

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



257
258
259
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 257

def hash
  [id, name, email, company, avatar_url, tags, is_subscribed, is_blocked, last_message_sent_at, last_message_received_at, messages_sent_count, messages_received_count, custom_fields, notes, created_at, platform, platform_identifier, display_identifier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



211
212
213
214
215
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 211

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



219
220
221
222
# File 'lib/zernio-sdk/models/list_contacts200_response_contacts_inner.rb', line 219

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end