Class: Zernio::ListFormLeads200ResponseLeadsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListFormLeads200ResponseLeadsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListFormLeads200ResponseLeadsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListFormLeads200ResponseLeadsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'ad_id')
    self.ad_id = attributes[:'ad_id']
  end

  if attributes.key?(:'form_id')
    self.form_id = attributes[:'form_id']
  end

  if attributes.key?(:'fields')
    if (value = attributes[:'fields']).is_a?(Hash)
      self.fields = value
    end
  end

  if attributes.key?(:'field_data')
    if (value = attributes[:'field_data']).is_a?(Array)
      self.field_data = value
    end
  end
end

Instance Attribute Details

#ad_idObject

Returns the value of attribute ad_id.



22
23
24
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 22

def ad_id
  @ad_id
end

#created_timeObject

Returns the value of attribute created_time.



20
21
22
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 20

def created_time
  @created_time
end

#field_dataObject

Returns the value of attribute field_data.



28
29
30
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 28

def field_data
  @field_data
end

#fieldsObject

Returns the value of attribute fields.



26
27
28
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 26

def fields
  @fields
end

#form_idObject

Returns the value of attribute form_id.



24
25
26
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 24

def form_id
  @form_id
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 18

def id
  @id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 31

def self.attribute_map
  {
    :'id' => :'id',
    :'created_time' => :'createdTime',
    :'ad_id' => :'adId',
    :'form_id' => :'formId',
    :'fields' => :'fields',
    :'field_data' => :'fieldData'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 160

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
70
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 65

def self.openapi_nullable
  Set.new([
    :'created_time',
    :'ad_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 53

def self.openapi_types
  {
    :'id' => :'String',
    :'created_time' => :'String',
    :'ad_id' => :'String',
    :'form_id' => :'String',
    :'fields' => :'Hash<String, String>',
    :'field_data' => :'Array<Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 134

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created_time == o.created_time &&
      ad_id == o.ad_id &&
      form_id == o.form_id &&
      fields == o.fields &&
      field_data == o.field_data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 147

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



153
154
155
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 153

def hash
  [id, created_time, ad_id, form_id, fields, field_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
130
# File 'lib/zernio-sdk/models/list_form_leads200_response_leads_inner.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end