Class: Zernio::ListInboxConversationAnalytics200ResponseItemsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListInboxConversationAnalytics200ResponseItemsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListInboxConversationAnalytics200ResponseItemsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListInboxConversationAnalytics200ResponseItemsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'conversation_id')
    self.conversation_id = attributes[:'conversation_id']
  end

  if attributes.key?(:'mongo_id')
    self.mongo_id = attributes[:'mongo_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'participant_name')
    self.participant_name = attributes[:'participant_name']
  end

  if attributes.key?(:'participant_username')
    self.participant_username = attributes[:'participant_username']
  end

  if attributes.key?(:'participant_picture')
    self.participant_picture = attributes[:'participant_picture']
  end

  if attributes.key?(:'last_message')
    self.last_message = attributes[:'last_message']
  end

  if attributes.key?(:'total_messages')
    self.total_messages = attributes[:'total_messages']
  end

  if attributes.key?(:'received')
    self.received = attributes[:'received']
  end

  if attributes.key?(:'sent')
    self.sent = attributes[:'sent']
  end

  if attributes.key?(:'read')
    self.read = attributes[:'read']
  end

  if attributes.key?(:'failed')
    self.failed = attributes[:'failed']
  end

  if attributes.key?(:'first_message_at')
    self.first_message_at = attributes[:'first_message_at']
  end

  if attributes.key?(:'last_message_at')
    self.last_message_at = attributes[:'last_message_at']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



24
25
26
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 24

def 
  @account_id
end

#conversation_idObject

The platformConversationId (the same identity used by metadata.conversationId)



19
20
21
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 19

def conversation_id
  @conversation_id
end

#failedObject

Returns the value of attribute failed.



45
46
47
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 45

def failed
  @failed
end

#first_message_atObject

Returns the value of attribute first_message_at.



47
48
49
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 47

def first_message_at
  @first_message_at
end

#last_messageObject

Cached preview from the Conversation doc



35
36
37
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 35

def last_message
  @last_message
end

#last_message_atObject

Returns the value of attribute last_message_at.



49
50
51
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 49

def last_message_at
  @last_message_at
end

#mongo_idObject

The Conversation document _id, when a matching doc exists



22
23
24
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 22

def mongo_id
  @mongo_id
end

#participant_nameObject

Returns the value of attribute participant_name.



28
29
30
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 28

def participant_name
  @participant_name
end

#participant_pictureObject

Returns the value of attribute participant_picture.



32
33
34
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 32

def participant_picture
  @participant_picture
end

#participant_usernameObject

Returns the value of attribute participant_username.



30
31
32
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 30

def participant_username
  @participant_username
end

#platformObject

Returns the value of attribute platform.



26
27
28
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 26

def platform
  @platform
end

#readObject

Returns the value of attribute read.



43
44
45
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 43

def read
  @read
end

#receivedObject

Returns the value of attribute received.



39
40
41
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 39

def received
  @received
end

#sentObject

Returns the value of attribute sent.



41
42
43
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 41

def sent
  @sent
end

#total_messagesObject

Returns the value of attribute total_messages.



37
38
39
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 37

def total_messages
  @total_messages
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 52

def self.attribute_map
  {
    :'conversation_id' => :'conversationId',
    :'mongo_id' => :'mongoId',
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'participant_name' => :'participantName',
    :'participant_username' => :'participantUsername',
    :'participant_picture' => :'participantPicture',
    :'last_message' => :'lastMessage',
    :'total_messages' => :'totalMessages',
    :'received' => :'received',
    :'sent' => :'sent',
    :'read' => :'read',
    :'failed' => :'failed',
    :'first_message_at' => :'firstMessageAt',
    :'last_message_at' => :'lastMessageAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 104

def self.openapi_nullable
  Set.new([
    :'mongo_id',
    :'participant_name',
    :'participant_username',
    :'participant_picture',
    :'last_message',
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 83

def self.openapi_types
  {
    :'conversation_id' => :'String',
    :'mongo_id' => :'String',
    :'account_id' => :'String',
    :'platform' => :'String',
    :'participant_name' => :'String',
    :'participant_username' => :'String',
    :'participant_picture' => :'String',
    :'last_message' => :'String',
    :'total_messages' => :'Integer',
    :'received' => :'Integer',
    :'sent' => :'Integer',
    :'read' => :'Integer',
    :'failed' => :'Integer',
    :'first_message_at' => :'Time',
    :'last_message_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      conversation_id == o.conversation_id &&
      mongo_id == o.mongo_id &&
       == o. &&
      platform == o.platform &&
      participant_name == o.participant_name &&
      participant_username == o.participant_username &&
      participant_picture == o.participant_picture &&
      last_message == o.last_message &&
      total_messages == o.total_messages &&
      received == o.received &&
      sent == o.sent &&
      read == o.read &&
      failed == o.failed &&
      first_message_at == o.first_message_at &&
      last_message_at == o.last_message_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 236

def hash
  [conversation_id, mongo_id, , platform, participant_name, participant_username, participant_picture, last_message, total_messages, received, sent, read, failed, first_message_at, last_message_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



193
194
195
196
197
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 193

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
# File 'lib/zernio-sdk/models/list_inbox_conversation_analytics200_response_items_inner.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end