Class: Zernio::ListInstagramStories200ResponseDataInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListInstagramStories200ResponseDataInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListInstagramStories200ResponseDataInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListInstagramStories200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'media_type')
    self.media_type = attributes[:'media_type']
  end

  if attributes.key?(:'media_product_type')
    self.media_product_type = attributes[:'media_product_type']
  end

  if attributes.key?(:'media_url')
    self.media_url = attributes[:'media_url']
  end

  if attributes.key?(:'permalink')
    self.permalink = attributes[:'permalink']
  end

  if attributes.key?(:'thumbnail_url')
    self.thumbnail_url = attributes[:'thumbnail_url']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end
end

Instance Attribute Details

#idObject

Instagram media ID of the story.



19
20
21
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 19

def id
  @id
end

#media_product_typeObject

Always 'STORY' for this endpoint.



25
26
27
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 25

def media_product_type
  @media_product_type
end

#media_typeObject

IMAGE / VIDEO / CAROUSEL_ALBUM



22
23
24
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 22

def media_type
  @media_type
end

#media_urlObject

Direct media URL. Null if Meta flagged the story for copyright. URL expires when the story expires.



28
29
30
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 28

def media_url
  @media_url
end

Public Instagram permalink to the story (only viewable while live).



31
32
33
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 31

def permalink
  @permalink
end

#thumbnail_urlObject

Thumbnail URL for video stories.



34
35
36
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 34

def thumbnail_url
  @thumbnail_url
end

#timestampObject

When the story was posted.



37
38
39
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 37

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 40

def self.attribute_map
  {
    :'id' => :'id',
    :'media_type' => :'mediaType',
    :'media_product_type' => :'mediaProductType',
    :'media_url' => :'mediaUrl',
    :'permalink' => :'permalink',
    :'thumbnail_url' => :'thumbnailUrl',
    :'timestamp' => :'timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
82
83
84
85
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 76

def self.openapi_nullable
  Set.new([
    :'media_type',
    :'media_product_type',
    :'media_url',
    :'permalink',
    :'thumbnail_url',
    :'timestamp'
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 63

def self.openapi_types
  {
    :'id' => :'String',
    :'media_type' => :'String',
    :'media_product_type' => :'String',
    :'media_url' => :'String',
    :'permalink' => :'String',
    :'thumbnail_url' => :'String',
    :'timestamp' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



166
167
168
169
170
171
172
173
174
175
176
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 166

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      media_type == o.media_type &&
      media_product_type == o.media_product_type &&
      media_url == o.media_url &&
      permalink == o.permalink &&
      thumbnail_url == o.thumbnail_url &&
      timestamp == o.timestamp
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 186

def hash
  [id, media_type, media_product_type, media_url, permalink, thumbnail_url, timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
# File 'lib/zernio-sdk/models/list_instagram_stories200_response_data_inner.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end