Class: Zernio::ListLocalServicesLeads200ResponseDataInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListLocalServicesLeads200ResponseDataInner
- Defined in:
- lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb
Instance Attribute Summary collapse
-
#category_id ⇒ Object
Returns the value of attribute category_id.
-
#charged ⇒ Object
Returns the value of attribute charged.
-
#contact ⇒ Object
Returns the value of attribute contact.
-
#created_time ⇒ Object
Google datetime in the customer's timezone (YYYY-MM-DD HH:MM:SS).
-
#credit_state ⇒ Object
Returns the value of attribute credit_state.
-
#credit_state_last_update ⇒ Object
Returns the value of attribute credit_state_last_update.
-
#id ⇒ Object
Lead id; pass to /v1/ads/local-services/leads/leadId/conversations.
-
#lead_type ⇒ Object
PHONE_CALL / MESSAGE / BOOKING.
-
#locale ⇒ Object
Returns the value of attribute locale.
-
#service_id ⇒ Object
Returns the value of attribute service_id.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListLocalServicesLeads200ResponseDataInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListLocalServicesLeads200ResponseDataInner
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListLocalServicesLeads200ResponseDataInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListLocalServicesLeads200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'lead_type') self.lead_type = attributes[:'lead_type'] end if attributes.key?(:'category_id') self.category_id = attributes[:'category_id'] end if attributes.key?(:'service_id') self.service_id = attributes[:'service_id'] end if attributes.key?(:'contact') self.contact = attributes[:'contact'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'created_time') self.created_time = attributes[:'created_time'] end if attributes.key?(:'locale') self.locale = attributes[:'locale'] end if attributes.key?(:'charged') self.charged = attributes[:'charged'] end if attributes.key?(:'credit_state') self.credit_state = attributes[:'credit_state'] end if attributes.key?(:'credit_state_last_update') self.credit_state_last_update = attributes[:'credit_state_last_update'] end end |
Instance Attribute Details
#category_id ⇒ Object
Returns the value of attribute category_id.
24 25 26 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 24 def category_id @category_id end |
#charged ⇒ Object
Returns the value of attribute charged.
37 38 39 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 37 def charged @charged end |
#contact ⇒ Object
Returns the value of attribute contact.
28 29 30 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 28 def contact @contact end |
#created_time ⇒ Object
Google datetime in the customer's timezone (YYYY-MM-DD HH:MM:SS).
33 34 35 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 33 def created_time @created_time end |
#credit_state ⇒ Object
Returns the value of attribute credit_state.
39 40 41 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 39 def credit_state @credit_state end |
#credit_state_last_update ⇒ Object
Returns the value of attribute credit_state_last_update.
41 42 43 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 41 def credit_state_last_update @credit_state_last_update end |
#id ⇒ Object
Lead id; pass to /v1/ads/local-services/leads/leadId/conversations.
19 20 21 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 19 def id @id end |
#lead_type ⇒ Object
PHONE_CALL / MESSAGE / BOOKING.
22 23 24 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 22 def lead_type @lead_type end |
#locale ⇒ Object
Returns the value of attribute locale.
35 36 37 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 35 def locale @locale end |
#service_id ⇒ Object
Returns the value of attribute service_id.
26 27 28 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 26 def service_id @service_id end |
#status ⇒ Object
Returns the value of attribute status.
30 31 32 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 30 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 44 def self.attribute_map { :'id' => :'id', :'lead_type' => :'leadType', :'category_id' => :'categoryId', :'service_id' => :'serviceId', :'contact' => :'contact', :'status' => :'status', :'created_time' => :'createdTime', :'locale' => :'locale', :'charged' => :'charged', :'credit_state' => :'creditState', :'credit_state_last_update' => :'creditStateLastUpdate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 88 def self.openapi_nullable Set.new([ :'id', :'lead_type', :'category_id', :'service_id', :'status', :'created_time', :'locale', :'credit_state', :'credit_state_last_update' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 71 def self.openapi_types { :'id' => :'String', :'lead_type' => :'String', :'category_id' => :'String', :'service_id' => :'String', :'contact' => :'ListLocalServicesLeads200ResponseDataInnerContact', :'status' => :'String', :'created_time' => :'String', :'locale' => :'String', :'charged' => :'Boolean', :'credit_state' => :'String', :'credit_state_last_update' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && lead_type == o.lead_type && category_id == o.category_id && service_id == o.service_id && contact == o.contact && status == o.status && created_time == o.created_time && locale == o.locale && charged == o.charged && credit_state == o.credit_state && credit_state_last_update == o.credit_state_last_update end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 204 def hash [id, lead_type, category_id, service_id, contact, status, created_time, locale, charged, credit_state, credit_state_last_update].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 |
# File 'lib/zernio-sdk/models/list_local_services_leads200_response_data_inner.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |