Class: Zernio::ListSmsOptOuts200ResponseOptOutsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListSmsOptOuts200ResponseOptOutsInner
- Defined in:
- lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb
Instance Attribute Summary collapse
-
#from ⇒ Object
Which of your numbers the recipient opted out from.
-
#keyword ⇒ Object
The keyword they sent (e.g. STOP), when the carrier recorded one.
-
#opted_out_at ⇒ Object
Returns the value of attribute opted_out_at.
-
#phone_number ⇒ Object
Returns the value of attribute phone_number.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListSmsOptOuts200ResponseOptOutsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListSmsOptOuts200ResponseOptOutsInner
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListSmsOptOuts200ResponseOptOutsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListSmsOptOuts200ResponseOptOutsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'opted_out_at') self.opted_out_at = attributes[:'opted_out_at'] end if attributes.key?(:'keyword') self.keyword = attributes[:'keyword'] end if attributes.key?(:'from') self.from = attributes[:'from'] end end |
Instance Attribute Details
#from ⇒ Object
Which of your numbers the recipient opted out from.
26 27 28 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 26 def from @from end |
#keyword ⇒ Object
The keyword they sent (e.g. STOP), when the carrier recorded one.
23 24 25 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 23 def keyword @keyword end |
#opted_out_at ⇒ Object
Returns the value of attribute opted_out_at.
20 21 22 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 20 def opted_out_at @opted_out_at end |
#phone_number ⇒ Object
Returns the value of attribute phone_number.
18 19 20 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 18 def phone_number @phone_number end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 29 def self.attribute_map { :'phone_number' => :'phoneNumber', :'opted_out_at' => :'optedOutAt', :'keyword' => :'keyword', :'from' => :'from' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 141 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 63 64 65 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 59 def self.openapi_nullable Set.new([ :'opted_out_at', :'keyword', :'from' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 49 def self.openapi_types { :'phone_number' => :'String', :'opted_out_at' => :'Time', :'keyword' => :'String', :'from' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 117 def ==(o) return true if self.equal?(o) self.class == o.class && phone_number == o.phone_number && opted_out_at == o.opted_out_at && keyword == o.keyword && from == o.from end |
#eql?(o) ⇒ Boolean
128 129 130 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 128 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 134 def hash [phone_number, opted_out_at, keyword, from].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
102 103 104 105 106 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 102 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
110 111 112 113 |
# File 'lib/zernio-sdk/models/list_sms_opt_outs200_response_opt_outs_inner.rb', line 110 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |