Class: Zernio::ListUsers200ResponseUsersInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_users200_response_users_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListUsers200ResponseUsersInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListUsers200ResponseUsersInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListUsers200ResponseUsersInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'is_root')
    self.is_root = attributes[:'is_root']
  end

  if attributes.key?(:'profile_access')
    if (value = attributes[:'profile_access']).is_a?(Array)
      self.profile_access = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'last_login_at')
    self. = attributes[:'last_login_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 18

def _id
  @_id
end

#created_atObject

Returns the value of attribute created_at.



30
31
32
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 30

def created_at
  @created_at
end

#emailObject

Returns the value of attribute email.



22
23
24
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 22

def email
  @email
end

#is_rootObject

Returns the value of attribute is_root.



26
27
28
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 26

def is_root
  @is_root
end

#last_login_atObject

Last sign-in, stamped at most once an hour, so it is accurate to within an hour rather than to the exact session. Omitted for members with no recorded sign-in since the field shipped, which does not mean they never signed in.



33
34
35
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 33

def 
  @last_login_at
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 20

def name
  @name
end

#profile_accessObject

Returns the value of attribute profile_access.



28
29
30
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 28

def profile_access
  @profile_access
end

#roleObject

Returns the value of attribute role.



24
25
26
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 24

def role
  @role
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 36

def self.attribute_map
  {
    :'_id' => :'_id',
    :'name' => :'name',
    :'email' => :'email',
    :'role' => :'role',
    :'is_root' => :'isRoot',
    :'profile_access' => :'profileAccess',
    :'created_at' => :'createdAt',
    :'last_login_at' => :'lastLoginAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 60

def self.openapi_types
  {
    :'_id' => :'String',
    :'name' => :'String',
    :'email' => :'String',
    :'role' => :'String',
    :'is_root' => :'Boolean',
    :'profile_access' => :'Array<String>',
    :'created_at' => :'Time',
    :'last_login_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      name == o.name &&
      email == o.email &&
      role == o.role &&
      is_root == o.is_root &&
      profile_access == o.profile_access &&
      created_at == o.created_at &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



168
169
170
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 168

def hash
  [_id, name, email, role, is_root, profile_access, created_at, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
# File 'lib/zernio-sdk/models/list_users200_response_users_inner.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end