Class: Zernio::ListWhatsAppFlows200ResponseFlowsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListWhatsAppFlows200ResponseFlowsInner
- Defined in:
- lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#categories ⇒ Object
Returns the value of attribute categories.
-
#id ⇒ Object
Returns the value of attribute id.
-
#lineage_id ⇒ Object
Stable group key for the flow's version lineage (the root flow's ID).
-
#name ⇒ Object
Returns the value of attribute name.
-
#status ⇒ Object
Returns the value of attribute status.
-
#validation_errors ⇒ Object
Returns the value of attribute validation_errors.
-
#version ⇒ Object
1-based version within the flow's clone lineage (Zernio-tracked; Meta has no native versioning).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListWhatsAppFlows200ResponseFlowsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListWhatsAppFlows200ResponseFlowsInner
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWhatsAppFlows200ResponseFlowsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWhatsAppFlows200ResponseFlowsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'categories') if (value = attributes[:'categories']).is_a?(Array) self.categories = value end end if attributes.key?(:'validation_errors') if (value = attributes[:'validation_errors']).is_a?(Array) self.validation_errors = value end end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'lineage_id') self.lineage_id = attributes[:'lineage_id'] end end |
Instance Attribute Details
#categories ⇒ Object
Returns the value of attribute categories.
24 25 26 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 24 def categories @categories end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 18 def id @id end |
#lineage_id ⇒ Object
Stable group key for the flow's version lineage (the root flow's ID).
32 33 34 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 32 def lineage_id @lineage_id end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 20 def name @name end |
#status ⇒ Object
Returns the value of attribute status.
22 23 24 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 22 def status @status end |
#validation_errors ⇒ Object
Returns the value of attribute validation_errors.
26 27 28 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 26 def validation_errors @validation_errors end |
#version ⇒ Object
1-based version within the flow's clone lineage (Zernio-tracked; Meta has no native versioning). Standalone flows are version 1.
29 30 31 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 29 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 57 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'status' => :'status', :'categories' => :'categories', :'validation_errors' => :'validation_errors', :'version' => :'version', :'lineage_id' => :'lineageId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 203 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 80 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'status' => :'String', :'categories' => :'Array<String>', :'validation_errors' => :'Array<Object>', :'version' => :'Integer', :'lineage_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 176 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && status == o.status && categories == o.categories && validation_errors == o.validation_errors && version == o.version && lineage_id == o.lineage_id end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 196 def hash [id, name, status, categories, validation_errors, version, lineage_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 149 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 225 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 |
# File 'lib/zernio-sdk/models/list_whats_app_flows200_response_flows_inner.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["DRAFT", "PUBLISHED", "DEPRECATED", "BLOCKED", "THROTTLED"]) return false unless status_validator.valid?(@status) true end |