Class: Zernio::ListWhatsAppPhoneNumbers200ResponsePhoneNumbersInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb

Overview

Phone number entry. Field names use Meta WhatsApp Cloud API snake_case (passed through unchanged); wabaId and wabaName are Zernio enrichment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListWhatsAppPhoneNumbers200ResponsePhoneNumbersInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWhatsAppPhoneNumbers200ResponsePhoneNumbersInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWhatsAppPhoneNumbers200ResponsePhoneNumbersInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'display_phone_number')
    self.display_phone_number = attributes[:'display_phone_number']
  end

  if attributes.key?(:'verified_name')
    self.verified_name = attributes[:'verified_name']
  end

  if attributes.key?(:'quality_rating')
    self.quality_rating = attributes[:'quality_rating']
  end

  if attributes.key?(:'name_status')
    self.name_status = attributes[:'name_status']
  end

  if attributes.key?(:'messaging_limit_tier')
    self.messaging_limit_tier = attributes[:'messaging_limit_tier']
  end

  if attributes.key?(:'waba_id')
    self.waba_id = attributes[:'waba_id']
  end

  if attributes.key?(:'waba_name')
    self.waba_name = attributes[:'waba_name']
  end
end

Instance Attribute Details

#display_phone_numberObject

E.164-formatted display number



23
24
25
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 23

def display_phone_number
  @display_phone_number
end

#idObject

Phone Number ID (Meta)



20
21
22
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 20

def id
  @id
end

#messaging_limit_tierObject

TIER_250, TIER_1K, TIER_10K, TIER_100K, or TIER_UNLIMITED



35
36
37
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 35

def messaging_limit_tier
  @messaging_limit_tier
end

#name_statusObject

APPROVED, PENDING_REVIEW, DECLINED, or NONE



32
33
34
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 32

def name_status
  @name_status
end

#quality_ratingObject

GREEN, YELLOW, RED, or UNKNOWN



29
30
31
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 29

def quality_rating
  @quality_rating
end

#verified_nameObject

Meta-verified business name



26
27
28
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 26

def verified_name
  @verified_name
end

#waba_idObject

WhatsApp Business Account ID (Zernio enrichment)



38
39
40
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 38

def waba_id
  @waba_id
end

#waba_nameObject

WABA display name (Zernio enrichment)



41
42
43
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 41

def waba_name
  @waba_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 44

def self.attribute_map
  {
    :'id' => :'id',
    :'display_phone_number' => :'display_phone_number',
    :'verified_name' => :'verified_name',
    :'quality_rating' => :'quality_rating',
    :'name_status' => :'name_status',
    :'messaging_limit_tier' => :'messaging_limit_tier',
    :'waba_id' => :'wabaId',
    :'waba_name' => :'wabaName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 68

def self.openapi_types
  {
    :'id' => :'String',
    :'display_phone_number' => :'String',
    :'verified_name' => :'String',
    :'quality_rating' => :'String',
    :'name_status' => :'String',
    :'messaging_limit_tier' => :'String',
    :'waba_id' => :'String',
    :'waba_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      display_phone_number == o.display_phone_number &&
      verified_name == o.verified_name &&
      quality_rating == o.quality_rating &&
      name_status == o.name_status &&
      messaging_limit_tier == o.messaging_limit_tier &&
      waba_id == o.waba_id &&
      waba_name == o.waba_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 174

def hash
  [id, display_phone_number, verified_name, quality_rating, name_status, messaging_limit_tier, waba_id, waba_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
# File 'lib/zernio-sdk/models/list_whats_app_phone_numbers200_response_phone_numbers_inner.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end