Class: Zernio::ListWorkflowExecutions200ResponseExecutionsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListWorkflowExecutions200ResponseExecutionsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWorkflowExecutions200ResponseExecutionsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWorkflowExecutions200ResponseExecutionsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'current_node_id')
    self.current_node_id = attributes[:'current_node_id']
  end

  if attributes.key?(:'waiting_for')
    self.waiting_for = attributes[:'waiting_for']
  end

  if attributes.key?(:'variables')
    if (value = attributes[:'variables']).is_a?(Hash)
      self.variables = value
    end
  end

  if attributes.key?(:'platform_identifier')
    self.platform_identifier = attributes[:'platform_identifier']
  end

  if attributes.key?(:'conversation_id')
    self.conversation_id = attributes[:'conversation_id']
  end

  if attributes.key?(:'step_count')
    self.step_count = attributes[:'step_count']
  end

  if attributes.key?(:'last_error')
    self.last_error = attributes[:'last_error']
  end

  if attributes.key?(:'resume_at')
    self.resume_at = attributes[:'resume_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end
end

Instance Attribute Details

#completed_atObject

Returns the value of attribute completed_at.



42
43
44
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 42

def completed_at
  @completed_at
end

#conversation_idObject

Returns the value of attribute conversation_id.



30
31
32
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 30

def conversation_id
  @conversation_id
end

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 38

def created_at
  @created_at
end

#current_node_idObject

Returns the value of attribute current_node_id.



22
23
24
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 22

def current_node_id
  @current_node_id
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 18

def id
  @id
end

#last_errorObject

Returns the value of attribute last_error.



34
35
36
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 34

def last_error
  @last_error
end

#platform_identifierObject

Returns the value of attribute platform_identifier.



28
29
30
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 28

def platform_identifier
  @platform_identifier
end

#resume_atObject

Returns the value of attribute resume_at.



36
37
38
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 36

def resume_at
  @resume_at
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 20

def status
  @status
end

#step_countObject

Returns the value of attribute step_count.



32
33
34
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 32

def step_count
  @step_count
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 40

def updated_at
  @updated_at
end

#variablesObject

Returns the value of attribute variables.



26
27
28
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 26

def variables
  @variables
end

#waiting_forObject

Returns the value of attribute waiting_for.



24
25
26
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 24

def waiting_for
  @waiting_for
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 67

def self.attribute_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'current_node_id' => :'currentNodeId',
    :'waiting_for' => :'waitingFor',
    :'variables' => :'variables',
    :'platform_identifier' => :'platformIdentifier',
    :'conversation_id' => :'conversationId',
    :'step_count' => :'stepCount',
    :'last_error' => :'lastError',
    :'resume_at' => :'resumeAt',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'completed_at' => :'completedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 256

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
119
120
121
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 115

def self.openapi_nullable
  Set.new([
    :'last_error',
    :'resume_at',
    :'completed_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 96

def self.openapi_types
  {
    :'id' => :'String',
    :'status' => :'String',
    :'current_node_id' => :'String',
    :'waiting_for' => :'ListWorkflowExecutions200ResponseExecutionsInnerWaitingFor',
    :'variables' => :'Hash<String, Object>',
    :'platform_identifier' => :'String',
    :'conversation_id' => :'String',
    :'step_count' => :'Integer',
    :'last_error' => :'String',
    :'resume_at' => :'Time',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'completed_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 223

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      status == o.status &&
      current_node_id == o.current_node_id &&
      waiting_for == o.waiting_for &&
      variables == o.variables &&
      platform_identifier == o.platform_identifier &&
      conversation_id == o.conversation_id &&
      step_count == o.step_count &&
      last_error == o.last_error &&
      resume_at == o.resume_at &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      completed_at == o.completed_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 243

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



249
250
251
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 249

def hash
  [id, status, current_node_id, waiting_for, variables, platform_identifier, conversation_id, step_count, last_error, resume_at, created_at, updated_at, completed_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 196

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
208
209
# File 'lib/zernio-sdk/models/list_workflow_executions200_response_executions_inner.rb', line 204

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["running", "waiting", "completed", "exited", "failed"])
  return false unless status_validator.valid?(@status)
  true
end