Class: Zernio::ListWorkflowVersions200ResponseVersionsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListWorkflowVersions200ResponseVersionsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWorkflowVersions200ResponseVersionsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWorkflowVersions200ResponseVersionsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_by_email')
    self.created_by_email = attributes[:'created_by_email']
  end

  if attributes.key?(:'restored_from_version')
    self.restored_from_version = attributes[:'restored_from_version']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 34

def created_at
  @created_at
end

#created_byObject

User id that authored this version



26
27
28
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 26

def created_by
  @created_by
end

#created_by_emailObject

Denormalized email so the history UI can render without a join



29
30
31
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 29

def created_by_email
  @created_by_email
end

#descriptionObject

Returns the value of attribute description.



23
24
25
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 23

def description
  @description
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 21

def name
  @name
end

#restored_from_versionObject

When non-null, this snapshot was created by restoring that version



32
33
34
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 32

def restored_from_version
  @restored_from_version
end

#versionObject

Monotonically increasing version number



19
20
21
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 19

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 37

def self.attribute_map
  {
    :'version' => :'version',
    :'name' => :'name',
    :'description' => :'description',
    :'created_by' => :'createdBy',
    :'created_by_email' => :'createdByEmail',
    :'restored_from_version' => :'restoredFromVersion',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 73

def self.openapi_nullable
  Set.new([
    :'description',
    :'created_by',
    :'created_by_email',
    :'restored_from_version',
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 60

def self.openapi_types
  {
    :'version' => :'Integer',
    :'name' => :'String',
    :'description' => :'String',
    :'created_by' => :'String',
    :'created_by_email' => :'String',
    :'restored_from_version' => :'Integer',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



144
145
146
147
148
149
150
151
152
153
154
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      version == o.version &&
      name == o.name &&
      description == o.description &&
      created_by == o.created_by &&
      created_by_email == o.created_by_email &&
      restored_from_version == o.restored_from_version &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 164

def hash
  [version, name, description, created_by, created_by_email, restored_from_version, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
# File 'lib/zernio-sdk/models/list_workflow_versions200_response_versions_inner.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end