Class: Zernio::ListWorkflows200ResponseWorkflowsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListWorkflows200ResponseWorkflowsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWorkflows200ResponseWorkflowsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWorkflows200ResponseWorkflowsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'account_name')
    self. = attributes[:'account_name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'node_count')
    self.node_count = attributes[:'node_count']
  end

  if attributes.key?(:'total_started')
    self.total_started = attributes[:'total_started']
  end

  if attributes.key?(:'total_completed')
    self.total_completed = attributes[:'total_completed']
  end

  if attributes.key?(:'total_exited')
    self.total_exited = attributes[:'total_exited']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



26
27
28
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 26

def 
  @account_id
end

#account_nameObject

Returns the value of attribute account_name.



28
29
30
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 28

def 
  @account_name
end

#created_atObject

Returns the value of attribute created_at.



40
41
42
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 40

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 22

def description
  @description
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 18

def id
  @id
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 20

def name
  @name
end

#node_countObject

Returns the value of attribute node_count.



32
33
34
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 32

def node_count
  @node_count
end

#platformObject

Returns the value of attribute platform.



24
25
26
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 24

def platform
  @platform
end

#statusObject

Returns the value of attribute status.



30
31
32
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 30

def status
  @status
end

#total_completedObject

Returns the value of attribute total_completed.



36
37
38
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 36

def total_completed
  @total_completed
end

#total_exitedObject

Returns the value of attribute total_exited.



38
39
40
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 38

def total_exited
  @total_exited
end

#total_startedObject

Returns the value of attribute total_started.



34
35
36
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 34

def total_started
  @total_started
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'platform' => :'platform',
    :'account_id' => :'accountId',
    :'account_name' => :'accountName',
    :'status' => :'status',
    :'node_count' => :'nodeCount',
    :'total_started' => :'totalStarted',
    :'total_completed' => :'totalCompleted',
    :'total_exited' => :'totalExited',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 242

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 93

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'platform' => :'String',
    :'account_id' => :'String',
    :'account_name' => :'String',
    :'status' => :'String',
    :'node_count' => :'Integer',
    :'total_started' => :'Integer',
    :'total_completed' => :'Integer',
    :'total_exited' => :'Integer',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      platform == o.platform &&
       == o. &&
       == o. &&
      status == o.status &&
      node_count == o.node_count &&
      total_started == o.total_started &&
      total_completed == o.total_completed &&
      total_exited == o.total_exited &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 235

def hash
  [id, name, description, platform, , , status, node_count, total_started, total_completed, total_exited, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
194
195
196
# File 'lib/zernio-sdk/models/list_workflows200_response_workflows_inner.rb', line 191

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["draft", "active", "paused"])
  return false unless status_validator.valid?(@status)
  true
end