Class: Zernio::OnWhatsAppNumberActionRequiredRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::OnWhatsAppNumberActionRequiredRequest
- Defined in:
- lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#event ⇒ Object
Returns the value of attribute event.
-
#id ⇒ Object
Returns the value of attribute id.
-
#number ⇒ Object
Returns the value of attribute number.
-
#reason ⇒ Object
Returns the value of attribute reason.
-
#requirements ⇒ Object
Every requirement on the order with the reviewer's current verdict.
-
#reviewed_at ⇒ Object
When the reviewer last commented on the order.
-
#timestamp ⇒ Object
UTC time at which Zernio generated this event (set once when the event payload is built, before delivery is queued).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OnWhatsAppNumberActionRequiredRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OnWhatsAppNumberActionRequiredRequest
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::OnWhatsAppNumberActionRequiredRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::OnWhatsAppNumberActionRequiredRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'event') self.event = attributes[:'event'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'reason') self.reason = attributes[:'reason'] end if attributes.key?(:'requirements') if (value = attributes[:'requirements']).is_a?(Array) self.requirements = value end end if attributes.key?(:'reviewed_at') self.reviewed_at = attributes[:'reviewed_at'] end if attributes.key?(:'number') self.number = attributes[:'number'] end end |
Instance Attribute Details
#event ⇒ Object
Returns the value of attribute event.
20 21 22 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 20 def event @event end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 18 def id @id end |
#number ⇒ Object
Returns the value of attribute number.
33 34 35 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 33 def number @number end |
#reason ⇒ Object
Returns the value of attribute reason.
25 26 27 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 25 def reason @reason end |
#requirements ⇒ Object
Every requirement on the order with the reviewer's current verdict. Omitted when the order's requirements could not be read.
28 29 30 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 28 def requirements @requirements end |
#reviewed_at ⇒ Object
When the reviewer last commented on the order. Omitted when there is no reviewer comment.
31 32 33 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 31 def reviewed_at @reviewed_at end |
#timestamp ⇒ Object
UTC time at which Zernio generated this event (set once when the event payload is built, before delivery is queued). Retries and redeliveries keep the original value, so it reflects the event, not the delivery attempt.
23 24 25 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 23 def end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 58 def self.attribute_map { :'id' => :'id', :'event' => :'event', :'timestamp' => :'timestamp', :'reason' => :'reason', :'requirements' => :'requirements', :'reviewed_at' => :'reviewedAt', :'number' => :'number' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 202 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 94 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 81 def self.openapi_types { :'id' => :'String', :'event' => :'String', :'timestamp' => :'Time', :'reason' => :'String', :'requirements' => :'Array<OnWhatsAppNumberActionRequiredRequestRequirementsInner>', :'reviewed_at' => :'Time', :'number' => :'OnWhatsAppNumberDeclinedRequestNumber' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 175 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && event == o.event && == o. && reason == o.reason && requirements == o.requirements && reviewed_at == o.reviewed_at && number == o.number end |
#eql?(o) ⇒ Boolean
189 190 191 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 189 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
195 196 197 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 195 def hash [id, event, , reason, requirements, reviewed_at, number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 159 160 161 |
# File 'lib/zernio-sdk/models/on_whats_app_number_action_required_request.rb', line 156 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' event_validator = EnumAttributeValidator.new('String', ["whatsapp.number.action_required"]) return false unless event_validator.valid?(@event) true end |