Class: Zernio::PlatformAnalytics
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::PlatformAnalytics
- Defined in:
- lib/zernio-sdk/models/platform_analytics.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_username ⇒ Object
Returns the value of attribute account_username.
-
#analytics ⇒ Object
Returns the value of attribute analytics.
-
#error_message ⇒ Object
Error details when status is failed.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_post_id ⇒ Object
The native post ID on the platform (e.g. Instagram media ID, tweet ID).
-
#platform_post_url ⇒ Object
Returns the value of attribute platform_post_url.
-
#status ⇒ Object
Returns the value of attribute status.
-
#sync_status ⇒ Object
Sync state of analytics for this platform.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PlatformAnalytics
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PlatformAnalytics
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::PlatformAnalytics` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::PlatformAnalytics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_username') self.account_username = attributes[:'account_username'] end if attributes.key?(:'analytics') self.analytics = attributes[:'analytics'] end if attributes.key?(:'sync_status') self.sync_status = attributes[:'sync_status'] end if attributes.key?(:'platform_post_url') self.platform_post_url = attributes[:'platform_post_url'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
25 26 27 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 25 def account_id @account_id end |
#account_username ⇒ Object
Returns the value of attribute account_username.
27 28 29 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 27 def account_username @account_username end |
#analytics ⇒ Object
Returns the value of attribute analytics.
29 30 31 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 29 def analytics @analytics end |
#error_message ⇒ Object
Error details when status is failed
37 38 39 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 37 def @error_message end |
#platform ⇒ Object
Returns the value of attribute platform.
18 19 20 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 18 def platform @platform end |
#platform_post_id ⇒ Object
The native post ID on the platform (e.g. Instagram media ID, tweet ID)
23 24 25 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 23 def platform_post_id @platform_post_id end |
#platform_post_url ⇒ Object
Returns the value of attribute platform_post_url.
34 35 36 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 34 def platform_post_url @platform_post_url end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 20 def status @status end |
#sync_status ⇒ Object
Sync state of analytics for this platform
32 33 34 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 32 def sync_status @sync_status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 62 def self.attribute_map { :'platform' => :'platform', :'status' => :'status', :'platform_post_id' => :'platformPostId', :'account_id' => :'accountId', :'account_username' => :'accountUsername', :'analytics' => :'analytics', :'sync_status' => :'syncStatus', :'platform_post_url' => :'platformPostUrl', :'error_message' => :'errorMessage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 235 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 106 107 108 109 110 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 102 def self.openapi_nullable Set.new([ :'platform_post_id', :'account_username', :'analytics', :'platform_post_url', :'error_message' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 87 def self.openapi_types { :'platform' => :'String', :'status' => :'String', :'platform_post_id' => :'String', :'account_id' => :'String', :'account_username' => :'String', :'analytics' => :'PostAnalytics', :'sync_status' => :'String', :'platform_post_url' => :'String', :'error_message' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 206 def ==(o) return true if self.equal?(o) self.class == o.class && platform == o.platform && status == o.status && platform_post_id == o.platform_post_id && account_id == o.account_id && account_username == o.account_username && analytics == o.analytics && sync_status == o.sync_status && platform_post_url == o.platform_post_url && == o. end |
#eql?(o) ⇒ Boolean
222 223 224 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 222 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
228 229 230 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 228 def hash [platform, status, platform_post_id, account_id, account_username, analytics, sync_status, platform_post_url, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 257 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
175 176 177 178 179 180 181 182 |
# File 'lib/zernio-sdk/models/platform_analytics.rb', line 175 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["published", "failed"]) return false unless status_validator.valid?(@status) sync_status_validator = EnumAttributeValidator.new('String', ["synced", "pending", "unavailable"]) return false unless sync_status_validator.valid?(@sync_status) true end |