Class: Zernio::Profile
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::Profile
- Defined in:
- lib/zernio-sdk/models/profile.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#color ⇒ Object
Returns the value of attribute color.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#is_default ⇒ Object
Returns the value of attribute is_default.
-
#is_over_limit ⇒ Object
Only present when includeOverLimit=true.
-
#name ⇒ Object
Returns the value of attribute name.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Profile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Profile
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/zernio-sdk/models/profile.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::Profile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::Profile`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'color') self.color = attributes[:'color'] end if attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] end if attributes.key?(:'is_over_limit') self.is_over_limit = attributes[:'is_over_limit'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/zernio-sdk/models/profile.rb', line 18 def _id @_id end |
#color ⇒ Object
Returns the value of attribute color.
26 27 28 |
# File 'lib/zernio-sdk/models/profile.rb', line 26 def color @color end |
#created_at ⇒ Object
Returns the value of attribute created_at.
33 34 35 |
# File 'lib/zernio-sdk/models/profile.rb', line 33 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
24 25 26 |
# File 'lib/zernio-sdk/models/profile.rb', line 24 def description @description end |
#is_default ⇒ Object
Returns the value of attribute is_default.
28 29 30 |
# File 'lib/zernio-sdk/models/profile.rb', line 28 def is_default @is_default end |
#is_over_limit ⇒ Object
Only present when includeOverLimit=true. Indicates if this profile exceeds the plan limit.
31 32 33 |
# File 'lib/zernio-sdk/models/profile.rb', line 31 def is_over_limit @is_over_limit end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/zernio-sdk/models/profile.rb', line 22 def name @name end |
#user_id ⇒ Object
Returns the value of attribute user_id.
20 21 22 |
# File 'lib/zernio-sdk/models/profile.rb', line 20 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/zernio-sdk/models/profile.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/zernio-sdk/models/profile.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/zernio-sdk/models/profile.rb', line 36 def self.attribute_map { :'_id' => :'_id', :'user_id' => :'userId', :'name' => :'name', :'description' => :'description', :'color' => :'color', :'is_default' => :'isDefault', :'is_over_limit' => :'isOverLimit', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/zernio-sdk/models/profile.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/zernio-sdk/models/profile.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/zernio-sdk/models/profile.rb', line 60 def self.openapi_types { :'_id' => :'String', :'user_id' => :'String', :'name' => :'String', :'description' => :'String', :'color' => :'String', :'is_default' => :'Boolean', :'is_over_limit' => :'Boolean', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/zernio-sdk/models/profile.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && user_id == o.user_id && name == o.name && description == o.description && color == o.color && is_default == o.is_default && is_over_limit == o.is_over_limit && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/zernio-sdk/models/profile.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/zernio-sdk/models/profile.rb', line 166 def hash [_id, user_id, name, description, color, is_default, is_over_limit, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 134 |
# File 'lib/zernio-sdk/models/profile.rb', line 130 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/zernio-sdk/models/profile.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 |
# File 'lib/zernio-sdk/models/profile.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |