Class: Zernio::QueryAdInsights200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::QueryAdInsights200Response
- Defined in:
- lib/zernio-sdk/models/query_ad_insights200_response.rb
Instance Attribute Summary collapse
-
#customer_id ⇒ Object
Google responses only: the customer the query ran against.
-
#data ⇒ Object
Returns the value of attribute data.
-
#field_mask ⇒ Object
Google responses only: the selected fields echoed by Google.
-
#object_id ⇒ Object
Meta responses only.
-
#paging ⇒ Object
Returns the value of attribute paging.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QueryAdInsights200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ QueryAdInsights200Response
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::QueryAdInsights200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::QueryAdInsights200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'object_id') self.object_id = attributes[:'object_id'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'field_mask') self.field_mask = attributes[:'field_mask'] end if attributes.key?(:'data') if (value = attributes[:'data']).is_a?(Array) self.data = value end end if attributes.key?(:'paging') self.paging = attributes[:'paging'] end end |
Instance Attribute Details
#customer_id ⇒ Object
Google responses only: the customer the query ran against.
22 23 24 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 22 def customer_id @customer_id end |
#data ⇒ Object
Returns the value of attribute data.
27 28 29 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 27 def data @data end |
#field_mask ⇒ Object
Google responses only: the selected fields echoed by Google.
25 26 27 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 25 def field_mask @field_mask end |
#object_id ⇒ Object
Meta responses only.
19 20 21 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 19 def object_id @object_id end |
#paging ⇒ Object
Returns the value of attribute paging.
29 30 31 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 29 def paging @paging end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 32 def self.attribute_map { :'object_id' => :'objectId', :'customer_id' => :'customerId', :'field_mask' => :'fieldMask', :'data' => :'data', :'paging' => :'paging' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 68 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 64 def self.openapi_nullable Set.new([ :'field_mask', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 53 def self.openapi_types { :'object_id' => :'String', :'customer_id' => :'String', :'field_mask' => :'String', :'data' => :'Array<Object>', :'paging' => :'QueryAdInsights200ResponsePaging' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 126 def ==(o) return true if self.equal?(o) self.class == o.class && object_id == o.object_id && customer_id == o.customer_id && field_mask == o.field_mask && data == o.data && paging == o.paging end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 144 def hash [object_id, customer_id, field_mask, data, paging].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 111 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
119 120 121 122 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 119 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |