Class: Zernio::ResyncPageWebhookSubscription200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ResyncPageWebhookSubscription200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ResyncPageWebhookSubscription200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ResyncPageWebhookSubscription200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'resubscribed')
    self.resubscribed = attributes[:'resubscribed']
  end

  if attributes.key?(:'page_id')
    self.page_id = attributes[:'page_id']
  end

  if attributes.key?(:'app_subscribed')
    self.app_subscribed = attributes[:'app_subscribed']
  end

  if attributes.key?(:'leadgen')
    self.leadgen = attributes[:'leadgen']
  end

  if attributes.key?(:'subscribed_fields')
    if (value = attributes[:'subscribed_fields']).is_a?(Array)
      self.subscribed_fields = value
    end
  end

  if attributes.key?(:'warning')
    self.warning = attributes[:'warning']
  end
end

Instance Attribute Details

#app_subscribedObject

Returns the value of attribute app_subscribed.



22
23
24
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 22

def app_subscribed
  @app_subscribed
end

#leadgenObject

Returns the value of attribute leadgen.



24
25
26
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 24

def leadgen
  @leadgen
end

#page_idObject

Returns the value of attribute page_id.



20
21
22
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 20

def page_id
  @page_id
end

#resubscribedObject

Returns the value of attribute resubscribed.



18
19
20
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 18

def resubscribed
  @resubscribed
end

#subscribed_fieldsObject

Returns the value of attribute subscribed_fields.



26
27
28
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 26

def subscribed_fields
  @subscribed_fields
end

#warningObject

Returns the value of attribute warning.



28
29
30
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 28

def warning
  @warning
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 31

def self.attribute_map
  {
    :'resubscribed' => :'resubscribed',
    :'page_id' => :'pageId',
    :'app_subscribed' => :'appSubscribed',
    :'leadgen' => :'leadgen',
    :'subscribed_fields' => :'subscribedFields',
    :'warning' => :'warning'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 157

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 65

def self.openapi_nullable
  Set.new([
    :'warning'
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 53

def self.openapi_types
  {
    :'resubscribed' => :'Boolean',
    :'page_id' => :'String',
    :'app_subscribed' => :'Boolean',
    :'leadgen' => :'Boolean',
    :'subscribed_fields' => :'Array<String>',
    :'warning' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



131
132
133
134
135
136
137
138
139
140
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 131

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      resubscribed == o.resubscribed &&
      page_id == o.page_id &&
      app_subscribed == o.app_subscribed &&
      leadgen == o.leadgen &&
      subscribed_fields == o.subscribed_fields &&
      warning == o.warning
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


144
145
146
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 144

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



150
151
152
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 150

def hash
  [resubscribed, page_id, app_subscribed, leadgen, subscribed_fields, warning].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 179

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
# File 'lib/zernio-sdk/models/resync_page_webhook_subscription200_response.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end