Class: Zernio::SearchAdTargeting200ResponseResultsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SearchAdTargeting200ResponseResultsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SearchAdTargeting200ResponseResultsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SearchAdTargeting200ResponseResultsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'path')
    if (value = attributes[:'path']).is_a?(Array)
      self.path = value
    end
  end

  if attributes.key?(:'audience_size')
    self.audience_size = attributes[:'audience_size']
  end
end

Instance Attribute Details

#audience_sizeObject

Optional estimated reachable users for this option, when the platform returns it.



31
32
33
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 31

def audience_size
  @audience_size
end

#idObject

The platform's opaque id. Use as a geo key (regions/cities/zips/metros) or an entity id (interests/behaviors) in TargetingSpec.



19
20
21
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 19

def id
  @id
end

#nameObject

Human-readable label.



22
23
24
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 22

def name
  @name
end

#pathObject

Optional breadcrumb of parent labels (e.g. ['United States', 'California', 'Los Angeles']). Disambiguates same-named results.



28
29
30
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 28

def path
  @path
end

#typeObject

What the result is (e.g. city, region, country, zip, metro, interest, behavior, income).



25
26
27
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 25

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 34

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'type' => :'type',
    :'path' => :'path',
    :'audience_size' => :'audienceSize'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 204

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 66

def self.openapi_nullable
  Set.new([
    :'audience_size'
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 55

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'path' => :'Array<String>',
    :'audience_size' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



179
180
181
182
183
184
185
186
187
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 179

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      type == o.type &&
      path == o.path &&
      audience_size == o.audience_size
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 191

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



197
198
199
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 197

def hash
  [id, name, type, path, audience_size].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 226

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
145
# File 'lib/zernio-sdk/models/search_ad_targeting200_response_results_inner.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @type.nil?
  true
end