Class: Zernio::SelectPinterestBoardRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/select_pinterest_board_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SelectPinterestBoardRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SelectPinterestBoardRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SelectPinterestBoardRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'board_id')
    self.board_id = attributes[:'board_id']
  else
    self.board_id = nil
  end

  if attributes.key?(:'board_name')
    self.board_name = attributes[:'board_name']
  end

  if attributes.key?(:'temp_token')
    self.temp_token = attributes[:'temp_token']
  else
    self.temp_token = nil
  end

  if attributes.key?(:'user_profile')
    self. = attributes[:'user_profile']
  end

  if attributes.key?(:'refresh_token')
    self.refresh_token = attributes[:'refresh_token']
  end

  if attributes.key?(:'expires_in')
    self.expires_in = attributes[:'expires_in']
  end

  if attributes.key?(:'redirect_url')
    self.redirect_url = attributes[:'redirect_url']
  end
end

Instance Attribute Details

#board_idObject

The Pinterest Board ID selected by the user



22
23
24
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 22

def board_id
  @board_id
end

#board_nameObject

The board name (for display purposes)



25
26
27
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 25

def board_name
  @board_name
end

#expires_inObject

Token expiration time in seconds



37
38
39
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 37

def expires_in
  @expires_in
end

#profile_idObject

Your Zernio profile ID



19
20
21
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 19

def profile_id
  @profile_id
end

#redirect_urlObject

Custom redirect URL after connection completes



40
41
42
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 40

def redirect_url
  @redirect_url
end

#refresh_tokenObject

Pinterest refresh token (if available)



34
35
36
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 34

def refresh_token
  @refresh_token
end

#temp_tokenObject

Temporary Pinterest access token from OAuth



28
29
30
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 28

def temp_token
  @temp_token
end

#user_profileObject

User profile data from OAuth redirect



31
32
33
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 31

def 
  @user_profile
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 43

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'board_id' => :'boardId',
    :'board_name' => :'boardName',
    :'temp_token' => :'tempToken',
    :'user_profile' => :'userProfile',
    :'refresh_token' => :'refreshToken',
    :'expires_in' => :'expiresIn',
    :'redirect_url' => :'redirect_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 67

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'board_id' => :'String',
    :'board_name' => :'String',
    :'temp_token' => :'String',
    :'user_profile' => :'Object',
    :'refresh_token' => :'String',
    :'expires_in' => :'Integer',
    :'redirect_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      board_id == o.board_id &&
      board_name == o.board_name &&
      temp_token == o.temp_token &&
       == o. &&
      refresh_token == o.refresh_token &&
      expires_in == o.expires_in &&
      redirect_url == o.redirect_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 224

def hash
  [profile_id, board_id, board_name, temp_token, , refresh_token, expires_in, redirect_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if @board_id.nil?
    invalid_properties.push('invalid value for "board_id", board_id cannot be nil.')
  end

  if @temp_token.nil?
    invalid_properties.push('invalid value for "temp_token", temp_token cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
167
168
169
# File 'lib/zernio-sdk/models/select_pinterest_board_request.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_id.nil?
  return false if @board_id.nil?
  return false if @temp_token.nil?
  true
end