Class: Zernio::SendBusinessAgentEventRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SendBusinessAgentEventRequest
- Defined in:
- lib/zernio-sdk/models/send_business_agent_event_request.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#payload ⇒ Object
JSON string passed to the agent verbatim.
-
#to ⇒ Object
Consumer E.164 phone number.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendBusinessAgentEventRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendBusinessAgentEventRequest
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendBusinessAgentEventRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendBusinessAgentEventRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'to') self.to = attributes[:'to'] else self.to = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'payload') self.payload = attributes[:'payload'] else self.payload = nil end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 23 def description @description end |
#payload ⇒ Object
JSON string passed to the agent verbatim.
26 27 28 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 26 def payload @payload end |
#to ⇒ Object
Consumer E.164 phone number.
19 20 21 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 19 def to @to end |
#type ⇒ Object
Returns the value of attribute type.
21 22 23 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 21 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 29 def self.attribute_map { :'to' => :'to', :'type' => :'type', :'description' => :'description', :'payload' => :'payload' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 233 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 59 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 49 def self.openapi_types { :'to' => :'String', :'type' => :'String', :'description' => :'String', :'payload' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
209 210 211 212 213 214 215 216 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 209 def ==(o) return true if self.equal?(o) self.class == o.class && to == o.to && type == o.type && description == o.description && payload == o.payload end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 226 def hash [to, type, description, payload].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @to.nil? invalid_properties.push('invalid value for "to", to cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @type.to_s.length > 256 invalid_properties.push('invalid value for "type", the character length must be smaller than or equal to 256.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @description.to_s.length > 1024 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1024.') end if @payload.nil? invalid_properties.push('invalid value for "payload", payload cannot be nil.') end if @payload.to_s.length > 4096 invalid_properties.push('invalid value for "payload", the character length must be smaller than or equal to 4096.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/zernio-sdk/models/send_business_agent_event_request.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @to.nil? return false if @type.nil? return false if @type.to_s.length > 256 return false if @description.nil? return false if @description.to_s.length > 1024 return false if @payload.nil? return false if @payload.to_s.length > 4096 true end |