Class: Zernio::SendDiscordDirectMessageRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/send_discord_direct_message_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendDiscordDirectMessageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendDiscordDirectMessageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendDiscordDirectMessageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  else
    self.user_id = nil
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'embeds')
    if (value = attributes[:'embeds']).is_a?(Array)
      self.embeds = value
    end
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'tts')
    self.tts = attributes[:'tts']
  end
end

Instance Attribute Details

#account_idObject

SocialAccount _id of the connected Discord account the bot speaks as. Caller must own the account (directly or via team membership).



19
20
21
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 19

def 
  @account_id
end

#attachmentsObject

Up to 10 media attachments. Each is { type: image|video|gif|document, url, filename?, mimeType?, size? }.



31
32
33
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 31

def attachments
  @attachments
end

#contentObject

Message text, up to 2,000 characters.



25
26
27
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 25

def content
  @content
end

#embedsObject

Up to 10 Discord embeds. Same shape as channel-post embeds (title, description, color, fields, etc.). See DiscordPlatformData.embeds for the embed object schema.



28
29
30
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 28

def embeds
  @embeds
end

#ttsObject

Send as text-to-speech message.



34
35
36
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 34

def tts
  @tts
end

#user_idObject

Discord snowflake ID of the recipient (15-21 digits).



22
23
24
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 22

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 37

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'user_id' => :'userId',
    :'content' => :'content',
    :'embeds' => :'embeds',
    :'attachments' => :'attachments',
    :'tts' => :'tts'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 255

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 59

def self.openapi_types
  {
    :'account_id' => :'String',
    :'user_id' => :'String',
    :'content' => :'String',
    :'embeds' => :'Array<Object>',
    :'attachments' => :'Array<SendDiscordDirectMessageRequestAttachmentsInner>',
    :'tts' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



229
230
231
232
233
234
235
236
237
238
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 229

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      user_id == o.user_id &&
      content == o.content &&
      embeds == o.embeds &&
      attachments == o.attachments &&
      tts == o.tts
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 242

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



248
249
250
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 248

def hash
  [, user_id, content, embeds, attachments, tts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if !@content.nil? && @content.to_s.length > 2000
    invalid_properties.push('invalid value for "content", the character length must be smaller than or equal to 2000.')
  end

  if !@embeds.nil? && @embeds.length > 10
    invalid_properties.push('invalid value for "embeds", number of items must be less than or equal to 10.')
  end

  if !@attachments.nil? && @attachments.length > 10
    invalid_properties.push('invalid value for "attachments", number of items must be less than or equal to 10.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 277

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
161
162
163
# File 'lib/zernio-sdk/models/send_discord_direct_message_request.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @user_id.nil?
  return false if !@content.nil? && @content.to_s.length > 2000
  return false if !@embeds.nil? && @embeds.length > 10
  return false if !@attachments.nil? && @attachments.length > 10
  true
end