Class: Zernio::SendInboxMessageRequestInteractiveActionOneOf2Parameters

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb

Overview

All optional.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendInboxMessageRequestInteractiveActionOneOf2Parameters

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendInboxMessageRequestInteractiveActionOneOf2Parameters` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendInboxMessageRequestInteractiveActionOneOf2Parameters`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'display_text')
    self.display_text = attributes[:'display_text']
  end

  if attributes.key?(:'ttl_minutes')
    self.ttl_minutes = attributes[:'ttl_minutes']
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end
end

Instance Attribute Details

#display_textObject

Button label. Defaults to "Call Now".



20
21
22
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 20

def display_text
  @display_text
end

#payloadObject

Arbitrary string echoed back as cta_payload on the calls webhook (connect/terminate) for attribution.



26
27
28
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 26

def payload
  @payload
end

#ttl_minutesObject

How long the button stays tappable. Defaults to 10080 (7 days).



23
24
25
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 23

def ttl_minutes
  @ttl_minutes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 29

def self.attribute_map
  {
    :'display_text' => :'display_text',
    :'ttl_minutes' => :'ttl_minutes',
    :'payload' => :'payload'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 48

def self.openapi_types
  {
    :'display_text' => :'String',
    :'ttl_minutes' => :'Integer',
    :'payload' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      display_text == o.display_text &&
      ttl_minutes == o.ttl_minutes &&
      payload == o.payload
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 190

def hash
  [display_text, ttl_minutes, payload].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 93

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@display_text.nil? && @display_text.to_s.length > 20
    invalid_properties.push('invalid value for "display_text", the character length must be smaller than or equal to 20.')
  end

  if !@ttl_minutes.nil? && @ttl_minutes > 43200
    invalid_properties.push('invalid value for "ttl_minutes", must be smaller than or equal to 43200.')
  end

  if !@ttl_minutes.nil? && @ttl_minutes < 1
    invalid_properties.push('invalid value for "ttl_minutes", must be greater than or equal to 1.')
  end

  if !@payload.nil? && @payload.to_s.length > 512
    invalid_properties.push('invalid value for "payload", the character length must be smaller than or equal to 512.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



117
118
119
120
121
122
123
124
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of2_parameters.rb', line 117

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@display_text.nil? && @display_text.to_s.length > 20
  return false if !@ttl_minutes.nil? && @ttl_minutes > 43200
  return false if !@ttl_minutes.nil? && @ttl_minutes < 1
  return false if !@payload.nil? && @payload.to_s.length > 512
  true
end