Class: Zernio::SendInboxMessageRequestInteractiveActionOneOf6SectionsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SendInboxMessageRequestInteractiveActionOneOf6SectionsInner
- Defined in:
- lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb
Instance Attribute Summary collapse
-
#product_items ⇒ Object
Returns the value of attribute product_items.
-
#title ⇒ Object
Optional section header.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendInboxMessageRequestInteractiveActionOneOf6SectionsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendInboxMessageRequestInteractiveActionOneOf6SectionsInner
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendInboxMessageRequestInteractiveActionOneOf6SectionsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendInboxMessageRequestInteractiveActionOneOf6SectionsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'product_items') if (value = attributes[:'product_items']).is_a?(Array) self.product_items = value end else self.product_items = nil end end |
Instance Attribute Details
#product_items ⇒ Object
Returns the value of attribute product_items.
21 22 23 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 21 def product_items @product_items end |
#title ⇒ Object
Optional section header.
19 20 21 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 19 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 24 def self.attribute_map { :'title' => :'title', :'product_items' => :'product_items' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 147 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 50 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 42 def self.openapi_types { :'title' => :'String', :'product_items' => :'Array<SendInboxMessageRequestInteractiveActionOneOf6SectionsInnerProductItemsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 125 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && product_items == o.product_items end |
#eql?(o) ⇒ Boolean
134 135 136 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 134 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
140 141 142 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 140 def hash [title, product_items].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @product_items.nil? invalid_properties.push('invalid value for "product_items", product_items cannot be nil.') end if @product_items.length < 1 invalid_properties.push('invalid value for "product_items", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 169 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
102 103 104 105 106 107 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of6_sections_inner.rb', line 102 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @product_items.nil? return false if @product_items.length < 1 true end |