Class: Zernio::SendInboxMessageRequestReplyMarkup
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SendInboxMessageRequestReplyMarkup
- Defined in:
- lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb
Overview
Telegram-native keyboard markup. Ignored on other platforms.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#keyboard ⇒ Object
Array of rows, each row is an array of buttons.
-
#one_time ⇒ Object
Hide keyboard after use (reply_keyboard only).
-
#type ⇒ Object
Keyboard type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendInboxMessageRequestReplyMarkup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendInboxMessageRequestReplyMarkup
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendInboxMessageRequestReplyMarkup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendInboxMessageRequestReplyMarkup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'keyboard') if (value = attributes[:'keyboard']).is_a?(Array) self.keyboard = value end end if attributes.key?(:'one_time') self.one_time = attributes[:'one_time'] else self.one_time = true end end |
Instance Attribute Details
#keyboard ⇒ Object
Array of rows, each row is an array of buttons
23 24 25 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 23 def keyboard @keyboard end |
#one_time ⇒ Object
Hide keyboard after use (reply_keyboard only)
26 27 28 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 26 def one_time @one_time end |
#type ⇒ Object
Keyboard type
20 21 22 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 20 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 51 def self.attribute_map { :'type' => :'type', :'keyboard' => :'keyboard', :'one_time' => :'oneTime' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 169 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 70 def self.openapi_types { :'type' => :'String', :'keyboard' => :'Array<Array<SendInboxMessageRequestReplyMarkupKeyboardInnerInner>>', :'one_time' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 146 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && keyboard == o.keyboard && one_time == o.one_time end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 162 def hash [type, keyboard, one_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_reply_markup.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["inline_keyboard", "reply_keyboard"]) return false unless type_validator.valid?(@type) true end |