Class: Zernio::UpdateAdAccountRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/update_ad_account_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateAdAccountRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdAccountRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdAccountRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'default_dsa_beneficiary')
    self.default_dsa_beneficiary = attributes[:'default_dsa_beneficiary']
  else
    self.default_dsa_beneficiary = nil
  end

  if attributes.key?(:'default_dsa_payor')
    self.default_dsa_payor = attributes[:'default_dsa_payor']
  end
end

Instance Attribute Details

#account_idObject

Social account ID (metaads, or a facebook/instagram posting account)



19
20
21
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 19

def 
  @account_id
end

#ad_account_idObject

Meta ad account ID (act_...)



22
23
24
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 22

def 
  @ad_account_id
end

#default_dsa_beneficiaryObject

Legal entity benefiting from ads on this ad account



25
26
27
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 25

def default_dsa_beneficiary
  @default_dsa_beneficiary
end

#default_dsa_payorObject

Legal entity paying for ads on this ad account. Defaults to defaultDsaBeneficiary when omitted.



28
29
30
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 28

def default_dsa_payor
  @default_dsa_payor
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 31

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'ad_account_id' => :'adAccountId',
    :'default_dsa_beneficiary' => :'defaultDsaBeneficiary',
    :'default_dsa_payor' => :'defaultDsaPayor'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 51

def self.openapi_types
  {
    :'account_id' => :'String',
    :'ad_account_id' => :'String',
    :'default_dsa_beneficiary' => :'String',
    :'default_dsa_payor' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      default_dsa_beneficiary == o.default_dsa_beneficiary &&
      default_dsa_payor == o.default_dsa_payor
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



212
213
214
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 212

def hash
  [, , default_dsa_beneficiary, default_dsa_payor].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 107

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @ad_account_id.nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  if @default_dsa_beneficiary.nil?
    invalid_properties.push('invalid value for "default_dsa_beneficiary", default_dsa_beneficiary cannot be nil.')
  end

  if @default_dsa_beneficiary.to_s.length > 100
    invalid_properties.push('invalid value for "default_dsa_beneficiary", the character length must be smaller than or equal to 100.')
  end

  if !@default_dsa_payor.nil? && @default_dsa_payor.to_s.length > 100
    invalid_properties.push('invalid value for "default_dsa_payor", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/update_ad_account_request.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @ad_account_id.nil?
  return false if @default_dsa_beneficiary.nil?
  return false if @default_dsa_beneficiary.to_s.length > 100
  return false if !@default_dsa_payor.nil? && @default_dsa_payor.to_s.length > 100
  true
end