Class: Zernio::UpdateAdCampaign200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateAdCampaign200Response
- Defined in:
- lib/zernio-sdk/models/update_ad_campaign200_response.rb
Overview
Echoes back only the fields you sent, plus updated.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bid_amount ⇒ Object
Returns the value of attribute bid_amount.
-
#bid_strategy ⇒ Object
Returns the value of attribute bid_strategy.
-
#budget ⇒ Object
Returns the value of attribute budget.
-
#budget_level ⇒ Object
Returns the value of attribute budget_level.
-
#platform_specific_data ⇒ Object
Returns the value of attribute platform_specific_data.
-
#roas_average_floor ⇒ Object
Returns the value of attribute roas_average_floor.
-
#updated ⇒ Object
Local Ad documents mirrored.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAdCampaign200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAdCampaign200Response
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdCampaign200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdCampaign200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'updated') self.updated = attributes[:'updated'] end if attributes.key?(:'budget') self.budget = attributes[:'budget'] end if attributes.key?(:'budget_level') self.budget_level = attributes[:'budget_level'] end if attributes.key?(:'bid_strategy') self.bid_strategy = attributes[:'bid_strategy'] end if attributes.key?(:'bid_amount') self.bid_amount = attributes[:'bid_amount'] end if attributes.key?(:'roas_average_floor') self.roas_average_floor = attributes[:'roas_average_floor'] end if attributes.key?(:'platform_specific_data') self.platform_specific_data = attributes[:'platform_specific_data'] end end |
Instance Attribute Details
#bid_amount ⇒ Object
Returns the value of attribute bid_amount.
28 29 30 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 28 def bid_amount @bid_amount end |
#bid_strategy ⇒ Object
Returns the value of attribute bid_strategy.
26 27 28 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 26 def bid_strategy @bid_strategy end |
#budget ⇒ Object
Returns the value of attribute budget.
22 23 24 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 22 def budget @budget end |
#budget_level ⇒ Object
Returns the value of attribute budget_level.
24 25 26 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 24 def budget_level @budget_level end |
#platform_specific_data ⇒ Object
Returns the value of attribute platform_specific_data.
32 33 34 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 32 def platform_specific_data @platform_specific_data end |
#roas_average_floor ⇒ Object
Returns the value of attribute roas_average_floor.
30 31 32 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 30 def roas_average_floor @roas_average_floor end |
#updated ⇒ Object
Local Ad documents mirrored. 0 on the empty-campaign path.
20 21 22 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 20 def updated @updated end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 57 def self.attribute_map { :'updated' => :'updated', :'budget' => :'budget', :'budget_level' => :'budgetLevel', :'bid_strategy' => :'bidStrategy', :'bid_amount' => :'bidAmount', :'roas_average_floor' => :'roasAverageFloor', :'platform_specific_data' => :'platformSpecificData' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 199 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 80 def self.openapi_types { :'updated' => :'Integer', :'budget' => :'AdBudget', :'budget_level' => :'String', :'bid_strategy' => :'BidStrategy', :'bid_amount' => :'Float', :'roas_average_floor' => :'Float', :'platform_specific_data' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && updated == o.updated && budget == o.budget && budget_level == o.budget_level && bid_strategy == o.bid_strategy && bid_amount == o.bid_amount && roas_average_floor == o.roas_average_floor && platform_specific_data == o.platform_specific_data end |
#eql?(o) ⇒ Boolean
186 187 188 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 186 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 192 def hash [updated, budget, budget_level, bid_strategy, bid_amount, roas_average_floor, platform_specific_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 |
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' budget_level_validator = EnumAttributeValidator.new('String', ["campaign"]) return false unless budget_level_validator.valid?(@budget_level) true end |