Class: Zernio::UpdateAdNegativeKeywordListRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateAdNegativeKeywordListRequest
- Defined in:
- lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Zernio SocialAccount id.
-
#customer_id ⇒ Object
Connected Google Ads customer id, without dashes.
-
#name ⇒ Object
Nonempty list name, trimmed before use.
-
#platform ⇒ Object
Optional courtesy field.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAdNegativeKeywordListRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAdNegativeKeywordListRequest
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdNegativeKeywordListRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdNegativeKeywordListRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end end |
Instance Attribute Details
#account_id ⇒ Object
Zernio SocialAccount id.
19 20 21 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 19 def account_id @account_id end |
#customer_id ⇒ Object
Connected Google Ads customer id, without dashes. Required when the connection has multiple customers.
22 23 24 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 22 def customer_id @customer_id end |
#name ⇒ Object
Nonempty list name, trimmed before use.
28 29 30 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 28 def name @name end |
#platform ⇒ Object
Optional courtesy field. The resolved account or campaign determines support; other platforms return 501.
25 26 27 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 25 def platform @platform end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 53 def self.attribute_map { :'account_id' => :'accountId', :'customer_id' => :'customerId', :'platform' => :'platform', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 258 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 73 def self.openapi_types { :'account_id' => :'String', :'customer_id' => :'String', :'platform' => :'String', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && customer_id == o.customer_id && platform == o.platform && name == o.name end |
#eql?(o) ⇒ Boolean
245 246 247 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 245 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
251 252 253 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 251 def hash [account_id, customer_id, platform, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end pattern = Regexp.new(/^[a-fA-F0-9]{24}$/) if @account_id !~ pattern invalid_properties.push("invalid value for \"account_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@customer_id.nil? && @customer_id !~ pattern invalid_properties.push("invalid value for \"customer_id\", must conform to the pattern #{pattern}.") end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/zernio-sdk/models/update_ad_negative_keyword_list_request.rb', line 161 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @account_id !~ Regexp.new(/^[a-fA-F0-9]{24}$/) return false if !@customer_id.nil? && @customer_id !~ Regexp.new(/^\d+$/) platform_validator = EnumAttributeValidator.new('String', ["facebook", "instagram", "tiktok", "linkedin", "pinterest", "google", "twitter", "openai"]) return false unless platform_validator.valid?(@platform) return false if @name.nil? return false if @name.to_s.length > 255 return false if @name.to_s.length < 1 true end |