Class: Zernio::UpdateAdTrackingTagsRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/update_ad_tracking_tags_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateAdTrackingTagsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdTrackingTagsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdTrackingTagsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'url_tags')
    if (value = attributes[:'url_tags']).is_a?(Array)
      self.url_tags = value
    end
  end

  if attributes.key?(:'creative')
    self.creative = attributes[:'creative']
  end

  if attributes.key?(:'tracking_url_template')
    self.tracking_url_template = attributes[:'tracking_url_template']
  end

  if attributes.key?(:'final_url_suffix')
    self.final_url_suffix = attributes[:'final_url_suffix']
  end

  if attributes.key?(:'dynamic_value_parameters')
    if (value = attributes[:'dynamic_value_parameters']).is_a?(Hash)
      self.dynamic_value_parameters = value
    end
  end

  if attributes.key?(:'custom_value_parameters')
    if (value = attributes[:'custom_value_parameters']).is_a?(Hash)
      self.custom_value_parameters = value
    end
  end
end

Instance Attribute Details

#creativeObject

Returns the value of attribute creative.



21
22
23
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 21

def creative
  @creative
end

#custom_value_parametersObject

LinkedIn only. key -> static value.



33
34
35
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 33

def custom_value_parameters
  @custom_value_parameters
end

#dynamic_value_parametersObject

LinkedIn only. key -> dynamic value enum (CAMPAIGN_ID, CAMPAIGN_NAME, CREATIVE_ID, ...).



30
31
32
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 30

def dynamic_value_parameters
  @dynamic_value_parameters
end

#final_url_suffixObject

Google only. Parse-only key=value params.



27
28
29
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 27

def final_url_suffix
  @final_url_suffix
end

#tracking_url_templateObject

Google only. Full tracking template (must contain lpurl).



24
25
26
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 24

def tracking_url_template
  @tracking_url_template
end

#url_tagsObject

Meta only. Click-URL params appended to a freshly-rebuilt creative.



19
20
21
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 19

def url_tags
  @url_tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 36

def self.attribute_map
  {
    :'url_tags' => :'urlTags',
    :'creative' => :'creative',
    :'tracking_url_template' => :'trackingUrlTemplate',
    :'final_url_suffix' => :'finalUrlSuffix',
    :'dynamic_value_parameters' => :'dynamicValueParameters',
    :'custom_value_parameters' => :'customValueParameters'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 165

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 58

def self.openapi_types
  {
    :'url_tags' => :'Array<UpdateAdTrackingTagsRequestUrlTagsInner>',
    :'creative' => :'UpdateAdTrackingTagsRequestCreative',
    :'tracking_url_template' => :'String',
    :'final_url_suffix' => :'String',
    :'dynamic_value_parameters' => :'Hash<String, String>',
    :'custom_value_parameters' => :'Hash<String, String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



139
140
141
142
143
144
145
146
147
148
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 139

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      url_tags == o.url_tags &&
      creative == o.creative &&
      tracking_url_template == o.tracking_url_template &&
      final_url_suffix == o.final_url_suffix &&
      dynamic_value_parameters == o.dynamic_value_parameters &&
      custom_value_parameters == o.custom_value_parameters
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 152

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



158
159
160
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 158

def hash
  [url_tags, creative, tracking_url_template, final_url_suffix, dynamic_value_parameters, custom_value_parameters].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 187

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
# File 'lib/zernio-sdk/models/update_ad_tracking_tags_request.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end