Class: Zernio::UpdateCampaignAdScheduleRequestScheduleInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCampaignAdScheduleRequestScheduleInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateCampaignAdScheduleRequestScheduleInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateCampaignAdScheduleRequestScheduleInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'day_of_week')
    self.day_of_week = attributes[:'day_of_week']
  else
    self.day_of_week = nil
  end

  if attributes.key?(:'start_hour')
    self.start_hour = attributes[:'start_hour']
  else
    self.start_hour = nil
  end

  if attributes.key?(:'start_minute')
    self.start_minute = attributes[:'start_minute']
  else
    self.start_minute = START_MINUTE::N0
  end

  if attributes.key?(:'end_hour')
    self.end_hour = attributes[:'end_hour']
  else
    self.end_hour = nil
  end

  if attributes.key?(:'end_minute')
    self.end_minute = attributes[:'end_minute']
  else
    self.end_minute = END_MINUTE::N0
  end

  if attributes.key?(:'bid_modifier')
    self.bid_modifier = attributes[:'bid_modifier']
  end
end

Instance Attribute Details

#bid_modifierObject

Bid adjustment for this window. Null runs it at the campaign bid.



32
33
34
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 32

def bid_modifier
  @bid_modifier
end

#day_of_weekObject

Returns the value of attribute day_of_week.



18
19
20
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 18

def day_of_week
  @day_of_week
end

#end_hourObject

24 means midnight at the end of the day.



26
27
28
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 26

def end_hour
  @end_hour
end

#end_minuteObject

Quarter-hours only. Must be 0 when endHour is 24.



29
30
31
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 29

def end_minute
  @end_minute
end

#start_hourObject

Returns the value of attribute start_hour.



20
21
22
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 20

def start_hour
  @start_hour
end

#start_minuteObject

Quarter-hours only.



23
24
25
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 23

def start_minute
  @start_minute
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 57

def self.attribute_map
  {
    :'day_of_week' => :'dayOfWeek',
    :'start_hour' => :'startHour',
    :'start_minute' => :'startMinute',
    :'end_hour' => :'endHour',
    :'end_minute' => :'endMinute',
    :'bid_modifier' => :'bidModifier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 322

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 91

def self.openapi_nullable
  Set.new([
    :'bid_modifier'
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 79

def self.openapi_types
  {
    :'day_of_week' => :'String',
    :'start_hour' => :'Integer',
    :'start_minute' => :'Integer',
    :'end_hour' => :'Integer',
    :'end_minute' => :'Integer',
    :'bid_modifier' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



296
297
298
299
300
301
302
303
304
305
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 296

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      day_of_week == o.day_of_week &&
      start_hour == o.start_hour &&
      start_minute == o.start_minute &&
      end_hour == o.end_hour &&
      end_minute == o.end_minute &&
      bid_modifier == o.bid_modifier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


309
310
311
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 309

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



315
316
317
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 315

def hash
  [day_of_week, start_hour, start_minute, end_hour, end_minute, bid_modifier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @day_of_week.nil?
    invalid_properties.push('invalid value for "day_of_week", day_of_week cannot be nil.')
  end

  if @start_hour.nil?
    invalid_properties.push('invalid value for "start_hour", start_hour cannot be nil.')
  end

  if @start_hour > 23
    invalid_properties.push('invalid value for "start_hour", must be smaller than or equal to 23.')
  end

  if @start_hour < 0
    invalid_properties.push('invalid value for "start_hour", must be greater than or equal to 0.')
  end

  if @end_hour.nil?
    invalid_properties.push('invalid value for "end_hour", end_hour cannot be nil.')
  end

  if @end_hour > 24
    invalid_properties.push('invalid value for "end_hour", must be smaller than or equal to 24.')
  end

  if @end_hour < 0
    invalid_properties.push('invalid value for "end_hour", must be greater than or equal to 0.')
  end

  if !@bid_modifier.nil? && @bid_modifier > 10
    invalid_properties.push('invalid value for "bid_modifier", must be smaller than or equal to 10.')
  end

  if !@bid_modifier.nil? && @bid_modifier < 0.1
    invalid_properties.push('invalid value for "bid_modifier", must be greater than or equal to 0.1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 344

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/zernio-sdk/models/update_campaign_ad_schedule_request_schedule_inner.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @day_of_week.nil?
  day_of_week_validator = EnumAttributeValidator.new('String', ["MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"])
  return false unless day_of_week_validator.valid?(@day_of_week)
  return false if @start_hour.nil?
  return false if @start_hour > 23
  return false if @start_hour < 0
  start_minute_validator = EnumAttributeValidator.new('Integer', [0, 15, 30, 45])
  return false unless start_minute_validator.valid?(@start_minute)
  return false if @end_hour.nil?
  return false if @end_hour > 24
  return false if @end_hour < 0
  end_minute_validator = EnumAttributeValidator.new('Integer', [0, 15, 30, 45])
  return false unless end_minute_validator.valid?(@end_minute)
  return false if !@bid_modifier.nil? && @bid_modifier > 10
  return false if !@bid_modifier.nil? && @bid_modifier < 0.1
  true
end