Class: Zernio::UpdateCampaignConversionGoals200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCampaignConversionGoals200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateCampaignConversionGoals200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateCampaignConversionGoals200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'goal_config_level')
    self.goal_config_level = attributes[:'goal_config_level']
  end

  if attributes.key?(:'custom_conversion_goal_id')
    self.custom_conversion_goal_id = attributes[:'custom_conversion_goal_id']
  end

  if attributes.key?(:'goals')
    if (value = attributes[:'goals']).is_a?(Array)
      self.goals = value
    end
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end
end

Instance Attribute Details

#campaign_id ⇒ Object

Returns the value of attribute campaign_id.



18
19
20
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 18

def campaign_id
  @campaign_id
end

#custom_conversion_goal_id ⇒ Object

Returns the value of attribute custom_conversion_goal_id.



22
23
24
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 22

def custom_conversion_goal_id
  @custom_conversion_goal_id
end

#customer_id ⇒ Object

Returns the value of attribute customer_id.



26
27
28
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 26

def customer_id
  @customer_id
end

#goal_config_level ⇒ Object

Returns the value of attribute goal_config_level.



20
21
22
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 20

def goal_config_level
  @goal_config_level
end

#goals ⇒ Object

Returns the value of attribute goals.



24
25
26
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 24

def goals
  @goals
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



62
63
64
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 51

def self.attribute_map
  {
    :'campaign_id' => :'campaignId',
    :'goal_config_level' => :'goalConfigLevel',
    :'custom_conversion_goal_id' => :'customConversionGoalId',
    :'goals' => :'goals',
    :'customer_id' => :'customerId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_of ⇒ Object

List of class defined in allOf (OpenAPI v3)



89
90
91
92
93
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 89

def self.openapi_all_of
  [
  :'GoogleCampaignConversionGoals'
  ]
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



83
84
85
86
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



72
73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 72

def self.openapi_types
  {
    :'campaign_id' => :'String',
    :'goal_config_level' => :'String',
    :'custom_conversion_goal_id' => :'String',
    :'goals' => :'Array<GoogleCampaignConversionGoalsGoalsInner>',
    :'customer_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



163
164
165
166
167
168
169
170
171
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      campaign_id == o.campaign_id &&
      goal_config_level == o.goal_config_level &&
      custom_conversion_goal_id == o.custom_conversion_goal_id &&
      goals == o.goals &&
      customer_id == o.customer_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 175

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



181
182
183
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 181

def hash
  [campaign_id, goal_config_level, custom_conversion_goal_id, goals, customer_id].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



144
145
146
147
148
149
# File 'lib/zernio-sdk/models/update_campaign_conversion_goals200_response.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  goal_config_level_validator = EnumAttributeValidator.new('String', ["CUSTOMER", "CAMPAIGN", "UNSPECIFIED", "UNKNOWN"])
  return false unless goal_config_level_validator.valid?(@goal_config_level)
  true
end