Class: Zernio::UpdateGmbLocationRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateGmbLocationRequest
- Defined in:
- lib/zernio-sdk/models/update_gmb_location_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Legacy alias for googleAccountId.
-
#google_account_id ⇒ Object
Optional but recommended.
-
#selected_location_id ⇒ Object
Returns the value of attribute selected_location_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateGmbLocationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateGmbLocationRequest
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateGmbLocationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateGmbLocationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'selected_location_id') self.selected_location_id = attributes[:'selected_location_id'] else self.selected_location_id = nil end if attributes.key?(:'google_account_id') self.google_account_id = attributes[:'google_account_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end end |
Instance Attribute Details
#account_id ⇒ Object
Legacy alias for googleAccountId. Use googleAccountId for new integrations.
24 25 26 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 24 def account_id @account_id end |
#google_account_id ⇒ Object
Optional but recommended. The Google Business Account resource name ("accounts/123") that owns the new location (from GET gmb-locations). When provided, the location is resolved directly instead of by enumerating the account, which is required for accounts with many locations. Named googleAccountId to disambiguate from the path accountId (the Zernio account). The legacy field name accountId is still accepted for backwards compatibility.
21 22 23 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 21 def google_account_id @google_account_id end |
#selected_location_id ⇒ Object
Returns the value of attribute selected_location_id.
18 19 20 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 18 def selected_location_id @selected_location_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 27 def self.attribute_map { :'selected_location_id' => :'selectedLocationId', :'google_account_id' => :'googleAccountId', :'account_id' => :'accountId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 193 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 46 def self.openapi_types { :'selected_location_id' => :'String', :'google_account_id' => :'String', :'account_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && selected_location_id == o.selected_location_id && google_account_id == o.google_account_id && account_id == o.account_id end |
#eql?(o) ⇒ Boolean
180 181 182 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 180 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 186 def hash [selected_location_id, google_account_id, account_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @selected_location_id.nil? invalid_properties.push('invalid value for "selected_location_id", selected_location_id cannot be nil.') end if @selected_location_id.to_s.length < 1 invalid_properties.push('invalid value for "selected_location_id", the character length must be greater than or equal to 1.') end if !@google_account_id.nil? && @google_account_id.to_s.length < 1 invalid_properties.push('invalid value for "google_account_id", the character length must be greater than or equal to 1.') end if !@account_id.nil? && @account_id.to_s.length < 1 invalid_properties.push('invalid value for "account_id", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 121 122 123 124 |
# File 'lib/zernio-sdk/models/update_gmb_location_request.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @selected_location_id.nil? return false if @selected_location_id.to_s.length < 1 return false if !@google_account_id.nil? && @google_account_id.to_s.length < 1 return false if !@account_id.nil? && @account_id.to_s.length < 1 true end |