Class: Zernio::UpdateProductRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/update_product_request.rb

Overview

At least one field is required.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateProductRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/zernio-sdk/models/update_product_request.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateProductRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateProductRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description_html')
    self.description_html = attributes[:'description_html']
  end

  if attributes.key?(:'handle')
    self.handle = attributes[:'handle']
  end

  if attributes.key?(:'vendor')
    self.vendor = attributes[:'vendor']
  end

  if attributes.key?(:'product_type')
    self.product_type = attributes[:'product_type']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'seo')
    self.seo = attributes[:'seo']
  end

  if attributes.key?(:'variants')
    if (value = attributes[:'variants']).is_a?(Array)
      self.variants = value
    end
  end
end

Instance Attribute Details

#description_htmlObject

Product description as HTML.



22
23
24
# File 'lib/zernio-sdk/models/update_product_request.rb', line 22

def description_html
  @description_html
end

#handleObject

URL slug of the product.



25
26
27
# File 'lib/zernio-sdk/models/update_product_request.rb', line 25

def handle
  @handle
end

#product_typeObject

Returns the value of attribute product_type.



29
30
31
# File 'lib/zernio-sdk/models/update_product_request.rb', line 29

def product_type
  @product_type
end

#seoObject

Returns the value of attribute seo.



37
38
39
# File 'lib/zernio-sdk/models/update_product_request.rb', line 37

def seo
  @seo
end

#statusObject

archived hides the product everywhere; draft keeps it editable but unpublished.



35
36
37
# File 'lib/zernio-sdk/models/update_product_request.rb', line 35

def status
  @status
end

#tagsObject

Replaces the full tag list.



32
33
34
# File 'lib/zernio-sdk/models/update_product_request.rb', line 32

def tags
  @tags
end

#titleObject

Returns the value of attribute title.



19
20
21
# File 'lib/zernio-sdk/models/update_product_request.rb', line 19

def title
  @title
end

#variantsObject

Price changes per variant. Only the listed variants change.



40
41
42
# File 'lib/zernio-sdk/models/update_product_request.rb', line 40

def variants
  @variants
end

#vendorObject

Returns the value of attribute vendor.



27
28
29
# File 'lib/zernio-sdk/models/update_product_request.rb', line 27

def vendor
  @vendor
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/zernio-sdk/models/update_product_request.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/zernio-sdk/models/update_product_request.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/zernio-sdk/models/update_product_request.rb', line 65

def self.attribute_map
  {
    :'title' => :'title',
    :'description_html' => :'descriptionHtml',
    :'handle' => :'handle',
    :'vendor' => :'vendor',
    :'product_type' => :'productType',
    :'tags' => :'tags',
    :'status' => :'status',
    :'seo' => :'seo',
    :'variants' => :'variants'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/zernio-sdk/models/update_product_request.rb', line 291

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
# File 'lib/zernio-sdk/models/update_product_request.rb', line 105

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/zernio-sdk/models/update_product_request.rb', line 90

def self.openapi_types
  {
    :'title' => :'String',
    :'description_html' => :'String',
    :'handle' => :'String',
    :'vendor' => :'String',
    :'product_type' => :'String',
    :'tags' => :'Array<String>',
    :'status' => :'String',
    :'seo' => :'UpdateProductRequestSeo',
    :'variants' => :'Array<UpdateProductRequestVariantsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/zernio-sdk/models/update_product_request.rb', line 262

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      description_html == o.description_html &&
      handle == o.handle &&
      vendor == o.vendor &&
      product_type == o.product_type &&
      tags == o.tags &&
      status == o.status &&
      seo == o.seo &&
      variants == o.variants
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


278
279
280
# File 'lib/zernio-sdk/models/update_product_request.rb', line 278

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



284
285
286
# File 'lib/zernio-sdk/models/update_product_request.rb', line 284

def hash
  [title, description_html, handle, vendor, product_type, tags, status, seo, variants].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/zernio-sdk/models/update_product_request.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@title.nil? && @title.to_s.length < 1
    invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.')
  end

  if !@handle.nil? && @handle.to_s.length < 1
    invalid_properties.push('invalid value for "handle", the character length must be greater than or equal to 1.')
  end

  if !@variants.nil? && @variants.length > 100
    invalid_properties.push('invalid value for "variants", number of items must be less than or equal to 100.')
  end

  if !@variants.nil? && @variants.length < 1
    invalid_properties.push('invalid value for "variants", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/zernio-sdk/models/update_product_request.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



193
194
195
196
197
198
199
200
201
202
# File 'lib/zernio-sdk/models/update_product_request.rb', line 193

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@title.nil? && @title.to_s.length < 1
  return false if !@handle.nil? && @handle.to_s.length < 1
  status_validator = EnumAttributeValidator.new('String', ["active", "draft", "archived"])
  return false unless status_validator.valid?(@status)
  return false if !@variants.nil? && @variants.length > 100
  return false if !@variants.nil? && @variants.length < 1
  true
end