Class: Zernio::UpdateWhatsAppCallingLegacyRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateWhatsAppCallingLegacyRequest
- Defined in:
- lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#call_icon_countries ⇒ Object
Returns the value of attribute call_icon_countries.
-
#forward_caller_id ⇒ Object
caller = present the WhatsApp user's number to the forward destination (sip: only).
-
#forward_to ⇒ Object
Returns the value of attribute forward_to.
-
#max_call_duration_seconds ⇒ Object
Hard cap (seconds) on forwarded calls; null clears the cap.
-
#recording_enabled ⇒ Object
Returns the value of attribute recording_enabled.
-
#sip_auth_password ⇒ Object
Returns the value of attribute sip_auth_password.
-
#sip_auth_username ⇒ Object
Returns the value of attribute sip_auth_username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateWhatsAppCallingLegacyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateWhatsAppCallingLegacyRequest
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateWhatsAppCallingLegacyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateWhatsAppCallingLegacyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'forward_to') self.forward_to = attributes[:'forward_to'] end if attributes.key?(:'sip_auth_username') self.sip_auth_username = attributes[:'sip_auth_username'] end if attributes.key?(:'sip_auth_password') self.sip_auth_password = attributes[:'sip_auth_password'] end if attributes.key?(:'recording_enabled') self.recording_enabled = attributes[:'recording_enabled'] end if attributes.key?(:'call_icon_countries') if (value = attributes[:'call_icon_countries']).is_a?(Array) self.call_icon_countries = value end end if attributes.key?(:'max_call_duration_seconds') self.max_call_duration_seconds = attributes[:'max_call_duration_seconds'] end if attributes.key?(:'forward_caller_id') self.forward_caller_id = attributes[:'forward_caller_id'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 18 def account_id @account_id end |
#call_icon_countries ⇒ Object
Returns the value of attribute call_icon_countries.
28 29 30 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 28 def call_icon_countries @call_icon_countries end |
#forward_caller_id ⇒ Object
caller = present the WhatsApp user's number to the forward destination (sip: only).
34 35 36 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 34 def forward_caller_id @forward_caller_id end |
#forward_to ⇒ Object
Returns the value of attribute forward_to.
20 21 22 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 20 def forward_to @forward_to end |
#max_call_duration_seconds ⇒ Object
Hard cap (seconds) on forwarded calls; null clears the cap.
31 32 33 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 31 def max_call_duration_seconds @max_call_duration_seconds end |
#recording_enabled ⇒ Object
Returns the value of attribute recording_enabled.
26 27 28 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 26 def recording_enabled @recording_enabled end |
#sip_auth_password ⇒ Object
Returns the value of attribute sip_auth_password.
24 25 26 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 24 def sip_auth_password @sip_auth_password end |
#sip_auth_username ⇒ Object
Returns the value of attribute sip_auth_username.
22 23 24 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 22 def sip_auth_username @sip_auth_username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 59 def self.attribute_map { :'account_id' => :'accountId', :'forward_to' => :'forwardTo', :'sip_auth_username' => :'sipAuthUsername', :'sip_auth_password' => :'sipAuthPassword', :'recording_enabled' => :'recordingEnabled', :'call_icon_countries' => :'callIconCountries', :'max_call_duration_seconds' => :'maxCallDurationSeconds', :'forward_caller_id' => :'forwardCallerId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 255 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 97 def self.openapi_nullable Set.new([ :'sip_auth_username', :'sip_auth_password', :'call_icon_countries', :'max_call_duration_seconds', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 83 def self.openapi_types { :'account_id' => :'String', :'forward_to' => :'String', :'sip_auth_username' => :'String', :'sip_auth_password' => :'String', :'recording_enabled' => :'Boolean', :'call_icon_countries' => :'Array<String>', :'max_call_duration_seconds' => :'Integer', :'forward_caller_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && forward_to == o.forward_to && sip_auth_username == o.sip_auth_username && sip_auth_password == o.sip_auth_password && recording_enabled == o.recording_enabled && call_icon_countries == o.call_icon_countries && max_call_duration_seconds == o.max_call_duration_seconds && forward_caller_id == o.forward_caller_id end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 248 def hash [account_id, forward_to, sip_auth_username, sip_auth_password, recording_enabled, call_icon_countries, max_call_duration_seconds, forward_caller_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if !@max_call_duration_seconds.nil? && @max_call_duration_seconds > 14400 invalid_properties.push('invalid value for "max_call_duration_seconds", must be smaller than or equal to 14400.') end if !@max_call_duration_seconds.nil? && @max_call_duration_seconds < 30 invalid_properties.push('invalid value for "max_call_duration_seconds", must be greater than or equal to 30.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 181 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if !@max_call_duration_seconds.nil? && @max_call_duration_seconds > 14400 return false if !@max_call_duration_seconds.nil? && @max_call_duration_seconds < 30 forward_caller_id_validator = EnumAttributeValidator.new('String', ["business", "caller"]) return false unless forward_caller_id_validator.valid?(@forward_caller_id) true end |