Class: Zernio::UpdateWorkflowRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateWorkflowRequest
- Defined in:
- lib/zernio-sdk/models/update_workflow_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Reassign the workflow to a different
SocialAccount. -
#description ⇒ Object
Returns the value of attribute description.
-
#edges ⇒ Object
Returns the value of attribute edges.
-
#entry_node_id ⇒ Object
Returns the value of attribute entry_node_id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#nodes ⇒ Object
Returns the value of attribute nodes.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateWorkflowRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateWorkflowRequest
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateWorkflowRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateWorkflowRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'nodes') if (value = attributes[:'nodes']).is_a?(Array) self.nodes = value end end if attributes.key?(:'edges') if (value = attributes[:'edges']).is_a?(Array) self.edges = value end end if attributes.key?(:'entry_node_id') self.entry_node_id = attributes[:'entry_node_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end end |
Instance Attribute Details
#account_id ⇒ Object
Reassign the workflow to a different SocialAccount. platform and profileId are derived server-side from the new account (the client never sends them directly). The account must belong to the caller's workspace and be on a workflow-supported platform (whatsapp, instagram, facebook, telegram, twitter, bluesky, reddit). Changing this triggers a graph revalidation against the new platform.
29 30 31 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 29 def account_id @account_id end |
#description ⇒ Object
Returns the value of attribute description.
20 21 22 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 20 def description @description end |
#edges ⇒ Object
Returns the value of attribute edges.
24 25 26 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 24 def edges @edges end |
#entry_node_id ⇒ Object
Returns the value of attribute entry_node_id.
26 27 28 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 26 def entry_node_id @entry_node_id end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 18 def name @name end |
#nodes ⇒ Object
Returns the value of attribute nodes.
22 23 24 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 22 def nodes @nodes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 32 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'nodes' => :'nodes', :'edges' => :'edges', :'entry_node_id' => :'entryNodeId', :'account_id' => :'accountId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 66 def self.openapi_nullable Set.new([ :'entry_node_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 54 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'nodes' => :'Array<WorkflowNode>', :'edges' => :'Array<WorkflowEdge>', :'entry_node_id' => :'String', :'account_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && nodes == o.nodes && edges == o.edges && entry_node_id == o.entry_node_id && account_id == o.account_id end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 153 def hash [name, description, nodes, edges, entry_node_id, account_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 |
# File 'lib/zernio-sdk/models/update_workflow_request.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |