Class: Zernio::UploadedOrDerivedAudienceMatchRulesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UploadedOrDerivedAudienceMatchRulesInner
- Defined in:
- lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#match_type ⇒ Object
Returns the value of attribute match_type.
-
#match_value ⇒ Object
Returns the value of attribute match_value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UploadedOrDerivedAudienceMatchRulesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UploadedOrDerivedAudienceMatchRulesInner
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UploadedOrDerivedAudienceMatchRulesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UploadedOrDerivedAudienceMatchRulesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'match_type') self.match_type = attributes[:'match_type'] else self.match_type = nil end if attributes.key?(:'match_value') self.match_value = attributes[:'match_value'] else self.match_value = nil end end |
Instance Attribute Details
#match_type ⇒ Object
Returns the value of attribute match_type.
18 19 20 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 18 def match_type @match_type end |
#match_value ⇒ Object
Returns the value of attribute match_value.
20 21 22 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 20 def match_value @match_value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 45 def self.attribute_map { :'match_type' => :'matchType', :'match_value' => :'matchValue' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 176 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 63 def self.openapi_types { :'match_type' => :'String', :'match_value' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
154 155 156 157 158 159 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 154 def ==(o) return true if self.equal?(o) self.class == o.class && match_type == o.match_type && match_value == o.match_value end |
#eql?(o) ⇒ Boolean
163 164 165 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 163 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
169 170 171 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 169 def hash [match_type, match_value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @match_type.nil? invalid_properties.push('invalid value for "match_type", match_type cannot be nil.') end if @match_value.nil? invalid_properties.push('invalid value for "match_value", match_value cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 198 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 127 128 129 130 |
# File 'lib/zernio-sdk/models/uploaded_or_derived_audience_match_rules_inner.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @match_type.nil? match_type_validator = EnumAttributeValidator.new('String', ["EXACT", "STARTS_WITH", "CONTAINS", "ENDS_WITH"]) return false unless match_type_validator.valid?(@match_type) return false if @match_value.nil? true end |