Class: Zernio::ValidateMedia200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/validate_media200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ValidateMedia200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ValidateMedia200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ValidateMedia200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'valid')
    self.valid = attributes[:'valid']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'content_type')
    self.content_type = attributes[:'content_type']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.key?(:'size_formatted')
    self.size_formatted = attributes[:'size_formatted']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'platform_limits')
    if (value = attributes[:'platform_limits']).is_a?(Hash)
      self.platform_limits = value
    end
  end
end

Instance Attribute Details

#content_typeObject

Returns the value of attribute content_type.



25
26
27
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 25

def content_type
  @content_type
end

#errorObject

Error message if valid is false



23
24
25
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 23

def error
  @error
end

#platform_limitsObject

Per-platform size limit comparison (only present when size and type are known)



35
36
37
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 35

def platform_limits
  @platform_limits
end

#sizeObject

File size in bytes



28
29
30
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 28

def size
  @size
end

#size_formattedObject

Returns the value of attribute size_formatted.



30
31
32
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 30

def size_formatted
  @size_formatted
end

#typeObject

Returns the value of attribute type.



32
33
34
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 32

def type
  @type
end

#urlObject

Returns the value of attribute url.



20
21
22
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 20

def url
  @url
end

#validObject

Returns the value of attribute valid.



18
19
20
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 18

def valid
  @valid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 60

def self.attribute_map
  {
    :'valid' => :'valid',
    :'url' => :'url',
    :'error' => :'error',
    :'content_type' => :'contentType',
    :'size' => :'size',
    :'size_formatted' => :'sizeFormatted',
    :'type' => :'type',
    :'platform_limits' => :'platformLimits'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 212

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 98

def self.openapi_nullable
  Set.new([
    :'size',
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 84

def self.openapi_types
  {
    :'valid' => :'Boolean',
    :'url' => :'String',
    :'error' => :'String',
    :'content_type' => :'String',
    :'size' => :'Integer',
    :'size_formatted' => :'String',
    :'type' => :'String',
    :'platform_limits' => :'Hash<String, ValidateMedia200ResponsePlatformLimitsValue>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      valid == o.valid &&
      url == o.url &&
      error == o.error &&
      content_type == o.content_type &&
      size == o.size &&
      size_formatted == o.size_formatted &&
      type == o.type &&
      platform_limits == o.platform_limits
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 199

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



205
206
207
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 205

def hash
  [valid, url, error, content_type, size, size_formatted, type, platform_limits].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
# File 'lib/zernio-sdk/models/validate_media200_response.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["image", "video", "unknown"])
  return false unless type_validator.valid?(@type)
  true
end