Class: Zernio::ValidatePhoneNumberKycAddressRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ValidatePhoneNumberKycAddressRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ValidatePhoneNumberKycAddressRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ValidatePhoneNumberKycAddressRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  else
    self.country = nil
  end

  if attributes.key?(:'street_address')
    self.street_address = attributes[:'street_address']
  else
    self.street_address = nil
  end

  if attributes.key?(:'locality')
    self.locality = attributes[:'locality']
  else
    self.locality = nil
  end

  if attributes.key?(:'administrative_area')
    self.administrative_area = attributes[:'administrative_area']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  else
    self.postal_code = nil
  end
end

Instance Attribute Details

#administrative_areaObject

State / province / region. When omitted, the pre-check is skipped (the final submit still validates).



27
28
29
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 27

def administrative_area
  @administrative_area
end

#countryObject

ISO 3166-1 alpha-2 country code.



19
20
21
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 19

def country
  @country
end

#localityObject

City / town.



24
25
26
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 24

def locality
  @locality
end

#postal_codeObject

Returns the value of attribute postal_code.



29
30
31
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 29

def postal_code
  @postal_code
end

#street_addressObject

Returns the value of attribute street_address.



21
22
23
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 21

def street_address
  @street_address
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 32

def self.attribute_map
  {
    :'country' => :'country',
    :'street_address' => :'street_address',
    :'locality' => :'locality',
    :'administrative_area' => :'administrative_area',
    :'postal_code' => :'postal_code'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 234

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



64
65
66
67
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 64

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 53

def self.openapi_types
  {
    :'country' => :'String',
    :'street_address' => :'String',
    :'locality' => :'String',
    :'administrative_area' => :'String',
    :'postal_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      country == o.country &&
      street_address == o.street_address &&
      locality == o.locality &&
      administrative_area == o.administrative_area &&
      postal_code == o.postal_code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 227

def hash
  [country, street_address, locality, administrative_area, postal_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @country.to_s.length > 2
    invalid_properties.push('invalid value for "country", the character length must be smaller than or equal to 2.')
  end

  if @country.to_s.length < 2
    invalid_properties.push('invalid value for "country", the character length must be greater than or equal to 2.')
  end

  if @street_address.nil?
    invalid_properties.push('invalid value for "street_address", street_address cannot be nil.')
  end

  if @locality.nil?
    invalid_properties.push('invalid value for "locality", locality cannot be nil.')
  end

  if @postal_code.nil?
    invalid_properties.push('invalid value for "postal_code", postal_code cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
153
154
155
156
157
# File 'lib/zernio-sdk/models/validate_phone_number_kyc_address_request.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @country.nil?
  return false if @country.to_s.length > 2
  return false if @country.to_s.length < 2
  return false if @street_address.nil?
  return false if @locality.nil?
  return false if @postal_code.nil?
  true
end