Class: Zernio::ValidateSubreddit200ResponseOneOfSubreddit

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ValidateSubreddit200ResponseOneOfSubreddit

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ValidateSubreddit200ResponseOneOfSubreddit` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ValidateSubreddit200ResponseOneOfSubreddit`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'subscribers')
    self.subscribers = attributes[:'subscribers']
  end

  if attributes.key?(:'is_nsfw')
    self.is_nsfw = attributes[:'is_nsfw']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'allow_images')
    self.allow_images = attributes[:'allow_images']
  end

  if attributes.key?(:'allow_videos')
    self.allow_videos = attributes[:'allow_videos']
  end
end

Instance Attribute Details

#allow_imagesObject

Returns the value of attribute allow_images.



30
31
32
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 30

def allow_images
  @allow_images
end

#allow_videosObject

Returns the value of attribute allow_videos.



32
33
34
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 32

def allow_videos
  @allow_videos
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 22

def description
  @description
end

#is_nsfwObject

Returns the value of attribute is_nsfw.



26
27
28
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 26

def is_nsfw
  @is_nsfw
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 18

def name
  @name
end

#subscribersObject

Returns the value of attribute subscribers.



24
25
26
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 24

def subscribers
  @subscribers
end

#titleObject

Returns the value of attribute title.



20
21
22
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 20

def title
  @title
end

#typeObject

Returns the value of attribute type.



28
29
30
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 28

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 57

def self.attribute_map
  {
    :'name' => :'name',
    :'title' => :'title',
    :'description' => :'description',
    :'subscribers' => :'subscribers',
    :'is_nsfw' => :'isNSFW',
    :'type' => :'type',
    :'allow_images' => :'allowImages',
    :'allow_videos' => :'allowVideos'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 206

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 81

def self.openapi_types
  {
    :'name' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'subscribers' => :'Integer',
    :'is_nsfw' => :'Boolean',
    :'type' => :'String',
    :'allow_images' => :'Boolean',
    :'allow_videos' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 178

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      title == o.title &&
      description == o.description &&
      subscribers == o.subscribers &&
      is_nsfw == o.is_nsfw &&
      type == o.type &&
      allow_images == o.allow_images &&
      allow_videos == o.allow_videos
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


193
194
195
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 193

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



199
200
201
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 199

def hash
  [name, title, description, subscribers, is_nsfw, type, allow_images, allow_videos].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 228

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
163
164
# File 'lib/zernio-sdk/models/validate_subreddit200_response_one_of_subreddit.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["public", "private", "restricted"])
  return false unless type_validator.valid?(@type)
  true
end