Class: Zernio::WebhookPayloadAccountConnectedAccount

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/webhook_payload_account_connected_account.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadAccountConnectedAccount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadAccountConnectedAccount` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadAccountConnectedAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  else
    self.platform = nil
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  else
    self.username = nil
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end
end

Instance Attribute Details

#account_idObject

The account's unique identifier (same as used in /v1/accounts/accountId)



19
20
21
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 19

def 
  @account_id
end

#display_nameObject

Returns the value of attribute display_name.



28
29
30
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 28

def display_name
  @display_name
end

#platformObject

Returns the value of attribute platform.



24
25
26
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 24

def platform
  @platform
end

#profile_idObject

The profile's unique identifier this account belongs to



22
23
24
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 22

def profile_id
  @profile_id
end

#usernameObject

Returns the value of attribute username.



26
27
28
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 26

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 31

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'profile_id' => :'profileId',
    :'platform' => :'platform',
    :'username' => :'username',
    :'display_name' => :'displayName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 63

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 52

def self.openapi_types
  {
    :'account_id' => :'String',
    :'profile_id' => :'String',
    :'platform' => :'String',
    :'username' => :'String',
    :'display_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
197
198
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      profile_id == o.profile_id &&
      platform == o.platform &&
      username == o.username &&
      display_name == o.display_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 202

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



208
209
210
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 208

def hash
  [, profile_id, platform, username, display_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 115

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if @platform.nil?
    invalid_properties.push('invalid value for "platform", platform cannot be nil.')
  end

  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
145
146
# File 'lib/zernio-sdk/models/webhook_payload_account_connected_account.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @profile_id.nil?
  return false if @platform.nil?
  return false if @username.nil?
  true
end