Class: Zernio::WebhookPayloadAdStatusChanged

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb

Overview

Webhook payload for the ad.status_changed event. Currently emitted only for Meta (metaads). Sourced from two Meta ad_account webhook fields: - in_process_ad_objects - the ad object finished processing and exited IN_PROCESS. status.raw carries Meta's status_name. - with_issues_ad_objects - the ad object entered WITH_ISSUES. status.raw is WITH_ISSUES and the error block is populated from Meta's error_code / error_summary / error_message.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadAdStatusChanged

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadAdStatusChanged` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadAdStatusChanged`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  else
    self. = nil
  end

  if attributes.key?(:'ad_object')
    self.ad_object = attributes[:'ad_object']
  else
    self.ad_object = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



24
25
26
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 24

def 
  @account
end

#ad_objectObject

Returns the value of attribute ad_object.



26
27
28
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 26

def ad_object
  @ad_object
end

#errorObject

Returns the value of attribute error.



30
31
32
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 30

def error
  @error
end

#eventObject

Returns the value of attribute event.



22
23
24
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 22

def event
  @event
end

#idObject

Stable webhook event ID



20
21
22
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 20

def id
  @id
end

#statusObject

Returns the value of attribute status.



28
29
30
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 28

def status
  @status
end

#timestampObject

ISO-8601 timestamp the webhook was produced.



33
34
35
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 33

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 58

def self.attribute_map
  {
    :'id' => :'id',
    :'event' => :'event',
    :'account' => :'account',
    :'ad_object' => :'adObject',
    :'status' => :'status',
    :'error' => :'error',
    :'timestamp' => :'timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 292

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 81

def self.openapi_types
  {
    :'id' => :'String',
    :'event' => :'String',
    :'account' => :'WebhookPayloadAdStatusChangedAccount',
    :'ad_object' => :'WebhookPayloadAdStatusChangedAdObject',
    :'status' => :'WebhookPayloadAdStatusChangedStatus',
    :'error' => :'WebhookPayloadAdStatusChangedError',
    :'timestamp' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



265
266
267
268
269
270
271
272
273
274
275
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 265

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      event == o.event &&
       == o. &&
      ad_object == o.ad_object &&
      status == o.status &&
      error == o.error &&
      timestamp == o.timestamp
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


279
280
281
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 279

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



285
286
287
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 285

def hash
  [id, event, , ad_object, status, error, timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @account.nil?
    invalid_properties.push('invalid value for "account", account cannot be nil.')
  end

  if @ad_object.nil?
    invalid_properties.push('invalid value for "ad_object", ad_object cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/zernio-sdk/models/webhook_payload_ad_status_changed.rb', line 190

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @event.nil?
  event_validator = EnumAttributeValidator.new('String', ["ad.status_changed"])
  return false unless event_validator.valid?(@event)
  return false if @account.nil?
  return false if @ad_object.nil?
  return false if @status.nil?
  return false if @timestamp.nil?
  true
end