Class: Zernio::WebhookPayloadConversationControlChangedControl

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadConversationControlChangedControl

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadConversationControlChangedControl` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadConversationControlChangedControl`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'owner')
    self.owner = attributes[:'owner']
  else
    self.owner = nil
  end

  if attributes.key?(:'previous_owner')
    self.previous_owner = attributes[:'previous_owner']
  else
    self.previous_owner = nil
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end
end

Instance Attribute Details

#metadataObject

Free-form string the transferring app attached to the handover, forwarded verbatim.



25
26
27
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 25

def 
  @metadata
end

#ownerObject

Who answers now. ai_agent: Meta Business Agent; app: you; other: another partner app on the number.



19
20
21
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 19

def owner
  @owner
end

#previous_ownerObject

Owner before this change, null when the thread had never been agent-handled.



22
23
24
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 22

def previous_owner
  @previous_owner
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 50

def self.attribute_map
  {
    :'owner' => :'owner',
    :'previous_owner' => :'previousOwner',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
82
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 78

def self.openapi_nullable
  Set.new([
    :'previous_owner',
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 69

def self.openapi_types
  {
    :'owner' => :'String',
    :'previous_owner' => :'String',
    :'metadata' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      owner == o.owner &&
      previous_owner == o.previous_owner &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 179

def hash
  [owner, previous_owner, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @owner.nil?
    invalid_properties.push('invalid value for "owner", owner cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
136
137
138
139
# File 'lib/zernio-sdk/models/webhook_payload_conversation_control_changed_control.rb', line 131

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @owner.nil?
  owner_validator = EnumAttributeValidator.new('String', ["app", "ai_agent", "other"])
  return false unless owner_validator.valid?(@owner)
  previous_owner_validator = EnumAttributeValidator.new('String', ["app", "ai_agent", "other"])
  return false unless previous_owner_validator.valid?(@previous_owner)
  true
end