Class: Zernio::WebhookPayloadConversationStarted

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/webhook_payload_conversation_started.rb

Overview

Fired once when a new conversation begins, in either direction. A conversation starts the first time an account and a contact exchange a message on any DM platform (Instagram, Messenger/Facebook, Telegram, WhatsApp, Twitter, Reddit, Bluesky, SMS). Platform-agnostic — one subscription covers every DM platform.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadConversationStarted

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadConversationStarted` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadConversationStarted`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'conversation')
    self.conversation = attributes[:'conversation']
  else
    self.conversation = nil
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  else
    self. = nil
  end

  if attributes.key?(:'started_at')
    self.started_at = attributes[:'started_at']
  else
    self.started_at = nil
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



26
27
28
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 26

def 
  @account
end

#conversationObject

Returns the value of attribute conversation.



24
25
26
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 24

def conversation
  @conversation
end

#eventObject

Returns the value of attribute event.



22
23
24
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 22

def event
  @event
end

#idObject

Stable webhook event ID



20
21
22
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 20

def id
  @id
end

#started_atObject

When the conversation document was created.



29
30
31
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 29

def started_at
  @started_at
end

#timestampObject

Returns the value of attribute timestamp.



31
32
33
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 31

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 56

def self.attribute_map
  {
    :'id' => :'id',
    :'event' => :'event',
    :'conversation' => :'conversation',
    :'account' => :'account',
    :'started_at' => :'startedAt',
    :'timestamp' => :'timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 283

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 78

def self.openapi_types
  {
    :'id' => :'String',
    :'event' => :'String',
    :'conversation' => :'WebhookPayloadConversationStartedConversation',
    :'account' => :'InboxWebhookAccount',
    :'started_at' => :'Time',
    :'timestamp' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



257
258
259
260
261
262
263
264
265
266
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 257

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      event == o.event &&
      conversation == o.conversation &&
       == o. &&
      started_at == o.started_at &&
      timestamp == o.timestamp
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 270

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



276
277
278
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 276

def hash
  [id, event, conversation, , started_at, timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @conversation.nil?
    invalid_properties.push('invalid value for "conversation", conversation cannot be nil.')
  end

  if @account.nil?
    invalid_properties.push('invalid value for "account", account cannot be nil.')
  end

  if @started_at.nil?
    invalid_properties.push('invalid value for "started_at", started_at cannot be nil.')
  end

  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/webhook_payload_conversation_started.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @event.nil?
  event_validator = EnumAttributeValidator.new('String', ["conversation.started"])
  return false unless event_validator.valid?(@event)
  return false if @conversation.nil?
  return false if @account.nil?
  return false if @started_at.nil?
  return false if @timestamp.nil?
  true
end