Class: Zernio::WebhookPayloadMessageMessageSenderInstagramProfile
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::WebhookPayloadMessageMessageSenderInstagramProfile
- Defined in:
- lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb
Overview
Instagram profile data for the sender. Only present for Instagram conversations.
Instance Attribute Summary collapse
-
#follower_count ⇒ Object
The sender's follower count on Instagram.
-
#is_follower ⇒ Object
Whether the sender follows your Instagram business account.
-
#is_following ⇒ Object
Whether your Instagram business account follows the sender.
-
#is_verified ⇒ Object
Whether the sender is a verified Instagram user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPayloadMessageMessageSenderInstagramProfile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPayloadMessageMessageSenderInstagramProfile
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadMessageMessageSenderInstagramProfile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadMessageMessageSenderInstagramProfile`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'is_follower') self.is_follower = attributes[:'is_follower'] end if attributes.key?(:'is_following') self.is_following = attributes[:'is_following'] end if attributes.key?(:'follower_count') self.follower_count = attributes[:'follower_count'] end if attributes.key?(:'is_verified') self.is_verified = attributes[:'is_verified'] end end |
Instance Attribute Details
#follower_count ⇒ Object
The sender's follower count on Instagram
26 27 28 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 26 def follower_count @follower_count end |
#is_follower ⇒ Object
Whether the sender follows your Instagram business account
20 21 22 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 20 def is_follower @is_follower end |
#is_following ⇒ Object
Whether your Instagram business account follows the sender
23 24 25 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 23 def is_following @is_following end |
#is_verified ⇒ Object
Whether the sender is a verified Instagram user
29 30 31 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 29 def is_verified @is_verified end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 32 def self.attribute_map { :'is_follower' => :'isFollower', :'is_following' => :'isFollowing', :'follower_count' => :'followerCount', :'is_verified' => :'isVerified' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 145 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 62 def self.openapi_nullable Set.new([ :'is_follower', :'is_following', :'follower_count', :'is_verified' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 52 def self.openapi_types { :'is_follower' => :'Boolean', :'is_following' => :'Boolean', :'follower_count' => :'Integer', :'is_verified' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
121 122 123 124 125 126 127 128 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 121 def ==(o) return true if self.equal?(o) self.class == o.class && is_follower == o.is_follower && is_following == o.is_following && follower_count == o.follower_count && is_verified == o.is_verified end |
#eql?(o) ⇒ Boolean
132 133 134 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 132 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
138 139 140 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 138 def hash [is_follower, is_following, follower_count, is_verified].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 167 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message_sender_instagram_profile.rb', line 114 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |