Class: Zernio::WebhookPayloadPostPostPlatformsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::WebhookPayloadPostPostPlatformsInner
- Defined in:
- lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
SocialAccount id this platform target published through.
-
#error ⇒ Object
Returns the value of attribute error.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
-
#published_url ⇒ Object
Returns the value of attribute published_url.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPayloadPostPostPlatformsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPayloadPostPostPlatformsInner
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadPostPostPlatformsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadPostPostPlatformsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] end if attributes.key?(:'published_url') self.published_url = attributes[:'published_url'] end if attributes.key?(:'error') self.error = attributes[:'error'] end end |
Instance Attribute Details
#account_id ⇒ Object
SocialAccount id this platform target published through. Use it to route events by connected account (e.g. separate staging vs production endpoints). A post can span multiple accounts.
23 24 25 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 23 def account_id @account_id end |
#error ⇒ Object
Returns the value of attribute error.
29 30 31 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 29 def error @error end |
#platform ⇒ Object
Returns the value of attribute platform.
18 19 20 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 18 def platform @platform end |
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
25 26 27 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 25 def platform_post_id @platform_post_id end |
#published_url ⇒ Object
Returns the value of attribute published_url.
27 28 29 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 27 def published_url @published_url end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 20 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 32 def self.attribute_map { :'platform' => :'platform', :'status' => :'status', :'account_id' => :'accountId', :'platform_post_id' => :'platformPostId', :'published_url' => :'publishedUrl', :'error' => :'error' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 189 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 54 def self.openapi_types { :'platform' => :'String', :'status' => :'String', :'account_id' => :'String', :'platform_post_id' => :'String', :'published_url' => :'String', :'error' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 163 def ==(o) return true if self.equal?(o) self.class == o.class && platform == o.platform && status == o.status && account_id == o.account_id && platform_post_id == o.platform_post_id && published_url == o.published_url && error == o.error end |
#eql?(o) ⇒ Boolean
176 177 178 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 176 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
182 183 184 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 182 def hash [platform, status, account_id, platform_post_id, published_url, error].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 211 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 139 |
# File 'lib/zernio-sdk/models/webhook_payload_post_post_platforms_inner.rb', line 134 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @platform.nil? return false if @status.nil? true end |