Class: Zernio::WebhookPayloadReactionReaction
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::WebhookPayloadReactionReaction
- Defined in:
- lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Returns the value of attribute action.
-
#emoji ⇒ Object
The emoji reacted with.
-
#message_id ⇒ Object
Internal Zernio message ID of the reacted-to message, when resolvable from the platform ID.
-
#platform_message_id ⇒ Object
Platform-native ID of the reacted-to message (e.g. WhatsApp wamid).
-
#reacted_at ⇒ Object
Returns the value of attribute reacted_at.
-
#sender ⇒ Object
Returns the value of attribute sender.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPayloadReactionReaction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPayloadReactionReaction
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadReactionReaction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadReactionReaction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'emoji') self.emoji = attributes[:'emoji'] else self.emoji = nil end if attributes.key?(:'action') self.action = attributes[:'action'] else self.action = nil end if attributes.key?(:'message_id') self. = attributes[:'message_id'] end if attributes.key?(:'platform_message_id') self. = attributes[:'platform_message_id'] else self. = nil end if attributes.key?(:'sender') self.sender = attributes[:'sender'] else self.sender = nil end if attributes.key?(:'reacted_at') self.reacted_at = attributes[:'reacted_at'] else self.reacted_at = nil end end |
Instance Attribute Details
#action ⇒ Object
Returns the value of attribute action.
21 22 23 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 21 def action @action end |
#emoji ⇒ Object
The emoji reacted with. May be an empty string when action is removed on WhatsApp (Meta does not report which emoji was removed).
19 20 21 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 19 def emoji @emoji end |
#message_id ⇒ Object
Internal Zernio message ID of the reacted-to message, when resolvable from the platform ID.
24 25 26 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 24 def @message_id end |
#platform_message_id ⇒ Object
Platform-native ID of the reacted-to message (e.g. WhatsApp wamid).
27 28 29 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 27 def @platform_message_id end |
#reacted_at ⇒ Object
Returns the value of attribute reacted_at.
31 32 33 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 31 def reacted_at @reacted_at end |
#sender ⇒ Object
Returns the value of attribute sender.
29 30 31 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 29 def sender @sender end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 56 def self.attribute_map { :'emoji' => :'emoji', :'action' => :'action', :'message_id' => :'messageId', :'platform_message_id' => :'platformMessageId', :'sender' => :'sender', :'reacted_at' => :'reactedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 78 def self.openapi_types { :'emoji' => :'String', :'action' => :'String', :'message_id' => :'String', :'platform_message_id' => :'String', :'sender' => :'WebhookPayloadReactionReactionSender', :'reacted_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
240 241 242 243 244 245 246 247 248 249 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 240 def ==(o) return true if self.equal?(o) self.class == o.class && emoji == o.emoji && action == o.action && == o. && == o. && sender == o.sender && reacted_at == o.reacted_at end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 259 def hash [emoji, action, , , sender, reacted_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @emoji.nil? invalid_properties.push('invalid value for "emoji", emoji cannot be nil.') end if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @platform_message_id.nil? invalid_properties.push('invalid value for "platform_message_id", platform_message_id cannot be nil.') end if @sender.nil? invalid_properties.push('invalid value for "sender", sender cannot be nil.') end if @reacted_at.nil? invalid_properties.push('invalid value for "reacted_at", reacted_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/zernio-sdk/models/webhook_payload_reaction_reaction.rb', line 176 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @emoji.nil? return false if @action.nil? action_validator = EnumAttributeValidator.new('String', ["added", "removed"]) return false unless action_validator.valid?(@action) return false if @platform_message_id.nil? return false if @sender.nil? return false if @reacted_at.nil? true end |