Class: Zernio::WebhookPayloadWhatsAppTemplateStatusUpdatedTemplate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadWhatsAppTemplateStatusUpdatedTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadWhatsAppTemplateStatusUpdatedTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadWhatsAppTemplateStatusUpdatedTemplate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  else
    self.template_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  else
    self.language = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  else
    self.reason = nil
  end
end

Instance Attribute Details

#languageObject

Meta's message_template_language (e.g. en_US).



25
26
27
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 25

def language
  @language
end

#nameObject

Meta's message_template_name.



22
23
24
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 22

def name
  @name
end

#reasonObject

Meta's free-form reason for the transition. \"NONE\" on approval; an explanation string on rejection.



31
32
33
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 31

def reason
  @reason
end

#statusObject

New status. Forwarded verbatim from Meta's event field. PENDING_DELETION is the 24h-grace state after a delete request before the template is actually removed.



28
29
30
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 28

def status
  @status
end

#template_idObject

Meta's message_template_id, returned as a string.



19
20
21
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 19

def template_id
  @template_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 56

def self.attribute_map
  {
    :'template_id' => :'templateId',
    :'name' => :'name',
    :'language' => :'language',
    :'status' => :'status',
    :'reason' => :'reason'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 259

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 77

def self.openapi_types
  {
    :'template_id' => :'String',
    :'name' => :'String',
    :'language' => :'String',
    :'status' => :'String',
    :'reason' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



234
235
236
237
238
239
240
241
242
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 234

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      template_id == o.template_id &&
      name == o.name &&
      language == o.language &&
      status == o.status &&
      reason == o.reason
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 252

def hash
  [template_id, name, language, status, reason].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @template_id.nil?
    invalid_properties.push('invalid value for "template_id", template_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @language.nil?
    invalid_properties.push('invalid value for "language", language cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @reason.nil?
    invalid_properties.push('invalid value for "reason", reason cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 281

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_status_updated_template.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @template_id.nil?
  return false if @name.nil?
  return false if @language.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["APPROVED", "REJECTED", "PENDING", "PAUSED", "DISABLED", "IN_APPEAL", "PENDING_DELETION"])
  return false unless status_validator.valid?(@status)
  return false if @reason.nil?
  true
end