Class: Zernio::XArticle
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::XArticle
- Defined in:
- lib/zernio-sdk/models/x_article.rb
Overview
Long-form X Article payload. X Articles require an eligible X Premium+ account. Articles are mutually exclusive with top-level/custom tweet media and with threadItems, poll, quoteTweetId, replyToTweetId, inReplyToTweetId, replySettings, sensitiveMedia, paidPartnership, and madeWithAi. Publishing normally performs two billable X API requests at $0.010 each (draft + publish, $0.020 total); mode draft performs only the $0.010 draft request. articleDraftId is an internal recovery checkpoint and must not be supplied by API clients.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#content_state ⇒ Object
Returns the value of attribute content_state.
-
#cover ⇒ Object
Returns the value of attribute cover.
-
#mode ⇒ Object
Publish creates an X Article draft and then publishes it.
-
#title ⇒ Object
Returns the value of attribute title.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ XArticle
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ XArticle
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/zernio-sdk/models/x_article.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::XArticle` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::XArticle`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'content_state') self.content_state = attributes[:'content_state'] else self.content_state = nil end if attributes.key?(:'mode') self.mode = attributes[:'mode'] else self.mode = 'publish' end if attributes.key?(:'cover') self.cover = attributes[:'cover'] end end |
Instance Attribute Details
#content_state ⇒ Object
Returns the value of attribute content_state.
21 22 23 |
# File 'lib/zernio-sdk/models/x_article.rb', line 21 def content_state @content_state end |
#cover ⇒ Object
Returns the value of attribute cover.
26 27 28 |
# File 'lib/zernio-sdk/models/x_article.rb', line 26 def cover @cover end |
#mode ⇒ Object
Publish creates an X Article draft and then publishes it. Draft stops after draft creation and returns the X draft ID without a public URL.
24 25 26 |
# File 'lib/zernio-sdk/models/x_article.rb', line 24 def mode @mode end |
#title ⇒ Object
Returns the value of attribute title.
19 20 21 |
# File 'lib/zernio-sdk/models/x_article.rb', line 19 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/zernio-sdk/models/x_article.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/zernio-sdk/models/x_article.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 |
# File 'lib/zernio-sdk/models/x_article.rb', line 51 def self.attribute_map { :'title' => :'title', :'content_state' => :'content_state', :'mode' => :'mode', :'cover' => :'cover' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/zernio-sdk/models/x_article.rb', line 217 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/zernio-sdk/models/x_article.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 |
# File 'lib/zernio-sdk/models/x_article.rb', line 71 def self.openapi_types { :'title' => :'String', :'content_state' => :'XArticleContentState', :'mode' => :'String', :'cover' => :'XArticleCover' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 |
# File 'lib/zernio-sdk/models/x_article.rb', line 193 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && content_state == o.content_state && mode == o.mode && cover == o.cover end |
#eql?(o) ⇒ Boolean
204 205 206 |
# File 'lib/zernio-sdk/models/x_article.rb', line 204 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
210 211 212 |
# File 'lib/zernio-sdk/models/x_article.rb', line 210 def hash [title, content_state, mode, cover].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/zernio-sdk/models/x_article.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @title.to_s.length < 1 invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.') end if @content_state.nil? invalid_properties.push('invalid value for "content_state", content_state cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/zernio-sdk/models/x_article.rb', line 239 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
147 148 149 150 151 152 153 154 155 |
# File 'lib/zernio-sdk/models/x_article.rb', line 147 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @title.nil? return false if @title.to_s.length < 1 return false if @content_state.nil? mode_validator = EnumAttributeValidator.new('String', ["publish", "draft"]) return false unless mode_validator.valid?(@mode) true end |