Class: Zernio::XArticleEntityOneOf2ValueData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::XArticleEntityOneOf2ValueData
- Defined in:
- lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb
Instance Attribute Summary collapse
-
#alt_text ⇒ Object
Supported for image and GIF URLs; rejected for MP4 media.
-
#caption ⇒ Object
Returns the value of attribute caption.
-
#url ⇒ Object
Public image, GIF, or MP4 URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ XArticleEntityOneOf2ValueData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ XArticleEntityOneOf2ValueData
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::XArticleEntityOneOf2ValueData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::XArticleEntityOneOf2ValueData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'caption') self.caption = attributes[:'caption'] end if attributes.key?(:'alt_text') self.alt_text = attributes[:'alt_text'] end end |
Instance Attribute Details
#alt_text ⇒ Object
Supported for image and GIF URLs; rejected for MP4 media.
24 25 26 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 24 def alt_text @alt_text end |
#caption ⇒ Object
Returns the value of attribute caption.
21 22 23 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 21 def caption @caption end |
#url ⇒ Object
Public image, GIF, or MP4 URL. Zernio uploads it to X and replaces it with native media metadata. Caller-supplied media IDs are rejected.
19 20 21 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 19 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 27 def self.attribute_map { :'url' => :'url', :'caption' => :'caption', :'alt_text' => :'altText' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 176 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 46 def self.openapi_types { :'url' => :'String', :'caption' => :'String', :'alt_text' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && url == o.url && caption == o.caption && alt_text == o.alt_text end |
#eql?(o) ⇒ Boolean
163 164 165 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 163 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
169 170 171 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 169 def hash [url, caption, alt_text].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end pattern = Regexp.new(/^https?:\/\/.+\.(?:[jJ][pP][eE]?[gG]|[pP][nN][gG]|[wW][eE][bB][pP]|[gG][iI][fF]|[mM][pP]4)(?:[?#].*)?$/) if @url !~ pattern invalid_properties.push("invalid value for \"url\", must conform to the pattern #{pattern}.") end if !@alt_text.nil? && @alt_text.to_s.length > 1000 invalid_properties.push('invalid value for "alt_text", the character length must be smaller than or equal to 1000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 198 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 118 119 120 |
# File 'lib/zernio-sdk/models/x_article_entity_one_of2_value_data.rb', line 114 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @url.nil? return false if @url !~ Regexp.new(/^https?:\/\/.+\.(?:[jJ][pP][eE]?[gG]|[pP][nN][gG]|[wW][eE][bB][pP]|[gG][iI][fF]|[mM][pP]4)(?:[?#].*)?$/) return false if !@alt_text.nil? && @alt_text.to_s.length > 1000 true end |