Class: Zernio::YouTubeVideoRetentionResponseRetentionCurveInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::YouTubeVideoRetentionResponseRetentionCurveInner
- Defined in:
- lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb
Instance Attribute Summary collapse
-
#audience_watch_ratio ⇒ Object
Absolute share of viewers watching at this point.
-
#elapsed_video_time_ratio ⇒ Object
Position in the video as a ratio (0.01-1.0, exclusive end of each interval).
-
#relative_retention_performance ⇒ Object
Retention vs videos of similar length (0 = worst, 0.5 = median, 1 = best).
-
#started_watching ⇒ Object
Viewers who started watching in this segment.
-
#stopped_watching ⇒ Object
Viewers who stopped watching in this segment.
-
#total_segment_impressions ⇒ Object
Total views of this segment, including rewatches.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ YouTubeVideoRetentionResponseRetentionCurveInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ YouTubeVideoRetentionResponseRetentionCurveInner
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::YouTubeVideoRetentionResponseRetentionCurveInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::YouTubeVideoRetentionResponseRetentionCurveInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'elapsed_video_time_ratio') self.elapsed_video_time_ratio = attributes[:'elapsed_video_time_ratio'] end if attributes.key?(:'audience_watch_ratio') self.audience_watch_ratio = attributes[:'audience_watch_ratio'] end if attributes.key?(:'relative_retention_performance') self.relative_retention_performance = attributes[:'relative_retention_performance'] end if attributes.key?(:'started_watching') self.started_watching = attributes[:'started_watching'] end if attributes.key?(:'stopped_watching') self.stopped_watching = attributes[:'stopped_watching'] end if attributes.key?(:'total_segment_impressions') self.total_segment_impressions = attributes[:'total_segment_impressions'] end end |
Instance Attribute Details
#audience_watch_ratio ⇒ Object
Absolute share of viewers watching at this point. Can exceed 1 (rewinds/looping, common on Shorts).
22 23 24 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 22 def audience_watch_ratio @audience_watch_ratio end |
#elapsed_video_time_ratio ⇒ Object
Position in the video as a ratio (0.01-1.0, exclusive end of each interval)
19 20 21 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 19 def elapsed_video_time_ratio @elapsed_video_time_ratio end |
#relative_retention_performance ⇒ Object
Retention vs videos of similar length (0 = worst, 0.5 = median, 1 = best)
25 26 27 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 25 def relative_retention_performance @relative_retention_performance end |
#started_watching ⇒ Object
Viewers who started watching in this segment
28 29 30 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 28 def started_watching @started_watching end |
#stopped_watching ⇒ Object
Viewers who stopped watching in this segment
31 32 33 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 31 def stopped_watching @stopped_watching end |
#total_segment_impressions ⇒ Object
Total views of this segment, including rewatches
34 35 36 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 34 def total_segment_impressions @total_segment_impressions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 37 def self.attribute_map { :'elapsed_video_time_ratio' => :'elapsedVideoTimeRatio', :'audience_watch_ratio' => :'audienceWatchRatio', :'relative_retention_performance' => :'relativeRetentionPerformance', :'started_watching' => :'startedWatching', :'stopped_watching' => :'stoppedWatching', :'total_segment_impressions' => :'totalSegmentImpressions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 59 def self.openapi_types { :'elapsed_video_time_ratio' => :'Float', :'audience_watch_ratio' => :'Float', :'relative_retention_performance' => :'Float', :'started_watching' => :'Integer', :'stopped_watching' => :'Integer', :'total_segment_impressions' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && elapsed_video_time_ratio == o.elapsed_video_time_ratio && audience_watch_ratio == o.audience_watch_ratio && relative_retention_performance == o.relative_retention_performance && started_watching == o.started_watching && stopped_watching == o.stopped_watching && total_segment_impressions == o.total_segment_impressions end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 153 def hash [elapsed_video_time_ratio, audience_watch_ratio, relative_retention_performance, started_watching, stopped_watching, total_segment_impressions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 |
# File 'lib/zernio-sdk/models/you_tube_video_retention_response_retention_curve_inner.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |