Class: Late::Ad
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::Ad
- Defined in:
- lib/late-sdk/models/ad.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#ad_set_name ⇒ Object
Returns the value of attribute ad_set_name.
-
#ad_type ⇒ Object
Returns the value of attribute ad_type.
-
#budget ⇒ Object
Returns the value of attribute budget.
-
#campaign_name ⇒ Object
Returns the value of attribute campaign_name.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#creative ⇒ Object
Platform-specific creative data.
-
#goal ⇒ Object
Returns the value of attribute goal.
-
#is_external ⇒ Object
True for ads synced from platform ad managers.
-
#metrics ⇒ Object
Returns the value of attribute metrics.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_ad_account_id ⇒ Object
Returns the value of attribute platform_ad_account_id.
-
#platform_ad_id ⇒ Object
Returns the value of attribute platform_ad_id.
-
#platform_ad_set_id ⇒ Object
Returns the value of attribute platform_ad_set_id.
-
#platform_campaign_id ⇒ Object
Returns the value of attribute platform_campaign_id.
-
#rejection_reason ⇒ Object
Returns the value of attribute rejection_reason.
-
#schedule ⇒ Object
Returns the value of attribute schedule.
-
#status ⇒ Object
Returns the value of attribute status.
-
#targeting ⇒ Object
Returns the value of attribute targeting.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ad
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ad
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/late-sdk/models/ad.rb', line 156 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::Ad` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::Ad`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'ad_type') self.ad_type = attributes[:'ad_type'] end if attributes.key?(:'goal') self.goal = attributes[:'goal'] end if attributes.key?(:'is_external') self.is_external = attributes[:'is_external'] end if attributes.key?(:'budget') self.budget = attributes[:'budget'] end if attributes.key?(:'metrics') self.metrics = attributes[:'metrics'] end if attributes.key?(:'platform_ad_id') self.platform_ad_id = attributes[:'platform_ad_id'] end if attributes.key?(:'platform_ad_account_id') self.platform_ad_account_id = attributes[:'platform_ad_account_id'] end if attributes.key?(:'platform_campaign_id') self.platform_campaign_id = attributes[:'platform_campaign_id'] end if attributes.key?(:'platform_ad_set_id') self.platform_ad_set_id = attributes[:'platform_ad_set_id'] end if attributes.key?(:'campaign_name') self.campaign_name = attributes[:'campaign_name'] end if attributes.key?(:'ad_set_name') self.ad_set_name = attributes[:'ad_set_name'] end if attributes.key?(:'creative') self.creative = attributes[:'creative'] end if attributes.key?(:'targeting') self.targeting = attributes[:'targeting'] end if attributes.key?(:'schedule') self.schedule = attributes[:'schedule'] end if attributes.key?(:'rejection_reason') self.rejection_reason = attributes[:'rejection_reason'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/late-sdk/models/ad.rb', line 18 def _id @_id end |
#ad_set_name ⇒ Object
Returns the value of attribute ad_set_name.
47 48 49 |
# File 'lib/late-sdk/models/ad.rb', line 47 def ad_set_name @ad_set_name end |
#ad_type ⇒ Object
Returns the value of attribute ad_type.
26 27 28 |
# File 'lib/late-sdk/models/ad.rb', line 26 def ad_type @ad_type end |
#budget ⇒ Object
Returns the value of attribute budget.
33 34 35 |
# File 'lib/late-sdk/models/ad.rb', line 33 def budget @budget end |
#campaign_name ⇒ Object
Returns the value of attribute campaign_name.
45 46 47 |
# File 'lib/late-sdk/models/ad.rb', line 45 def campaign_name @campaign_name end |
#created_at ⇒ Object
Returns the value of attribute created_at.
58 59 60 |
# File 'lib/late-sdk/models/ad.rb', line 58 def created_at @created_at end |
#creative ⇒ Object
Platform-specific creative data
50 51 52 |
# File 'lib/late-sdk/models/ad.rb', line 50 def creative @creative end |
#goal ⇒ Object
Returns the value of attribute goal.
28 29 30 |
# File 'lib/late-sdk/models/ad.rb', line 28 def goal @goal end |
#is_external ⇒ Object
True for ads synced from platform ad managers
31 32 33 |
# File 'lib/late-sdk/models/ad.rb', line 31 def is_external @is_external end |
#metrics ⇒ Object
Returns the value of attribute metrics.
35 36 37 |
# File 'lib/late-sdk/models/ad.rb', line 35 def metrics @metrics end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/late-sdk/models/ad.rb', line 20 def name @name end |
#platform ⇒ Object
Returns the value of attribute platform.
22 23 24 |
# File 'lib/late-sdk/models/ad.rb', line 22 def platform @platform end |
#platform_ad_account_id ⇒ Object
Returns the value of attribute platform_ad_account_id.
39 40 41 |
# File 'lib/late-sdk/models/ad.rb', line 39 def platform_ad_account_id @platform_ad_account_id end |
#platform_ad_id ⇒ Object
Returns the value of attribute platform_ad_id.
37 38 39 |
# File 'lib/late-sdk/models/ad.rb', line 37 def platform_ad_id @platform_ad_id end |
#platform_ad_set_id ⇒ Object
Returns the value of attribute platform_ad_set_id.
43 44 45 |
# File 'lib/late-sdk/models/ad.rb', line 43 def platform_ad_set_id @platform_ad_set_id end |
#platform_campaign_id ⇒ Object
Returns the value of attribute platform_campaign_id.
41 42 43 |
# File 'lib/late-sdk/models/ad.rb', line 41 def platform_campaign_id @platform_campaign_id end |
#rejection_reason ⇒ Object
Returns the value of attribute rejection_reason.
56 57 58 |
# File 'lib/late-sdk/models/ad.rb', line 56 def rejection_reason @rejection_reason end |
#schedule ⇒ Object
Returns the value of attribute schedule.
54 55 56 |
# File 'lib/late-sdk/models/ad.rb', line 54 def schedule @schedule end |
#status ⇒ Object
Returns the value of attribute status.
24 25 26 |
# File 'lib/late-sdk/models/ad.rb', line 24 def status @status end |
#targeting ⇒ Object
Returns the value of attribute targeting.
52 53 54 |
# File 'lib/late-sdk/models/ad.rb', line 52 def targeting @targeting end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
60 61 62 |
# File 'lib/late-sdk/models/ad.rb', line 60 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
112 113 114 |
# File 'lib/late-sdk/models/ad.rb', line 112 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
117 118 119 |
# File 'lib/late-sdk/models/ad.rb', line 117 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/late-sdk/models/ad.rb', line 85 def self.attribute_map { :'_id' => :'_id', :'name' => :'name', :'platform' => :'platform', :'status' => :'status', :'ad_type' => :'adType', :'goal' => :'goal', :'is_external' => :'isExternal', :'budget' => :'budget', :'metrics' => :'metrics', :'platform_ad_id' => :'platformAdId', :'platform_ad_account_id' => :'platformAdAccountId', :'platform_campaign_id' => :'platformCampaignId', :'platform_ad_set_id' => :'platformAdSetId', :'campaign_name' => :'campaignName', :'ad_set_name' => :'adSetName', :'creative' => :'creative', :'targeting' => :'targeting', :'schedule' => :'schedule', :'rejection_reason' => :'rejectionReason', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/late-sdk/models/ad.rb', line 361 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
149 150 151 152 |
# File 'lib/late-sdk/models/ad.rb', line 149 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/late-sdk/models/ad.rb', line 122 def self.openapi_types { :'_id' => :'String', :'name' => :'String', :'platform' => :'String', :'status' => :'String', :'ad_type' => :'String', :'goal' => :'String', :'is_external' => :'Boolean', :'budget' => :'AdBudget', :'metrics' => :'AdMetrics', :'platform_ad_id' => :'String', :'platform_ad_account_id' => :'String', :'platform_campaign_id' => :'String', :'platform_ad_set_id' => :'String', :'campaign_name' => :'String', :'ad_set_name' => :'String', :'creative' => :'Object', :'targeting' => :'Object', :'schedule' => :'AdSchedule', :'rejection_reason' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/late-sdk/models/ad.rb', line 320 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && name == o.name && platform == o.platform && status == o.status && ad_type == o.ad_type && goal == o.goal && is_external == o.is_external && budget == o.budget && metrics == o.metrics && platform_ad_id == o.platform_ad_id && platform_ad_account_id == o.platform_ad_account_id && platform_campaign_id == o.platform_campaign_id && platform_ad_set_id == o.platform_ad_set_id && campaign_name == o.campaign_name && ad_set_name == o.ad_set_name && creative == o.creative && targeting == o.targeting && schedule == o.schedule && rejection_reason == o.rejection_reason && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
348 349 350 |
# File 'lib/late-sdk/models/ad.rb', line 348 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
354 355 356 |
# File 'lib/late-sdk/models/ad.rb', line 354 def hash [_id, name, platform, status, ad_type, goal, is_external, budget, metrics, platform_ad_id, platform_ad_account_id, platform_campaign_id, platform_ad_set_id, campaign_name, ad_set_name, creative, targeting, schedule, rejection_reason, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
257 258 259 260 261 |
# File 'lib/late-sdk/models/ad.rb', line 257 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/late-sdk/models/ad.rb', line 383 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/late-sdk/models/ad.rb', line 265 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' platform_validator = EnumAttributeValidator.new('String', ["facebook", "instagram", "tiktok", "linkedin", "pinterest", "google", "twitter"]) return false unless platform_validator.valid?(@platform) status_validator = EnumAttributeValidator.new('String', ["active", "paused", "pending_review", "rejected", "completed", "cancelled", "error"]) return false unless status_validator.valid?(@status) ad_type_validator = EnumAttributeValidator.new('String', ["boost", "standalone"]) return false unless ad_type_validator.valid?(@ad_type) goal_validator = EnumAttributeValidator.new('String', ["engagement", "traffic", "awareness", "video_views"]) return false unless goal_validator.valid?(@goal) true end |