Class: Late::TwitterPlatformData

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/twitter_platform_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TwitterPlatformData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::TwitterPlatformData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::TwitterPlatformData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'reply_to_tweet_id')
    self.reply_to_tweet_id = attributes[:'reply_to_tweet_id']
  end

  if attributes.key?(:'reply_settings')
    self.reply_settings = attributes[:'reply_settings']
  end

  if attributes.key?(:'thread_items')
    if (value = attributes[:'thread_items']).is_a?(Array)
      self.thread_items = value
    end
  end

  if attributes.key?(:'poll')
    self.poll = attributes[:'poll']
  end

  if attributes.key?(:'long_video')
    self.long_video = attributes[:'long_video']
  else
    self.long_video = false
  end
end

Instance Attribute Details

#long_videoObject

Enable long video uploads (over 140 seconds) using amplify_video media category. Requires the connected X account to have an active X Premium subscription. When true, videos are uploaded with the amplify_video category which supports longer durations (up to 10 minutes via API). When false or omitted, the standard tweet_video category is used (140 second limit). Note that not all Premium accounts have API long-video access, as X may require separate allowlisting.



30
31
32
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 30

def long_video
  @long_video
end

#pollObject

Returns the value of attribute poll.



27
28
29
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 27

def poll
  @poll
end

#reply_settingsObject

Controls who can reply to the tweet. "following" allows only people you follow, "mentionedUsers" allows only mentioned users, "subscribers" allows only subscribers, "verified" allows only verified users. Omit for default (everyone can reply). For threads, applies to the first tweet only. Cannot be combined with replyToTweetId.



22
23
24
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 22

def reply_settings
  @reply_settings
end

#reply_to_tweet_idObject

ID of an existing tweet to reply to. The published tweet will appear as a reply in that tweet’s thread. For threads, only the first tweet replies to the target; subsequent tweets chain normally.



19
20
21
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 19

def reply_to_tweet_id
  @reply_to_tweet_id
end

#thread_itemsObject

Complete sequence of tweets in a thread. The first item becomes the root tweet, subsequent items are chained as replies. When threadItems is provided, the top-level content field is used only for display and search purposes, it is NOT published. You must include your first tweet as threadItems.



25
26
27
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 25

def thread_items
  @thread_items
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 55

def self.attribute_map
  {
    :'reply_to_tweet_id' => :'replyToTweetId',
    :'reply_settings' => :'replySettings',
    :'thread_items' => :'threadItems',
    :'poll' => :'poll',
    :'long_video' => :'longVideo'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 187

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 76

def self.openapi_types
  {
    :'reply_to_tweet_id' => :'String',
    :'reply_settings' => :'String',
    :'thread_items' => :'Array<TwitterPlatformDataThreadItemsInner>',
    :'poll' => :'TwitterPlatformDataPoll',
    :'long_video' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      reply_to_tweet_id == o.reply_to_tweet_id &&
      reply_settings == o.reply_settings &&
      thread_items == o.thread_items &&
      poll == o.poll &&
      long_video == o.long_video
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



180
181
182
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 180

def hash
  [reply_to_tweet_id, reply_settings, thread_items, poll, long_video].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



135
136
137
138
139
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 135

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



143
144
145
146
147
148
# File 'lib/late-sdk/models/twitter_platform_data.rb', line 143

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  reply_settings_validator = EnumAttributeValidator.new('String', ["following", "mentionedUsers", "subscribers", "verified"])
  return false unless reply_settings_validator.valid?(@reply_settings)
  true
end