Class: Zernio::ApiKey
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ApiKey
- Defined in:
- lib/zernio-sdk/models/api_key.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#key ⇒ Object
Returned only once, on creation.
-
#key_preview ⇒ Object
Returns the value of attribute key_preview.
-
#name ⇒ Object
Returns the value of attribute name.
-
#permission ⇒ Object
'read-write' allows all operations, 'read' restricts to GET requests only.
-
#profile_ids ⇒ Object
Profiles this key can access (populated with name and color).
-
#scope ⇒ Object
'full' grants access to all profiles, 'profiles' restricts to specific profiles.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApiKey
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApiKey
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/zernio-sdk/models/api_key.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ApiKey` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ApiKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'key_preview') self.key_preview = attributes[:'key_preview'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'scope') self.scope = attributes[:'scope'] else self.scope = 'full' end if attributes.key?(:'profile_ids') if (value = attributes[:'profile_ids']).is_a?(Array) self.profile_ids = value end end if attributes.key?(:'permission') self. = attributes[:'permission'] else self. = 'read-write' end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
26 27 28 |
# File 'lib/zernio-sdk/models/api_key.rb', line 26 def created_at @created_at end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
24 25 26 |
# File 'lib/zernio-sdk/models/api_key.rb', line 24 def expires_at @expires_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/api_key.rb', line 18 def id @id end |
#key ⇒ Object
Returned only once, on creation
29 30 31 |
# File 'lib/zernio-sdk/models/api_key.rb', line 29 def key @key end |
#key_preview ⇒ Object
Returns the value of attribute key_preview.
22 23 24 |
# File 'lib/zernio-sdk/models/api_key.rb', line 22 def key_preview @key_preview end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/api_key.rb', line 20 def name @name end |
#permission ⇒ Object
'read-write' allows all operations, 'read' restricts to GET requests only
38 39 40 |
# File 'lib/zernio-sdk/models/api_key.rb', line 38 def @permission end |
#profile_ids ⇒ Object
Profiles this key can access (populated with name and color). Only present when scope is 'profiles'.
35 36 37 |
# File 'lib/zernio-sdk/models/api_key.rb', line 35 def profile_ids @profile_ids end |
#scope ⇒ Object
'full' grants access to all profiles, 'profiles' restricts to specific profiles
32 33 34 |
# File 'lib/zernio-sdk/models/api_key.rb', line 32 def scope @scope end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/zernio-sdk/models/api_key.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/zernio-sdk/models/api_key.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/zernio-sdk/models/api_key.rb', line 63 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'key_preview' => :'keyPreview', :'expires_at' => :'expiresAt', :'created_at' => :'createdAt', :'key' => :'key', :'scope' => :'scope', :'profile_ids' => :'profileIds', :'permission' => :'permission' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/zernio-sdk/models/api_key.rb', line 237 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/zernio-sdk/models/api_key.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/zernio-sdk/models/api_key.rb', line 88 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'key_preview' => :'String', :'expires_at' => :'Time', :'created_at' => :'Time', :'key' => :'String', :'scope' => :'String', :'profile_ids' => :'Array<ApiKeyProfileIdsInner>', :'permission' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/zernio-sdk/models/api_key.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && key_preview == o.key_preview && expires_at == o.expires_at && created_at == o.created_at && key == o.key && scope == o.scope && profile_ids == o.profile_ids && == o. end |
#eql?(o) ⇒ Boolean
224 225 226 |
# File 'lib/zernio-sdk/models/api_key.rb', line 224 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
230 231 232 |
# File 'lib/zernio-sdk/models/api_key.rb', line 230 def hash [id, name, key_preview, expires_at, created_at, key, scope, profile_ids, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 |
# File 'lib/zernio-sdk/models/api_key.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/zernio-sdk/models/api_key.rb', line 259 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 182 183 184 |
# File 'lib/zernio-sdk/models/api_key.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' scope_validator = EnumAttributeValidator.new('String', ["full", "profiles"]) return false unless scope_validator.valid?(@scope) = EnumAttributeValidator.new('String', ["read-write", "read"]) return false unless .valid?(@permission) true end |