Class: Zernio::AttachCampaignAssetsRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/attach_campaign_assets_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AttachCampaignAssetsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AttachCampaignAssetsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AttachCampaignAssetsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'sitelinks')
    if (value = attributes[:'sitelinks']).is_a?(Array)
      self.sitelinks = value
    end
  end

  if attributes.key?(:'callouts')
    if (value = attributes[:'callouts']).is_a?(Array)
      self.callouts = value
    end
  end

  if attributes.key?(:'structured_snippets')
    if (value = attributes[:'structured_snippets']).is_a?(Array)
      self.structured_snippets = value
    end
  end
end

Instance Attribute Details

#account_idObject

Zernio Google Ads SocialAccount id — resolves the customer id + refresh token.



19
20
21
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 19

def 
  @account_id
end

#calloutsObject

Returns the value of attribute callouts.



27
28
29
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 27

def callouts
  @callouts
end

#customer_idObject

Numeric Google Ads customer id. Required when the connection has multiple Google Ads accounts; optional (and inferred) when it has only one.



22
23
24
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 22

def customer_id
  @customer_id
end

See POST /v1/ads/create sitelinks — same shape.



25
26
27
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 25

def sitelinks
  @sitelinks
end

#structured_snippetsObject

Returns the value of attribute structured_snippets.



29
30
31
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 29

def structured_snippets
  @structured_snippets
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 32

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'customer_id' => :'customerId',
    :'sitelinks' => :'sitelinks',
    :'callouts' => :'callouts',
    :'structured_snippets' => :'structuredSnippets'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 255

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



64
65
66
67
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 64

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 53

def self.openapi_types
  {
    :'account_id' => :'String',
    :'customer_id' => :'String',
    :'sitelinks' => :'Array<AttachCampaignAssetsRequestSitelinksInner>',
    :'callouts' => :'Array<String>',
    :'structured_snippets' => :'Array<AttachCampaignAssetsRequestStructuredSnippetsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



230
231
232
233
234
235
236
237
238
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 230

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      customer_id == o.customer_id &&
      sitelinks == o.sitelinks &&
      callouts == o.callouts &&
      structured_snippets == o.structured_snippets
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 242

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



248
249
250
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 248

def hash
  [, customer_id, sitelinks, callouts, structured_snippets].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if !@sitelinks.nil? && @sitelinks.length > 20
    invalid_properties.push('invalid value for "sitelinks", number of items must be less than or equal to 20.')
  end

  if !@sitelinks.nil? && @sitelinks.length < 2
    invalid_properties.push('invalid value for "sitelinks", number of items must be greater than or equal to 2.')
  end

  if !@callouts.nil? && @callouts.length > 20
    invalid_properties.push('invalid value for "callouts", number of items must be less than or equal to 20.')
  end

  if !@callouts.nil? && @callouts.length < 1
    invalid_properties.push('invalid value for "callouts", number of items must be greater than or equal to 1.')
  end

  if !@structured_snippets.nil? && @structured_snippets.length > 20
    invalid_properties.push('invalid value for "structured_snippets", number of items must be less than or equal to 20.')
  end

  if !@structured_snippets.nil? && @structured_snippets.length < 1
    invalid_properties.push('invalid value for "structured_snippets", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 277

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
158
159
160
161
162
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if !@sitelinks.nil? && @sitelinks.length > 20
  return false if !@sitelinks.nil? && @sitelinks.length < 2
  return false if !@callouts.nil? && @callouts.length > 20
  return false if !@callouts.nil? && @callouts.length < 1
  return false if !@structured_snippets.nil? && @structured_snippets.length > 20
  return false if !@structured_snippets.nil? && @structured_snippets.length < 1
  true
end