Class: Zernio::BatchGetGoogleBusinessReviewsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::BatchGetGoogleBusinessReviewsRequest
- Defined in:
- lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb
Instance Attribute Summary collapse
-
#location_names ⇒ Object
Array of full location resource names (e.g. ['accounts/123/locations/456']).
-
#page_size ⇒ Object
Number of reviews per page (max 50).
-
#page_token ⇒ Object
Pagination token from previous response.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BatchGetGoogleBusinessReviewsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BatchGetGoogleBusinessReviewsRequest
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BatchGetGoogleBusinessReviewsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BatchGetGoogleBusinessReviewsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'location_names') if (value = attributes[:'location_names']).is_a?(Array) self.location_names = value end else self.location_names = nil end if attributes.key?(:'page_size') self.page_size = attributes[:'page_size'] else self.page_size = 50 end if attributes.key?(:'page_token') self.page_token = attributes[:'page_token'] end end |
Instance Attribute Details
#location_names ⇒ Object
Array of full location resource names (e.g. ['accounts/123/locations/456'])
19 20 21 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 19 def location_names @location_names end |
#page_size ⇒ Object
Number of reviews per page (max 50)
22 23 24 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 22 def page_size @page_size end |
#page_token ⇒ Object
Pagination token from previous response
25 26 27 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 25 def page_token @page_token end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 28 def self.attribute_map { :'location_names' => :'locationNames', :'page_size' => :'pageSize', :'page_token' => :'pageToken' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 170 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 47 def self.openapi_types { :'location_names' => :'Array<String>', :'page_size' => :'Integer', :'page_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 147 def ==(o) return true if self.equal?(o) self.class == o.class && location_names == o.location_names && page_size == o.page_size && page_token == o.page_token end |
#eql?(o) ⇒ Boolean
157 158 159 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 157 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 163 def hash [location_names, page_size, page_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 98 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @location_names.nil? invalid_properties.push('invalid value for "location_names", location_names cannot be nil.') end if !@page_size.nil? && @page_size > 50 invalid_properties.push('invalid value for "page_size", must be smaller than or equal to 50.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 118 119 |
# File 'lib/zernio-sdk/models/batch_get_google_business_reviews_request.rb', line 114 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @location_names.nil? return false if !@page_size.nil? && @page_size > 50 true end |