Class: Zernio::CreateAdCampaignRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateAdCampaignRequest
- Defined in:
- lib/zernio-sdk/models/create_ad_campaign_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Zernio SocialAccount id (posting or ads variant) used to resolve the Meta token.
-
#ad_account_id ⇒ Object
Meta ad account id (act_
). -
#budget_amount ⇒ Object
Campaign-level (CBO) budget in whole currency units.
-
#budget_type ⇒ Object
Returns the value of attribute budget_type.
-
#goal ⇒ Object
Mapped to the ODAX objective (same mapping as POST /v1/ads/create).
-
#name ⇒ Object
Returns the value of attribute name.
-
#special_ad_categories ⇒ Object
Returns the value of attribute special_ad_categories.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAdCampaignRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateAdCampaignRequest
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateAdCampaignRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateAdCampaignRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] else self.ad_account_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'goal') self.goal = attributes[:'goal'] else self.goal = nil end if attributes.key?(:'special_ad_categories') if (value = attributes[:'special_ad_categories']).is_a?(Array) self.special_ad_categories = value end end if attributes.key?(:'budget_amount') self.budget_amount = attributes[:'budget_amount'] end if attributes.key?(:'budget_type') self.budget_type = attributes[:'budget_type'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = 'PAUSED' end end |
Instance Attribute Details
#account_id ⇒ Object
Zernio SocialAccount id (posting or ads variant) used to resolve the Meta token.
19 20 21 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 19 def account_id @account_id end |
#ad_account_id ⇒ Object
Meta ad account id (act_
22 23 24 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 22 def ad_account_id @ad_account_id end |
#budget_amount ⇒ Object
Campaign-level (CBO) budget in whole currency units. Requires budgetType.
32 33 34 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 32 def budget_amount @budget_amount end |
#budget_type ⇒ Object
Returns the value of attribute budget_type.
34 35 36 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 34 def budget_type @budget_type end |
#goal ⇒ Object
Mapped to the ODAX objective (same mapping as POST /v1/ads/create).
27 28 29 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 27 def goal @goal end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 24 def name @name end |
#special_ad_categories ⇒ Object
Returns the value of attribute special_ad_categories.
29 30 31 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 29 def special_ad_categories @special_ad_categories end |
#status ⇒ Object
Returns the value of attribute status.
36 37 38 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 36 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 61 def self.attribute_map { :'account_id' => :'accountId', :'ad_account_id' => :'adAccountId', :'name' => :'name', :'goal' => :'goal', :'special_ad_categories' => :'specialAdCategories', :'budget_amount' => :'budgetAmount', :'budget_type' => :'budgetType', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 305 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 85 def self.openapi_types { :'account_id' => :'String', :'ad_account_id' => :'String', :'name' => :'String', :'goal' => :'String', :'special_ad_categories' => :'Array<String>', :'budget_amount' => :'Float', :'budget_type' => :'String', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 277 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && ad_account_id == o.ad_account_id && name == o.name && goal == o.goal && special_ad_categories == o.special_ad_categories && budget_amount == o.budget_amount && budget_type == o.budget_type && status == o.status end |
#eql?(o) ⇒ Boolean
292 293 294 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 292 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
298 299 300 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 298 def hash [account_id, ad_account_id, name, goal, special_ad_categories, budget_amount, budget_type, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @ad_account_id.nil? invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if @goal.nil? invalid_properties.push('invalid value for "goal", goal cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 327 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/zernio-sdk/models/create_ad_campaign_request.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @ad_account_id.nil? return false if @name.nil? return false if @name.to_s.length > 255 return false if @goal.nil? goal_validator = EnumAttributeValidator.new('String', ["engagement", "traffic", "awareness", "video_views", "lead_generation", "lead_conversion", "job_applicants", "conversions", "app_promotion", "catalog_sales"]) return false unless goal_validator.valid?(@goal) budget_type_validator = EnumAttributeValidator.new('String', ["daily", "lifetime"]) return false unless budget_type_validator.valid?(@budget_type) status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "PAUSED"]) return false unless status_validator.valid?(@status) true end |