Class: Zernio::CreateAdInsightsReportRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateAdInsightsReportRequest
- Defined in:
- lib/zernio-sdk/models/create_ad_insights_report_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Zernio SocialAccount id (posting or ads variant).
-
#breakdowns ⇒ Object
Comma-separated Graph breakdowns.
-
#date_preset ⇒ Object
Mutually exclusive with fromDate/toDate.
-
#fields ⇒ Object
Comma-separated Graph insights fields.
-
#filtering ⇒ Object
Meta filter objects, applied server-side.
-
#from_date ⇒ Object
Returns the value of attribute from_date.
-
#level ⇒ Object
Returns the value of attribute level.
-
#object_id ⇒ Object
Meta insights node: act_
, campaign id, ad set id or ad id. -
#time_increment ⇒ Object
Returns the value of attribute time_increment.
-
#to_date ⇒ Object
Returns the value of attribute to_date.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAdInsightsReportRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateAdInsightsReportRequest
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateAdInsightsReportRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateAdInsightsReportRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'object_id') self.object_id = attributes[:'object_id'] else self.object_id = nil end if attributes.key?(:'level') self.level = attributes[:'level'] end if attributes.key?(:'fields') self.fields = attributes[:'fields'] end if attributes.key?(:'breakdowns') self.breakdowns = attributes[:'breakdowns'] end if attributes.key?(:'filtering') if (value = attributes[:'filtering']).is_a?(Array) self.filtering = value end end if attributes.key?(:'date_preset') self.date_preset = attributes[:'date_preset'] end if attributes.key?(:'from_date') self.from_date = attributes[:'from_date'] end if attributes.key?(:'to_date') self.to_date = attributes[:'to_date'] end if attributes.key?(:'time_increment') self.time_increment = attributes[:'time_increment'] end end |
Instance Attribute Details
#account_id ⇒ Object
Zernio SocialAccount id (posting or ads variant).
19 20 21 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 19 def account_id @account_id end |
#breakdowns ⇒ Object
Comma-separated Graph breakdowns.
30 31 32 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 30 def breakdowns @breakdowns end |
#date_preset ⇒ Object
Mutually exclusive with fromDate/toDate.
36 37 38 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 36 def date_preset @date_preset end |
#fields ⇒ Object
Comma-separated Graph insights fields.
27 28 29 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 27 def fields @fields end |
#filtering ⇒ Object
Meta filter objects, applied server-side.
33 34 35 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 33 def filtering @filtering end |
#from_date ⇒ Object
Returns the value of attribute from_date.
38 39 40 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 38 def from_date @from_date end |
#level ⇒ Object
Returns the value of attribute level.
24 25 26 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 24 def level @level end |
#object_id ⇒ Object
Meta insights node: act_
22 23 24 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 22 def object_id @object_id end |
#time_increment ⇒ Object
Returns the value of attribute time_increment.
42 43 44 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 42 def time_increment @time_increment end |
#to_date ⇒ Object
Returns the value of attribute to_date.
40 41 42 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 40 def to_date @to_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 67 def self.attribute_map { :'account_id' => :'accountId', :'object_id' => :'objectId', :'level' => :'level', :'fields' => :'fields', :'breakdowns' => :'breakdowns', :'filtering' => :'filtering', :'date_preset' => :'datePreset', :'from_date' => :'fromDate', :'to_date' => :'toDate', :'time_increment' => :'timeIncrement' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 93 def self.openapi_types { :'account_id' => :'String', :'object_id' => :'String', :'level' => :'String', :'fields' => :'String', :'breakdowns' => :'String', :'filtering' => :'Array<CreateAdInsightsReportRequestFilteringInner>', :'date_preset' => :'String', :'from_date' => :'Date', :'to_date' => :'Date', :'time_increment' => :'CreateAdInsightsReportRequestTimeIncrement' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && object_id == o.object_id && level == o.level && fields == o.fields && breakdowns == o.breakdowns && filtering == o.filtering && date_preset == o.date_preset && from_date == o.from_date && to_date == o.to_date && time_increment == o.time_increment end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 259 def hash [account_id, object_id, level, fields, breakdowns, filtering, date_preset, from_date, to_date, time_increment].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @object_id.nil? invalid_properties.push('invalid value for "object_id", object_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 |
# File 'lib/zernio-sdk/models/create_ad_insights_report_request.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @object_id.nil? level_validator = EnumAttributeValidator.new('String', ["ad", "adset", "campaign", "account"]) return false unless level_validator.valid?(@level) true end |