Class: Zernio::CreateWebhookSettingsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateWebhookSettingsRequest
- Defined in:
- lib/zernio-sdk/models/create_webhook_settings_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#custom_headers ⇒ Object
Custom headers to include in webhook requests.
-
#events ⇒ Object
Events to subscribe to (at least one required).
-
#is_active ⇒ Object
Enable or disable webhook delivery.
-
#name ⇒ Object
Webhook name (1-50 characters).
-
#secret ⇒ Object
Secret key for HMAC-SHA256 signature verification.
-
#url ⇒ Object
Webhook endpoint URL (must be a valid URL, whitespace trimmed).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateWebhookSettingsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateWebhookSettingsRequest
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateWebhookSettingsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateWebhookSettingsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end else self.events = nil end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] else self.is_active = true end if attributes.key?(:'custom_headers') if (value = attributes[:'custom_headers']).is_a?(Hash) self.custom_headers = value end end end |
Instance Attribute Details
#custom_headers ⇒ Object
Custom headers to include in webhook requests
34 35 36 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 34 def custom_headers @custom_headers end |
#events ⇒ Object
Events to subscribe to (at least one required)
28 29 30 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 28 def events @events end |
#is_active ⇒ Object
Enable or disable webhook delivery. Defaults to true when omitted.
31 32 33 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 31 def is_active @is_active end |
#name ⇒ Object
Webhook name (1-50 characters)
19 20 21 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 19 def name @name end |
#secret ⇒ Object
Secret key for HMAC-SHA256 signature verification
25 26 27 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 25 def secret @secret end |
#url ⇒ Object
Webhook endpoint URL (must be a valid URL, whitespace trimmed)
22 23 24 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 22 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 59 def self.attribute_map { :'name' => :'name', :'url' => :'url', :'secret' => :'secret', :'events' => :'events', :'is_active' => :'isActive', :'custom_headers' => :'customHeaders' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 252 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 81 def self.openapi_types { :'name' => :'String', :'url' => :'String', :'secret' => :'String', :'events' => :'Array<String>', :'is_active' => :'Boolean', :'custom_headers' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && url == o.url && secret == o.secret && events == o.events && is_active == o.is_active && custom_headers == o.custom_headers end |
#eql?(o) ⇒ Boolean
239 240 241 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 239 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 245 def hash [name, url, secret, events, is_active, custom_headers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 153 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 50 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 50.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end if @events.nil? invalid_properties.push('invalid value for "events", events cannot be nil.') end if @events.length < 1 invalid_properties.push('invalid value for "events", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 274 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zernio-sdk/models/create_webhook_settings_request.rb', line 185 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 50 return false if @name.to_s.length < 1 return false if @url.nil? return false if @events.nil? return false if @events.length < 1 true end |