Class: Zernio::DuplicateAdRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::DuplicateAdRequest
- Defined in:
- lib/zernio-sdk/models/duplicate_ad_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_set_id ⇒ Object
Destination platform ad set id (defaults to the source's ad set).
-
#rename_prefix ⇒ Object
Returns the value of attribute rename_prefix.
-
#rename_strategy ⇒ Object
Returns the value of attribute rename_strategy.
-
#rename_suffix ⇒ Object
Returns the value of attribute rename_suffix.
-
#status_option ⇒ Object
Returns the value of attribute status_option.
-
#sync_after ⇒ Object
Returns the value of attribute sync_after.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DuplicateAdRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DuplicateAdRequest
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::DuplicateAdRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::DuplicateAdRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_set_id') self.ad_set_id = attributes[:'ad_set_id'] end if attributes.key?(:'status_option') self.status_option = attributes[:'status_option'] else self.status_option = 'PAUSED' end if attributes.key?(:'rename_strategy') self.rename_strategy = attributes[:'rename_strategy'] end if attributes.key?(:'rename_prefix') self.rename_prefix = attributes[:'rename_prefix'] end if attributes.key?(:'rename_suffix') self.rename_suffix = attributes[:'rename_suffix'] end if attributes.key?(:'sync_after') self.sync_after = attributes[:'sync_after'] else self.sync_after = true end end |
Instance Attribute Details
#ad_set_id ⇒ Object
Destination platform ad set id (defaults to the source's ad set)
19 20 21 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 19 def ad_set_id @ad_set_id end |
#rename_prefix ⇒ Object
Returns the value of attribute rename_prefix.
25 26 27 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 25 def rename_prefix @rename_prefix end |
#rename_strategy ⇒ Object
Returns the value of attribute rename_strategy.
23 24 25 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 23 def rename_strategy @rename_strategy end |
#rename_suffix ⇒ Object
Returns the value of attribute rename_suffix.
27 28 29 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 27 def rename_suffix @rename_suffix end |
#status_option ⇒ Object
Returns the value of attribute status_option.
21 22 23 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 21 def status_option @status_option end |
#sync_after ⇒ Object
Returns the value of attribute sync_after.
29 30 31 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 29 def sync_after @sync_after end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 54 def self.attribute_map { :'ad_set_id' => :'adSetId', :'status_option' => :'statusOption', :'rename_strategy' => :'renameStrategy', :'rename_prefix' => :'renamePrefix', :'rename_suffix' => :'renameSuffix', :'sync_after' => :'syncAfter' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 205 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 76 def self.openapi_types { :'ad_set_id' => :'String', :'status_option' => :'String', :'rename_strategy' => :'String', :'rename_prefix' => :'String', :'rename_suffix' => :'String', :'sync_after' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && ad_set_id == o.ad_set_id && status_option == o.status_option && rename_strategy == o.rename_strategy && rename_prefix == o.rename_prefix && rename_suffix == o.rename_suffix && sync_after == o.sync_after end |
#eql?(o) ⇒ Boolean
192 193 194 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 192 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 198 def hash [ad_set_id, status_option, rename_strategy, rename_prefix, rename_suffix, sync_after].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 152 153 154 155 |
# File 'lib/zernio-sdk/models/duplicate_ad_request.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_option_validator = EnumAttributeValidator.new('String', ["ACTIVE", "PAUSED", "INHERITED_FROM_SOURCE"]) return false unless status_option_validator.valid?(@status_option) rename_strategy_validator = EnumAttributeValidator.new('String', ["DEEP_RENAME", "ONLY_TOP_LEVEL_RENAME", "NO_RENAME"]) return false unless rename_strategy_validator.valid?(@rename_strategy) true end |