Class: Zernio::DuplicateAdSetRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::DuplicateAdSetRequest
- Defined in:
- lib/zernio-sdk/models/duplicate_ad_set_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#campaign_id ⇒ Object
Destination platform campaign id (defaults to the source's campaign).
-
#deep_copy ⇒ Object
Copy child ads + creatives.
-
#end_time ⇒ Object
Returns the value of attribute end_time.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#rename_prefix ⇒ Object
Returns the value of attribute rename_prefix.
-
#rename_strategy ⇒ Object
Returns the value of attribute rename_strategy.
-
#rename_suffix ⇒ Object
Returns the value of attribute rename_suffix.
-
#start_time ⇒ Object
Reschedule the copy's start time.
-
#status_option ⇒ Object
Returns the value of attribute status_option.
-
#sync_after ⇒ Object
Returns the value of attribute sync_after.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DuplicateAdSetRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DuplicateAdSetRequest
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::DuplicateAdSetRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::DuplicateAdSetRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'deep_copy') self.deep_copy = attributes[:'deep_copy'] else self.deep_copy = true end if attributes.key?(:'status_option') self.status_option = attributes[:'status_option'] else self.status_option = 'PAUSED' end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'rename_strategy') self.rename_strategy = attributes[:'rename_strategy'] end if attributes.key?(:'rename_prefix') self.rename_prefix = attributes[:'rename_prefix'] end if attributes.key?(:'rename_suffix') self.rename_suffix = attributes[:'rename_suffix'] end if attributes.key?(:'sync_after') self.sync_after = attributes[:'sync_after'] else self.sync_after = true end end |
Instance Attribute Details
#campaign_id ⇒ Object
Destination platform campaign id (defaults to the source's campaign)
21 22 23 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 21 def campaign_id @campaign_id end |
#deep_copy ⇒ Object
Copy child ads + creatives
24 25 26 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 24 def deep_copy @deep_copy end |
#end_time ⇒ Object
Returns the value of attribute end_time.
31 32 33 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 31 def end_time @end_time end |
#platform ⇒ Object
Returns the value of attribute platform.
18 19 20 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 18 def platform @platform end |
#rename_prefix ⇒ Object
Returns the value of attribute rename_prefix.
35 36 37 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 35 def rename_prefix @rename_prefix end |
#rename_strategy ⇒ Object
Returns the value of attribute rename_strategy.
33 34 35 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 33 def rename_strategy @rename_strategy end |
#rename_suffix ⇒ Object
Returns the value of attribute rename_suffix.
37 38 39 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 37 def rename_suffix @rename_suffix end |
#start_time ⇒ Object
Reschedule the copy's start time
29 30 31 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 29 def start_time @start_time end |
#status_option ⇒ Object
Returns the value of attribute status_option.
26 27 28 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 26 def status_option @status_option end |
#sync_after ⇒ Object
Returns the value of attribute sync_after.
39 40 41 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 39 def sync_after @sync_after end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 64 def self.attribute_map { :'platform' => :'platform', :'campaign_id' => :'campaignId', :'deep_copy' => :'deepCopy', :'status_option' => :'statusOption', :'start_time' => :'startTime', :'end_time' => :'endTime', :'rename_strategy' => :'renameStrategy', :'rename_prefix' => :'renamePrefix', :'rename_suffix' => :'renameSuffix', :'sync_after' => :'syncAfter' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 264 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 106 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 90 def self.openapi_types { :'platform' => :'String', :'campaign_id' => :'String', :'deep_copy' => :'Boolean', :'status_option' => :'String', :'start_time' => :'Time', :'end_time' => :'Time', :'rename_strategy' => :'String', :'rename_prefix' => :'String', :'rename_suffix' => :'String', :'sync_after' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && platform == o.platform && campaign_id == o.campaign_id && deep_copy == o.deep_copy && status_option == o.status_option && start_time == o.start_time && end_time == o.end_time && rename_strategy == o.rename_strategy && rename_prefix == o.rename_prefix && rename_suffix == o.rename_suffix && sync_after == o.sync_after end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 257 def hash [platform, campaign_id, deep_copy, status_option, start_time, end_time, rename_strategy, rename_prefix, rename_suffix, sync_after].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
178 179 180 181 182 183 184 185 186 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 178 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/zernio-sdk/models/duplicate_ad_set_request.rb', line 190 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @platform.nil? platform_validator = EnumAttributeValidator.new('String', ["facebook", "instagram"]) return false unless platform_validator.valid?(@platform) status_option_validator = EnumAttributeValidator.new('String', ["ACTIVE", "PAUSED", "INHERITED_FROM_SOURCE"]) return false unless status_option_validator.valid?(@status_option) rename_strategy_validator = EnumAttributeValidator.new('String', ["DEEP_RENAME", "ONLY_TOP_LEVEL_RENAME", "NO_RENAME"]) return false unless rename_strategy_validator.valid?(@rename_strategy) true end |