Class: Zernio::GMBFoodMenusApi
- Inherits:
-
Object
- Object
- Zernio::GMBFoodMenusApi
- Defined in:
- lib/zernio-sdk/api/gmb_food_menus_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_google_business_food_menus(account_id, opts = {}) ⇒ GetGoogleBusinessFoodMenus200Response
Get food menus Returns food menus for a GBP location including sections, items, pricing, and dietary info.
-
#get_google_business_food_menus_with_http_info(account_id, opts = {}) ⇒ Array<(GetGoogleBusinessFoodMenus200Response, Integer, Hash)>
Get food menus Returns food menus for a GBP location including sections, items, pricing, and dietary info.
-
#initialize(api_client = ApiClient.default) ⇒ GMBFoodMenusApi
constructor
A new instance of GMBFoodMenusApi.
-
#update_google_business_food_menus(account_id, update_google_business_food_menus_request, opts = {}) ⇒ UpdateGoogleBusinessFoodMenus200Response
Update food menus Updates food menus for a GBP location.
-
#update_google_business_food_menus_with_http_info(account_id, update_google_business_food_menus_request, opts = {}) ⇒ Array<(UpdateGoogleBusinessFoodMenus200Response, Integer, Hash)>
Update food menus Updates food menus for a GBP location.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ GMBFoodMenusApi
Returns a new instance of GMBFoodMenusApi.
19 20 21 |
# File 'lib/zernio-sdk/api/gmb_food_menus_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zernio-sdk/api/gmb_food_menus_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_google_business_food_menus(account_id, opts = {}) ⇒ GetGoogleBusinessFoodMenus200Response
Get food menus Returns food menus for a GBP location including sections, items, pricing, and dietary info. Only for locations with food menu support.
28 29 30 31 |
# File 'lib/zernio-sdk/api/gmb_food_menus_api.rb', line 28 def (account_id, opts = {}) data, _status_code, _headers = (account_id, opts) data end |
#get_google_business_food_menus_with_http_info(account_id, opts = {}) ⇒ Array<(GetGoogleBusinessFoodMenus200Response, Integer, Hash)>
Get food menus Returns food menus for a GBP location including sections, items, pricing, and dietary info. Only for locations with food menu support.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/zernio-sdk/api/gmb_food_menus_api.rb', line 39 def (account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBFoodMenusApi.get_google_business_food_menus ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBFoodMenusApi.get_google_business_food_menus" end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-food-menus'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetGoogleBusinessFoodMenus200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBFoodMenusApi.get_google_business_food_menus", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBFoodMenusApi#get_google_business_food_menus\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_google_business_food_menus(account_id, update_google_business_food_menus_request, opts = {}) ⇒ UpdateGoogleBusinessFoodMenus200Response
Update food menus Updates food menus for a GBP location. Send the full menus array. Use updateMask for partial updates.
95 96 97 98 |
# File 'lib/zernio-sdk/api/gmb_food_menus_api.rb', line 95 def (account_id, , opts = {}) data, _status_code, _headers = (account_id, , opts) data end |
#update_google_business_food_menus_with_http_info(account_id, update_google_business_food_menus_request, opts = {}) ⇒ Array<(UpdateGoogleBusinessFoodMenus200Response, Integer, Hash)>
Update food menus Updates food menus for a GBP location. Send the full menus array. Use updateMask for partial updates.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/api/gmb_food_menus_api.rb', line 107 def (account_id, , opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBFoodMenusApi.update_google_business_food_menus ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBFoodMenusApi.update_google_business_food_menus" end # verify the required parameter 'update_google_business_food_menus_request' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'update_google_business_food_menus_request' when calling GMBFoodMenusApi.update_google_business_food_menus" end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-food-menus'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body() # return_type return_type = opts[:debug_return_type] || 'UpdateGoogleBusinessFoodMenus200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBFoodMenusApi.update_google_business_food_menus", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBFoodMenusApi#update_google_business_food_menus\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |