Class: Zernio::GMBReviewsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/zernio-sdk/api/gmb_reviews_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ GMBReviewsApi

Returns a new instance of GMBReviewsApi.



19
20
21
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#batch_get_google_business_reviews(account_id, batch_get_google_business_reviews_request, opts = {}) ⇒ BatchGetGoogleBusinessReviews200Response

Batch get reviews Fetches reviews across multiple locations in a single request. More efficient than calling GET /gmb-reviews per location for multi-location businesses. Returns a flat list of individual reviews, each tagged with its review resource name. Note: this endpoint does not return aggregate metrics (averageRating / totalReviewCount). For those, use the single-location GET /gmb-reviews endpoint.

Parameters:

Returns:



28
29
30
31
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 28

def batch_get_google_business_reviews(, batch_get_google_business_reviews_request, opts = {})
  data, _status_code, _headers = batch_get_google_business_reviews_with_http_info(, batch_get_google_business_reviews_request, opts)
  data
end

#batch_get_google_business_reviews_with_http_info(account_id, batch_get_google_business_reviews_request, opts = {}) ⇒ Array<(BatchGetGoogleBusinessReviews200Response, Integer, Hash)>

Batch get reviews Fetches reviews across multiple locations in a single request. More efficient than calling GET /gmb-reviews per location for multi-location businesses. Returns a flat list of individual reviews, each tagged with its review resource name. Note: this endpoint does not return aggregate metrics (averageRating / totalReviewCount). For those, use the single-location GET /gmb-reviews endpoint.

Parameters:

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 39

def batch_get_google_business_reviews_with_http_info(, batch_get_google_business_reviews_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GMBReviewsApi.batch_get_google_business_reviews ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBReviewsApi.batch_get_google_business_reviews"
  end
  # verify the required parameter 'batch_get_google_business_reviews_request' is set
  if @api_client.config.client_side_validation && batch_get_google_business_reviews_request.nil?
    fail ArgumentError, "Missing the required parameter 'batch_get_google_business_reviews_request' when calling GMBReviewsApi.batch_get_google_business_reviews"
  end
  # resource path
  local_var_path = '/v1/accounts/{accountId}/gmb-reviews/batch'.sub('{' + 'accountId' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(batch_get_google_business_reviews_request)

  # return_type
  return_type = opts[:debug_return_type] || 'BatchGetGoogleBusinessReviews200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"GMBReviewsApi.batch_get_google_business_reviews",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GMBReviewsApi#batch_get_google_business_reviews\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_google_business_review_reply(account_id, review_id, opts = {}) ⇒ DeleteGoogleBusinessReviewReply200Response

Delete a review reply Removes the business owner reply from a Google Business review. The review itself remains.

Parameters:

  • account_id (String)

    The Zernio account ID (from /v1/accounts)

  • review_id (String)

    The review ID portion (e.g. &quot;AIe9_BGx1234567890&quot;), not the full resource name

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



102
103
104
105
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 102

def delete_google_business_review_reply(, review_id, opts = {})
  data, _status_code, _headers = delete_google_business_review_reply_with_http_info(, review_id, opts)
  data
end

#delete_google_business_review_reply_with_http_info(account_id, review_id, opts = {}) ⇒ Array<(DeleteGoogleBusinessReviewReply200Response, Integer, Hash)>

Delete a review reply Removes the business owner reply from a Google Business review. The review itself remains.

Parameters:

  • account_id (String)

    The Zernio account ID (from /v1/accounts)

  • review_id (String)

    The review ID portion (e.g. &quot;AIe9_BGx1234567890&quot;), not the full resource name

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 113

def delete_google_business_review_reply_with_http_info(, review_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GMBReviewsApi.delete_google_business_review_reply ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBReviewsApi.delete_google_business_review_reply"
  end
  # verify the required parameter 'review_id' is set
  if @api_client.config.client_side_validation && review_id.nil?
    fail ArgumentError, "Missing the required parameter 'review_id' when calling GMBReviewsApi.delete_google_business_review_reply"
  end
  # resource path
  local_var_path = '/v1/accounts/{accountId}/gmb-reviews/{reviewId}/reply'.sub('{' + 'accountId' + '}', CGI.escape(.to_s)).sub('{' + 'reviewId' + '}', CGI.escape(review_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteGoogleBusinessReviewReply200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"GMBReviewsApi.delete_google_business_review_reply",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GMBReviewsApi#delete_google_business_review_reply\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_google_business_reviews(account_id, opts = {}) ⇒ GetGoogleBusinessReviews200Response

Get reviews Returns reviews for a GBP account including ratings, comments, and owner replies. Use nextPageToken for pagination.

Parameters:

  • account_id (String)

    The Zernio account ID (from /v1/accounts)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :location_id (String)

    Override which location to query. If omitted, uses the account's selected location. Use GET /gmb-locations to list valid IDs.

  • :page_size (Integer)

    Number of reviews to fetch per page (max 50) (default to 50)

  • :page_token (String)

    Pagination token from previous response

Returns:



173
174
175
176
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 173

def get_google_business_reviews(, opts = {})
  data, _status_code, _headers = get_google_business_reviews_with_http_info(, opts)
  data
end

#get_google_business_reviews_with_http_info(account_id, opts = {}) ⇒ Array<(GetGoogleBusinessReviews200Response, Integer, Hash)>

Get reviews Returns reviews for a GBP account including ratings, comments, and owner replies. Use nextPageToken for pagination.

Parameters:

  • account_id (String)

    The Zernio account ID (from /v1/accounts)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :location_id (String)

    Override which location to query. If omitted, uses the account's selected location. Use GET /gmb-locations to list valid IDs.

  • :page_size (Integer)

    Number of reviews to fetch per page (max 50) (default to 50)

  • :page_token (String)

    Pagination token from previous response

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 186

def get_google_business_reviews_with_http_info(, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GMBReviewsApi.get_google_business_reviews ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBReviewsApi.get_google_business_reviews"
  end
  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 50
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling GMBReviewsApi.get_google_business_reviews, must be smaller than or equal to 50.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling GMBReviewsApi.get_google_business_reviews, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/v1/accounts/{accountId}/gmb-reviews'.sub('{' + 'accountId' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'pageToken'] = opts[:'page_token'] if !opts[:'page_token'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetGoogleBusinessReviews200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"GMBReviewsApi.get_google_business_reviews",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GMBReviewsApi#get_google_business_reviews\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#reply_to_google_business_review(account_id, review_id, reply_to_google_business_review_request, opts = {}) ⇒ ReplyToGoogleBusinessReview200Response

Reply to a review Posts (or updates) the business owner reply to a Google Business review. The reply is associated with the account's currently selected location (set via /v1/accounts/accountId/gmb-locations). Calling this endpoint a second time on the same review overwrites the previous reply (PUT semantics on Google's side).

Parameters:

  • account_id (String)

    The Zernio account ID (from /v1/accounts)

  • review_id (String)

    The review ID portion (e.g. &quot;AIe9_BGx1234567890&quot;), not the full resource name

  • reply_to_google_business_review_request (ReplyToGoogleBusinessReviewRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



252
253
254
255
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 252

def reply_to_google_business_review(, review_id, reply_to_google_business_review_request, opts = {})
  data, _status_code, _headers = reply_to_google_business_review_with_http_info(, review_id, reply_to_google_business_review_request, opts)
  data
end

#reply_to_google_business_review_with_http_info(account_id, review_id, reply_to_google_business_review_request, opts = {}) ⇒ Array<(ReplyToGoogleBusinessReview200Response, Integer, Hash)>

Reply to a review Posts (or updates) the business owner reply to a Google Business review. The reply is associated with the account's currently selected location (set via /v1/accounts/accountId/gmb-locations). Calling this endpoint a second time on the same review overwrites the previous reply (PUT semantics on Google's side).

Parameters:

  • account_id (String)

    The Zernio account ID (from /v1/accounts)

  • review_id (String)

    The review ID portion (e.g. &quot;AIe9_BGx1234567890&quot;), not the full resource name

  • reply_to_google_business_review_request (ReplyToGoogleBusinessReviewRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/zernio-sdk/api/gmb_reviews_api.rb', line 264

def reply_to_google_business_review_with_http_info(, review_id, reply_to_google_business_review_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GMBReviewsApi.reply_to_google_business_review ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBReviewsApi.reply_to_google_business_review"
  end
  # verify the required parameter 'review_id' is set
  if @api_client.config.client_side_validation && review_id.nil?
    fail ArgumentError, "Missing the required parameter 'review_id' when calling GMBReviewsApi.reply_to_google_business_review"
  end
  # verify the required parameter 'reply_to_google_business_review_request' is set
  if @api_client.config.client_side_validation && reply_to_google_business_review_request.nil?
    fail ArgumentError, "Missing the required parameter 'reply_to_google_business_review_request' when calling GMBReviewsApi.reply_to_google_business_review"
  end
  # resource path
  local_var_path = '/v1/accounts/{accountId}/gmb-reviews/{reviewId}/reply'.sub('{' + 'accountId' + '}', CGI.escape(.to_s)).sub('{' + 'reviewId' + '}', CGI.escape(review_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(reply_to_google_business_review_request)

  # return_type
  return_type = opts[:debug_return_type] || 'ReplyToGoogleBusinessReview200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"GMBReviewsApi.reply_to_google_business_review",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GMBReviewsApi#reply_to_google_business_review\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end