Class: Zernio::GetAdTrackingTags200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetAdTrackingTags200Response
- Defined in:
- lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#custom_value_parameters ⇒ Object
LinkedIn.
-
#dynamic_value_parameters ⇒ Object
LinkedIn.
-
#final_url_suffix ⇒ Object
Google.
-
#level ⇒ Object
Returns the value of attribute level.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#template_url_spec ⇒ Object
Meta: third-party click-tracking template (Dynamic Ads).
-
#tracking_url_template ⇒ Object
Google.
-
#url_tags ⇒ Object
Meta: &-joined click-URL params.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetAdTrackingTags200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetAdTrackingTags200Response
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAdTrackingTags200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAdTrackingTags200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'level') self.level = attributes[:'level'] end if attributes.key?(:'url_tags') self. = attributes[:'url_tags'] end if attributes.key?(:'template_url_spec') self.template_url_spec = attributes[:'template_url_spec'] end if attributes.key?(:'tracking_url_template') self.tracking_url_template = attributes[:'tracking_url_template'] end if attributes.key?(:'final_url_suffix') self.final_url_suffix = attributes[:'final_url_suffix'] end if attributes.key?(:'dynamic_value_parameters') self.dynamic_value_parameters = attributes[:'dynamic_value_parameters'] end if attributes.key?(:'custom_value_parameters') self.custom_value_parameters = attributes[:'custom_value_parameters'] end end |
Instance Attribute Details
#custom_value_parameters ⇒ Object
LinkedIn.
38 39 40 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 38 def custom_value_parameters @custom_value_parameters end |
#dynamic_value_parameters ⇒ Object
LinkedIn.
35 36 37 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 35 def dynamic_value_parameters @dynamic_value_parameters end |
#final_url_suffix ⇒ Object
Google.
32 33 34 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 32 def final_url_suffix @final_url_suffix end |
#level ⇒ Object
Returns the value of attribute level.
20 21 22 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 20 def level @level end |
#platform ⇒ Object
Returns the value of attribute platform.
18 19 20 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 18 def platform @platform end |
#template_url_spec ⇒ Object
Meta: third-party click-tracking template (Dynamic Ads).
26 27 28 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 26 def template_url_spec @template_url_spec end |
#tracking_url_template ⇒ Object
Google.
29 30 31 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 29 def tracking_url_template @tracking_url_template end |
#url_tags ⇒ Object
Meta: &-joined click-URL params.
23 24 25 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 23 def @url_tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 63 def self.attribute_map { :'platform' => :'platform', :'level' => :'level', :'url_tags' => :'urlTags', :'template_url_spec' => :'templateUrlSpec', :'tracking_url_template' => :'trackingUrlTemplate', :'final_url_suffix' => :'finalUrlSuffix', :'dynamic_value_parameters' => :'dynamicValueParameters', :'custom_value_parameters' => :'customValueParameters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 218 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 101 def self.openapi_nullable Set.new([ :'url_tags', :'template_url_spec', :'tracking_url_template', :'final_url_suffix', :'dynamic_value_parameters', :'custom_value_parameters' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 87 def self.openapi_types { :'platform' => :'String', :'level' => :'String', :'url_tags' => :'String', :'template_url_spec' => :'Object', :'tracking_url_template' => :'String', :'final_url_suffix' => :'String', :'dynamic_value_parameters' => :'Object', :'custom_value_parameters' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && platform == o.platform && level == o.level && == o. && template_url_spec == o.template_url_spec && tracking_url_template == o.tracking_url_template && final_url_suffix == o.final_url_suffix && dynamic_value_parameters == o.dynamic_value_parameters && custom_value_parameters == o.custom_value_parameters end |
#eql?(o) ⇒ Boolean
205 206 207 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 205 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 211 def hash [platform, level, , template_url_spec, tracking_url_template, final_url_suffix, dynamic_value_parameters, custom_value_parameters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 163 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 |
# File 'lib/zernio-sdk/models/get_ad_tracking_tags200_response.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' level_validator = EnumAttributeValidator.new('String', ["creative", "campaign"]) return false unless level_validator.valid?(@level) true end |