Class: Zernio::GetAllAccountsHealth200ResponseAccountsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetAllAccountsHealth200ResponseAccountsInner
- Defined in:
- lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#can_fetch_analytics ⇒ Object
Returns the value of attribute can_fetch_analytics.
-
#can_post ⇒ Object
Returns the value of attribute can_post.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#issues ⇒ Object
Returns the value of attribute issues.
-
#needs_reconnect ⇒ Object
Returns the value of attribute needs_reconnect.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#profile_id ⇒ Object
Returns the value of attribute profile_id.
-
#status ⇒ Object
Returns the value of attribute status.
-
#token_expires_at ⇒ Object
Returns the value of attribute token_expires_at.
-
#token_valid ⇒ Object
Returns the value of attribute token_valid.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetAllAccountsHealth200ResponseAccountsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetAllAccountsHealth200ResponseAccountsInner
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAllAccountsHealth200ResponseAccountsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAllAccountsHealth200ResponseAccountsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'can_post') self.can_post = attributes[:'can_post'] end if attributes.key?(:'can_fetch_analytics') self.can_fetch_analytics = attributes[:'can_fetch_analytics'] end if attributes.key?(:'token_valid') self.token_valid = attributes[:'token_valid'] end if attributes.key?(:'token_expires_at') self.token_expires_at = attributes[:'token_expires_at'] end if attributes.key?(:'needs_reconnect') self.needs_reconnect = attributes[:'needs_reconnect'] end if attributes.key?(:'issues') if (value = attributes[:'issues']).is_a?(Array) self.issues = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 18 def account_id @account_id end |
#can_fetch_analytics ⇒ Object
Returns the value of attribute can_fetch_analytics.
32 33 34 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 32 def can_fetch_analytics @can_fetch_analytics end |
#can_post ⇒ Object
Returns the value of attribute can_post.
30 31 32 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 30 def can_post @can_post end |
#display_name ⇒ Object
Returns the value of attribute display_name.
24 25 26 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 24 def display_name @display_name end |
#issues ⇒ Object
Returns the value of attribute issues.
40 41 42 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 40 def issues @issues end |
#needs_reconnect ⇒ Object
Returns the value of attribute needs_reconnect.
38 39 40 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 38 def needs_reconnect @needs_reconnect end |
#platform ⇒ Object
Returns the value of attribute platform.
20 21 22 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 20 def platform @platform end |
#profile_id ⇒ Object
Returns the value of attribute profile_id.
26 27 28 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 26 def profile_id @profile_id end |
#status ⇒ Object
Returns the value of attribute status.
28 29 30 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 28 def status @status end |
#token_expires_at ⇒ Object
Returns the value of attribute token_expires_at.
36 37 38 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 36 def token_expires_at @token_expires_at end |
#token_valid ⇒ Object
Returns the value of attribute token_valid.
34 35 36 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 34 def token_valid @token_valid end |
#username ⇒ Object
Returns the value of attribute username.
22 23 24 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 22 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 65 def self.attribute_map { :'account_id' => :'accountId', :'platform' => :'platform', :'username' => :'username', :'display_name' => :'displayName', :'profile_id' => :'profileId', :'status' => :'status', :'can_post' => :'canPost', :'can_fetch_analytics' => :'canFetchAnalytics', :'token_valid' => :'tokenValid', :'token_expires_at' => :'tokenExpiresAt', :'needs_reconnect' => :'needsReconnect', :'issues' => :'issues' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 244 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 111 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 93 def self.openapi_types { :'account_id' => :'String', :'platform' => :'String', :'username' => :'String', :'display_name' => :'String', :'profile_id' => :'String', :'status' => :'String', :'can_post' => :'Boolean', :'can_fetch_analytics' => :'Boolean', :'token_valid' => :'Boolean', :'token_expires_at' => :'Time', :'needs_reconnect' => :'Boolean', :'issues' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && platform == o.platform && username == o.username && display_name == o.display_name && profile_id == o.profile_id && status == o.status && can_post == o.can_post && can_fetch_analytics == o.can_fetch_analytics && token_valid == o.token_valid && token_expires_at == o.token_expires_at && needs_reconnect == o.needs_reconnect && issues == o.issues end |
#eql?(o) ⇒ Boolean
231 232 233 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 231 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
237 238 239 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 237 def hash [account_id, platform, username, display_name, profile_id, status, can_post, can_fetch_analytics, token_valid, token_expires_at, needs_reconnect, issues].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 189 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 185 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 |
# File 'lib/zernio-sdk/models/get_all_accounts_health200_response_accounts_inner.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["healthy", "warning", "error"]) return false unless status_validator.valid?(@status) true end |