Class: Zernio::GetInboxConversationMessages200ResponseMessagesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetInboxConversationMessages200ResponseMessagesInner
- Defined in:
- lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#attachments ⇒ Object
Returns the value of attribute attachments.
-
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
-
#delivered_at ⇒ Object
Returns the value of attribute delivered_at.
-
#delivery_error ⇒ Object
Returns the value of attribute delivery_error.
-
#delivery_status ⇒ Object
Lifecycle status for outgoing messages.
-
#direction ⇒ Object
Returns the value of attribute direction.
-
#edit_count ⇒ Object
Total number of edits applied.
-
#edit_history ⇒ Object
Every prior version of the message, oldest first.
-
#edited_at ⇒ Object
When the most recent edit happened.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_deleted ⇒ Object
True if the sender has deleted (unsent) this message.
-
#is_edited ⇒ Object
True if the sender has edited this message at least once.
-
#is_story_mention ⇒ Object
Instagram story mention.
-
#message ⇒ Object
Returns the value of attribute message.
-
#metadata ⇒ Object
Platform-specific extras.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#reactions ⇒ Object
Emoji reactions on this message (WhatsApp / Telegram).
-
#read_at ⇒ Object
Returns the value of attribute read_at.
-
#sender_id ⇒ Object
Returns the value of attribute sender_id.
-
#sender_name ⇒ Object
Returns the value of attribute sender_name.
-
#sender_verified_type ⇒ Object
X/Twitter verified badge type.
-
#sent_at ⇒ Object
Original send time for outgoing messages (used for Messenger watermark queries).
-
#story_reply ⇒ Object
Instagram story reply.
-
#subject ⇒ Object
Reddit message subject.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetInboxConversationMessages200ResponseMessagesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetInboxConversationMessages200ResponseMessagesInner
Initializes the object
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 202 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetInboxConversationMessages200ResponseMessagesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetInboxConversationMessages200ResponseMessagesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'conversation_id') self.conversation_id = attributes[:'conversation_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'message') self. = attributes[:'message'] end if attributes.key?(:'sender_id') self.sender_id = attributes[:'sender_id'] end if attributes.key?(:'sender_name') self.sender_name = attributes[:'sender_name'] end if attributes.key?(:'sender_verified_type') self.sender_verified_type = attributes[:'sender_verified_type'] end if attributes.key?(:'direction') self.direction = attributes[:'direction'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'story_reply') self.story_reply = attributes[:'story_reply'] end if attributes.key?(:'is_story_mention') self.is_story_mention = attributes[:'is_story_mention'] end if attributes.key?(:'is_edited') self.is_edited = attributes[:'is_edited'] end if attributes.key?(:'edited_at') self.edited_at = attributes[:'edited_at'] end if attributes.key?(:'edit_count') self.edit_count = attributes[:'edit_count'] end if attributes.key?(:'edit_history') if (value = attributes[:'edit_history']).is_a?(Array) self.edit_history = value end end if attributes.key?(:'is_deleted') self.is_deleted = attributes[:'is_deleted'] end if attributes.key?(:'deleted_at') self.deleted_at = attributes[:'deleted_at'] end if attributes.key?(:'delivery_status') self.delivery_status = attributes[:'delivery_status'] end if attributes.key?(:'delivered_at') self.delivered_at = attributes[:'delivered_at'] end if attributes.key?(:'read_at') self.read_at = attributes[:'read_at'] end if attributes.key?(:'sent_at') self.sent_at = attributes[:'sent_at'] end if attributes.key?(:'delivery_error') self.delivery_error = attributes[:'delivery_error'] end if attributes.key?(:'reactions') if (value = attributes[:'reactions']).is_a?(Array) self.reactions = value end end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
22 23 24 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 22 def account_id @account_id end |
#attachments ⇒ Object
Returns the value of attribute attachments.
39 40 41 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 39 def @attachments end |
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
20 21 22 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 20 def conversation_id @conversation_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
37 38 39 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 37 def created_at @created_at end |
#deleted_at ⇒ Object
Returns the value of attribute deleted_at.
65 66 67 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 65 def deleted_at @deleted_at end |
#delivered_at ⇒ Object
Returns the value of attribute delivered_at.
70 71 72 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 70 def delivered_at @delivered_at end |
#delivery_error ⇒ Object
Returns the value of attribute delivery_error.
77 78 79 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 77 def delivery_error @delivery_error end |
#delivery_status ⇒ Object
Lifecycle status for outgoing messages. Not all platforms emit every state (see webhook support matrix).
68 69 70 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 68 def delivery_status @delivery_status end |
#direction ⇒ Object
Returns the value of attribute direction.
35 36 37 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 35 def direction @direction end |
#edit_count ⇒ Object
Total number of edits applied.
57 58 59 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 57 def edit_count @edit_count end |
#edit_history ⇒ Object
Every prior version of the message, oldest first.
60 61 62 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 60 def edit_history @edit_history end |
#edited_at ⇒ Object
When the most recent edit happened.
54 55 56 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 54 def edited_at @edited_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 18 def id @id end |
#is_deleted ⇒ Object
True if the sender has deleted (unsent) this message. The original message and attachments fields remain populated.
63 64 65 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 63 def is_deleted @is_deleted end |
#is_edited ⇒ Object
True if the sender has edited this message at least once.
51 52 53 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 51 def is_edited @is_edited end |
#is_story_mention ⇒ Object
Instagram story mention
48 49 50 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 48 def is_story_mention @is_story_mention end |
#message ⇒ Object
Returns the value of attribute message.
26 27 28 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 26 def @message end |
#metadata ⇒ Object
Platform-specific extras. Free-form, but commonly includes: quotedMessageId (platformMessageId this message replies to), waInteractive (a compact descriptor of WhatsApp interactive content sent: buttons / list / cta_url / flow / location_request), and for inbound interactive taps interactiveType / interactiveId.
83 84 85 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 83 def @metadata end |
#platform ⇒ Object
Returns the value of attribute platform.
24 25 26 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 24 def platform @platform end |
#reactions ⇒ Object
Emoji reactions on this message (WhatsApp / Telegram). At most one per party in a 1:1 thread.
80 81 82 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 80 def reactions @reactions end |
#read_at ⇒ Object
Returns the value of attribute read_at.
72 73 74 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 72 def read_at @read_at end |
#sender_id ⇒ Object
Returns the value of attribute sender_id.
28 29 30 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 28 def sender_id @sender_id end |
#sender_name ⇒ Object
Returns the value of attribute sender_name.
30 31 32 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 30 def sender_name @sender_name end |
#sender_verified_type ⇒ Object
X/Twitter verified badge type. Only present for Twitter/X messages.
33 34 35 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 33 def sender_verified_type @sender_verified_type end |
#sent_at ⇒ Object
Original send time for outgoing messages (used for Messenger watermark queries).
75 76 77 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 75 def sent_at @sent_at end |
#story_reply ⇒ Object
Instagram story reply
45 46 47 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 45 def story_reply @story_reply end |
#subject ⇒ Object
Reddit message subject
42 43 44 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 42 def subject @subject end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
141 142 143 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 141 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
146 147 148 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 146 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 108 def self.attribute_map { :'id' => :'id', :'conversation_id' => :'conversationId', :'account_id' => :'accountId', :'platform' => :'platform', :'message' => :'message', :'sender_id' => :'senderId', :'sender_name' => :'senderName', :'sender_verified_type' => :'senderVerifiedType', :'direction' => :'direction', :'created_at' => :'createdAt', :'attachments' => :'attachments', :'subject' => :'subject', :'story_reply' => :'storyReply', :'is_story_mention' => :'isStoryMention', :'is_edited' => :'isEdited', :'edited_at' => :'editedAt', :'edit_count' => :'editCount', :'edit_history' => :'editHistory', :'is_deleted' => :'isDeleted', :'deleted_at' => :'deletedAt', :'delivery_status' => :'deliveryStatus', :'delivered_at' => :'deliveredAt', :'read_at' => :'readAt', :'sent_at' => :'sentAt', :'delivery_error' => :'deliveryError', :'reactions' => :'reactions', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 433 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 184 def self.openapi_nullable Set.new([ :'sender_name', :'sender_verified_type', :'subject', :'story_reply', :'is_story_mention', :'edited_at', :'deleted_at', :'delivery_status', :'delivered_at', :'read_at', :'sent_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 151 def self.openapi_types { :'id' => :'String', :'conversation_id' => :'String', :'account_id' => :'String', :'platform' => :'String', :'message' => :'String', :'sender_id' => :'String', :'sender_name' => :'String', :'sender_verified_type' => :'String', :'direction' => :'String', :'created_at' => :'Time', :'attachments' => :'Array<GetInboxConversationMessages200ResponseMessagesInnerAttachmentsInner>', :'subject' => :'String', :'story_reply' => :'Boolean', :'is_story_mention' => :'Boolean', :'is_edited' => :'Boolean', :'edited_at' => :'Time', :'edit_count' => :'Integer', :'edit_history' => :'Array<InboxMessageEditHistoryEntry>', :'is_deleted' => :'Boolean', :'deleted_at' => :'Time', :'delivery_status' => :'String', :'delivered_at' => :'Time', :'read_at' => :'Time', :'sent_at' => :'Time', :'delivery_error' => :'GetInboxConversationMessages200ResponseMessagesInnerDeliveryError', :'reactions' => :'Array<GetInboxConversationMessages200ResponseMessagesInnerReactionsInner>', :'metadata' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 386 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && conversation_id == o.conversation_id && account_id == o.account_id && platform == o.platform && == o. && sender_id == o.sender_id && sender_name == o.sender_name && sender_verified_type == o.sender_verified_type && direction == o.direction && created_at == o.created_at && == o. && subject == o.subject && story_reply == o.story_reply && is_story_mention == o.is_story_mention && is_edited == o.is_edited && edited_at == o.edited_at && edit_count == o.edit_count && edit_history == o.edit_history && is_deleted == o.is_deleted && deleted_at == o.deleted_at && delivery_status == o.delivery_status && delivered_at == o.delivered_at && read_at == o.read_at && sent_at == o.sent_at && delivery_error == o.delivery_error && reactions == o.reactions && == o. end |
#eql?(o) ⇒ Boolean
420 421 422 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 420 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
426 427 428 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 426 def hash [id, conversation_id, account_id, platform, , sender_id, sender_name, sender_verified_type, direction, created_at, , subject, story_reply, is_story_mention, is_edited, edited_at, edit_count, edit_history, is_deleted, deleted_at, delivery_status, delivered_at, read_at, sent_at, delivery_error, reactions, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
335 336 337 338 339 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 335 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 455 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
343 344 345 346 347 348 349 350 351 352 |
# File 'lib/zernio-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 343 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' sender_verified_type_validator = EnumAttributeValidator.new('String', ["blue", "government", "business", "none"]) return false unless sender_verified_type_validator.valid?(@sender_verified_type) direction_validator = EnumAttributeValidator.new('String', ["incoming", "outgoing"]) return false unless direction_validator.valid?(@direction) delivery_status_validator = EnumAttributeValidator.new('String', ["sent", "delivered", "read", "failed", "deleted"]) return false unless delivery_status_validator.valid?(@delivery_status) true end |