Class: Zernio::GetLinkedInSupplyForecastRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetLinkedInSupplyForecastRequest
- Defined in:
- lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#ad_account_id ⇒ Object
Returns the value of attribute ad_account_id.
-
#campaign_type ⇒ Object
Defaults to SPONSORED_UPDATES.
-
#competing_bid ⇒ Object
Returns the value of attribute competing_bid.
-
#connected_television_only ⇒ Object
Defaults to false.
-
#currency ⇒ Object
ISO 4217, defaults to USD.
-
#daily_budget ⇒ Object
Either dailyBudget or totalBudget is required.
-
#enable_audience_expansion ⇒ Object
Defaults to false.
-
#enable_audience_network ⇒ Object
Defaults to false.
-
#objective_type ⇒ Object
Returns the value of attribute objective_type.
-
#optimization_target ⇒ Object
When set, the forecast assumes auto-bidding.
-
#spec ⇒ Object
Returns the value of attribute spec.
-
#time_range_end ⇒ Object
Unix ms.
-
#time_range_start ⇒ Object
Unix ms.
-
#total_budget ⇒ Object
Returns the value of attribute total_budget.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetLinkedInSupplyForecastRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetLinkedInSupplyForecastRequest
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 140 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetLinkedInSupplyForecastRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetLinkedInSupplyForecastRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] else self.ad_account_id = nil end if attributes.key?(:'spec') self.spec = attributes[:'spec'] else self.spec = nil end if attributes.key?(:'campaign_type') self.campaign_type = attributes[:'campaign_type'] end if attributes.key?(:'time_range_start') self.time_range_start = attributes[:'time_range_start'] else self.time_range_start = nil end if attributes.key?(:'time_range_end') self.time_range_end = attributes[:'time_range_end'] else self.time_range_end = nil end if attributes.key?(:'objective_type') self.objective_type = attributes[:'objective_type'] end if attributes.key?(:'optimization_target') self.optimization_target = attributes[:'optimization_target'] end if attributes.key?(:'daily_budget') self.daily_budget = attributes[:'daily_budget'] end if attributes.key?(:'total_budget') self.total_budget = attributes[:'total_budget'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'competing_bid') self.competing_bid = attributes[:'competing_bid'] end if attributes.key?(:'enable_audience_network') self.enable_audience_network = attributes[:'enable_audience_network'] end if attributes.key?(:'enable_audience_expansion') self.enable_audience_expansion = attributes[:'enable_audience_expansion'] end if attributes.key?(:'connected_television_only') self.connected_television_only = attributes[:'connected_television_only'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 18 def account_id @account_id end |
#ad_account_id ⇒ Object
Returns the value of attribute ad_account_id.
20 21 22 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 20 def ad_account_id @ad_account_id end |
#campaign_type ⇒ Object
Defaults to SPONSORED_UPDATES.
25 26 27 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 25 def campaign_type @campaign_type end |
#competing_bid ⇒ Object
Returns the value of attribute competing_bid.
46 47 48 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 46 def competing_bid @competing_bid end |
#connected_television_only ⇒ Object
Defaults to false.
55 56 57 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 55 def connected_television_only @connected_television_only end |
#currency ⇒ Object
ISO 4217, defaults to USD.
44 45 46 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 44 def currency @currency end |
#daily_budget ⇒ Object
Either dailyBudget or totalBudget is required.
39 40 41 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 39 def daily_budget @daily_budget end |
#enable_audience_expansion ⇒ Object
Defaults to false.
52 53 54 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 52 def enable_audience_expansion @enable_audience_expansion end |
#enable_audience_network ⇒ Object
Defaults to false. Required true for connectedTelevisionOnly.
49 50 51 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 49 def enable_audience_network @enable_audience_network end |
#objective_type ⇒ Object
Returns the value of attribute objective_type.
33 34 35 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 33 def objective_type @objective_type end |
#optimization_target ⇒ Object
When set, the forecast assumes auto-bidding. When unset, competingBid is required.
36 37 38 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 36 def optimization_target @optimization_target end |
#spec ⇒ Object
Returns the value of attribute spec.
22 23 24 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 22 def spec @spec end |
#time_range_end ⇒ Object
Unix ms. Must be after start and within LinkedIn's max horizon.
31 32 33 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 31 def time_range_end @time_range_end end |
#time_range_start ⇒ Object
Unix ms. Must be in the future.
28 29 30 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 28 def time_range_start @time_range_start end |
#total_budget ⇒ Object
Returns the value of attribute total_budget.
41 42 43 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 41 def total_budget @total_budget end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
101 102 103 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 101 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
106 107 108 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 106 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 80 def self.attribute_map { :'account_id' => :'accountId', :'ad_account_id' => :'adAccountId', :'spec' => :'spec', :'campaign_type' => :'campaignType', :'time_range_start' => :'timeRangeStart', :'time_range_end' => :'timeRangeEnd', :'objective_type' => :'objectiveType', :'optimization_target' => :'optimizationTarget', :'daily_budget' => :'dailyBudget', :'total_budget' => :'totalBudget', :'currency' => :'currency', :'competing_bid' => :'competingBid', :'enable_audience_network' => :'enableAudienceNetwork', :'enable_audience_expansion' => :'enableAudienceExpansion', :'connected_television_only' => :'connectedTelevisionOnly' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 377 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
132 133 134 135 136 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 132 def self.openapi_nullable Set.new([ :'spec', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 111 def self.openapi_types { :'account_id' => :'String', :'ad_account_id' => :'String', :'spec' => :'TargetingSpec', :'campaign_type' => :'String', :'time_range_start' => :'Integer', :'time_range_end' => :'Integer', :'objective_type' => :'String', :'optimization_target' => :'String', :'daily_budget' => :'Float', :'total_budget' => :'Float', :'currency' => :'String', :'competing_bid' => :'GetLinkedInSupplyForecastRequestCompetingBid', :'enable_audience_network' => :'Boolean', :'enable_audience_expansion' => :'Boolean', :'connected_television_only' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 342 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && ad_account_id == o.ad_account_id && spec == o.spec && campaign_type == o.campaign_type && time_range_start == o.time_range_start && time_range_end == o.time_range_end && objective_type == o.objective_type && optimization_target == o.optimization_target && daily_budget == o.daily_budget && total_budget == o.total_budget && currency == o.currency && competing_bid == o.competing_bid && enable_audience_network == o.enable_audience_network && enable_audience_expansion == o.enable_audience_expansion && connected_television_only == o.connected_television_only end |
#eql?(o) ⇒ Boolean
364 365 366 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 364 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
370 371 372 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 370 def hash [account_id, ad_account_id, spec, campaign_type, time_range_start, time_range_end, objective_type, optimization_target, daily_budget, total_budget, currency, competing_bid, enable_audience_network, enable_audience_expansion, connected_television_only].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 227 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @ad_account_id.nil? invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.') end if @time_range_start.nil? invalid_properties.push('invalid value for "time_range_start", time_range_start cannot be nil.') end if @time_range_end.nil? invalid_properties.push('invalid value for "time_range_end", time_range_end cannot be nil.') end if !@currency.nil? && @currency.to_s.length > 3 invalid_properties.push('invalid value for "currency", the character length must be smaller than or equal to 3.') end if !@currency.nil? && @currency.to_s.length < 3 invalid_properties.push('invalid value for "currency", the character length must be greater than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 399 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/zernio-sdk/models/get_linked_in_supply_forecast_request.rb', line 259 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @ad_account_id.nil? campaign_type_validator = EnumAttributeValidator.new('String', ["SPONSORED_UPDATES", "SPONSORED_INMAILS", "DYNAMIC"]) return false unless campaign_type_validator.valid?(@campaign_type) return false if @time_range_start.nil? return false if @time_range_end.nil? return false if !@currency.nil? && @currency.to_s.length > 3 return false if !@currency.nil? && @currency.to_s.length < 3 true end |