Class: Zernio::GetPhoneNumber200ResponsePhoneNumber

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetPhoneNumber200ResponsePhoneNumber

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetPhoneNumber200ResponsePhoneNumber` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetPhoneNumber200ResponsePhoneNumber`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'meta_preverified_id')
    self.meta_preverified_id = attributes[:'meta_preverified_id']
  end

  if attributes.key?(:'meta_verification_status')
    self.meta_verification_status = attributes[:'meta_verification_status']
  end

  if attributes.key?(:'onfido_verification_url')
    self.onfido_verification_url = attributes[:'onfido_verification_url']
  end

  if attributes.key?(:'end_user_first_name')
    self.end_user_first_name = attributes[:'end_user_first_name']
  end

  if attributes.key?(:'end_user_last_name')
    self.end_user_last_name = attributes[:'end_user_last_name']
  end

  if attributes.key?(:'regulatory_decline_reason')
    self.regulatory_decline_reason = attributes[:'regulatory_decline_reason']
  end

  if attributes.key?(:'provisioned_at')
    self.provisioned_at = attributes[:'provisioned_at']
  end
end

Instance Attribute Details

#countryObject

Returns the value of attribute country.



24
25
26
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 24

def country
  @country
end

#end_user_first_nameObject

Returns the value of attribute end_user_first_name.



33
34
35
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 33

def end_user_first_name
  @end_user_first_name
end

#end_user_last_nameObject

Returns the value of attribute end_user_last_name.



35
36
37
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 35

def end_user_last_name
  @end_user_last_name
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 18

def id
  @id
end

#meta_preverified_idObject

Returns the value of attribute meta_preverified_id.



26
27
28
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 26

def meta_preverified_id
  @meta_preverified_id
end

#meta_verification_statusObject

Returns the value of attribute meta_verification_status.



28
29
30
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 28

def meta_verification_status
  @meta_verification_status
end

#onfido_verification_urlObject

For a regulated number with an Onfido ID step — the link to forward to the end user. Appears once the order is placed; null otherwise.



31
32
33
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 31

def onfido_verification_url
  @onfido_verification_url
end

#phone_numberObject

Returns the value of attribute phone_number.



20
21
22
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 20

def phone_number
  @phone_number
end

#provisioned_atObject

Returns the value of attribute provisioned_at.



40
41
42
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 40

def provisioned_at
  @provisioned_at
end

#regulatory_decline_reasonObject

Reviewer rejection reason when status is regulatory_declined.



38
39
40
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 38

def regulatory_decline_reason
  @regulatory_decline_reason
end

#statusObject

Returns the value of attribute status.



22
23
24
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 22

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'phone_number' => :'phoneNumber',
    :'status' => :'status',
    :'country' => :'country',
    :'meta_preverified_id' => :'metaPreverifiedId',
    :'meta_verification_status' => :'metaVerificationStatus',
    :'onfido_verification_url' => :'onfidoVerificationUrl',
    :'end_user_first_name' => :'endUserFirstName',
    :'end_user_last_name' => :'endUserLastName',
    :'regulatory_decline_reason' => :'regulatoryDeclineReason',
    :'provisioned_at' => :'provisionedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 239

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
113
114
115
116
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 109

def self.openapi_nullable
  Set.new([
    :'onfido_verification_url',
    :'end_user_first_name',
    :'end_user_last_name',
    :'regulatory_decline_reason',
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 92

def self.openapi_types
  {
    :'id' => :'String',
    :'phone_number' => :'String',
    :'status' => :'String',
    :'country' => :'String',
    :'meta_preverified_id' => :'String',
    :'meta_verification_status' => :'String',
    :'onfido_verification_url' => :'String',
    :'end_user_first_name' => :'String',
    :'end_user_last_name' => :'String',
    :'regulatory_decline_reason' => :'String',
    :'provisioned_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      phone_number == o.phone_number &&
      status == o.status &&
      country == o.country &&
      meta_preverified_id == o.meta_preverified_id &&
      meta_verification_status == o.meta_verification_status &&
      onfido_verification_url == o.onfido_verification_url &&
      end_user_first_name == o.end_user_first_name &&
      end_user_last_name == o.end_user_last_name &&
      regulatory_decline_reason == o.regulatory_decline_reason &&
      provisioned_at == o.provisioned_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 232

def hash
  [id, phone_number, status, country, meta_preverified_id, meta_verification_status, onfido_verification_url, end_user_first_name, end_user_last_name, regulatory_decline_reason, provisioned_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
194
# File 'lib/zernio-sdk/models/get_phone_number200_response_phone_number.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["pending_payment", "pending_regulatory", "regulatory_declined", "provisioning", "verifying", "active", "suspended", "releasing", "released"])
  return false unless status_validator.valid?(@status)
  true
end