Class: Zernio::GetSlackSettings200ResponseAccount
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetSlackSettings200ResponseAccount
- Defined in:
- lib/zernio-sdk/models/get_slack_settings200_response_account.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#channel_id ⇒ Object
Returns the value of attribute channel_id.
-
#channel_name ⇒ Object
Returns the value of attribute channel_name.
-
#channel_type ⇒ Object
public or private.
-
#default_icon_url ⇒ Object
Returns the value of attribute default_icon_url.
-
#default_username ⇒ Object
Returns the value of attribute default_username.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#team_id ⇒ Object
Returns the value of attribute team_id.
-
#team_name ⇒ Object
Returns the value of attribute team_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetSlackSettings200ResponseAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetSlackSettings200ResponseAccount
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetSlackSettings200ResponseAccount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetSlackSettings200ResponseAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'channel_id') self.channel_id = attributes[:'channel_id'] end if attributes.key?(:'channel_name') self.channel_name = attributes[:'channel_name'] end if attributes.key?(:'channel_type') self.channel_type = attributes[:'channel_type'] end if attributes.key?(:'team_id') self.team_id = attributes[:'team_id'] end if attributes.key?(:'team_name') self.team_name = attributes[:'team_name'] end if attributes.key?(:'default_username') self.default_username = attributes[:'default_username'] end if attributes.key?(:'default_icon_url') self.default_icon_url = attributes[:'default_icon_url'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 18 def _id @_id end |
#channel_id ⇒ Object
Returns the value of attribute channel_id.
24 25 26 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 24 def channel_id @channel_id end |
#channel_name ⇒ Object
Returns the value of attribute channel_name.
26 27 28 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 26 def channel_name @channel_name end |
#channel_type ⇒ Object
public or private
29 30 31 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 29 def channel_type @channel_type end |
#default_icon_url ⇒ Object
Returns the value of attribute default_icon_url.
37 38 39 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 37 def default_icon_url @default_icon_url end |
#default_username ⇒ Object
Returns the value of attribute default_username.
35 36 37 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 35 def default_username @default_username end |
#display_name ⇒ Object
Returns the value of attribute display_name.
22 23 24 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 22 def display_name @display_name end |
#platform ⇒ Object
Returns the value of attribute platform.
20 21 22 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 20 def platform @platform end |
#team_id ⇒ Object
Returns the value of attribute team_id.
31 32 33 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 31 def team_id @team_id end |
#team_name ⇒ Object
Returns the value of attribute team_name.
33 34 35 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 33 def team_name @team_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 40 def self.attribute_map { :'_id' => :'_id', :'platform' => :'platform', :'display_name' => :'displayName', :'channel_id' => :'channelId', :'channel_name' => :'channelName', :'channel_type' => :'channelType', :'team_id' => :'teamId', :'team_name' => :'teamName', :'default_username' => :'defaultUsername', :'default_icon_url' => :'defaultIconUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 199 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 82 def self.openapi_nullable Set.new([ :'display_name', :'channel_id', :'channel_name', :'channel_type', :'team_id', :'team_name', :'default_username', :'default_icon_url' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 66 def self.openapi_types { :'_id' => :'String', :'platform' => :'String', :'display_name' => :'String', :'channel_id' => :'String', :'channel_name' => :'String', :'channel_type' => :'String', :'team_id' => :'String', :'team_name' => :'String', :'default_username' => :'String', :'default_icon_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 169 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && platform == o.platform && display_name == o.display_name && channel_id == o.channel_id && channel_name == o.channel_name && channel_type == o.channel_type && team_id == o.team_id && team_name == o.team_name && default_username == o.default_username && default_icon_url == o.default_icon_url end |
#eql?(o) ⇒ Boolean
186 187 188 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 186 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 192 def hash [_id, platform, display_name, channel_id, channel_name, channel_type, team_id, team_name, default_username, default_icon_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
154 155 156 157 158 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 154 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 |
# File 'lib/zernio-sdk/models/get_slack_settings200_response_account.rb', line 162 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |