Class: Zernio::GooglePmaxAssetGroup

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/google_pmax_asset_group.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GooglePmaxAssetGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GooglePmaxAssetGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GooglePmaxAssetGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'resource_name')
    self.resource_name = attributes[:'resource_name']
  else
    self.resource_name = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'final_urls')
    if (value = attributes[:'final_urls']).is_a?(Array)
      self.final_urls = value
    end
  else
    self.final_urls = nil
  end

  if attributes.key?(:'assets')
    if (value = attributes[:'assets']).is_a?(Array)
      self.assets = value
    end
  else
    self.assets = nil
  end
end

Instance Attribute Details

#assetsObject

Returns the value of attribute assets.



29
30
31
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 29

def assets
  @assets
end

#final_urlsObject

Returns the value of attribute final_urls.



27
28
29
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 27

def final_urls
  @final_urls
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 18

def id
  @id
end

#nameObject

Returns the value of attribute name.



22
23
24
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 22

def name
  @name
end

#resource_nameObject

Returns the value of attribute resource_name.



20
21
22
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 20

def resource_name
  @resource_name
end

#statusObject

Asset-group status on Google. Campaign status independently controls delivery.



25
26
27
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 25

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 32

def self.attribute_map
  {
    :'id' => :'id',
    :'resource_name' => :'resourceName',
    :'name' => :'name',
    :'status' => :'status',
    :'final_urls' => :'finalUrls',
    :'assets' => :'assets'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 261

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 54

def self.openapi_types
  {
    :'id' => :'String',
    :'resource_name' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'final_urls' => :'Array<String>',
    :'assets' => :'Array<GooglePmaxAssetGroupAssetsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      resource_name == o.resource_name &&
      name == o.name &&
      status == o.status &&
      final_urls == o.final_urls &&
      assets == o.assets
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


248
249
250
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 248

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



254
255
256
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 254

def hash
  [id, resource_name, name, status, final_urls, assets].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @resource_name.nil?
    invalid_properties.push('invalid value for "resource_name", resource_name cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @final_urls.nil?
    invalid_properties.push('invalid value for "final_urls", final_urls cannot be nil.')
  end

  if @assets.nil?
    invalid_properties.push('invalid value for "assets", assets cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 283

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
169
170
171
# File 'lib/zernio-sdk/models/google_pmax_asset_group.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @resource_name.nil?
  return false if @name.nil?
  return false if @status.nil?
  return false if @final_urls.nil?
  return false if @assets.nil?
  true
end