Class: Zernio::GooglePmaxAssetGroupAssetsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GooglePmaxAssetGroupAssetsInner
- Defined in:
- lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb
Instance Attribute Summary collapse
-
#field_type ⇒ Object
Google asset role, such as HEADLINE or LOGO.
-
#image_url ⇒ Object
Returns the value of attribute image_url.
-
#resource_name ⇒ Object
Returns the value of attribute resource_name.
-
#status ⇒ Object
Returns the value of attribute status.
-
#text ⇒ Object
Returns the value of attribute text.
-
#youtube_video_id ⇒ Object
Returns the value of attribute youtube_video_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GooglePmaxAssetGroupAssetsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GooglePmaxAssetGroupAssetsInner
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GooglePmaxAssetGroupAssetsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GooglePmaxAssetGroupAssetsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] else self.resource_name = nil end if attributes.key?(:'field_type') self.field_type = attributes[:'field_type'] else self.field_type = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'text') self.text = attributes[:'text'] end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'youtube_video_id') self.youtube_video_id = attributes[:'youtube_video_id'] end end |
Instance Attribute Details
#field_type ⇒ Object
Google asset role, such as HEADLINE or LOGO.
21 22 23 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 21 def field_type @field_type end |
#image_url ⇒ Object
Returns the value of attribute image_url.
27 28 29 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 27 def image_url @image_url end |
#resource_name ⇒ Object
Returns the value of attribute resource_name.
18 19 20 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 18 def resource_name @resource_name end |
#status ⇒ Object
Returns the value of attribute status.
23 24 25 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 23 def status @status end |
#text ⇒ Object
Returns the value of attribute text.
25 26 27 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 25 def text @text end |
#youtube_video_id ⇒ Object
Returns the value of attribute youtube_video_id.
29 30 31 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 29 def youtube_video_id @youtube_video_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 32 def self.attribute_map { :'resource_name' => :'resourceName', :'field_type' => :'fieldType', :'status' => :'status', :'text' => :'text', :'image_url' => :'imageUrl', :'youtube_video_id' => :'youtubeVideoId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 206 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 54 def self.openapi_types { :'resource_name' => :'String', :'field_type' => :'String', :'status' => :'String', :'text' => :'String', :'image_url' => :'String', :'youtube_video_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && resource_name == o.resource_name && field_type == o.field_type && status == o.status && text == o.text && image_url == o.image_url && youtube_video_id == o.youtube_video_id end |
#eql?(o) ⇒ Boolean
193 194 195 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 193 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 199 def hash [resource_name, field_type, status, text, image_url, youtube_video_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @resource_name.nil? invalid_properties.push('invalid value for "resource_name", resource_name cannot be nil.') end if @field_type.nil? invalid_properties.push('invalid value for "field_type", field_type cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 144 145 146 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_assets_inner.rb', line 140 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @resource_name.nil? return false if @field_type.nil? return false if @status.nil? true end |