Class: Zernio::ListAdKeywords200ResponseKeywordsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListAdKeywords200ResponseKeywordsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListAdKeywords200ResponseKeywordsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListAdKeywords200ResponseKeywordsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'campaign_name')
    self.campaign_name = attributes[:'campaign_name']
  end

  if attributes.key?(:'campaign_status')
    self.campaign_status = attributes[:'campaign_status']
  end

  if attributes.key?(:'ad_set_id')
    self.ad_set_id = attributes[:'ad_set_id']
  end

  if attributes.key?(:'ad_set_name')
    self.ad_set_name = attributes[:'ad_set_name']
  end

  if attributes.key?(:'ad_set_status')
    self.ad_set_status = attributes[:'ad_set_status']
  end

  if attributes.key?(:'keyword')
    self.keyword = attributes[:'keyword']
  end

  if attributes.key?(:'match_type')
    self.match_type = attributes[:'match_type']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'negative')
    self.negative = attributes[:'negative']
  end

  if attributes.key?(:'synced_at')
    self.synced_at = attributes[:'synced_at']
  end
end

Instance Attribute Details

#account_idObject

Social account ID owning the sync



21
22
23
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 21

def 
  @account_id
end

#ad_account_idObject

Google customer ID



28
29
30
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 28

def 
  @ad_account_id
end

#ad_set_idObject

Google ad group ID



37
38
39
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 37

def ad_set_id
  @ad_set_id
end

#ad_set_nameObject

Returns the value of attribute ad_set_name.



39
40
41
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 39

def ad_set_name
  @ad_set_name
end

#ad_set_statusObject

Returns the value of attribute ad_set_status.



41
42
43
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 41

def ad_set_status
  @ad_set_status
end

#campaign_idObject

Returns the value of attribute campaign_id.



30
31
32
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 30

def campaign_id
  @campaign_id
end

#campaign_nameObject

Returns the value of attribute campaign_name.



32
33
34
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 32

def campaign_name
  @campaign_name
end

#campaign_statusObject

Returns the value of attribute campaign_status.



34
35
36
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 34

def campaign_status
  @campaign_status
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 18

def id
  @id
end

#keywordObject

Returns the value of attribute keyword.



43
44
45
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 43

def keyword
  @keyword
end

#match_typeObject

Returns the value of attribute match_type.



45
46
47
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 45

def match_type
  @match_type
end

#negativeObject

Returns the value of attribute negative.



49
50
51
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 49

def negative
  @negative
end

#platformObject

Returns the value of attribute platform.



25
26
27
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 25

def platform
  @platform
end

#profile_idObject

Returns the value of attribute profile_id.



23
24
25
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 23

def profile_id
  @profile_id
end

#statusObject

Returns the value of attribute status.



47
48
49
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 47

def status
  @status
end

#synced_atObject

Returns the value of attribute synced_at.



51
52
53
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 51

def synced_at
  @synced_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



98
99
100
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 98

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



103
104
105
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 103

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 76

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'accountId',
    :'profile_id' => :'profileId',
    :'platform' => :'platform',
    :'ad_account_id' => :'adAccountId',
    :'campaign_id' => :'campaignId',
    :'campaign_name' => :'campaignName',
    :'campaign_status' => :'campaignStatus',
    :'ad_set_id' => :'adSetId',
    :'ad_set_name' => :'adSetName',
    :'ad_set_status' => :'adSetStatus',
    :'keyword' => :'keyword',
    :'match_type' => :'matchType',
    :'status' => :'status',
    :'negative' => :'negative',
    :'synced_at' => :'syncedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 310

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



130
131
132
133
134
135
136
137
138
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 130

def self.openapi_nullable
  Set.new([
    :'campaign_name',
    :'campaign_status',
    :'ad_set_name',
    :'ad_set_status',
    :'synced_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 108

def self.openapi_types
  {
    :'id' => :'String',
    :'account_id' => :'String',
    :'profile_id' => :'String',
    :'platform' => :'String',
    :'ad_account_id' => :'String',
    :'campaign_id' => :'String',
    :'campaign_name' => :'String',
    :'campaign_status' => :'String',
    :'ad_set_id' => :'String',
    :'ad_set_name' => :'String',
    :'ad_set_status' => :'String',
    :'keyword' => :'String',
    :'match_type' => :'String',
    :'status' => :'String',
    :'negative' => :'Boolean',
    :'synced_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      profile_id == o.profile_id &&
      platform == o.platform &&
       == o. &&
      campaign_id == o.campaign_id &&
      campaign_name == o.campaign_name &&
      campaign_status == o.campaign_status &&
      ad_set_id == o.ad_set_id &&
      ad_set_name == o.ad_set_name &&
      ad_set_status == o.ad_set_status &&
      keyword == o.keyword &&
      match_type == o.match_type &&
      status == o.status &&
      negative == o.negative &&
      synced_at == o.synced_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


297
298
299
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 297

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



303
304
305
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 303

def hash
  [id, , profile_id, platform, , campaign_id, campaign_name, campaign_status, ad_set_id, ad_set_name, ad_set_status, keyword, match_type, status, negative, synced_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



223
224
225
226
227
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 223

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 332

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
235
236
237
238
239
240
# File 'lib/zernio-sdk/models/list_ad_keywords200_response_keywords_inner.rb', line 231

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  platform_validator = EnumAttributeValidator.new('String', ["google"])
  return false unless platform_validator.valid?(@platform)
  match_type_validator = EnumAttributeValidator.new('String', ["exact", "phrase", "broad", "unknown"])
  return false unless match_type_validator.valid?(@match_type)
  status_validator = EnumAttributeValidator.new('String', ["active", "paused"])
  return false unless status_validator.valid?(@status)
  true
end