Class: Zernio::ListBroadcasts200ResponseBroadcastsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListBroadcasts200ResponseBroadcastsInner
- Defined in:
- lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_name ⇒ Object
Display name of the sending account.
-
#completed_at ⇒ Object
Returns the value of attribute completed_at.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#delivered_count ⇒ Object
Returns the value of attribute delivered_count.
-
#description ⇒ Object
Returns the value of attribute description.
-
#failed_count ⇒ Object
Returns the value of attribute failed_count.
-
#id ⇒ Object
Returns the value of attribute id.
-
#message_preview ⇒ Object
Template name or message text snippet.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#read_count ⇒ Object
Returns the value of attribute read_count.
-
#recipient_count ⇒ Object
Returns the value of attribute recipient_count.
-
#scheduled_at ⇒ Object
Returns the value of attribute scheduled_at.
-
#sent_count ⇒ Object
Returns the value of attribute sent_count.
-
#started_at ⇒ Object
Returns the value of attribute started_at.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListBroadcasts200ResponseBroadcastsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListBroadcasts200ResponseBroadcastsInner
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 140 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListBroadcasts200ResponseBroadcastsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListBroadcasts200ResponseBroadcastsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'message_preview') self. = attributes[:'message_preview'] end if attributes.key?(:'scheduled_at') self.scheduled_at = attributes[:'scheduled_at'] end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end if attributes.key?(:'recipient_count') self.recipient_count = attributes[:'recipient_count'] end if attributes.key?(:'sent_count') self.sent_count = attributes[:'sent_count'] end if attributes.key?(:'delivered_count') self.delivered_count = attributes[:'delivered_count'] end if attributes.key?(:'read_count') self.read_count = attributes[:'read_count'] end if attributes.key?(:'failed_count') self.failed_count = attributes[:'failed_count'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
26 27 28 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 26 def account_id @account_id end |
#account_name ⇒ Object
Display name of the sending account
29 30 31 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 29 def account_name @account_name end |
#completed_at ⇒ Object
Returns the value of attribute completed_at.
40 41 42 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 40 def completed_at @completed_at end |
#created_at ⇒ Object
Returns the value of attribute created_at.
52 53 54 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 52 def created_at @created_at end |
#delivered_count ⇒ Object
Returns the value of attribute delivered_count.
46 47 48 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 46 def delivered_count @delivered_count end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 22 def description @description end |
#failed_count ⇒ Object
Returns the value of attribute failed_count.
50 51 52 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 50 def failed_count @failed_count end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 18 def id @id end |
#message_preview ⇒ Object
Template name or message text snippet
34 35 36 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 34 def @message_preview end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 20 def name @name end |
#platform ⇒ Object
Returns the value of attribute platform.
24 25 26 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 24 def platform @platform end |
#read_count ⇒ Object
Returns the value of attribute read_count.
48 49 50 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 48 def read_count @read_count end |
#recipient_count ⇒ Object
Returns the value of attribute recipient_count.
42 43 44 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 42 def recipient_count @recipient_count end |
#scheduled_at ⇒ Object
Returns the value of attribute scheduled_at.
36 37 38 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 36 def scheduled_at @scheduled_at end |
#sent_count ⇒ Object
Returns the value of attribute sent_count.
44 45 46 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 44 def sent_count @sent_count end |
#started_at ⇒ Object
Returns the value of attribute started_at.
38 39 40 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 38 def started_at @started_at end |
#status ⇒ Object
Returns the value of attribute status.
31 32 33 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 31 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
100 101 102 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 100 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
105 106 107 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 105 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 77 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'platform' => :'platform', :'account_id' => :'accountId', :'account_name' => :'accountName', :'status' => :'status', :'message_preview' => :'messagePreview', :'scheduled_at' => :'scheduledAt', :'started_at' => :'startedAt', :'completed_at' => :'completedAt', :'recipient_count' => :'recipientCount', :'sent_count' => :'sentCount', :'delivered_count' => :'deliveredCount', :'read_count' => :'readCount', :'failed_count' => :'failedCount', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 289 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
133 134 135 136 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 133 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 110 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'platform' => :'String', :'account_id' => :'String', :'account_name' => :'String', :'status' => :'String', :'message_preview' => :'String', :'scheduled_at' => :'Time', :'started_at' => :'Time', :'completed_at' => :'Time', :'recipient_count' => :'Integer', :'sent_count' => :'Integer', :'delivered_count' => :'Integer', :'read_count' => :'Integer', :'failed_count' => :'Integer', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && platform == o.platform && account_id == o.account_id && account_name == o.account_name && status == o.status && == o. && scheduled_at == o.scheduled_at && started_at == o.started_at && completed_at == o.completed_at && recipient_count == o.recipient_count && sent_count == o.sent_count && delivered_count == o.delivered_count && read_count == o.read_count && failed_count == o.failed_count && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
276 277 278 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 276 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
282 283 284 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 282 def hash [id, name, description, platform, account_id, account_name, status, , scheduled_at, started_at, completed_at, recipient_count, sent_count, delivered_count, read_count, failed_count, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
225 226 227 228 229 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 225 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 311 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
233 234 235 236 237 238 |
# File 'lib/zernio-sdk/models/list_broadcasts200_response_broadcasts_inner.rb', line 233 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["draft", "scheduled", "sending", "completed", "failed", "cancelled"]) return false unless status_validator.valid?(@status) true end |