Class: Zernio::ListInboxComments200ResponseDataInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListInboxComments200ResponseDataInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListInboxComments200ResponseDataInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListInboxComments200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'account_username')
    self. = attributes[:'account_username']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'picture')
    self.picture = attributes[:'picture']
  end

  if attributes.key?(:'permalink')
    self.permalink = attributes[:'permalink']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'comment_count')
    self.comment_count = attributes[:'comment_count']
  end

  if attributes.key?(:'like_count')
    self.like_count = attributes[:'like_count']
  end

  if attributes.key?(:'cid')
    self.cid = attributes[:'cid']
  end

  if attributes.key?(:'subreddit')
    self.subreddit = attributes[:'subreddit']
  end

  if attributes.key?(:'is_ad')
    self.is_ad = attributes[:'is_ad']
  end

  if attributes.key?(:'ad_id')
    self.ad_id = attributes[:'ad_id']
  end

  if attributes.key?(:'placement')
    self.placement = attributes[:'placement']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



22
23
24
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 22

def 
  @account_id
end

#account_usernameObject

Returns the value of attribute account_username.



24
25
26
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 24

def 
  @account_username
end

#ad_idObject

Internal Zernio ad id — only on ad rows.



48
49
50
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 48

def ad_id
  @ad_id
end

#cidObject

Bluesky content identifier



39
40
41
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 39

def cid
  @cid
end

#comment_countObject

Returns the value of attribute comment_count.



34
35
36
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 34

def comment_count
  @comment_count
end

#contentObject

Returns the value of attribute content.



26
27
28
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 26

def content
  @content
end

#created_timeObject

Returns the value of attribute created_time.



32
33
34
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 32

def created_time
  @created_time
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 18

def id
  @id
end

#is_adObject

True when this row is an ad (boosted/dark post). platform is then the placement (facebook = the Page dark post / instagram = the IG media), id is {adId}:{placement}, and the thread is at GET /v1/ads/adId/comments?placement=#placement.



45
46
47
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 45

def is_ad
  @is_ad
end

#like_countObject

Returns the value of attribute like_count.



36
37
38
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 36

def like_count
  @like_count
end

Returns the value of attribute permalink.



30
31
32
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 30

def permalink
  @permalink
end

#pictureObject

Returns the value of attribute picture.



28
29
30
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 28

def picture
  @picture
end

#placementObject

Which side of the ad this row's comments are on — only on ad rows.



51
52
53
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 51

def placement
  @placement
end

#platformObject

Returns the value of attribute platform.



20
21
22
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 20

def platform
  @platform
end

#subredditObject

Reddit subreddit name



42
43
44
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 42

def subreddit
  @subreddit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



97
98
99
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 97

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



102
103
104
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 102

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 76

def self.attribute_map
  {
    :'id' => :'id',
    :'platform' => :'platform',
    :'account_id' => :'accountId',
    :'account_username' => :'accountUsername',
    :'content' => :'content',
    :'picture' => :'picture',
    :'permalink' => :'permalink',
    :'created_time' => :'createdTime',
    :'comment_count' => :'commentCount',
    :'like_count' => :'likeCount',
    :'cid' => :'cid',
    :'subreddit' => :'subreddit',
    :'is_ad' => :'isAd',
    :'ad_id' => :'adId',
    :'placement' => :'placement'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 278

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
132
133
134
135
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 128

def self.openapi_nullable
  Set.new([
    :'picture',
    :'permalink',
    :'cid',
    :'subreddit',
  ])
end

.openapi_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 107

def self.openapi_types
  {
    :'id' => :'String',
    :'platform' => :'String',
    :'account_id' => :'String',
    :'account_username' => :'String',
    :'content' => :'String',
    :'picture' => :'String',
    :'permalink' => :'String',
    :'created_time' => :'Time',
    :'comment_count' => :'Integer',
    :'like_count' => :'Integer',
    :'cid' => :'String',
    :'subreddit' => :'String',
    :'is_ad' => :'Boolean',
    :'ad_id' => :'String',
    :'placement' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      platform == o.platform &&
       == o. &&
       == o. &&
      content == o.content &&
      picture == o.picture &&
      permalink == o.permalink &&
      created_time == o.created_time &&
      comment_count == o.comment_count &&
      like_count == o.like_count &&
      cid == o.cid &&
      subreddit == o.subreddit &&
      is_ad == o.is_ad &&
      ad_id == o.ad_id &&
      placement == o.placement
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 271

def hash
  [id, platform, , , content, picture, permalink, created_time, comment_count, like_count, cid, subreddit, is_ad, ad_id, placement].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



216
217
218
219
220
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 216

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
229
# File 'lib/zernio-sdk/models/list_inbox_comments200_response_data_inner.rb', line 224

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  placement_validator = EnumAttributeValidator.new('String', ["facebook", "instagram"])
  return false unless placement_validator.valid?(@placement)
  true
end