Class: Zernio::ListInboxConversations200ResponseDataInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListInboxConversations200ResponseDataInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListInboxConversations200ResponseDataInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListInboxConversations200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'account_username')
    self. = attributes[:'account_username']
  end

  if attributes.key?(:'participant_id')
    self.participant_id = attributes[:'participant_id']
  end

  if attributes.key?(:'participant_name')
    self.participant_name = attributes[:'participant_name']
  end

  if attributes.key?(:'participant_picture')
    self.participant_picture = attributes[:'participant_picture']
  end

  if attributes.key?(:'participant_verified_type')
    self.participant_verified_type = attributes[:'participant_verified_type']
  end

  if attributes.key?(:'last_message')
    self.last_message = attributes[:'last_message']
  end

  if attributes.key?(:'updated_time')
    self.updated_time = attributes[:'updated_time']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'unread_count')
    self.unread_count = attributes[:'unread_count']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'instagram_profile')
    self.instagram_profile = attributes[:'instagram_profile']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



22
23
24
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 22

def 
  @account_id
end

#account_usernameObject

Returns the value of attribute account_username.



24
25
26
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 24

def 
  @account_username
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 18

def id
  @id
end

#instagram_profileObject

Returns the value of attribute instagram_profile.



47
48
49
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 47

def instagram_profile
  @instagram_profile
end

#last_messageObject

Returns the value of attribute last_message.



35
36
37
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 35

def last_message
  @last_message
end

#participant_idObject

Returns the value of attribute participant_id.



26
27
28
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 26

def participant_id
  @participant_id
end

#participant_nameObject

Returns the value of attribute participant_name.



28
29
30
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 28

def participant_name
  @participant_name
end

#participant_pictureObject

Returns the value of attribute participant_picture.



30
31
32
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 30

def participant_picture
  @participant_picture
end

#participant_verified_typeObject

X/Twitter verified badge type. Only present for Twitter/X conversations.



33
34
35
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 33

def participant_verified_type
  @participant_verified_type
end

#platformObject

Returns the value of attribute platform.



20
21
22
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 20

def platform
  @platform
end

#statusObject

Returns the value of attribute status.



39
40
41
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 39

def status
  @status
end

#unread_countObject

Number of unread messages



42
43
44
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 42

def unread_count
  @unread_count
end

#updated_timeObject

Returns the value of attribute updated_time.



37
38
39
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 37

def updated_time
  @updated_time
end

#urlObject

Direct link to open the conversation on the platform (if available)



45
46
47
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 45

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



92
93
94
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 92

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 97

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 72

def self.attribute_map
  {
    :'id' => :'id',
    :'platform' => :'platform',
    :'account_id' => :'accountId',
    :'account_username' => :'accountUsername',
    :'participant_id' => :'participantId',
    :'participant_name' => :'participantName',
    :'participant_picture' => :'participantPicture',
    :'participant_verified_type' => :'participantVerifiedType',
    :'last_message' => :'lastMessage',
    :'updated_time' => :'updatedTime',
    :'status' => :'status',
    :'unread_count' => :'unreadCount',
    :'url' => :'url',
    :'instagram_profile' => :'instagramProfile'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 279

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
126
127
128
129
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 122

def self.openapi_nullable
  Set.new([
    :'participant_picture',
    :'participant_verified_type',
    :'unread_count',
    :'url',
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 102

def self.openapi_types
  {
    :'id' => :'String',
    :'platform' => :'String',
    :'account_id' => :'String',
    :'account_username' => :'String',
    :'participant_id' => :'String',
    :'participant_name' => :'String',
    :'participant_picture' => :'String',
    :'participant_verified_type' => :'String',
    :'last_message' => :'String',
    :'updated_time' => :'Time',
    :'status' => :'String',
    :'unread_count' => :'Integer',
    :'url' => :'String',
    :'instagram_profile' => :'ListInboxConversations200ResponseDataInnerInstagramProfile'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 245

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      platform == o.platform &&
       == o. &&
       == o. &&
      participant_id == o.participant_id &&
      participant_name == o.participant_name &&
      participant_picture == o.participant_picture &&
      participant_verified_type == o.participant_verified_type &&
      last_message == o.last_message &&
      updated_time == o.updated_time &&
      status == o.status &&
      unread_count == o.unread_count &&
      url == o.url &&
      instagram_profile == o.instagram_profile
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 266

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



272
273
274
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 272

def hash
  [id, platform, , , participant_id, participant_name, participant_picture, participant_verified_type, last_message, updated_time, status, unread_count, url, instagram_profile].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 206

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 301

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 214

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  participant_verified_type_validator = EnumAttributeValidator.new('String', ["blue", "government", "business", "none"])
  return false unless participant_verified_type_validator.valid?(@participant_verified_type)
  status_validator = EnumAttributeValidator.new('String', ["active", "archived"])
  return false unless status_validator.valid?(@status)
  true
end