Class: Zernio::ListPhoneNumbers200ResponseNumbersInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListPhoneNumbers200ResponseNumbersInner
- Defined in:
- lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#country ⇒ Object
Returns the value of attribute country.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#end_user_first_name ⇒ Object
Returns the value of attribute end_user_first_name.
-
#end_user_last_name ⇒ Object
Returns the value of attribute end_user_last_name.
-
#hosted_by_zernio ⇒ Object
False for numbers you brought yourself (connected via Meta embedded signup) — they live on your own carrier, so SMS/Calls can't be enabled on them.
-
#meta_preverified_id ⇒ Object
Returns the value of attribute meta_preverified_id.
-
#meta_verification_status ⇒ Object
Returns the value of attribute meta_verification_status.
-
#monthly_cents ⇒ Object
Per-country monthly price in cents ($2..$25).
-
#onfido_verification_url ⇒ Object
For regulated (Tier 3/4) numbers with an Onfido ID-verification step — the link to forward to the end user.
-
#phone_number ⇒ Object
Returns the value of attribute phone_number.
-
#profile_id ⇒ Object
Returns the value of attribute profile_id.
-
#provisioned_at ⇒ Object
Returns the value of attribute provisioned_at.
-
#registrant_name ⇒ Object
For regulated numbers, who it's registered for (company or person) — set from the submitted KYC.
-
#regulatory_decline_reason ⇒ Object
Reviewer rejection reason when status is regulatory_declined.
-
#status ⇒ Object
Returns the value of attribute status.
-
#telnyx_order_id ⇒ Object
Present once the number order has been placed (i.e. the requirement group was approved).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListPhoneNumbers200ResponseNumbersInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListPhoneNumbers200ResponseNumbersInner
Initializes the object
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 150 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListPhoneNumbers200ResponseNumbersInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListPhoneNumbers200ResponseNumbersInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'registrant_name') self.registrant_name = attributes[:'registrant_name'] end if attributes.key?(:'telnyx_order_id') self.telnyx_order_id = attributes[:'telnyx_order_id'] end if attributes.key?(:'monthly_cents') self.monthly_cents = attributes[:'monthly_cents'] end if attributes.key?(:'hosted_by_zernio') self.hosted_by_zernio = attributes[:'hosted_by_zernio'] end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'provisioned_at') self.provisioned_at = attributes[:'provisioned_at'] end if attributes.key?(:'meta_preverified_id') self. = attributes[:'meta_preverified_id'] end if attributes.key?(:'meta_verification_status') self. = attributes[:'meta_verification_status'] end if attributes.key?(:'onfido_verification_url') self.onfido_verification_url = attributes[:'onfido_verification_url'] end if attributes.key?(:'end_user_first_name') self.end_user_first_name = attributes[:'end_user_first_name'] end if attributes.key?(:'end_user_last_name') self.end_user_last_name = attributes[:'end_user_last_name'] end if attributes.key?(:'regulatory_decline_reason') self.regulatory_decline_reason = attributes[:'regulatory_decline_reason'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 18 def _id @_id end |
#country ⇒ Object
Returns the value of attribute country.
22 23 24 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 22 def country @country end |
#created_at ⇒ Object
Returns the value of attribute created_at.
56 57 58 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 56 def created_at @created_at end |
#end_user_first_name ⇒ Object
Returns the value of attribute end_user_first_name.
49 50 51 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 49 def end_user_first_name @end_user_first_name end |
#end_user_last_name ⇒ Object
Returns the value of attribute end_user_last_name.
51 52 53 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 51 def end_user_last_name @end_user_last_name end |
#hosted_by_zernio ⇒ Object
False for numbers you brought yourself (connected via Meta embedded signup) — they live on your own carrier, so SMS/Calls can't be enabled on them.
36 37 38 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 36 def hosted_by_zernio @hosted_by_zernio end |
#meta_preverified_id ⇒ Object
Returns the value of attribute meta_preverified_id.
42 43 44 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 42 def @meta_preverified_id end |
#meta_verification_status ⇒ Object
Returns the value of attribute meta_verification_status.
44 45 46 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 44 def @meta_verification_status end |
#monthly_cents ⇒ Object
Per-country monthly price in cents ($2..$25).
33 34 35 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 33 def monthly_cents @monthly_cents end |
#onfido_verification_url ⇒ Object
For regulated (Tier 3/4) numbers with an Onfido ID-verification step — the link to forward to the end user. Set once the order is placed; null otherwise. Poll this field after submitting KYC.
47 48 49 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 47 def onfido_verification_url @onfido_verification_url end |
#phone_number ⇒ Object
Returns the value of attribute phone_number.
20 21 22 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 20 def phone_number @phone_number end |
#profile_id ⇒ Object
Returns the value of attribute profile_id.
38 39 40 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 38 def profile_id @profile_id end |
#provisioned_at ⇒ Object
Returns the value of attribute provisioned_at.
40 41 42 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 40 def provisioned_at @provisioned_at end |
#registrant_name ⇒ Object
For regulated numbers, who it's registered for (company or person) — set from the submitted KYC.
27 28 29 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 27 def registrant_name @registrant_name end |
#regulatory_decline_reason ⇒ Object
Reviewer rejection reason when status is regulatory_declined.
54 55 56 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 54 def regulatory_decline_reason @regulatory_decline_reason end |
#status ⇒ Object
Returns the value of attribute status.
24 25 26 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 24 def status @status end |
#telnyx_order_id ⇒ Object
Present once the number order has been placed (i.e. the requirement group was approved). Absent while still in identity review.
30 31 32 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 30 def telnyx_order_id @telnyx_order_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
104 105 106 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 104 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
109 110 111 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 109 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 81 def self.attribute_map { :'_id' => :'_id', :'phone_number' => :'phoneNumber', :'country' => :'country', :'status' => :'status', :'registrant_name' => :'registrantName', :'telnyx_order_id' => :'telnyxOrderId', :'monthly_cents' => :'monthlyCents', :'hosted_by_zernio' => :'hostedByZernio', :'profile_id' => :'profileId', :'provisioned_at' => :'provisionedAt', :'meta_preverified_id' => :'metaPreverifiedId', :'meta_verification_status' => :'metaVerificationStatus', :'onfido_verification_url' => :'onfidoVerificationUrl', :'end_user_first_name' => :'endUserFirstName', :'end_user_last_name' => :'endUserLastName', :'regulatory_decline_reason' => :'regulatoryDeclineReason', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 299 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
137 138 139 140 141 142 143 144 145 146 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 137 def self.openapi_nullable Set.new([ :'registrant_name', :'telnyx_order_id', :'onfido_verification_url', :'end_user_first_name', :'end_user_last_name', :'regulatory_decline_reason', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 114 def self.openapi_types { :'_id' => :'String', :'phone_number' => :'String', :'country' => :'String', :'status' => :'String', :'registrant_name' => :'String', :'telnyx_order_id' => :'String', :'monthly_cents' => :'Integer', :'hosted_by_zernio' => :'Boolean', :'profile_id' => :'Object', :'provisioned_at' => :'Time', :'meta_preverified_id' => :'String', :'meta_verification_status' => :'String', :'onfido_verification_url' => :'String', :'end_user_first_name' => :'String', :'end_user_last_name' => :'String', :'regulatory_decline_reason' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 262 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && phone_number == o.phone_number && country == o.country && status == o.status && registrant_name == o.registrant_name && telnyx_order_id == o.telnyx_order_id && monthly_cents == o.monthly_cents && hosted_by_zernio == o.hosted_by_zernio && profile_id == o.profile_id && provisioned_at == o.provisioned_at && == o. && == o. && onfido_verification_url == o.onfido_verification_url && end_user_first_name == o.end_user_first_name && end_user_last_name == o.end_user_last_name && regulatory_decline_reason == o.regulatory_decline_reason && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
286 287 288 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 286 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
292 293 294 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 292 def hash [_id, phone_number, country, status, registrant_name, telnyx_order_id, monthly_cents, hosted_by_zernio, profile_id, provisioned_at, , , onfido_verification_url, end_user_first_name, end_user_last_name, regulatory_decline_reason, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
235 236 237 238 239 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 235 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 321 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
243 244 245 246 247 248 |
# File 'lib/zernio-sdk/models/list_phone_numbers200_response_numbers_inner.rb', line 243 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["pending_payment", "pending_regulatory", "regulatory_declined", "provisioning", "verifying", "active", "suspended", "releasing", "released"]) return false unless status_validator.valid?(@status) true end |