Class: Zernio::ListSmsRegistrations200ResponseRegistrationsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListSmsRegistrations200ResponseRegistrationsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListSmsRegistrations200ResponseRegistrationsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListSmsRegistrations200ResponseRegistrationsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'registration_type')
    self.registration_type = attributes[:'registration_type']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'brand_status')
    self.brand_status = attributes[:'brand_status']
  end

  if attributes.key?(:'campaign_status')
    self.campaign_status = attributes[:'campaign_status']
  end

  if attributes.key?(:'brand_id')
    self.brand_id = attributes[:'brand_id']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'decline_reason')
    self.decline_reason = attributes[:'decline_reason']
  end

  if attributes.key?(:'phone_numbers')
    if (value = attributes[:'phone_numbers']).is_a?(Array)
      self.phone_numbers = value
    end
  end

  if attributes.key?(:'awaiting_otp')
    self.awaiting_otp = attributes[:'awaiting_otp']
  end

  if attributes.key?(:'trust_score')
    self.trust_score = attributes[:'trust_score']
  end

  if attributes.key?(:'throughput')
    self.throughput = attributes[:'throughput']
  end
end

Instance Attribute Details

#awaiting_otpObject

Sole-prop 10DLC only; the OTP step is still pending.



43
44
45
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 43

def awaiting_otp
  @awaiting_otp
end

#brand_idObject

TCR brand id, useful when referencing the brand in carrier support threads.



33
34
35
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 33

def brand_id
  @brand_id
end

#brand_statusObject

Carrier-registry brand status (e.g. VERIFIED).



28
29
30
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 28

def brand_status
  @brand_status
end

#campaign_idObject

TCR campaign id.



36
37
38
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 36

def campaign_id
  @campaign_id
end

#campaign_statusObject

Returns the value of attribute campaign_status.



30
31
32
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 30

def campaign_status
  @campaign_status
end

#decline_reasonObject

Returns the value of attribute decline_reason.



38
39
40
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 38

def decline_reason
  @decline_reason
end

#display_nameObject

Returns the value of attribute display_name.



22
23
24
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 22

def display_name
  @display_name
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 18

def id
  @id
end

#phone_numbersObject

Returns the value of attribute phone_numbers.



40
41
42
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 40

def phone_numbers
  @phone_numbers
end

#registration_typeObject

Returns the value of attribute registration_type.



20
21
22
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 20

def registration_type
  @registration_type
end

#statusObject

requested/changes_requested = pre-submission review states; customers see them as pending / needs changes.



25
26
27
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 25

def status
  @status
end

#throughputObject

Returns the value of attribute throughput.



48
49
50
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 48

def throughput
  @throughput
end

#trust_scoreObject

Carrier-assigned brand trust score; drives throughput.



46
47
48
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 46

def trust_score
  @trust_score
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



92
93
94
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 92

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 97

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 73

def self.attribute_map
  {
    :'id' => :'id',
    :'registration_type' => :'registrationType',
    :'display_name' => :'displayName',
    :'status' => :'status',
    :'brand_status' => :'brandStatus',
    :'campaign_status' => :'campaignStatus',
    :'brand_id' => :'brandId',
    :'campaign_id' => :'campaignId',
    :'decline_reason' => :'declineReason',
    :'phone_numbers' => :'phoneNumbers',
    :'awaiting_otp' => :'awaitingOtp',
    :'trust_score' => :'trustScore',
    :'throughput' => :'throughput'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 276

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
125
126
127
128
129
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 121

def self.openapi_nullable
  Set.new([
    :'display_name',
    :'brand_id',
    :'campaign_id',
    :'decline_reason',
    :'trust_score',
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 102

def self.openapi_types
  {
    :'id' => :'String',
    :'registration_type' => :'String',
    :'display_name' => :'String',
    :'status' => :'String',
    :'brand_status' => :'String',
    :'campaign_status' => :'String',
    :'brand_id' => :'String',
    :'campaign_id' => :'String',
    :'decline_reason' => :'String',
    :'phone_numbers' => :'Array<String>',
    :'awaiting_otp' => :'Boolean',
    :'trust_score' => :'Float',
    :'throughput' => :'ListSmsRegistrations200ResponseRegistrationsInnerThroughput'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      registration_type == o.registration_type &&
      display_name == o.display_name &&
      status == o.status &&
      brand_status == o.brand_status &&
      campaign_status == o.campaign_status &&
      brand_id == o.brand_id &&
      campaign_id == o.campaign_id &&
      decline_reason == o.decline_reason &&
      phone_numbers == o.phone_numbers &&
      awaiting_otp == o.awaiting_otp &&
      trust_score == o.trust_score &&
      throughput == o.throughput
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 263

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



269
270
271
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 269

def hash
  [id, registration_type, display_name, status, brand_status, campaign_status, brand_id, campaign_id, decline_reason, phone_numbers, awaiting_otp, trust_score, throughput].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



204
205
206
207
208
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 204

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 212

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  registration_type_validator = EnumAttributeValidator.new('String', ["standard_10dlc", "sole_prop_10dlc", "toll_free"])
  return false unless registration_type_validator.valid?(@registration_type)
  status_validator = EnumAttributeValidator.new('String', ["pending", "approved", "rejected", "requested", "changes_requested", "deactivated"])
  return false unless status_validator.valid?(@status)
  true
end