Class: Zernio::PortfolioBidStrategy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::PortfolioBidStrategy
- Defined in:
- lib/zernio-sdk/models/portfolio_bid_strategy.rb
Overview
A Google Ads portfolio bid strategy: a named bidding strategy shared across campaigns, with its R.130 report metrics over the queried date range.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#average_cpc ⇒ Object
Average CPC in the account's currency units.
-
#campaign_count ⇒ Object
Number of campaigns currently attached.
-
#clicks ⇒ Object
Returns the value of attribute clicks.
-
#conversions ⇒ Object
Returns the value of attribute conversions.
-
#cost ⇒ Object
Cost in the account's currency units (converted from micros).
-
#cost_per_conversion ⇒ Object
Cost per conversion in the account's currency units.
-
#id ⇒ Object
Numeric bid strategy id; pass as portfolioBidStrategyId or in the strategyId path.
-
#impressions ⇒ Object
Returns the value of attribute impressions.
-
#name ⇒ Object
Returns the value of attribute name.
-
#status ⇒ Object
ENABLED or REMOVED.
-
#target_cpa ⇒ Object
Current target, in the account's currency units.
-
#target_roas ⇒ Object
Current target as a decimal multiplier (2.0 = 2.0x).
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PortfolioBidStrategy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PortfolioBidStrategy
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 133 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::PortfolioBidStrategy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::PortfolioBidStrategy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'campaign_count') self.campaign_count = attributes[:'campaign_count'] end if attributes.key?(:'clicks') self.clicks = attributes[:'clicks'] end if attributes.key?(:'cost') self.cost = attributes[:'cost'] end if attributes.key?(:'cost_per_conversion') self.cost_per_conversion = attributes[:'cost_per_conversion'] end if attributes.key?(:'impressions') self.impressions = attributes[:'impressions'] end if attributes.key?(:'average_cpc') self.average_cpc = attributes[:'average_cpc'] end if attributes.key?(:'conversions') self.conversions = attributes[:'conversions'] end if attributes.key?(:'target_cpa') self.target_cpa = attributes[:'target_cpa'] end if attributes.key?(:'target_roas') self.target_roas = attributes[:'target_roas'] end end |
Instance Attribute Details
#average_cpc ⇒ Object
Average CPC in the account's currency units.
43 44 45 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 43 def average_cpc @average_cpc end |
#campaign_count ⇒ Object
Number of campaigns currently attached.
30 31 32 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 30 def campaign_count @campaign_count end |
#clicks ⇒ Object
Returns the value of attribute clicks.
32 33 34 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 32 def clicks @clicks end |
#conversions ⇒ Object
Returns the value of attribute conversions.
45 46 47 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 45 def conversions @conversions end |
#cost ⇒ Object
Cost in the account's currency units (converted from micros).
35 36 37 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 35 def cost @cost end |
#cost_per_conversion ⇒ Object
Cost per conversion in the account's currency units.
38 39 40 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 38 def cost_per_conversion @cost_per_conversion end |
#id ⇒ Object
Numeric bid strategy id; pass as portfolioBidStrategyId or in the strategyId path.
20 21 22 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 20 def id @id end |
#impressions ⇒ Object
Returns the value of attribute impressions.
40 41 42 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 40 def impressions @impressions end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 22 def name @name end |
#status ⇒ Object
ENABLED or REMOVED.
27 28 29 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 27 def status @status end |
#target_cpa ⇒ Object
Current target, in the account's currency units. Null for a ROAS-family type (TARGET_ROAS, MAXIMIZE_CONVERSION_VALUE), or a Maximize type with no target set. Pre-fills the edit form's target field.
48 49 50 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 48 def target_cpa @target_cpa end |
#target_roas ⇒ Object
Current target as a decimal multiplier (2.0 = 2.0x). Null for a CPA-family type (TARGET_CPA, MAXIMIZE_CONVERSIONS), or a Maximize type with no target set.
51 52 53 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 51 def target_roas @target_roas end |
#type ⇒ Object
Returns the value of attribute type.
24 25 26 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 24 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
95 96 97 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 95 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
100 101 102 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 100 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 76 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'type' => :'type', :'status' => :'status', :'campaign_count' => :'campaignCount', :'clicks' => :'clicks', :'cost' => :'cost', :'cost_per_conversion' => :'costPerConversion', :'impressions' => :'impressions', :'average_cpc' => :'averageCpc', :'conversions' => :'conversions', :'target_cpa' => :'targetCpa', :'target_roas' => :'targetRoas' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 262 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
124 125 126 127 128 129 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 124 def self.openapi_nullable Set.new([ :'target_cpa', :'target_roas' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 105 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'type' => :'String', :'status' => :'String', :'campaign_count' => :'Integer', :'clicks' => :'Integer', :'cost' => :'Float', :'cost_per_conversion' => :'Float', :'impressions' => :'Integer', :'average_cpc' => :'Float', :'conversions' => :'Float', :'target_cpa' => :'Float', :'target_roas' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && type == o.type && status == o.status && campaign_count == o.campaign_count && clicks == o.clicks && cost == o.cost && cost_per_conversion == o.cost_per_conversion && impressions == o.impressions && average_cpc == o.average_cpc && conversions == o.conversions && target_cpa == o.target_cpa && target_roas == o.target_roas end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 255 def hash [id, name, type, status, campaign_count, clicks, cost, cost_per_conversion, impressions, average_cpc, conversions, target_cpa, target_roas].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 206 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 202 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
210 211 212 213 214 215 |
# File 'lib/zernio-sdk/models/portfolio_bid_strategy.rb', line 210 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["TARGET_CPA", "TARGET_ROAS", "MAXIMIZE_CONVERSIONS", "MAXIMIZE_CONVERSION_VALUE"]) return false unless type_validator.valid?(@type) true end |