Class: Zernio::SendInboxMessageRequestTemplateElementsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SendInboxMessageRequestTemplateElementsInner
- Defined in:
- lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb
Instance Attribute Summary collapse
-
#buttons ⇒ Object
Element buttons (Instagram/Facebook only).
-
#components ⇒ Object
WhatsApp only.
-
#image_url ⇒ Object
Element image URL (Instagram/Facebook only).
-
#language ⇒ Object
WhatsApp only.
-
#name ⇒ Object
WhatsApp only.
-
#subtitle ⇒ Object
Element subtitle (Instagram/Facebook only).
-
#title ⇒ Object
Element title (max 80 chars).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendInboxMessageRequestTemplateElementsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendInboxMessageRequestTemplateElementsInner
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendInboxMessageRequestTemplateElementsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendInboxMessageRequestTemplateElementsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'subtitle') self.subtitle = attributes[:'subtitle'] end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'buttons') if (value = attributes[:'buttons']).is_a?(Array) self. = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'language') self.language = attributes[:'language'] end if attributes.key?(:'components') if (value = attributes[:'components']).is_a?(Array) self.components = value end end end |
Instance Attribute Details
#buttons ⇒ Object
Element buttons (Instagram/Facebook only)
28 29 30 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 28 def @buttons end |
#components ⇒ Object
WhatsApp only. Meta Cloud API send-shape components array, forwarded to Meta verbatim.
37 38 39 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 37 def components @components end |
#image_url ⇒ Object
Element image URL (Instagram/Facebook only)
25 26 27 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 25 def image_url @image_url end |
#language ⇒ Object
WhatsApp only. Template language code (e.g. en_US).
34 35 36 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 34 def language @language end |
#name ⇒ Object
WhatsApp only. Name of the approved template to send.
31 32 33 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 31 def name @name end |
#subtitle ⇒ Object
Element subtitle (Instagram/Facebook only)
22 23 24 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 22 def subtitle @subtitle end |
#title ⇒ Object
Element title (max 80 chars). Required for Instagram/Facebook generic templates.
19 20 21 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 19 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 40 def self.attribute_map { :'title' => :'title', :'subtitle' => :'subtitle', :'image_url' => :'imageUrl', :'buttons' => :'buttons', :'name' => :'name', :'language' => :'language', :'components' => :'components' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 212 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 63 def self.openapi_types { :'title' => :'String', :'subtitle' => :'String', :'image_url' => :'String', :'buttons' => :'Array<SendInboxMessageRequestTemplateElementsInnerButtonsInner>', :'name' => :'String', :'language' => :'String', :'components' => :'Array<Hash<String, Object>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 185 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && subtitle == o.subtitle && image_url == o.image_url && == o. && name == o.name && language == o.language && components == o.components end |
#eql?(o) ⇒ Boolean
199 200 201 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 199 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 205 def hash [title, subtitle, image_url, , name, language, components].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@title.nil? && @title.to_s.length > 80 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 80.') end if !@buttons.nil? && @buttons.length > 3 invalid_properties.push('invalid value for "buttons", number of items must be less than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 152 153 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_template_elements_inner.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@title.nil? && @title.to_s.length > 80 return false if !@buttons.nil? && @buttons.length > 3 true end |