Class: Zernio::UpdateAdCampaignRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/update_ad_campaign_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateAdCampaignRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdCampaignRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdCampaignRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  else
    self.platform = nil
  end

  if attributes.key?(:'budget')
    self.budget = attributes[:'budget']
  end

  if attributes.key?(:'bid_strategy')
    self.bid_strategy = attributes[:'bid_strategy']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'platform_specific_data')
    self.platform_specific_data = attributes[:'platform_specific_data']
  end
end

Instance Attribute Details

#account_idObject

Zernio SocialAccount id owning the ad account. Required only to update an EMPTY campaign (zero ads), which has no local Ad documents to resolve a token from.



19
20
21
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 19

def 
  @account_id
end

#bid_strategyObject

Campaign-level default. Ad sets inherit this unless they override.



26
27
28
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 26

def bid_strategy
  @bid_strategy
end

#budgetObject

Returns the value of attribute budget.



23
24
25
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 23

def budget
  @budget
end

#nameObject

Rename the campaign (Meta only; other platforms return 501). At least one of budget/bidStrategy/name/platformSpecificData is required.



29
30
31
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 29

def name
  @name
end

#platformObject

Returns the value of attribute platform.



21
22
23
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 21

def platform
  @platform
end

#platform_specific_dataObject

Returns the value of attribute platform_specific_data.



31
32
33
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 31

def platform_specific_data
  @platform_specific_data
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 56

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'budget' => :'budget',
    :'bid_strategy' => :'bidStrategy',
    :'name' => :'name',
    :'platform_specific_data' => :'platformSpecificData'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 78

def self.openapi_types
  {
    :'account_id' => :'String',
    :'platform' => :'String',
    :'budget' => :'UpdateAdCampaignRequestBudget',
    :'bid_strategy' => :'BidStrategy',
    :'name' => :'String',
    :'platform_specific_data' => :'UpdateAdCampaignRequestPlatformSpecificData'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
200
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      platform == o.platform &&
      budget == o.budget &&
      bid_strategy == o.bid_strategy &&
      name == o.name &&
      platform_specific_data == o.platform_specific_data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 210

def hash
  [, platform, budget, bid_strategy, name, platform_specific_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @platform.nil?
    invalid_properties.push('invalid value for "platform", platform cannot be nil.')
  end

  if !@name.nil? && @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
161
162
163
# File 'lib/zernio-sdk/models/update_ad_campaign_request.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @platform.nil?
  platform_validator = EnumAttributeValidator.new('String', ["facebook", "instagram"])
  return false unless platform_validator.valid?(@platform)
  return false if !@name.nil? && @name.to_s.length > 255
  true
end