Class: Zernio::UpdateAdRequestTargeting
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateAdRequestTargeting
- Defined in:
- lib/zernio-sdk/models/update_ad_request_targeting.rb
Overview
Meta + TikTok (demographics/interests) and Google (keyword edits only). Pinterest / X / LinkedIn return 501.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#advantage_audience ⇒ Object
Meta only.
-
#age_max ⇒ Object
Returns the value of attribute age_max.
-
#age_min ⇒ Object
Returns the value of attribute age_min.
-
#countries ⇒ Object
Returns the value of attribute countries.
-
#interests ⇒ Object
Interest objects from /v1/ads/interests.
-
#keywords ⇒ Object
Google only.
-
#negative_keywords ⇒ Object
Google only.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAdRequestTargeting
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAdRequestTargeting
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdRequestTargeting` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdRequestTargeting`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end end if attributes.key?(:'negative_keywords') if (value = attributes[:'negative_keywords']).is_a?(Array) self.negative_keywords = value end end if attributes.key?(:'age_min') self.age_min = attributes[:'age_min'] end if attributes.key?(:'age_max') self.age_max = attributes[:'age_max'] end if attributes.key?(:'countries') if (value = attributes[:'countries']).is_a?(Array) self.countries = value end end if attributes.key?(:'interests') if (value = attributes[:'interests']).is_a?(Array) self.interests = value end end if attributes.key?(:'advantage_audience') self.advantage_audience = attributes[:'advantage_audience'] end end |
Instance Attribute Details
#advantage_audience ⇒ Object
Meta only. Omit to preserve the existing setting on update. 0 = disabled, 1 = enabled.
35 36 37 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 35 def advantage_audience @advantage_audience end |
#age_max ⇒ Object
Returns the value of attribute age_max.
27 28 29 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 27 def age_max @age_max end |
#age_min ⇒ Object
Returns the value of attribute age_min.
25 26 27 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 25 def age_min @age_min end |
#countries ⇒ Object
Returns the value of attribute countries.
29 30 31 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 29 def countries @countries end |
#interests ⇒ Object
Interest objects from /v1/ads/interests. Each must include id and name.
32 33 34 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 32 def interests @interests end |
#keywords ⇒ Object
Google only. The FULL new set of positive keywords for the ad group; live keywords not listed are removed. Entries are strings (BROAD) or { text, matchType } with matchType exact | phrase | broad. Mirrored to GET /v1/ads/keywords immediately.
20 21 22 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 20 def keywords @keywords end |
#negative_keywords ⇒ Object
Google only. Same declarative contract as keywords, for the ad group's negative keywords.
23 24 25 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 23 def negative_keywords @negative_keywords end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 60 def self.attribute_map { :'keywords' => :'keywords', :'negative_keywords' => :'negativeKeywords', :'age_min' => :'ageMin', :'age_max' => :'ageMax', :'countries' => :'countries', :'interests' => :'interests', :'advantage_audience' => :'advantage_audience' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 83 def self.openapi_types { :'keywords' => :'Array<UpdateAdRequestTargetingKeywordsInner>', :'negative_keywords' => :'Array<UpdateAdRequestTargetingKeywordsInner>', :'age_min' => :'Integer', :'age_max' => :'Integer', :'countries' => :'Array<String>', :'interests' => :'Array<UpdateAdRequestTargetingInterestsInner>', :'advantage_audience' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 239 def ==(o) return true if self.equal?(o) self.class == o.class && keywords == o.keywords && negative_keywords == o.negative_keywords && age_min == o.age_min && age_max == o.age_max && countries == o.countries && interests == o.interests && advantage_audience == o.advantage_audience end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 259 def hash [keywords, negative_keywords, age_min, age_max, countries, interests, advantage_audience].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@age_min.nil? && @age_min > 65 invalid_properties.push('invalid value for "age_min", must be smaller than or equal to 65.') end if !@age_min.nil? && @age_min < 13 invalid_properties.push('invalid value for "age_min", must be greater than or equal to 13.') end if !@age_max.nil? && @age_max > 65 invalid_properties.push('invalid value for "age_max", must be smaller than or equal to 65.') end if !@age_max.nil? && @age_max < 13 invalid_properties.push('invalid value for "age_max", must be greater than or equal to 13.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@age_min.nil? && @age_min > 65 return false if !@age_min.nil? && @age_min < 13 return false if !@age_max.nil? && @age_max > 65 return false if !@age_max.nil? && @age_max < 13 advantage_audience_validator = EnumAttributeValidator.new('Integer', [0, 1]) return false unless advantage_audience_validator.valid?(@advantage_audience) true end |