Class: Zernio::UpdateAdRequestTargeting

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/update_ad_request_targeting.rb

Overview

Meta + TikTok only. Pinterest / X / LinkedIn / Google return 501.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateAdRequestTargeting

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdRequestTargeting` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdRequestTargeting`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'age_min')
    self.age_min = attributes[:'age_min']
  end

  if attributes.key?(:'age_max')
    self.age_max = attributes[:'age_max']
  end

  if attributes.key?(:'countries')
    if (value = attributes[:'countries']).is_a?(Array)
      self.countries = value
    end
  end

  if attributes.key?(:'interests')
    if (value = attributes[:'interests']).is_a?(Array)
      self.interests = value
    end
  end

  if attributes.key?(:'advantage_audience')
    self.advantage_audience = attributes[:'advantage_audience']
  end
end

Instance Attribute Details

#advantage_audienceObject

Meta only. Omit to preserve the existing setting on update. 0 = disabled, 1 = enabled.



29
30
31
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 29

def advantage_audience
  @advantage_audience
end

#age_maxObject

Returns the value of attribute age_max.



21
22
23
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 21

def age_max
  @age_max
end

#age_minObject

Returns the value of attribute age_min.



19
20
21
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 19

def age_min
  @age_min
end

#countriesObject

Returns the value of attribute countries.



23
24
25
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 23

def countries
  @countries
end

#interestsObject

Interest objects from /v1/ads/interests. Each must include id and name.



26
27
28
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 26

def interests
  @interests
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 54

def self.attribute_map
  {
    :'age_min' => :'ageMin',
    :'age_max' => :'ageMax',
    :'countries' => :'countries',
    :'interests' => :'interests',
    :'advantage_audience' => :'advantage_audience'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 242

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 75

def self.openapi_types
  {
    :'age_min' => :'Integer',
    :'age_max' => :'Integer',
    :'countries' => :'Array<String>',
    :'interests' => :'Array<UpdateAdRequestTargetingInterestsInner>',
    :'advantage_audience' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      age_min == o.age_min &&
      age_max == o.age_max &&
      countries == o.countries &&
      interests == o.interests &&
      advantage_audience == o.advantage_audience
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 235

def hash
  [age_min, age_max, countries, interests, advantage_audience].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@age_min.nil? && @age_min > 65
    invalid_properties.push('invalid value for "age_min", must be smaller than or equal to 65.')
  end

  if !@age_min.nil? && @age_min < 13
    invalid_properties.push('invalid value for "age_min", must be greater than or equal to 13.')
  end

  if !@age_max.nil? && @age_max > 65
    invalid_properties.push('invalid value for "age_max", must be smaller than or equal to 65.')
  end

  if !@age_max.nil? && @age_max < 13
    invalid_properties.push('invalid value for "age_max", must be greater than or equal to 13.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
162
163
164
165
166
167
# File 'lib/zernio-sdk/models/update_ad_request_targeting.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@age_min.nil? && @age_min > 65
  return false if !@age_min.nil? && @age_min < 13
  return false if !@age_max.nil? && @age_max > 65
  return false if !@age_max.nil? && @age_max < 13
  advantage_audience_validator = EnumAttributeValidator.new('Integer', [0, 1])
  return false unless advantage_audience_validator.valid?(@advantage_audience)
  true
end