Class: Zernio::UsageMetering

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/usage_metering.rb

Overview

Billed spend by product family over a window, from Metronome's invoice breakdown (the CHARGE view). Returned by GET /v1/usage.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UsageMetering

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/zernio-sdk/models/usage_metering.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UsageMetering` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UsageMetering`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'supported')
    self.supported = attributes[:'supported']
  end

  if attributes.key?(:'granularity')
    self.granularity = attributes[:'granularity']
  end

  if attributes.key?(:'days')
    if (value = attributes[:'days']).is_a?(Array)
      self.days = value
    end
  end

  if attributes.key?(:'totals')
    self.totals = attributes[:'totals']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'peaks')
    self.peaks = attributes[:'peaks']
  end

  if attributes.key?(:'call_usage')
    self.call_usage = attributes[:'call_usage']
  end

  if attributes.key?(:'period')
    self.period = attributes[:'period']
  end

  if attributes.key?(:'tax')
    self.tax = attributes[:'tax']
  end
end

Instance Attribute Details

#call_usageObject

Returns the value of attribute call_usage.



34
35
36
# File 'lib/zernio-sdk/models/usage_metering.rb', line 34

def call_usage
  @call_usage
end

#daysObject

One row per bucket. Empty when granularity=total. date is a UTC date (month buckets use the 1st).



25
26
27
# File 'lib/zernio-sdk/models/usage_metering.rb', line 25

def days
  @days
end

#granularityObject

Returns the value of attribute granularity.



22
23
24
# File 'lib/zernio-sdk/models/usage_metering.rb', line 22

def granularity
  @granularity
end

#line_itemsObject

Per-invoice-line-item rows (largest spend first) for a detailed breakdown.



30
31
32
# File 'lib/zernio-sdk/models/usage_metering.rb', line 30

def line_items
  @line_items
end

#peaksObject

Returns the value of attribute peaks.



32
33
34
# File 'lib/zernio-sdk/models/usage_metering.rb', line 32

def peaks
  @peaks
end

#periodObject

Returns the value of attribute period.



36
37
38
# File 'lib/zernio-sdk/models/usage_metering.rb', line 36

def period
  @period
end

#supportedObject

False for legacy Stripe accounts (no Metronome invoice to split); days and totals are then empty/zero.



20
21
22
# File 'lib/zernio-sdk/models/usage_metering.rb', line 20

def supported
  @supported
end

#taxObject

Returns the value of attribute tax.



38
39
40
# File 'lib/zernio-sdk/models/usage_metering.rb', line 38

def tax
  @tax
end

#totalsObject

Returns the value of attribute totals.



27
28
29
# File 'lib/zernio-sdk/models/usage_metering.rb', line 27

def totals
  @totals
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/zernio-sdk/models/usage_metering.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/zernio-sdk/models/usage_metering.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/zernio-sdk/models/usage_metering.rb', line 63

def self.attribute_map
  {
    :'supported' => :'supported',
    :'granularity' => :'granularity',
    :'days' => :'days',
    :'totals' => :'totals',
    :'line_items' => :'lineItems',
    :'peaks' => :'peaks',
    :'call_usage' => :'callUsage',
    :'period' => :'period',
    :'tax' => :'tax'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/zernio-sdk/models/usage_metering.rb', line 223

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/zernio-sdk/models/usage_metering.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/zernio-sdk/models/usage_metering.rb', line 88

def self.openapi_types
  {
    :'supported' => :'Boolean',
    :'granularity' => :'String',
    :'days' => :'Array<UsageMeteringDaysInner>',
    :'totals' => :'UsageMeteringTotals',
    :'line_items' => :'Array<UsageMeteringLineItemsInner>',
    :'peaks' => :'UsageMeteringPeaks',
    :'call_usage' => :'UsageMeteringCallUsage',
    :'period' => :'UsageMeteringPeriod',
    :'tax' => :'UsageMeteringTax'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/zernio-sdk/models/usage_metering.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      supported == o.supported &&
      granularity == o.granularity &&
      days == o.days &&
      totals == o.totals &&
      line_items == o.line_items &&
      peaks == o.peaks &&
      call_usage == o.call_usage &&
      period == o.period &&
      tax == o.tax
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/zernio-sdk/models/usage_metering.rb', line 210

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



216
217
218
# File 'lib/zernio-sdk/models/usage_metering.rb', line 216

def hash
  [supported, granularity, days, totals, line_items, peaks, call_usage, period, tax].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
# File 'lib/zernio-sdk/models/usage_metering.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/zernio-sdk/models/usage_metering.rb', line 245

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



175
176
177
178
179
180
# File 'lib/zernio-sdk/models/usage_metering.rb', line 175

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  granularity_validator = EnumAttributeValidator.new('String', ["day", "month", "total"])
  return false unless granularity_validator.valid?(@granularity)
  true
end