Class: Zernio::WebhookPayloadMessageMessage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::WebhookPayloadMessageMessage
- Defined in:
- lib/zernio-sdk/models/webhook_payload_message_message.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attachments ⇒ Object
Returns the value of attribute attachments.
-
#conversation_id ⇒ Object
Internal conversation ID.
-
#direction ⇒ Object
Returns the value of attribute direction.
-
#id ⇒ Object
Internal message ID.
-
#is_read ⇒ Object
Returns the value of attribute is_read.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_message_id ⇒ Object
Platform's message ID.
-
#sender ⇒ Object
Returns the value of attribute sender.
-
#sent_at ⇒ Object
When the message was sent, as reported by the platform and passed through unmodified.
-
#text ⇒ Object
Message text content.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPayloadMessageMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPayloadMessageMessage
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadMessageMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadMessageMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'conversation_id') self.conversation_id = attributes[:'conversation_id'] else self.conversation_id = nil end if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'platform_message_id') self. = attributes[:'platform_message_id'] else self. = nil end if attributes.key?(:'direction') self.direction = attributes[:'direction'] else self.direction = nil end if attributes.key?(:'text') self.text = attributes[:'text'] else self.text = nil end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'sender') self.sender = attributes[:'sender'] else self.sender = nil end if attributes.key?(:'sent_at') self.sent_at = attributes[:'sent_at'] else self.sent_at = nil end if attributes.key?(:'is_read') self.is_read = attributes[:'is_read'] else self.is_read = nil end end |
Instance Attribute Details
#attachments ⇒ Object
Returns the value of attribute attachments.
34 35 36 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 34 def end |
#conversation_id ⇒ Object
Internal conversation ID
22 23 24 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 22 def conversation_id @conversation_id end |
#direction ⇒ Object
Returns the value of attribute direction.
29 30 31 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 29 def direction @direction end |
#id ⇒ Object
Internal message ID
19 20 21 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 19 def id @id end |
#is_read ⇒ Object
Returns the value of attribute is_read.
41 42 43 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 41 def is_read @is_read end |
#platform ⇒ Object
Returns the value of attribute platform.
24 25 26 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 24 def platform @platform end |
#platform_message_id ⇒ Object
Platform's message ID
27 28 29 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 27 def end |
#sender ⇒ Object
Returns the value of attribute sender.
36 37 38 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 36 def sender @sender end |
#sent_at ⇒ Object
When the message was sent, as reported by the platform and passed through unmodified. Full ISO 8601 date-time: Instagram and Facebook carry millisecond precision, while some platforms (for example WhatsApp and Telegram) report whole seconds. Use this field as the chronological ordering key. If two messages share the same value, fetch the conversation messages with sortOrder=desc for the deterministic order.
39 40 41 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 39 def sent_at @sent_at end |
#text ⇒ Object
Message text content
32 33 34 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 32 def text @text end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 66 def self.attribute_map { :'id' => :'id', :'conversation_id' => :'conversationId', :'platform' => :'platform', :'platform_message_id' => :'platformMessageId', :'direction' => :'direction', :'text' => :'text', :'attachments' => :'attachments', :'sender' => :'sender', :'sent_at' => :'sentAt', :'is_read' => :'isRead' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 379 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 112 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 108 def self.openapi_nullable Set.new([ :'text', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 92 def self.openapi_types { :'id' => :'String', :'conversation_id' => :'String', :'platform' => :'String', :'platform_message_id' => :'String', :'direction' => :'String', :'text' => :'String', :'attachments' => :'Array<WebhookPayloadMessageMessageAttachmentsInner>', :'sender' => :'WebhookPayloadMessageMessageSender', :'sent_at' => :'Time', :'is_read' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 349 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && conversation_id == o.conversation_id && platform == o.platform && == o. && direction == o.direction && text == o.text && == o. && sender == o.sender && sent_at == o.sent_at && is_read == o.is_read end |
#eql?(o) ⇒ Boolean
366 367 368 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 366 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
372 373 374 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 372 def hash [id, conversation_id, platform, , direction, text, , sender, sent_at, is_read].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @conversation_id.nil? invalid_properties.push('invalid value for "conversation_id", conversation_id cannot be nil.') end if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end if .nil? invalid_properties.push('invalid value for "platform_message_id", platform_message_id cannot be nil.') end if @direction.nil? invalid_properties.push('invalid value for "direction", direction cannot be nil.') end if .nil? invalid_properties.push('invalid value for "attachments", attachments cannot be nil.') end if @sender.nil? invalid_properties.push('invalid value for "sender", sender cannot be nil.') end if @sent_at.nil? invalid_properties.push('invalid value for "sent_at", sent_at cannot be nil.') end if @is_read.nil? invalid_properties.push('invalid value for "is_read", is_read cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 401 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/zernio-sdk/models/webhook_payload_message_message.rb', line 239 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @conversation_id.nil? return false if @platform.nil? platform_validator = EnumAttributeValidator.new('String', ["instagram", "facebook", "telegram", "whatsapp", "sms"]) return false unless platform_validator.valid?(@platform) return false if .nil? return false if @direction.nil? direction_validator = EnumAttributeValidator.new('String', ["incoming", "outgoing"]) return false unless direction_validator.valid?(@direction) return false if .nil? return false if @sender.nil? return false if @sent_at.nil? return false if @is_read.nil? true end |