Class: Zernio::XApiOperation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::XApiOperation
- Defined in:
- lib/zernio-sdk/models/x_api_operation.rb
Overview
A single X API operation with its per-call price and the Zernio platform methods that trigger it.
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Human-readable label shown on Metronome invoices.
-
#event_type ⇒ Object
Metronome
event_typeemitted when this operation runs. -
#operation ⇒ Object
Internal operation key.
-
#price_per_call_cents ⇒ Object
Per-call price in cents.
-
#price_per_call_usd ⇒ Object
Returns the value of attribute price_per_call_usd.
-
#tier ⇒ Object
Tier key derived from
pricePerCallUsd(e.g.x_api_005for $0.005,x_api_200for $0.200). -
#triggered_by ⇒ Object
Zernio platform methods that emit this operation, with their metering rule.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ XApiOperation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ XApiOperation
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::XApiOperation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::XApiOperation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'operation') self.operation = attributes[:'operation'] end if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'price_per_call_usd') self.price_per_call_usd = attributes[:'price_per_call_usd'] end if attributes.key?(:'price_per_call_cents') self.price_per_call_cents = attributes[:'price_per_call_cents'] end if attributes.key?(:'tier') self.tier = attributes[:'tier'] end if attributes.key?(:'triggered_by') if (value = attributes[:'triggered_by']).is_a?(Array) self.triggered_by = value end end end |
Instance Attribute Details
#display_name ⇒ Object
Human-readable label shown on Metronome invoices.
26 27 28 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 26 def display_name @display_name end |
#event_type ⇒ Object
Metronome event_type emitted when this operation runs.
23 24 25 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 23 def event_type @event_type end |
#operation ⇒ Object
Internal operation key. Matches keys in xApiCallsByOperation.
20 21 22 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 20 def operation @operation end |
#price_per_call_cents ⇒ Object
Per-call price in cents. Fractional values are intentional.
31 32 33 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 31 def price_per_call_cents @price_per_call_cents end |
#price_per_call_usd ⇒ Object
Returns the value of attribute price_per_call_usd.
28 29 30 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 28 def price_per_call_usd @price_per_call_usd end |
#tier ⇒ Object
Tier key derived from pricePerCallUsd (e.g. x_api_005 for $0.005, x_api_200 for $0.200). Useful for grouping operations by price in dashboards.
34 35 36 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 34 def tier @tier end |
#triggered_by ⇒ Object
Zernio platform methods that emit this operation, with their metering rule.
37 38 39 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 37 def triggered_by @triggered_by end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 40 def self.attribute_map { :'operation' => :'operation', :'event_type' => :'eventType', :'display_name' => :'displayName', :'price_per_call_usd' => :'pricePerCallUsd', :'price_per_call_cents' => :'pricePerCallCents', :'tier' => :'tier', :'triggered_by' => :'triggeredBy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 63 def self.openapi_types { :'operation' => :'String', :'event_type' => :'String', :'display_name' => :'String', :'price_per_call_usd' => :'Float', :'price_per_call_cents' => :'Float', :'tier' => :'String', :'triggered_by' => :'Array<XApiOperationTriggeredByInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && operation == o.operation && event_type == o.event_type && display_name == o.display_name && price_per_call_usd == o.price_per_call_usd && price_per_call_cents == o.price_per_call_cents && tier == o.tier && triggered_by == o.triggered_by end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 165 def hash [operation, event_type, display_name, price_per_call_usd, price_per_call_cents, tier, triggered_by].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 134 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 130 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 |
# File 'lib/zernio-sdk/models/x_api_operation.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |